/*
 * Cuttermaran - The Mpeg Cutter
 * 
 * Copyright (C) 2004  Tobias Arnold (cuttermaran@gmx.net)
 * 
 * This file is part of cuttermaran, a free MPEG cut program.
 * See http://cuttermaran.kickme.to for updates.
 *
 * This program is free software; you can redistribute it and/or modify it 
 * under the terms of the GNU General Public License as published by the 
 * Free Software Foundation; either version 2 of the License, or 
 * (at your option) any later version. 
 * 
 * This program is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the 
 * GNU General Public License for more details. 
 * 
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */

using System;
using System.IO;
using System.Collections;
using System.Diagnostics;

using Coremoran.AVStreams;
using GUI.data;
using Coremoran.Common;

namespace GUI
{
	/// <summary>
	/// Parses and executes the commandline
	/// </summary>
	public class CLI
	{
		/// <summary>
		/// Executes a cpf file given via commandline
		/// or loads the specified video and audio files given via commandline
		/// or loads the specified video file and searches for corresponding audio files
		/// </summary>
		public static void ExecuteCommandLine(StateController i_State)
		{
			string    s_VideoFile  = null;
			ArrayList i_AudioFiles = new ArrayList();

			String[] args = System.Environment.GetCommandLineArgs();
			if (args.Length <= 1) // args[0] is always the path to Cuttermaran.EXE
				return;

			if (args.Length == 2) // one cpf file or only a video file specified
			{
				if (Path.GetExtension(args[1]).ToLower() == ".cpf")
				{
					i_State.LoadProject(new FileStream(args[1], FileMode.Open));
					if (i_State.CmdCut || i_State.CmdCutAudio)
					{
						if (i_State.CmdCutAudio)
							i_State.CutAudioOnly(i_State.CmdOutFile);
						else
							i_State.ProcessCut(i_State.Cuts, i_State.CmdOutFile, i_State.CmdCloseApp, i_State.CmdUnattended);
					}
					return;
				}

				// only a video file without audio files specified
				// --> try to find corresponding audio files
				if (Helper.GetMediaType(args[1]) == MediaType.Video)
				{
					s_VideoFile  = args[1];
					i_AudioFiles = GUIHelper.AudioMatchList(Path.GetDirectoryName(s_VideoFile),Path.GetFileNameWithoutExtension(s_VideoFile));
				}
			}
			else // a video and one or more audio files specified
			{
				for (int i=1; i<args.Length; ++i)
				{
					switch (Helper.GetMediaType(args[i]))
					{
						case MediaType.Video:
							s_VideoFile = args[i];
							break;
						case MediaType.Audio:
							i_AudioFiles.Add(args[i]);
							break;
						default:
							throw new Exception("Invalid file type found in commandline");
					}
				}
			}

			// Loading audio only is not allowed !
			if (s_VideoFile == null)
				throw new Exception("No video file found in commandline!");

			i_State.LoadAudioAndVideo(s_VideoFile, i_AudioFiles);
		}
	}
}
