/*
 * Cuttermaran - The Mpeg Cutter
 * 
 * Copyright (C) 2003-2005 Tobias Arnold (cuttermaran@gmx.net)
 * 
 * This file is part of cuttermaran, a free MPEG cut program.
 * See http://www.cuttermaran.de for updates.
 *
 * This program is free software; you can redistribute it and/or modify it 
 * under the terms of the GNU General Public License as published by the 
 * Free Software Foundation; either version 2 of the License, or 
 * (at your option) any later version. 
 * 
 * This program is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the 
 * GNU General Public License for more details. 
 * 
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */

using System;
using System.IO;
using System.Data;
using System.Drawing;
using System.Management;
using System.Reflection;
using System.Collections;
using System.Diagnostics;
using System.ComponentModel;
using System.Windows.Forms;
using System.Runtime.InteropServices;

using GUI.data;
using Coremoran.AVStreams;
using Configuration;
using StringResources;
using Coremoran.Algorithms;

namespace GUI
{
	/// <summary>
	/// Summary description for CutDialog.
	/// </summary>
	public class CutDialog : GUIBaseForm
	{
		private System.Windows.Forms.Button butStart;
		private System.Windows.Forms.Button butCancel;
		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;
		private System.Windows.Forms.Button butSelectOutput;
		private System.Windows.Forms.Label lblOutput;
		private System.Windows.Forms.ErrorProvider errorProviderFileExists;
		private System.Windows.Forms.TextBox tbOutputFile;
		private System.Windows.Forms.Label label1;
		private System.Windows.Forms.ComboBox comboOutputPath;
		private System.Windows.Forms.FolderBrowserDialog folderBrowserOutput;

		private StateController State=null;
		private MRUPathManager recentOutputPaths;
		private System.Windows.Forms.TabControl tabControl1;
		private System.Windows.Forms.TabPage tabPage1;
		private System.Windows.Forms.Label label2;
		private System.Windows.Forms.Label lblFreeSpace;
		private System.Windows.Forms.Button butSelectOutputFile;
		private System.Windows.Forms.SaveFileDialog saveVideoDialog;
		private System.Windows.Forms.TabPage tabMuxing;
		private System.Windows.Forms.TabPage tabEncoding;
		private System.Windows.Forms.TabPage tabChapter;
		private System.Windows.Forms.Panel panelCutParameter;
		private bool validateCancel=false;

		// Dialoge
		CutParamControl cutParamControl=new CutParamControl();
		EncodingControl encodingControl=new EncodingControl();
		MuxingControl muxingControl=new MuxingControl();
		private System.Windows.Forms.Button butStart2;
		ChapterControl chapterControl=new ChapterControl();

		private string defaultExtension;

		public CutDialog(StateController state)
		{
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();

			State=state;
			recentOutputPaths=new MRUPathManager();
			defaultExtension=state.Cuts[0].VideoStream.StreamExtension;

			// Dialoge hinzufgen
			panelCutParameter.Controls.Add(cutParamControl);
			tabEncoding.Controls.Add(encodingControl);
			tabMuxing.Controls.Add(muxingControl);
			tabChapter.Controls.Add(chapterControl);
		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		private static string LocalPath
		{
			get
			{
				return Path.GetDirectoryName(Assembly.GetEntryAssembly().Location);
			}
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(CutDialog));
			System.Configuration.AppSettingsReader configurationAppSettings = new System.Configuration.AppSettingsReader();
			this.butStart = new System.Windows.Forms.Button();
			this.butCancel = new System.Windows.Forms.Button();
			this.lblOutput = new System.Windows.Forms.Label();
			this.butSelectOutput = new System.Windows.Forms.Button();
			this.errorProviderFileExists = new System.Windows.Forms.ErrorProvider();
			this.tbOutputFile = new System.Windows.Forms.TextBox();
			this.comboOutputPath = new System.Windows.Forms.ComboBox();
			this.label1 = new System.Windows.Forms.Label();
			this.tabControl1 = new System.Windows.Forms.TabControl();
			this.tabPage1 = new System.Windows.Forms.TabPage();
			this.panelCutParameter = new System.Windows.Forms.Panel();
			this.butSelectOutputFile = new System.Windows.Forms.Button();
			this.lblFreeSpace = new System.Windows.Forms.Label();
			this.label2 = new System.Windows.Forms.Label();
			this.tabMuxing = new System.Windows.Forms.TabPage();
			this.tabEncoding = new System.Windows.Forms.TabPage();
			this.tabChapter = new System.Windows.Forms.TabPage();
			this.butStart2 = new System.Windows.Forms.Button();
			this.folderBrowserOutput = new System.Windows.Forms.FolderBrowserDialog();
			this.saveVideoDialog = new System.Windows.Forms.SaveFileDialog();
			this.tabControl1.SuspendLayout();
			this.tabPage1.SuspendLayout();
			this.SuspendLayout();
			// 
			// butStart
			// 
			this.butStart.AccessibleDescription = resources.GetString("butStart.AccessibleDescription");
			this.butStart.AccessibleName = resources.GetString("butStart.AccessibleName");
			this.butStart.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butStart.Anchor")));
			this.butStart.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butStart.BackgroundImage")));
			this.butStart.DialogResult = System.Windows.Forms.DialogResult.OK;
			this.butStart.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butStart.Dock")));
			this.butStart.Enabled = ((bool)(resources.GetObject("butStart.Enabled")));
			this.errorProviderFileExists.SetError(this.butStart, resources.GetString("butStart.Error"));
			this.butStart.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butStart.FlatStyle")));
			this.butStart.Font = ((System.Drawing.Font)(resources.GetObject("butStart.Font")));
			this.errorProviderFileExists.SetIconAlignment(this.butStart, ((System.Windows.Forms.ErrorIconAlignment)(resources.GetObject("butStart.IconAlignment"))));
			this.errorProviderFileExists.SetIconPadding(this.butStart, ((int)(resources.GetObject("butStart.IconPadding"))));
			this.butStart.Image = ((System.Drawing.Image)(resources.GetObject("butStart.Image")));
			this.butStart.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butStart.ImageAlign")));
			this.butStart.ImageIndex = ((int)(resources.GetObject("butStart.ImageIndex")));
			this.butStart.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butStart.ImeMode")));
			this.butStart.Location = ((System.Drawing.Point)(resources.GetObject("butStart.Location")));
			this.butStart.Name = "butStart";
			this.butStart.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butStart.RightToLeft")));
			this.butStart.Size = ((System.Drawing.Size)(resources.GetObject("butStart.Size")));
			this.butStart.TabIndex = ((int)(resources.GetObject("butStart.TabIndex")));
			this.butStart.Text = resources.GetString("butStart.Text");
			this.butStart.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butStart.TextAlign")));
			this.butStart.Visible = ((bool)(resources.GetObject("butStart.Visible")));
			// 
			// butCancel
			// 
			this.butCancel.AccessibleDescription = resources.GetString("butCancel.AccessibleDescription");
			this.butCancel.AccessibleName = resources.GetString("butCancel.AccessibleName");
			this.butCancel.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butCancel.Anchor")));
			this.butCancel.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butCancel.BackgroundImage")));
			this.butCancel.CausesValidation = false;
			this.butCancel.DialogResult = System.Windows.Forms.DialogResult.Cancel;
			this.butCancel.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butCancel.Dock")));
			this.butCancel.Enabled = ((bool)(resources.GetObject("butCancel.Enabled")));
			this.errorProviderFileExists.SetError(this.butCancel, resources.GetString("butCancel.Error"));
			this.butCancel.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butCancel.FlatStyle")));
			this.butCancel.Font = ((System.Drawing.Font)(resources.GetObject("butCancel.Font")));
			this.errorProviderFileExists.SetIconAlignment(this.butCancel, ((System.Windows.Forms.ErrorIconAlignment)(resources.GetObject("butCancel.IconAlignment"))));
			this.errorProviderFileExists.SetIconPadding(this.butCancel, ((int)(resources.GetObject("butCancel.IconPadding"))));
			this.butCancel.Image = ((System.Drawing.Image)(resources.GetObject("butCancel.Image")));
			this.butCancel.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butCancel.ImageAlign")));
			this.butCancel.ImageIndex = ((int)(resources.GetObject("butCancel.ImageIndex")));
			this.butCancel.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butCancel.ImeMode")));
			this.butCancel.Location = ((System.Drawing.Point)(resources.GetObject("butCancel.Location")));
			this.butCancel.Name = "butCancel";
			this.butCancel.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butCancel.RightToLeft")));
			this.butCancel.Size = ((System.Drawing.Size)(resources.GetObject("butCancel.Size")));
			this.butCancel.TabIndex = ((int)(resources.GetObject("butCancel.TabIndex")));
			this.butCancel.Text = resources.GetString("butCancel.Text");
			this.butCancel.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butCancel.TextAlign")));
			this.butCancel.Visible = ((bool)(resources.GetObject("butCancel.Visible")));
			// 
			// lblOutput
			// 
			this.lblOutput.AccessibleDescription = resources.GetString("lblOutput.AccessibleDescription");
			this.lblOutput.AccessibleName = resources.GetString("lblOutput.AccessibleName");
			this.lblOutput.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("lblOutput.Anchor")));
			this.lblOutput.AutoSize = ((bool)(resources.GetObject("lblOutput.AutoSize")));
			this.lblOutput.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("lblOutput.Dock")));
			this.lblOutput.Enabled = ((bool)(resources.GetObject("lblOutput.Enabled")));
			this.errorProviderFileExists.SetError(this.lblOutput, resources.GetString("lblOutput.Error"));
			this.lblOutput.Font = ((System.Drawing.Font)(resources.GetObject("lblOutput.Font")));
			this.errorProviderFileExists.SetIconAlignment(this.lblOutput, ((System.Windows.Forms.ErrorIconAlignment)(resources.GetObject("lblOutput.IconAlignment"))));
			this.errorProviderFileExists.SetIconPadding(this.lblOutput, ((int)(resources.GetObject("lblOutput.IconPadding"))));
			this.lblOutput.Image = ((System.Drawing.Image)(resources.GetObject("lblOutput.Image")));
			this.lblOutput.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("lblOutput.ImageAlign")));
			this.lblOutput.ImageIndex = ((int)(resources.GetObject("lblOutput.ImageIndex")));
			this.lblOutput.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("lblOutput.ImeMode")));
			this.lblOutput.Location = ((System.Drawing.Point)(resources.GetObject("lblOutput.Location")));
			this.lblOutput.Name = "lblOutput";
			this.lblOutput.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("lblOutput.RightToLeft")));
			this.lblOutput.Size = ((System.Drawing.Size)(resources.GetObject("lblOutput.Size")));
			this.lblOutput.TabIndex = ((int)(resources.GetObject("lblOutput.TabIndex")));
			this.lblOutput.Text = resources.GetString("lblOutput.Text");
			this.lblOutput.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("lblOutput.TextAlign")));
			this.lblOutput.Visible = ((bool)(resources.GetObject("lblOutput.Visible")));
			// 
			// butSelectOutput
			// 
			this.butSelectOutput.AccessibleDescription = resources.GetString("butSelectOutput.AccessibleDescription");
			this.butSelectOutput.AccessibleName = resources.GetString("butSelectOutput.AccessibleName");
			this.butSelectOutput.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butSelectOutput.Anchor")));
			this.butSelectOutput.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butSelectOutput.BackgroundImage")));
			this.butSelectOutput.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butSelectOutput.Dock")));
			this.butSelectOutput.Enabled = ((bool)(resources.GetObject("butSelectOutput.Enabled")));
			this.errorProviderFileExists.SetError(this.butSelectOutput, resources.GetString("butSelectOutput.Error"));
			this.butSelectOutput.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butSelectOutput.FlatStyle")));
			this.butSelectOutput.Font = ((System.Drawing.Font)(resources.GetObject("butSelectOutput.Font")));
			this.errorProviderFileExists.SetIconAlignment(this.butSelectOutput, ((System.Windows.Forms.ErrorIconAlignment)(resources.GetObject("butSelectOutput.IconAlignment"))));
			this.errorProviderFileExists.SetIconPadding(this.butSelectOutput, ((int)(resources.GetObject("butSelectOutput.IconPadding"))));
			this.butSelectOutput.Image = ((System.Drawing.Image)(resources.GetObject("butSelectOutput.Image")));
			this.butSelectOutput.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butSelectOutput.ImageAlign")));
			this.butSelectOutput.ImageIndex = ((int)(resources.GetObject("butSelectOutput.ImageIndex")));
			this.butSelectOutput.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butSelectOutput.ImeMode")));
			this.butSelectOutput.Location = ((System.Drawing.Point)(resources.GetObject("butSelectOutput.Location")));
			this.butSelectOutput.Name = "butSelectOutput";
			this.butSelectOutput.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butSelectOutput.RightToLeft")));
			this.butSelectOutput.Size = ((System.Drawing.Size)(resources.GetObject("butSelectOutput.Size")));
			this.butSelectOutput.TabIndex = ((int)(resources.GetObject("butSelectOutput.TabIndex")));
			this.butSelectOutput.Text = resources.GetString("butSelectOutput.Text");
			this.butSelectOutput.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butSelectOutput.TextAlign")));
			this.butSelectOutput.Visible = ((bool)(resources.GetObject("butSelectOutput.Visible")));
			this.butSelectOutput.Click += new System.EventHandler(this.butSelectOutput_Click);
			this.butSelectOutput.Validating += new System.ComponentModel.CancelEventHandler(this.tbOutputFile_Validating);
			// 
			// errorProviderFileExists
			// 
			this.errorProviderFileExists.ContainerControl = this;
			this.errorProviderFileExists.Icon = ((System.Drawing.Icon)(resources.GetObject("errorProviderFileExists.Icon")));
			// 
			// tbOutputFile
			// 
			this.tbOutputFile.AccessibleDescription = resources.GetString("tbOutputFile.AccessibleDescription");
			this.tbOutputFile.AccessibleName = resources.GetString("tbOutputFile.AccessibleName");
			this.tbOutputFile.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("tbOutputFile.Anchor")));
			this.tbOutputFile.AutoSize = ((bool)(resources.GetObject("tbOutputFile.AutoSize")));
			this.tbOutputFile.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("tbOutputFile.BackgroundImage")));
			this.tbOutputFile.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("tbOutputFile.Dock")));
			this.tbOutputFile.Enabled = ((bool)(resources.GetObject("tbOutputFile.Enabled")));
			this.errorProviderFileExists.SetError(this.tbOutputFile, resources.GetString("tbOutputFile.Error"));
			this.tbOutputFile.Font = ((System.Drawing.Font)(resources.GetObject("tbOutputFile.Font")));
			this.errorProviderFileExists.SetIconAlignment(this.tbOutputFile, ((System.Windows.Forms.ErrorIconAlignment)(resources.GetObject("tbOutputFile.IconAlignment"))));
			this.errorProviderFileExists.SetIconPadding(this.tbOutputFile, ((int)(resources.GetObject("tbOutputFile.IconPadding"))));
			this.tbOutputFile.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("tbOutputFile.ImeMode")));
			this.tbOutputFile.Location = ((System.Drawing.Point)(resources.GetObject("tbOutputFile.Location")));
			this.tbOutputFile.MaxLength = ((int)(resources.GetObject("tbOutputFile.MaxLength")));
			this.tbOutputFile.Multiline = ((bool)(resources.GetObject("tbOutputFile.Multiline")));
			this.tbOutputFile.Name = "tbOutputFile";
			this.tbOutputFile.PasswordChar = ((char)(resources.GetObject("tbOutputFile.PasswordChar")));
			this.tbOutputFile.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("tbOutputFile.RightToLeft")));
			this.tbOutputFile.ScrollBars = ((System.Windows.Forms.ScrollBars)(resources.GetObject("tbOutputFile.ScrollBars")));
			this.tbOutputFile.Size = ((System.Drawing.Size)(resources.GetObject("tbOutputFile.Size")));
			this.tbOutputFile.TabIndex = ((int)(resources.GetObject("tbOutputFile.TabIndex")));
			this.tbOutputFile.Text = resources.GetString("tbOutputFile.Text");
			this.tbOutputFile.TextAlign = ((System.Windows.Forms.HorizontalAlignment)(resources.GetObject("tbOutputFile.TextAlign")));
			this.tbOutputFile.Visible = ((bool)(resources.GetObject("tbOutputFile.Visible")));
			this.tbOutputFile.WordWrap = ((bool)(resources.GetObject("tbOutputFile.WordWrap")));
			this.tbOutputFile.Validating += new System.ComponentModel.CancelEventHandler(this.tbOutputFile_Validating);
			// 
			// comboOutputPath
			// 
			this.comboOutputPath.AccessibleDescription = resources.GetString("comboOutputPath.AccessibleDescription");
			this.comboOutputPath.AccessibleName = resources.GetString("comboOutputPath.AccessibleName");
			this.comboOutputPath.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("comboOutputPath.Anchor")));
			this.comboOutputPath.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("comboOutputPath.BackgroundImage")));
			this.comboOutputPath.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("comboOutputPath.Dock")));
			this.comboOutputPath.Enabled = ((bool)(resources.GetObject("comboOutputPath.Enabled")));
			this.errorProviderFileExists.SetError(this.comboOutputPath, resources.GetString("comboOutputPath.Error"));
			this.comboOutputPath.Font = ((System.Drawing.Font)(resources.GetObject("comboOutputPath.Font")));
			this.errorProviderFileExists.SetIconAlignment(this.comboOutputPath, ((System.Windows.Forms.ErrorIconAlignment)(resources.GetObject("comboOutputPath.IconAlignment"))));
			this.errorProviderFileExists.SetIconPadding(this.comboOutputPath, ((int)(resources.GetObject("comboOutputPath.IconPadding"))));
			this.comboOutputPath.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("comboOutputPath.ImeMode")));
			this.comboOutputPath.IntegralHeight = ((bool)(resources.GetObject("comboOutputPath.IntegralHeight")));
			this.comboOutputPath.ItemHeight = ((int)(resources.GetObject("comboOutputPath.ItemHeight")));
			this.comboOutputPath.Location = ((System.Drawing.Point)(resources.GetObject("comboOutputPath.Location")));
			this.comboOutputPath.MaxDropDownItems = ((int)(resources.GetObject("comboOutputPath.MaxDropDownItems")));
			this.comboOutputPath.MaxLength = ((int)(resources.GetObject("comboOutputPath.MaxLength")));
			this.comboOutputPath.Name = "comboOutputPath";
			this.comboOutputPath.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("comboOutputPath.RightToLeft")));
			this.comboOutputPath.Size = ((System.Drawing.Size)(resources.GetObject("comboOutputPath.Size")));
			this.comboOutputPath.TabIndex = ((int)(resources.GetObject("comboOutputPath.TabIndex")));
			this.comboOutputPath.Text = resources.GetString("comboOutputPath.Text");
			this.comboOutputPath.Visible = ((bool)(resources.GetObject("comboOutputPath.Visible")));
			this.comboOutputPath.Validating += new System.ComponentModel.CancelEventHandler(this.comboOutputPath_Validating);
			this.comboOutputPath.SelectedIndexChanged += new System.EventHandler(this.comboOutputPath_SelectedIndexChanged);
			// 
			// label1
			// 
			this.label1.AccessibleDescription = resources.GetString("label1.AccessibleDescription");
			this.label1.AccessibleName = resources.GetString("label1.AccessibleName");
			this.label1.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("label1.Anchor")));
			this.label1.AutoSize = ((bool)(resources.GetObject("label1.AutoSize")));
			this.label1.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("label1.Dock")));
			this.label1.Enabled = ((bool)(resources.GetObject("label1.Enabled")));
			this.errorProviderFileExists.SetError(this.label1, resources.GetString("label1.Error"));
			this.label1.Font = ((System.Drawing.Font)(resources.GetObject("label1.Font")));
			this.errorProviderFileExists.SetIconAlignment(this.label1, ((System.Windows.Forms.ErrorIconAlignment)(resources.GetObject("label1.IconAlignment"))));
			this.errorProviderFileExists.SetIconPadding(this.label1, ((int)(resources.GetObject("label1.IconPadding"))));
			this.label1.Image = ((System.Drawing.Image)(resources.GetObject("label1.Image")));
			this.label1.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label1.ImageAlign")));
			this.label1.ImageIndex = ((int)(resources.GetObject("label1.ImageIndex")));
			this.label1.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("label1.ImeMode")));
			this.label1.Location = ((System.Drawing.Point)(resources.GetObject("label1.Location")));
			this.label1.Name = "label1";
			this.label1.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("label1.RightToLeft")));
			this.label1.Size = ((System.Drawing.Size)(resources.GetObject("label1.Size")));
			this.label1.TabIndex = ((int)(resources.GetObject("label1.TabIndex")));
			this.label1.Text = resources.GetString("label1.Text");
			this.label1.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label1.TextAlign")));
			this.label1.Visible = ((bool)(resources.GetObject("label1.Visible")));
			// 
			// tabControl1
			// 
			this.tabControl1.AccessibleDescription = resources.GetString("tabControl1.AccessibleDescription");
			this.tabControl1.AccessibleName = resources.GetString("tabControl1.AccessibleName");
			this.tabControl1.Alignment = ((System.Windows.Forms.TabAlignment)(resources.GetObject("tabControl1.Alignment")));
			this.tabControl1.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("tabControl1.Anchor")));
			this.tabControl1.Appearance = ((System.Windows.Forms.TabAppearance)(resources.GetObject("tabControl1.Appearance")));
			this.tabControl1.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("tabControl1.BackgroundImage")));
			this.tabControl1.Controls.Add(this.tabPage1);
			this.tabControl1.Controls.Add(this.tabMuxing);
			this.tabControl1.Controls.Add(this.tabEncoding);
			this.tabControl1.Controls.Add(this.tabChapter);
			this.tabControl1.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("tabControl1.Dock")));
			this.tabControl1.Enabled = ((bool)(resources.GetObject("tabControl1.Enabled")));
			this.errorProviderFileExists.SetError(this.tabControl1, resources.GetString("tabControl1.Error"));
			this.tabControl1.Font = ((System.Drawing.Font)(resources.GetObject("tabControl1.Font")));
			this.errorProviderFileExists.SetIconAlignment(this.tabControl1, ((System.Windows.Forms.ErrorIconAlignment)(resources.GetObject("tabControl1.IconAlignment"))));
			this.errorProviderFileExists.SetIconPadding(this.tabControl1, ((int)(resources.GetObject("tabControl1.IconPadding"))));
			this.tabControl1.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("tabControl1.ImeMode")));
			this.tabControl1.ItemSize = ((System.Drawing.Size)(resources.GetObject("tabControl1.ItemSize")));
			this.tabControl1.Location = ((System.Drawing.Point)(resources.GetObject("tabControl1.Location")));
			this.tabControl1.Name = "tabControl1";
			this.tabControl1.Padding = ((System.Drawing.Point)(resources.GetObject("tabControl1.Padding")));
			this.tabControl1.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("tabControl1.RightToLeft")));
			this.tabControl1.SelectedIndex = 0;
			this.tabControl1.ShowToolTips = ((bool)(resources.GetObject("tabControl1.ShowToolTips")));
			this.tabControl1.Size = ((System.Drawing.Size)(resources.GetObject("tabControl1.Size")));
			this.tabControl1.TabIndex = ((int)(resources.GetObject("tabControl1.TabIndex")));
			this.tabControl1.Text = resources.GetString("tabControl1.Text");
			this.tabControl1.Visible = ((bool)(resources.GetObject("tabControl1.Visible")));
			// 
			// tabPage1
			// 
			this.tabPage1.AccessibleDescription = resources.GetString("tabPage1.AccessibleDescription");
			this.tabPage1.AccessibleName = resources.GetString("tabPage1.AccessibleName");
			this.tabPage1.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("tabPage1.Anchor")));
			this.tabPage1.AutoScroll = ((bool)(resources.GetObject("tabPage1.AutoScroll")));
			this.tabPage1.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("tabPage1.AutoScrollMargin")));
			this.tabPage1.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("tabPage1.AutoScrollMinSize")));
			this.tabPage1.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("tabPage1.BackgroundImage")));
			this.tabPage1.Controls.Add(this.panelCutParameter);
			this.tabPage1.Controls.Add(this.butSelectOutputFile);
			this.tabPage1.Controls.Add(this.lblFreeSpace);
			this.tabPage1.Controls.Add(this.label2);
			this.tabPage1.Controls.Add(this.lblOutput);
			this.tabPage1.Controls.Add(this.comboOutputPath);
			this.tabPage1.Controls.Add(this.label1);
			this.tabPage1.Controls.Add(this.butSelectOutput);
			this.tabPage1.Controls.Add(this.tbOutputFile);
			this.tabPage1.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("tabPage1.Dock")));
			this.tabPage1.Enabled = ((bool)(resources.GetObject("tabPage1.Enabled")));
			this.errorProviderFileExists.SetError(this.tabPage1, resources.GetString("tabPage1.Error"));
			this.tabPage1.Font = ((System.Drawing.Font)(resources.GetObject("tabPage1.Font")));
			this.errorProviderFileExists.SetIconAlignment(this.tabPage1, ((System.Windows.Forms.ErrorIconAlignment)(resources.GetObject("tabPage1.IconAlignment"))));
			this.errorProviderFileExists.SetIconPadding(this.tabPage1, ((int)(resources.GetObject("tabPage1.IconPadding"))));
			this.tabPage1.ImageIndex = ((int)(resources.GetObject("tabPage1.ImageIndex")));
			this.tabPage1.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("tabPage1.ImeMode")));
			this.tabPage1.Location = ((System.Drawing.Point)(resources.GetObject("tabPage1.Location")));
			this.tabPage1.Name = "tabPage1";
			this.tabPage1.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("tabPage1.RightToLeft")));
			this.tabPage1.Size = ((System.Drawing.Size)(resources.GetObject("tabPage1.Size")));
			this.tabPage1.TabIndex = ((int)(resources.GetObject("tabPage1.TabIndex")));
			this.tabPage1.Text = resources.GetString("tabPage1.Text");
			this.tabPage1.ToolTipText = resources.GetString("tabPage1.ToolTipText");
			this.tabPage1.Visible = ((bool)(resources.GetObject("tabPage1.Visible")));
			// 
			// panelCutParameter
			// 
			this.panelCutParameter.AccessibleDescription = resources.GetString("panelCutParameter.AccessibleDescription");
			this.panelCutParameter.AccessibleName = resources.GetString("panelCutParameter.AccessibleName");
			this.panelCutParameter.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("panelCutParameter.Anchor")));
			this.panelCutParameter.AutoScroll = ((bool)(resources.GetObject("panelCutParameter.AutoScroll")));
			this.panelCutParameter.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("panelCutParameter.AutoScrollMargin")));
			this.panelCutParameter.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("panelCutParameter.AutoScrollMinSize")));
			this.panelCutParameter.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("panelCutParameter.BackgroundImage")));
			this.panelCutParameter.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("panelCutParameter.Dock")));
			this.panelCutParameter.Enabled = ((bool)(resources.GetObject("panelCutParameter.Enabled")));
			this.errorProviderFileExists.SetError(this.panelCutParameter, resources.GetString("panelCutParameter.Error"));
			this.panelCutParameter.Font = ((System.Drawing.Font)(resources.GetObject("panelCutParameter.Font")));
			this.errorProviderFileExists.SetIconAlignment(this.panelCutParameter, ((System.Windows.Forms.ErrorIconAlignment)(resources.GetObject("panelCutParameter.IconAlignment"))));
			this.errorProviderFileExists.SetIconPadding(this.panelCutParameter, ((int)(resources.GetObject("panelCutParameter.IconPadding"))));
			this.panelCutParameter.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("panelCutParameter.ImeMode")));
			this.panelCutParameter.Location = ((System.Drawing.Point)(resources.GetObject("panelCutParameter.Location")));
			this.panelCutParameter.Name = "panelCutParameter";
			this.panelCutParameter.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("panelCutParameter.RightToLeft")));
			this.panelCutParameter.Size = ((System.Drawing.Size)(resources.GetObject("panelCutParameter.Size")));
			this.panelCutParameter.TabIndex = ((int)(resources.GetObject("panelCutParameter.TabIndex")));
			this.panelCutParameter.Text = resources.GetString("panelCutParameter.Text");
			this.panelCutParameter.Visible = ((bool)(resources.GetObject("panelCutParameter.Visible")));
			// 
			// butSelectOutputFile
			// 
			this.butSelectOutputFile.AccessibleDescription = resources.GetString("butSelectOutputFile.AccessibleDescription");
			this.butSelectOutputFile.AccessibleName = resources.GetString("butSelectOutputFile.AccessibleName");
			this.butSelectOutputFile.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butSelectOutputFile.Anchor")));
			this.butSelectOutputFile.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butSelectOutputFile.BackgroundImage")));
			this.butSelectOutputFile.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butSelectOutputFile.Dock")));
			this.butSelectOutputFile.Enabled = ((bool)(resources.GetObject("butSelectOutputFile.Enabled")));
			this.errorProviderFileExists.SetError(this.butSelectOutputFile, resources.GetString("butSelectOutputFile.Error"));
			this.butSelectOutputFile.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butSelectOutputFile.FlatStyle")));
			this.butSelectOutputFile.Font = ((System.Drawing.Font)(resources.GetObject("butSelectOutputFile.Font")));
			this.errorProviderFileExists.SetIconAlignment(this.butSelectOutputFile, ((System.Windows.Forms.ErrorIconAlignment)(resources.GetObject("butSelectOutputFile.IconAlignment"))));
			this.errorProviderFileExists.SetIconPadding(this.butSelectOutputFile, ((int)(resources.GetObject("butSelectOutputFile.IconPadding"))));
			this.butSelectOutputFile.Image = ((System.Drawing.Image)(resources.GetObject("butSelectOutputFile.Image")));
			this.butSelectOutputFile.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butSelectOutputFile.ImageAlign")));
			this.butSelectOutputFile.ImageIndex = ((int)(resources.GetObject("butSelectOutputFile.ImageIndex")));
			this.butSelectOutputFile.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butSelectOutputFile.ImeMode")));
			this.butSelectOutputFile.Location = ((System.Drawing.Point)(resources.GetObject("butSelectOutputFile.Location")));
			this.butSelectOutputFile.Name = "butSelectOutputFile";
			this.butSelectOutputFile.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butSelectOutputFile.RightToLeft")));
			this.butSelectOutputFile.Size = ((System.Drawing.Size)(resources.GetObject("butSelectOutputFile.Size")));
			this.butSelectOutputFile.TabIndex = ((int)(resources.GetObject("butSelectOutputFile.TabIndex")));
			this.butSelectOutputFile.Text = resources.GetString("butSelectOutputFile.Text");
			this.butSelectOutputFile.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butSelectOutputFile.TextAlign")));
			this.butSelectOutputFile.Visible = ((bool)(resources.GetObject("butSelectOutputFile.Visible")));
			this.butSelectOutputFile.Click += new System.EventHandler(this.butSelectOutputFile_Click);
			// 
			// lblFreeSpace
			// 
			this.lblFreeSpace.AccessibleDescription = resources.GetString("lblFreeSpace.AccessibleDescription");
			this.lblFreeSpace.AccessibleName = resources.GetString("lblFreeSpace.AccessibleName");
			this.lblFreeSpace.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("lblFreeSpace.Anchor")));
			this.lblFreeSpace.AutoSize = ((bool)(resources.GetObject("lblFreeSpace.AutoSize")));
			this.lblFreeSpace.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("lblFreeSpace.Dock")));
			this.lblFreeSpace.Enabled = ((bool)(resources.GetObject("lblFreeSpace.Enabled")));
			this.errorProviderFileExists.SetError(this.lblFreeSpace, resources.GetString("lblFreeSpace.Error"));
			this.lblFreeSpace.Font = ((System.Drawing.Font)(resources.GetObject("lblFreeSpace.Font")));
			this.errorProviderFileExists.SetIconAlignment(this.lblFreeSpace, ((System.Windows.Forms.ErrorIconAlignment)(resources.GetObject("lblFreeSpace.IconAlignment"))));
			this.errorProviderFileExists.SetIconPadding(this.lblFreeSpace, ((int)(resources.GetObject("lblFreeSpace.IconPadding"))));
			this.lblFreeSpace.Image = ((System.Drawing.Image)(resources.GetObject("lblFreeSpace.Image")));
			this.lblFreeSpace.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("lblFreeSpace.ImageAlign")));
			this.lblFreeSpace.ImageIndex = ((int)(resources.GetObject("lblFreeSpace.ImageIndex")));
			this.lblFreeSpace.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("lblFreeSpace.ImeMode")));
			this.lblFreeSpace.Location = ((System.Drawing.Point)(resources.GetObject("lblFreeSpace.Location")));
			this.lblFreeSpace.Name = "lblFreeSpace";
			this.lblFreeSpace.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("lblFreeSpace.RightToLeft")));
			this.lblFreeSpace.Size = ((System.Drawing.Size)(resources.GetObject("lblFreeSpace.Size")));
			this.lblFreeSpace.TabIndex = ((int)(resources.GetObject("lblFreeSpace.TabIndex")));
			this.lblFreeSpace.Text = resources.GetString("lblFreeSpace.Text");
			this.lblFreeSpace.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("lblFreeSpace.TextAlign")));
			this.lblFreeSpace.Visible = ((bool)(resources.GetObject("lblFreeSpace.Visible")));
			// 
			// label2
			// 
			this.label2.AccessibleDescription = resources.GetString("label2.AccessibleDescription");
			this.label2.AccessibleName = resources.GetString("label2.AccessibleName");
			this.label2.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("label2.Anchor")));
			this.label2.AutoSize = ((bool)(resources.GetObject("label2.AutoSize")));
			this.label2.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("label2.Dock")));
			this.label2.Enabled = ((bool)(resources.GetObject("label2.Enabled")));
			this.errorProviderFileExists.SetError(this.label2, resources.GetString("label2.Error"));
			this.label2.Font = ((System.Drawing.Font)(resources.GetObject("label2.Font")));
			this.errorProviderFileExists.SetIconAlignment(this.label2, ((System.Windows.Forms.ErrorIconAlignment)(resources.GetObject("label2.IconAlignment"))));
			this.errorProviderFileExists.SetIconPadding(this.label2, ((int)(resources.GetObject("label2.IconPadding"))));
			this.label2.Image = ((System.Drawing.Image)(resources.GetObject("label2.Image")));
			this.label2.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label2.ImageAlign")));
			this.label2.ImageIndex = ((int)(resources.GetObject("label2.ImageIndex")));
			this.label2.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("label2.ImeMode")));
			this.label2.Location = ((System.Drawing.Point)(resources.GetObject("label2.Location")));
			this.label2.Name = "label2";
			this.label2.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("label2.RightToLeft")));
			this.label2.Size = ((System.Drawing.Size)(resources.GetObject("label2.Size")));
			this.label2.TabIndex = ((int)(resources.GetObject("label2.TabIndex")));
			this.label2.Text = resources.GetString("label2.Text");
			this.label2.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label2.TextAlign")));
			this.label2.Visible = ((bool)(resources.GetObject("label2.Visible")));
			// 
			// tabMuxing
			// 
			this.tabMuxing.AccessibleDescription = resources.GetString("tabMuxing.AccessibleDescription");
			this.tabMuxing.AccessibleName = resources.GetString("tabMuxing.AccessibleName");
			this.tabMuxing.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("tabMuxing.Anchor")));
			this.tabMuxing.AutoScroll = ((bool)(resources.GetObject("tabMuxing.AutoScroll")));
			this.tabMuxing.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("tabMuxing.AutoScrollMargin")));
			this.tabMuxing.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("tabMuxing.AutoScrollMinSize")));
			this.tabMuxing.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("tabMuxing.BackgroundImage")));
			this.tabMuxing.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("tabMuxing.Dock")));
			this.tabMuxing.Enabled = ((bool)(resources.GetObject("tabMuxing.Enabled")));
			this.errorProviderFileExists.SetError(this.tabMuxing, resources.GetString("tabMuxing.Error"));
			this.tabMuxing.Font = ((System.Drawing.Font)(resources.GetObject("tabMuxing.Font")));
			this.errorProviderFileExists.SetIconAlignment(this.tabMuxing, ((System.Windows.Forms.ErrorIconAlignment)(resources.GetObject("tabMuxing.IconAlignment"))));
			this.errorProviderFileExists.SetIconPadding(this.tabMuxing, ((int)(resources.GetObject("tabMuxing.IconPadding"))));
			this.tabMuxing.ImageIndex = ((int)(resources.GetObject("tabMuxing.ImageIndex")));
			this.tabMuxing.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("tabMuxing.ImeMode")));
			this.tabMuxing.Location = ((System.Drawing.Point)(resources.GetObject("tabMuxing.Location")));
			this.tabMuxing.Name = "tabMuxing";
			this.tabMuxing.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("tabMuxing.RightToLeft")));
			this.tabMuxing.Size = ((System.Drawing.Size)(resources.GetObject("tabMuxing.Size")));
			this.tabMuxing.TabIndex = ((int)(resources.GetObject("tabMuxing.TabIndex")));
			this.tabMuxing.Text = resources.GetString("tabMuxing.Text");
			this.tabMuxing.ToolTipText = resources.GetString("tabMuxing.ToolTipText");
			this.tabMuxing.Visible = ((bool)(resources.GetObject("tabMuxing.Visible")));
			// 
			// tabEncoding
			// 
			this.tabEncoding.AccessibleDescription = resources.GetString("tabEncoding.AccessibleDescription");
			this.tabEncoding.AccessibleName = resources.GetString("tabEncoding.AccessibleName");
			this.tabEncoding.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("tabEncoding.Anchor")));
			this.tabEncoding.AutoScroll = ((bool)(resources.GetObject("tabEncoding.AutoScroll")));
			this.tabEncoding.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("tabEncoding.AutoScrollMargin")));
			this.tabEncoding.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("tabEncoding.AutoScrollMinSize")));
			this.tabEncoding.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("tabEncoding.BackgroundImage")));
			this.tabEncoding.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("tabEncoding.Dock")));
			this.tabEncoding.Enabled = ((bool)(resources.GetObject("tabEncoding.Enabled")));
			this.errorProviderFileExists.SetError(this.tabEncoding, resources.GetString("tabEncoding.Error"));
			this.tabEncoding.Font = ((System.Drawing.Font)(resources.GetObject("tabEncoding.Font")));
			this.errorProviderFileExists.SetIconAlignment(this.tabEncoding, ((System.Windows.Forms.ErrorIconAlignment)(resources.GetObject("tabEncoding.IconAlignment"))));
			this.errorProviderFileExists.SetIconPadding(this.tabEncoding, ((int)(resources.GetObject("tabEncoding.IconPadding"))));
			this.tabEncoding.ImageIndex = ((int)(resources.GetObject("tabEncoding.ImageIndex")));
			this.tabEncoding.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("tabEncoding.ImeMode")));
			this.tabEncoding.Location = ((System.Drawing.Point)(resources.GetObject("tabEncoding.Location")));
			this.tabEncoding.Name = "tabEncoding";
			this.tabEncoding.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("tabEncoding.RightToLeft")));
			this.tabEncoding.Size = ((System.Drawing.Size)(resources.GetObject("tabEncoding.Size")));
			this.tabEncoding.TabIndex = ((int)(resources.GetObject("tabEncoding.TabIndex")));
			this.tabEncoding.Text = resources.GetString("tabEncoding.Text");
			this.tabEncoding.ToolTipText = resources.GetString("tabEncoding.ToolTipText");
			this.tabEncoding.Visible = ((bool)(resources.GetObject("tabEncoding.Visible")));
			// 
			// tabChapter
			// 
			this.tabChapter.AccessibleDescription = resources.GetString("tabChapter.AccessibleDescription");
			this.tabChapter.AccessibleName = resources.GetString("tabChapter.AccessibleName");
			this.tabChapter.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("tabChapter.Anchor")));
			this.tabChapter.AutoScroll = ((bool)(resources.GetObject("tabChapter.AutoScroll")));
			this.tabChapter.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("tabChapter.AutoScrollMargin")));
			this.tabChapter.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("tabChapter.AutoScrollMinSize")));
			this.tabChapter.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("tabChapter.BackgroundImage")));
			this.tabChapter.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("tabChapter.Dock")));
			this.tabChapter.Enabled = ((bool)(resources.GetObject("tabChapter.Enabled")));
			this.errorProviderFileExists.SetError(this.tabChapter, resources.GetString("tabChapter.Error"));
			this.tabChapter.Font = ((System.Drawing.Font)(resources.GetObject("tabChapter.Font")));
			this.errorProviderFileExists.SetIconAlignment(this.tabChapter, ((System.Windows.Forms.ErrorIconAlignment)(resources.GetObject("tabChapter.IconAlignment"))));
			this.errorProviderFileExists.SetIconPadding(this.tabChapter, ((int)(resources.GetObject("tabChapter.IconPadding"))));
			this.tabChapter.ImageIndex = ((int)(resources.GetObject("tabChapter.ImageIndex")));
			this.tabChapter.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("tabChapter.ImeMode")));
			this.tabChapter.Location = ((System.Drawing.Point)(resources.GetObject("tabChapter.Location")));
			this.tabChapter.Name = "tabChapter";
			this.tabChapter.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("tabChapter.RightToLeft")));
			this.tabChapter.Size = ((System.Drawing.Size)(resources.GetObject("tabChapter.Size")));
			this.tabChapter.TabIndex = ((int)(resources.GetObject("tabChapter.TabIndex")));
			this.tabChapter.Text = resources.GetString("tabChapter.Text");
			this.tabChapter.ToolTipText = resources.GetString("tabChapter.ToolTipText");
			this.tabChapter.Visible = ((bool)(resources.GetObject("tabChapter.Visible")));
			// 
			// butStart2
			// 
			this.butStart2.AccessibleDescription = resources.GetString("butStart2.AccessibleDescription");
			this.butStart2.AccessibleName = resources.GetString("butStart2.AccessibleName");
			this.butStart2.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butStart2.Anchor")));
			this.butStart2.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butStart2.BackgroundImage")));
			this.butStart2.DialogResult = System.Windows.Forms.DialogResult.Yes;
			this.butStart2.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butStart2.Dock")));
			this.butStart2.Enabled = ((bool)(resources.GetObject("butStart2.Enabled")));
			this.errorProviderFileExists.SetError(this.butStart2, resources.GetString("butStart2.Error"));
			this.butStart2.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butStart2.FlatStyle")));
			this.butStart2.Font = ((System.Drawing.Font)(resources.GetObject("butStart2.Font")));
			this.errorProviderFileExists.SetIconAlignment(this.butStart2, ((System.Windows.Forms.ErrorIconAlignment)(resources.GetObject("butStart2.IconAlignment"))));
			this.errorProviderFileExists.SetIconPadding(this.butStart2, ((int)(resources.GetObject("butStart2.IconPadding"))));
			this.butStart2.Image = ((System.Drawing.Image)(resources.GetObject("butStart2.Image")));
			this.butStart2.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butStart2.ImageAlign")));
			this.butStart2.ImageIndex = ((int)(resources.GetObject("butStart2.ImageIndex")));
			this.butStart2.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butStart2.ImeMode")));
			this.butStart2.Location = ((System.Drawing.Point)(resources.GetObject("butStart2.Location")));
			this.butStart2.Name = "butStart2";
			this.butStart2.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butStart2.RightToLeft")));
			this.butStart2.Size = ((System.Drawing.Size)(resources.GetObject("butStart2.Size")));
			this.butStart2.TabIndex = ((int)(resources.GetObject("butStart2.TabIndex")));
			this.butStart2.Text = resources.GetString("butStart2.Text");
			this.butStart2.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butStart2.TextAlign")));
			this.butStart2.Visible = ((bool)(resources.GetObject("butStart2.Visible")));
			// 
			// folderBrowserOutput
			// 
			this.folderBrowserOutput.Description = resources.GetString("folderBrowserOutput.Description");
			this.folderBrowserOutput.SelectedPath = resources.GetString("folderBrowserOutput.SelectedPath");
			// 
			// saveVideoDialog
			// 
			this.saveVideoDialog.DefaultExt = "mpv";
			this.saveVideoDialog.Filter = ((string)(configurationAppSettings.GetValue("VideoDialog.Filter", typeof(string))));
			this.saveVideoDialog.Title = resources.GetString("saveVideoDialog.Title");
			// 
			// CutDialog
			// 
			this.AcceptButton = this.butStart;
			this.AccessibleDescription = resources.GetString("$this.AccessibleDescription");
			this.AccessibleName = resources.GetString("$this.AccessibleName");
			this.AutoScaleBaseSize = ((System.Drawing.Size)(resources.GetObject("$this.AutoScaleBaseSize")));
			this.AutoScroll = ((bool)(resources.GetObject("$this.AutoScroll")));
			this.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("$this.AutoScrollMargin")));
			this.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("$this.AutoScrollMinSize")));
			this.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("$this.BackgroundImage")));
			this.CancelButton = this.butCancel;
			this.ClientSize = ((System.Drawing.Size)(resources.GetObject("$this.ClientSize")));
			this.Controls.Add(this.butStart2);
			this.Controls.Add(this.tabControl1);
			this.Controls.Add(this.butCancel);
			this.Controls.Add(this.butStart);
			this.Enabled = ((bool)(resources.GetObject("$this.Enabled")));
			this.Font = ((System.Drawing.Font)(resources.GetObject("$this.Font")));
			this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedDialog;
			this.Icon = ((System.Drawing.Icon)(resources.GetObject("$this.Icon")));
			this.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("$this.ImeMode")));
			this.Location = ((System.Drawing.Point)(resources.GetObject("$this.Location")));
			this.MaximizeBox = false;
			this.MaximumSize = ((System.Drawing.Size)(resources.GetObject("$this.MaximumSize")));
			this.MinimizeBox = false;
			this.MinimumSize = ((System.Drawing.Size)(resources.GetObject("$this.MinimumSize")));
			this.Name = "CutDialog";
			this.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("$this.RightToLeft")));
			this.ShowInTaskbar = false;
			this.StartPosition = ((System.Windows.Forms.FormStartPosition)(resources.GetObject("$this.StartPosition")));
			this.Text = resources.GetString("$this.Text");
			this.Closing += new System.ComponentModel.CancelEventHandler(this.CutDialog_Closing);
			this.Load += new System.EventHandler(this.CutDialog_Load);
			this.tabControl1.ResumeLayout(false);
			this.tabPage1.ResumeLayout(false);
			this.ResumeLayout(false);

		}
		#endregion

		private void CutDialog_Load(object sender, System.EventArgs e)
		{
			#region common
			if (State.StateFileName==string.Empty)
				tbOutputFile.Text=Path.GetFileNameWithoutExtension(State.Cuts[0].VideoName);
			else
				tbOutputFile.Text=Path.GetFileNameWithoutExtension(State.StateFileName);
			tbOutputFile.Text+="_cut"+State.Cuts[0].VideoStream.StreamExtension;
			recentOutputPaths.Entries=Settings.CurrentSettings.MRUOutputPathsEntries;
			if (recentOutputPaths.Entries.Count==0)
				recentOutputPaths.AddItem(Settings.CurrentSettings.TempDir);
			recentOutputPaths.FillRecentList(comboOutputPath);
			tbOutputFile_Validating(tbOutputFile,null);
			#endregion

			cutParamControl.LoadData();
			encodingControl.LoadData();
			muxingControl.LoadData();
			chapterControl.LoadData();

			cutParamControl.NewAspectRatioEnabled=((Mpeg12Video)State.Cuts[0].VideoStream).Sequence0.sequence_extension_exist; // Nur fr MPEG2

			RetrieveFreeDriveSpace(Path.GetPathRoot(CutFileName));
		}

		private void butSelectOutput_Click(object sender, System.EventArgs e)
		{
			folderBrowserOutput.SelectedPath=comboOutputPath.Text;
			if (folderBrowserOutput.ShowDialog()==DialogResult.OK)
			{
				recentOutputPaths.AddItem(folderBrowserOutput.SelectedPath);
				recentOutputPaths.FillRecentList(comboOutputPath);
			}
		}

		private void butSelectOutputFile_Click(object sender, System.EventArgs e)
		{
			saveVideoDialog.FileName=CutFileName;
			if (saveVideoDialog.ShowDialog()==DialogResult.OK)
			{
				recentOutputPaths.AddItem(Path.GetDirectoryName(saveVideoDialog.FileName));
				recentOutputPaths.FillRecentList(comboOutputPath);
				tbOutputFile.Text=Path.GetFileName(saveVideoDialog.FileName);
			}
		}

		public string CutFileName
		{
			get
			{
				string path=Path.Combine(comboOutputPath.Text,tbOutputFile.Text);
				if (!Path.HasExtension(path))
					path+=defaultExtension;
				return path;
			}
		}

		private void CutDialog_Closing(object sender, System.ComponentModel.CancelEventArgs e)
		{
			if (DialogResult==DialogResult.OK || DialogResult==DialogResult.Yes)
			{
				try
				{
					// Seite prfen
					validateCancel=true;
					muxingControl.ValidateCancel=true;
					if (!this.Validate())
					{
						e.Cancel=true;
						return;
					}

					if (File.Exists(CutFileName))
					{
						if (MessageBox.Show(Resource.CurrentResource.FormatMessage(Resource.FILE_EXIST_OVERWRITE,CutFileName),Resource.CurrentResource[Resource.ATTENTION],MessageBoxButtons.YesNo)==DialogResult.No)
						{
							e.Cancel=true;
							return;
						}
					}

					// Werte zurckschreiben
					Settings.CurrentSettings.MRUOutputPathsEntries=recentOutputPaths.Entries;

					cutParamControl.UnLoadData();
					encodingControl.UnLoadData();
					muxingControl.UnLoadData();
					chapterControl.UnLoadData();
				}
				finally
				{
					validateCancel=false;
					muxingControl.ValidateCancel=false;
				}
			}
		}

		private void tbOutputFile_Validating(object sender, System.ComponentModel.CancelEventArgs e)
		{
			// 1. prfen ob Dateiname gltig
			if (tbOutputFile.Text.Trim()==string.Empty || tbOutputFile.Text.IndexOfAny(new char [] {'\\','/',':','*','?','"','<','>','|'})>-1)
			{
				MessageBox.Show(Resource.CurrentResource[Resource.FILENAME_NOT_VALID],this.Text,MessageBoxButtons.OK,MessageBoxIcon.Error);
				if (validateCancel)
					e.Cancel=true;
				return;
			}

			// 2. prfen, ob Pfad+Dateiname existieren
			string path=CutFileName;
			if (File.Exists(path))
				errorProviderFileExists.SetError(tbOutputFile,Resource.CurrentResource.FormatMessage(Resource.FILE_EXIST,path));
			else
				errorProviderFileExists.SetError(tbOutputFile,string.Empty);

			// 3. Prfen, ob das nicht der Name der aktuellen Datei ist!
			path=State.VideoStream.StreamName.ToLower();
			bool isOk=path!=CutFileName.ToLower();
			foreach (CutPoint cp in State.Cuts)
				isOk&=cp.VideoName.ToLower()!=CutFileName.ToLower();
			if (!isOk)
			{
				MessageBox.Show(Resource.CurrentResource.FormatMessage(Resource.FILE_IS_IN_USE,path),this.Text,MessageBoxButtons.OK,MessageBoxIcon.Error);
				if (validateCancel)
					e.Cancel=true;
			}
		}

		private void comboOutputPath_SelectedIndexChanged(object sender, System.EventArgs e)
		{
			recentOutputPaths.AddItem(comboOutputPath.Text);
			RetrieveFreeDriveSpace(Path.GetPathRoot(comboOutputPath.Text));
		}

		private void comboOutputPath_Validating(object sender, System.ComponentModel.CancelEventArgs e)
		{
			if (comboOutputPath.Text.Trim()!=string.Empty)
			{
				if (Directory.Exists(comboOutputPath.Text))
				{
					recentOutputPaths.AddItem(comboOutputPath.Text);
					recentOutputPaths.FillRecentList(comboOutputPath);
				}
				else
				{
					MessageBox.Show(Resource.CurrentResource.FormatMessage(Resource.PATH_NOT_EXIST,comboOutputPath.Text),this.Text,MessageBoxButtons.OK,MessageBoxIcon.Error);
					if (validateCancel)
						e.Cancel=true;
				}
			}
		}

		[DllImport("kernel32.dll")]
		public static extern bool GetDiskFreeSpaceEx(
			string lpDirectoryName,
			out UInt64 lpFreeBytesAvailable,
			out UInt64 lpTotalNumberOfBytes,
			out UInt64 lpTotalNumberOfFreeBytes);

		private void RetrieveFreeDriveSpace(string drive)
		{
			try
			{
				if (drive==null || drive==string.Empty)
				{
					lblFreeSpace.Text=Resource.CurrentResource[Resource.UNKNOWN_DRIVE];
					return;
				}
				drive=drive.ToUpper();
				if (!drive.EndsWith("\\"))
					drive+="\\";

				ulong freeBytesAvailable = 0;
				ulong totalNumberOfBytes = 0;
				ulong totalNumberOfFreeBytes = 0;

				GetDiskFreeSpaceEx(
					drive,
					out freeBytesAvailable,
					out totalNumberOfBytes,
					out totalNumberOfFreeBytes);

				lblFreeSpace.Text=string.Format("{0} {1:N2} GB",drive,totalNumberOfFreeBytes/(1024*1024*1024m));
			}
			catch
			{
				lblFreeSpace.Text=string.Format("{0} {1}",drive,Resource.CurrentResource[Resource.UNKNOWN_DRIVE]);
			}
		}
	}
}
