/*
 * Cuttermaran - The Mpeg Cutter
 * 
 * Copyright (C) 2003-2006  Tobias Arnold (cuttermaran@gmx.net)
 * 
 * This file is part of cuttermaran, a free MPEG cut program.
 * See http://www.cuttermaran.de for updates.
 *
 * This program is free software; you can redistribute it and/or modify it 
 * under the terms of the GNU General Public License as published by the 
 * Free Software Foundation; either version 2 of the License, or 
 * (at your option) any later version. 
 * 
 * This program is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the 
 * GNU General Public License for more details. 
 * 
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */

using System;
using System.IO;
using System.Drawing;
using System.Collections;
using System.Collections.Specialized;
using System.Configuration;
using System.Diagnostics;
using GUI.Actions;
using Coremoran.AVStreams;
using StringResources;
using Configuration;
using Coremoran.Common;
using Coremoran.Algorithms;
using GUI.MainForm;

namespace GUI
{

	/// <summary>
	/// Summary description for CutList.
	/// </summary>
	public class CutList : BaseCutList
	{
		public CutList()
		{
		}

		/// <summary>
		/// The caller of this function must have set the progressbar maximum
		/// </summary>
		public override void Cut(string destFileName,bool audioOnly,out StringCollection VideoNames,out StringCollection AudioNames,out StringCollection chapterNames,IProcessInformation pi)
		{
			VideoNames=new StringCollection();
			AudioNames=new StringCollection();
			chapterNames=new StringCollection();

			Mpeg12StreamWriter VideoFile=null;
			AudioStreamWriter [] AudioFile=new AudioStreamWriter[this[0].AudioStreams.Count];

			try
			{
				int totalCuts = 0;

				int audioIndex;
				for (audioIndex=0;audioIndex<this[0].AudioStreams.Count;++audioIndex)
				{
					totalCuts ++;
					int dupIndex=1;
					string audioBaseName=Path.ChangeExtension(destFileName,null);
					string audioName=string.Format("{0}{1}",audioBaseName,((BasicAudioStream)this[0].AudioStreams[audioIndex]).StreamExtension);
					while (AudioNames.Contains(audioName))
						audioName=string.Format("{0}[{1}]{2}",audioBaseName,++dupIndex,((BasicAudioStream)this[0].AudioStreams[audioIndex]).StreamExtension);
					AudioNames.Add(audioName);
					AudioFile[audioIndex]=(AudioStreamWriter)((BasicAudioStream)this[0].AudioStreams[audioIndex]).CreateWriter(AudioNames[audioIndex]);
					AudioFile[audioIndex].PI=pi;
				}

				if (!audioOnly)
				{
					totalCuts ++;
					VideoNames.Add(destFileName);
					Mpeg12Video basV=(Mpeg12Video)this[0].VideoStream;
					VideoFile=(Mpeg12StreamWriter)basV.CreateWriter(destFileName);

					// Writer parametrisieren
					VideoFile.ComplianceMaxBitrate=decimal.Parse(ConfigurationSettings.AppSettings["ComplianceMaxBitrate"]);
					if (basV.Sequence0.VideoFormat!=2) // NTSC
						VideoFile.ComplianceMaxFrames=int.Parse(ConfigurationSettings.AppSettings["ComplianceMaxFramesPAL"]);
					else
						VideoFile.ComplianceMaxFrames=int.Parse(ConfigurationSettings.AppSettings["ComplianceMaxFramesNTSC"]);
					VideoFile.ModifySDE=Settings.CurrentSettings.SDEaction!=1;
					VideoFile.RecalcBitrate=Settings.CurrentSettings.RecalcBitrate;
					if (basV.Sequence0.sequence_extension_exist) // Nur fr MPEG-2!
						VideoFile.CreateDVDCompliantStream=Settings.CurrentSettings.CreateDVDCompliantStream && Settings.CurrentSettings.EncodeMode;
					else
						VideoFile.CreateDVDCompliantStream=false;
					if (Settings.CurrentSettings.SDEaction==2) // SDE delete
						VideoFile.SDE=null;
					else
						VideoFile.SDE=basV.Sequence0.sde_data;
					VideoFile.FirstSequence=(FirstSequenceAction)Settings.CurrentSettings.FirstSequence;
					VideoFile.SequenceEnd=(SequenceEndAction)Settings.CurrentSettings.SequenceEndCode;
					VideoFile.PI=pi;
					VideoFile.VideoEncoder=new Mpeg12Encoder();
					VideoFile.NewAspectRatio=Settings.CurrentSettings.NewAspectRation;
				}

				ActionObject i_Act = (ActionObject) pi;

				for (int i=0;i<this.Count;++i)
				{
					if (!audioOnly)
					{
						if (this[i].VideoStream==null)
						{
							this[i].VideoStream=new Mpeg12Video();
							this[i].VideoStream.CreateIndex(this[i].VideoName,pi);

							if (!i_Act.KeepRunning) // check after CreateIndex()
								break;
						}

 						i_Act.CurrentFile = this[i].VideoStream.StreamName;
						i_Act.ProgressDescription=Resource.CurrentResource.FormatMessage(Resource.CUTTING_VIDEO_MSG,i+1);

						this[i].VideoStream.Cut(VideoFile,this[i].StartFrame,this[i].EndFrame);

						if (!i_Act.KeepRunning) // check after Cut()
							break;

						// The caller of the Cut() function must have set the progressbar maximum
						i_Act.TotalProgressIncrement();
					}

					for (audioIndex=0;audioIndex<this[i].AudioStreams.Count;++audioIndex)
					{
						BasicAudioStream bas=(BasicAudioStream)this[i].AudioStreams[audioIndex];

						i_Act.CurrentFile = bas.StreamName;
						i_Act.ProgressDescription=Resource.CurrentResource.FormatMessage(Resource.CUTTING_AUDIO_MSG,i+1,audioIndex+1);

						// Der berechnete StartAudioFrame darf nicht spter sein als die
						// Lnge des Audiostreams!
						// Im Augenblick Test auf "echt kleiner" da einige Decoder wohl
						// Probleme haben, Streams mit nur einem Frame abzuspielen!!!
						if (this[i].AudioInfo(audioIndex).StartFrame<this[i].AudioInfo(audioIndex).EndFrame)
						{
							if (this[i].AudioInfo(audioIndex).LeftPaddingFrames>0)
								bas.WritePaddingPakets(AudioFile[audioIndex],this[i].AudioInfo(audioIndex).StartFrame,this[i].AudioInfo(audioIndex).LeftPaddingFrames,BasicAudioStream.PaddingDirection.Left);

							bas.Cut(AudioFile[audioIndex],
								this[i].AudioInfo(audioIndex).StartFrame,this[i].AudioInfo(audioIndex).EndFrame);

							if (!i_Act.KeepRunning) // after Cut()
								break;

							if (this[i].AudioInfo(audioIndex).RightPaddingFrames>0)
								bas.WritePaddingPakets(AudioFile[audioIndex],this[i].AudioInfo(audioIndex).EndFrame,this[i].AudioInfo(audioIndex).RightPaddingFrames,BasicAudioStream.PaddingDirection.Right);
						}

						// The caller of this function must have set the progressbar maximum
						i_Act.TotalProgressIncrement();
					} // end for
					if (!i_Act.KeepRunning)
						break;
				} // end for

				// Video schlieen, damit Zeitstempel der Indexdatei akzeptiert wird!
				if (!audioOnly && VideoFile!=null && i_Act.KeepRunning)
				{
					// If CreateDVDCompliantStream = true -> VideoFile.Close() will call the Encoder
					// So we must set the correct filename here to be displayed in ThreadControl!
					i_Act.CurrentFile = destFileName;
					VideoFile.Close();

					// falls vorhanden und gewnscht: Indexdatei schreiben
					if (VideoFile.ResultIndex!=null && Settings.CurrentSettings.CreateInfoFile)
						VideoFile.ResultIndex.Serialize(destFileName+".info");

					// falls Index vorhanden .d2v File schreiben, wenn gewnscht
					if (VideoFile.ResultIndex!=null && Settings.CurrentSettings.CreateD2VFile)
					{
						using (d2vBaseWriter dgw=d2vBaseWriter.CreateWriter(Path.ChangeExtension(destFileName,".d2v"),Settings.CurrentSettings.D2VFileType))
						{
							dgw.WriteContent(VideoFile.ResultIndex,destFileName);
						}
					}

					// Kapitellisten schreiben
					int chapters=0;
					foreach (CutPoint cp in this)
						chapters+=cp.ChapterItems.Length;

					if (chapters!=0 || Settings.CurrentSettings.AutoCreateChapters)
					{
						if (Settings.CurrentSettings.AutoCreateChapters)
							this.AutoCreateChapters(Settings.CurrentSettings.AutoChaptersValue);
					
						if (Settings.CurrentSettings.IfoEditChapters)
						{
							chapterNames.Add(Path.ChangeExtension(destFileName,".celltimes.txt"));
							using (IfoEditCelltimesWriter ifoFile=new IfoEditCelltimesWriter(Path.ChangeExtension(destFileName,".celltimes.txt")))
							{
								ifoFile.WriteContent(this);
							}
						}
						if (Settings.CurrentSettings.MaestroChapters)
						{
							chapterNames.Add(Path.ChangeExtension(destFileName,".maestro.chp"));
							using (MaestroCHPWriter maestroFile=new MaestroCHPWriter(Path.ChangeExtension(destFileName,".maestro.chp")))
							{
								maestroFile.WriteContent(this);
							}
						}
						if (Settings.CurrentSettings.ScenaristChapters)
						{
							chapterNames.Add(Path.ChangeExtension(destFileName,".scenarist.txt"));
							using (ScenaristWriter scenaristFile=new ScenaristWriter(Path.ChangeExtension(destFileName,".scenarist.txt")))
							{
								scenaristFile.WriteContent(this);
							}
						}
						if (Settings.CurrentSettings.CCEChapters)
						{
							chapterNames.Add(Path.ChangeExtension(destFileName,".cce.txt"));
							using (CCEChapterWriter cceFile=new CCEChapterWriter(Path.ChangeExtension(destFileName,".cce.txt")))
							{
								cceFile.WriteContent(this);
							}
						}
						if (Settings.CurrentSettings.DVDAuthorChapters)
						{
							chapterNames.Add(Path.ChangeExtension(destFileName,".dvdauthor.txt"));
							using (DVDAuthorChapterWriter dvdAuthorFile=new DVDAuthorChapterWriter(Path.ChangeExtension(destFileName,".dvdauthor.txt")))
							{
								dvdAuthorFile.WriteContent(this);
							}
						}
						if (Settings.CurrentSettings.OGGChapters)
						{
							chapterNames.Add(Path.ChangeExtension(destFileName,".ogg.txt"));
							using (OGGChapterWriter oggFile=new OGGChapterWriter(Path.ChangeExtension(destFileName,".ogg.txt")))
							{
								oggFile.WriteContent(this);
							}
						}
					}
				}
			}
			finally // egal was passiert ist, alles zu machen!
			{
				if (!audioOnly && VideoFile!=null && VideoFile.IsOpen)
					VideoFile.Close();

				for (int index=0;index<AudioFile.Length;++index)
					if (AudioFile[index]!=null && AudioFile[index].IsOpen)
					{
						long len=AudioFile[index].Length;
						AudioFile[index].Close();
						if (len==0)
						{
							File.Delete(AudioNames[index]);
							AudioNames[index]=string.Empty;
						}
					}
			}
		}

		public override void Remove(object obj)
		{
			int index = base.IndexOf(obj);
			base.Remove(obj);
			AdjustLastCutListPosition(index);
		}

		public override void RemoveAt(int index)
		{
			base.RemoveAt(index);
			AdjustLastCutListPosition(index);
		}

		/// <summary>
		/// This function avoids a wrong order after editing a cut, 
		/// then deleting a cut before the insert position
		/// and then re-inserting the edited cut
		/// </summary>
		protected void AdjustLastCutListPosition(int index)
		{
			StateController i_State = CMMain.globalApplication.Controller;
			if (i_State.CurrentCut == null)
				return;
			
			int insertPos = i_State.CurrentCut.LastCutListPosition;
			if (insertPos <= 0) // do NOT decrement if insertPos == 0 !!!!
				return;

			// The deleted cut was before the edited cut -> decrement insert pos
			if (index < insertPos)
				i_State.CurrentCut.LastCutListPosition --;
		}
	}
}
