/*
 * Cuttermaran - The Mpeg Cutter
 * 
 * Copyright (C) 2003-2006  Tobias Arnold (cuttermaran@gmx.net)
 * 
 * This file is part of cuttermaran, a free MPEG cut program.
 * See http://www.cuttermaran.de for updates.
 *
 * This program is free software; you can redistribute it and/or modify it 
 * under the terms of the GNU General Public License as published by the 
 * Free Software Foundation; either version 2 of the License, or 
 * (at your option) any later version. 
 * 
 * This program is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the 
 * GNU General Public License for more details. 
 * 
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */

using System;
using System.IO;
using System.Data;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Configuration;
using System.Globalization;
using System.Reflection;
using System.Runtime.InteropServices;
using System.Threading;
using System.Diagnostics;
using Crownwood.Magic.Common;
using Crownwood.Magic.Docking;
using Configuration;
using StringResources;
using Coremoran.AVStreams;
using GUI.data;
using Coremoran.Common;

using ICSharpCode.SharpZipLib.Zip;

namespace GUI.MainForm
{
	/// <summary>
	/// Summary description for CMMain.
	/// </summary>
	public class CMMain : BaseDlgOwner
	{
		private System.ComponentModel.Container components = null;
		private MRUFileManager recentProjects;
		private System.Windows.Forms.OpenFileDialog openProjectDialog;
		private System.Windows.Forms.SaveFileDialog saveProjectDialog;
		private System.Windows.Forms.SaveFileDialog saveFrameDialog;
		private System.Windows.Forms.SaveFileDialog saveResultAudioDialog;
		private System.Windows.Forms.MainMenu mainMenu;
		private System.Windows.Forms.MenuItem menuItem1;
		private System.Windows.Forms.MenuItem menuItemNew;
		private System.Windows.Forms.MenuItem menuItemOpen;
		private System.Windows.Forms.MenuItem menuItemSave;
		private System.Windows.Forms.MenuItem menuItemSaveAs;
		private System.Windows.Forms.MenuItem menuItem10;
		private System.Windows.Forms.MenuItem menuItemRecent;
		private System.Windows.Forms.MenuItem menuItem7;
		private System.Windows.Forms.MenuItem menuExit;
		private System.Windows.Forms.MenuItem menuItem4;
		private System.Windows.Forms.MenuItem menuSaveFrame;
		private System.Windows.Forms.MenuItem menuItem3;
		private System.Windows.Forms.MenuItem menuSettings;
		private System.Windows.Forms.MenuItem menuItem2;
		private System.Windows.Forms.MenuItem menuAbout;
		private System.Windows.Forms.MenuItem menuSupportforum;
		private System.Windows.Forms.MenuItem menuCut;
		private System.Windows.Forms.MenuItem menuCutAudioOnly;
		private System.Windows.Forms.MenuItem menuItem11;
		private System.Windows.Forms.MenuItem menuPreview;
		private System.Windows.Forms.MenuItem menuItemWindows;
		private System.Windows.Forms.MenuItem menuItemWindowStreamInfo;
		private System.Windows.Forms.MenuItem menuItemWindowCutList;
		private System.Windows.Forms.MenuItem menuItemWindowChapterList;
		private System.Windows.Forms.MenuItem menuItemWindowResult;
		private System.Windows.Forms.MenuItem menuItemWindowCutOut;
		private System.Windows.Forms.MenuItem menuItemWindowNavigation;
		private System.Windows.Forms.MenuItem menuItemWindowScrollBar;
		private System.Windows.Forms.MenuItem menuItemLanguages;
		private System.Windows.Forms.MenuItem menuItemWindowMarker;
		private System.Windows.Forms.MenuItem menuItem5;
		private System.Windows.Forms.MenuItem menuAllowGUIResize;
		private System.Windows.Forms.MenuItem menuAllowGUIFloating;
		private System.Windows.Forms.MenuItem menuItem6;
		private System.Windows.Forms.MenuItem menuItemPrDefault;
		private System.Windows.Forms.MenuItem menuItemPrPlay;
		private System.Windows.Forms.MenuItem menuItemUserDefined;
		private System.Windows.Forms.MenuItem menuItemPresets;
		private System.Windows.Forms.MenuItem menuItemHtmHelp;
		private System.Windows.Forms.MenuItem menuItemWiki;
		private System.Windows.Forms.MenuItem menuItemHomepage;

		protected DockingManager _manager;
		protected Crownwood.Magic.Controls.TabControl _filler;
		public static CMMain     globalApplication;
		public StateController   Controller;
		protected TabManager     mi_VideoTabs;

		private Content contentCutListCtrl;
		private Content contentScrollCtrl;
		private Content contentStreamInfoCtrl;
		private Content contentChapterListCtrl;
		private Content contentCurrentCutOutCtrl;
		private Content contentNavgationCtrl;
		private Content contentResultCtrl;
		private Content contentMarkerCtrl;
		private CurrentFrameCtrl currentFrameControl;
		private Hashtable languages=new Hashtable();
		private bool isInPlayMode;

		public CMMain()
		{
			globalApplication=this;
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();

			Controller=new StateController();

			// Reduce the amount of flicker that occurs when windows are redocked within
			// the container. As this prevents unsightly backcolors being drawn in the
			// WM_ERASEBACKGROUND that seems to occur.
			SetStyle(ControlStyles.DoubleBuffer, true);
			SetStyle(ControlStyles.AllPaintingInWmPaint, true);

			currentFrameControl=new CurrentFrameCtrl();
			_filler = new Crownwood.Magic.Controls.TabControl();
			_filler.TabPages.Add(new Crownwood.Magic.Controls.TabPage("First", currentFrameControl));
			_filler.Appearance = Crownwood.Magic.Controls.TabControl.VisualAppearance.MultiForm; //.MultiDocument;
			_filler.Dock = DockStyle.Fill;
			_filler.Style = VisualStyle.IDE;
			_filler.IDEPixelBorder = true;
			_filler.HideTabsMode=Crownwood.Magic.Controls.TabControl.HideTabsModes.HideAlways;
			Controls.Add(_filler);

			_manager = new DockingManager(this, VisualStyle.IDE);
			_manager.InnerControl=_filler;
			_manager.TabControlFont=new Font("Microsoft Sans Serif",8.25f);

			// Manager EventHander
			_manager.ContentShown +=new Crownwood.Magic.Docking.DockingManager.ContentHandler(_manager_ContentShown);
			_manager.ContentHidden+=new Crownwood.Magic.Docking.DockingManager.ContentHandler(_manager_ContentHidden);

			WindowContent bottomArea=AddControl(new CutListCtrl(),Resource.WINDOW_CUT_LIST,State.DockBottom,null,true,0,out contentCutListCtrl);
			AddControl(new ScrollCtrl(),Resource.WINDOW_SCROLL,State.DockBottom,null,false,0,out contentScrollCtrl);
			AddControl(new StreamInfoCtrl(),Resource.WINDOW_STREAM_INFO,State.DockTop,null,false,0,out contentStreamInfoCtrl);
			AddControl(new ChapterListCtrl(),Resource.WINDOW_CHAPTER_LIST,State.DockBottom,bottomArea,true,0,out contentChapterListCtrl);
			AddControl(new CurrentCutOutCtrl(),Resource.WINDOW_CURRENT_CUT_OUT,State.DockLeft,null,false,0,out contentCurrentCutOutCtrl);
			WindowContent navArea=AddControl(new NavigationCtrl(),Resource.WINDOW_NAVIGATION,State.DockRight,null,false,0,out contentNavgationCtrl);
			AddControl(new MarkerCtrl(),Resource.WINDOW_MARKER,State.DockRight,navArea,false,1,out contentMarkerCtrl);
			AddControl(new ResultCtrl(),Resource.WINDOW_RESULT,State.DockBottom,bottomArea,true,0,out contentResultCtrl);

			mi_VideoTabs = new TabManager(_manager, Resource.CurrentResource[Resource.VIDEO]);
			mi_VideoTabs.SelectionChanged += new GUI.MainForm.TabManager.SelectionChangedDelegate(Controller.SetActiveVideoTab);
			mi_VideoTabs.AddedNewTab(contentStreamInfoCtrl, false);

			// Weitere Events
			Controller.CutPointModified+=new CutPointModifiedDelegate(this.OnCutPointModified);
			Controller.SetDefaults+=new SetDefaultsDelegate(OnSetDefaults);
			Controller.GuiEnabled+=new GuiEnabledDelegate(OnGuiEnabled);
			Controller.SettingsChanged+=new SettingsChangedDelegate(OnSettingsChanged);
			Controller.AudioVideoOpened+=new AudioVideoOpenedDelegate(OnAudioVideoOpened);
		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if (Controller.CurrentDecoder!=null)
					Controller.CurrentDecoder.CloseVideo();

				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		[DllImport("msvcrt.dll", CallingConvention = CallingConvention.Cdecl)]
		public static extern int _controlfp(int n, int mask);

		/// <summary>
		/// The main entry point for the application.
		/// </summary>
		[STAThread]
		static void Main() 
		{
#if !DEBUG
			try
			{
#endif
			// fixes .NET FPU-Bug
			// see: http://support.microsoft.com/default.aspx?scid=KB;EN-US;q326219
			const int _EM_OVERFLOW = 0x00000004;
			const int _MCW_EM = 0x0008001F;
			_controlfp(~_EM_OVERFLOW, _MCW_EM);

			// Visual Studio Bug im Design Mode (inherited Controls) umgehen
			MainBaseControl.designMode=false;
			GUIBaseForm.designMode=false;

			// ggf. Sprachen installieren
			DirectoryInfo dInfo=new DirectoryInfo(Settings.CurrentSettings.SettingsPath);
			foreach (FileInfo fi in dInfo.GetFiles("*.clf"))
			{
				InstallLanguage(fi.FullName);
				fi.Delete();
			}

			// Sprache setzen
			Thread.CurrentThread.CurrentUICulture = 
				new System.Globalization.CultureInfo(Settings.CurrentSettings.Language);

			string []args=System.Environment.GetCommandLineArgs();
			if (args.Length==2 && args[1]=="-restore")
			{
				if (MessageBox.Show(null,Resource.CurrentResource[Resource.DELETE_SETTINGS],"Cuttermaran",MessageBoxButtons.YesNo)==DialogResult.Yes)
				{
					if (Settings.CurrentSettings.RestoreDefaults())
						MessageBox.Show(Resource.CurrentResource[Resource.DELETE_OK],"Cuttermaran");
					else
						MessageBox.Show(Resource.CurrentResource[Resource.DELETE_ERROR],"Cuttermaran");
				}
			}
			else
				Application.Run(new MainForm.CMMain());

#if !DEBUG
			}
			catch (Exception currentException)
			{
				ErrorDialog ed=new ErrorDialog(currentException);
				ed.ShowDialog();
			}
#endif
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(CMMain));
			System.Configuration.AppSettingsReader configurationAppSettings = new System.Configuration.AppSettingsReader();
			this.mainMenu = new System.Windows.Forms.MainMenu();
			this.menuItem1 = new System.Windows.Forms.MenuItem();
			this.menuItemNew = new System.Windows.Forms.MenuItem();
			this.menuItemOpen = new System.Windows.Forms.MenuItem();
			this.menuItemSave = new System.Windows.Forms.MenuItem();
			this.menuItemSaveAs = new System.Windows.Forms.MenuItem();
			this.menuItem10 = new System.Windows.Forms.MenuItem();
			this.menuItemRecent = new System.Windows.Forms.MenuItem();
			this.menuItem7 = new System.Windows.Forms.MenuItem();
			this.menuExit = new System.Windows.Forms.MenuItem();
			this.menuItem4 = new System.Windows.Forms.MenuItem();
			this.menuCut = new System.Windows.Forms.MenuItem();
			this.menuPreview = new System.Windows.Forms.MenuItem();
			this.menuCutAudioOnly = new System.Windows.Forms.MenuItem();
			this.menuItem11 = new System.Windows.Forms.MenuItem();
			this.menuSaveFrame = new System.Windows.Forms.MenuItem();
			this.menuItem3 = new System.Windows.Forms.MenuItem();
			this.menuSettings = new System.Windows.Forms.MenuItem();
			this.menuItemLanguages = new System.Windows.Forms.MenuItem();
			this.menuItemWindows = new System.Windows.Forms.MenuItem();
			this.menuItemWindowStreamInfo = new System.Windows.Forms.MenuItem();
			this.menuItemWindowCutList = new System.Windows.Forms.MenuItem();
			this.menuItemWindowChapterList = new System.Windows.Forms.MenuItem();
			this.menuItemWindowResult = new System.Windows.Forms.MenuItem();
			this.menuItemWindowCutOut = new System.Windows.Forms.MenuItem();
			this.menuItemWindowNavigation = new System.Windows.Forms.MenuItem();
			this.menuItemWindowScrollBar = new System.Windows.Forms.MenuItem();
			this.menuItemWindowMarker = new System.Windows.Forms.MenuItem();
			this.menuItem5 = new System.Windows.Forms.MenuItem();
			this.menuAllowGUIFloating = new System.Windows.Forms.MenuItem();
			this.menuAllowGUIResize = new System.Windows.Forms.MenuItem();
			this.menuItem6 = new System.Windows.Forms.MenuItem();
			this.menuItemPresets = new System.Windows.Forms.MenuItem();
			this.menuItemPrDefault = new System.Windows.Forms.MenuItem();
			this.menuItemPrPlay = new System.Windows.Forms.MenuItem();
			this.menuItemUserDefined = new System.Windows.Forms.MenuItem();
			this.menuItem2 = new System.Windows.Forms.MenuItem();
			this.menuItemHtmHelp = new System.Windows.Forms.MenuItem();
			this.menuItemWiki = new System.Windows.Forms.MenuItem();
			this.menuSupportforum = new System.Windows.Forms.MenuItem();
			this.menuAbout = new System.Windows.Forms.MenuItem();
			this.openProjectDialog = new System.Windows.Forms.OpenFileDialog();
			this.saveProjectDialog = new System.Windows.Forms.SaveFileDialog();
			this.saveFrameDialog = new System.Windows.Forms.SaveFileDialog();
			this.saveResultAudioDialog = new System.Windows.Forms.SaveFileDialog();
			this.menuItemHomepage = new System.Windows.Forms.MenuItem();
			// 
			// mainMenu
			// 
			this.mainMenu.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
																					 this.menuItem1,
																					 this.menuItem4,
																					 this.menuItemLanguages,
																					 this.menuItemWindows,
																					 this.menuItem2});
			this.mainMenu.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("mainMenu.RightToLeft")));
			// 
			// menuItem1
			// 
			this.menuItem1.Enabled = ((bool)(resources.GetObject("menuItem1.Enabled")));
			this.menuItem1.Index = 0;
			this.menuItem1.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
																					  this.menuItemNew,
																					  this.menuItemOpen,
																					  this.menuItemSave,
																					  this.menuItemSaveAs,
																					  this.menuItem10,
																					  this.menuItemRecent,
																					  this.menuItem7,
																					  this.menuExit});
			this.menuItem1.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuItem1.Shortcut")));
			this.menuItem1.ShowShortcut = ((bool)(resources.GetObject("menuItem1.ShowShortcut")));
			this.menuItem1.Text = resources.GetString("menuItem1.Text");
			this.menuItem1.Visible = ((bool)(resources.GetObject("menuItem1.Visible")));
			// 
			// menuItemNew
			// 
			this.menuItemNew.Enabled = ((bool)(resources.GetObject("menuItemNew.Enabled")));
			this.menuItemNew.Index = 0;
			this.menuItemNew.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuItemNew.Shortcut")));
			this.menuItemNew.ShowShortcut = ((bool)(resources.GetObject("menuItemNew.ShowShortcut")));
			this.menuItemNew.Text = resources.GetString("menuItemNew.Text");
			this.menuItemNew.Visible = ((bool)(resources.GetObject("menuItemNew.Visible")));
			this.menuItemNew.Click += new System.EventHandler(this.menuItemNew_Click);
			// 
			// menuItemOpen
			// 
			this.menuItemOpen.Enabled = ((bool)(resources.GetObject("menuItemOpen.Enabled")));
			this.menuItemOpen.Index = 1;
			this.menuItemOpen.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuItemOpen.Shortcut")));
			this.menuItemOpen.ShowShortcut = ((bool)(resources.GetObject("menuItemOpen.ShowShortcut")));
			this.menuItemOpen.Text = resources.GetString("menuItemOpen.Text");
			this.menuItemOpen.Visible = ((bool)(resources.GetObject("menuItemOpen.Visible")));
			this.menuItemOpen.Click += new System.EventHandler(this.menuItemOpen_Click);
			// 
			// menuItemSave
			// 
			this.menuItemSave.Enabled = ((bool)(resources.GetObject("menuItemSave.Enabled")));
			this.menuItemSave.Index = 2;
			this.menuItemSave.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuItemSave.Shortcut")));
			this.menuItemSave.ShowShortcut = ((bool)(resources.GetObject("menuItemSave.ShowShortcut")));
			this.menuItemSave.Text = resources.GetString("menuItemSave.Text");
			this.menuItemSave.Visible = ((bool)(resources.GetObject("menuItemSave.Visible")));
			this.menuItemSave.Click += new System.EventHandler(this.menuItemSave_Click);
			// 
			// menuItemSaveAs
			// 
			this.menuItemSaveAs.Enabled = ((bool)(resources.GetObject("menuItemSaveAs.Enabled")));
			this.menuItemSaveAs.Index = 3;
			this.menuItemSaveAs.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuItemSaveAs.Shortcut")));
			this.menuItemSaveAs.ShowShortcut = ((bool)(resources.GetObject("menuItemSaveAs.ShowShortcut")));
			this.menuItemSaveAs.Text = resources.GetString("menuItemSaveAs.Text");
			this.menuItemSaveAs.Visible = ((bool)(resources.GetObject("menuItemSaveAs.Visible")));
			this.menuItemSaveAs.Click += new System.EventHandler(this.menuItemSaveAs_Click);
			// 
			// menuItem10
			// 
			this.menuItem10.Enabled = ((bool)(resources.GetObject("menuItem10.Enabled")));
			this.menuItem10.Index = 4;
			this.menuItem10.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuItem10.Shortcut")));
			this.menuItem10.ShowShortcut = ((bool)(resources.GetObject("menuItem10.ShowShortcut")));
			this.menuItem10.Text = resources.GetString("menuItem10.Text");
			this.menuItem10.Visible = ((bool)(resources.GetObject("menuItem10.Visible")));
			// 
			// menuItemRecent
			// 
			this.menuItemRecent.Enabled = ((bool)(resources.GetObject("menuItemRecent.Enabled")));
			this.menuItemRecent.Index = 5;
			this.menuItemRecent.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuItemRecent.Shortcut")));
			this.menuItemRecent.ShowShortcut = ((bool)(resources.GetObject("menuItemRecent.ShowShortcut")));
			this.menuItemRecent.Text = resources.GetString("menuItemRecent.Text");
			this.menuItemRecent.Visible = ((bool)(resources.GetObject("menuItemRecent.Visible")));
			// 
			// menuItem7
			// 
			this.menuItem7.Enabled = ((bool)(resources.GetObject("menuItem7.Enabled")));
			this.menuItem7.Index = 6;
			this.menuItem7.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuItem7.Shortcut")));
			this.menuItem7.ShowShortcut = ((bool)(resources.GetObject("menuItem7.ShowShortcut")));
			this.menuItem7.Text = resources.GetString("menuItem7.Text");
			this.menuItem7.Visible = ((bool)(resources.GetObject("menuItem7.Visible")));
			// 
			// menuExit
			// 
			this.menuExit.Enabled = ((bool)(resources.GetObject("menuExit.Enabled")));
			this.menuExit.Index = 7;
			this.menuExit.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuExit.Shortcut")));
			this.menuExit.ShowShortcut = ((bool)(resources.GetObject("menuExit.ShowShortcut")));
			this.menuExit.Text = resources.GetString("menuExit.Text");
			this.menuExit.Visible = ((bool)(resources.GetObject("menuExit.Visible")));
			this.menuExit.Click += new System.EventHandler(this.menuExit_Click);
			// 
			// menuItem4
			// 
			this.menuItem4.Enabled = ((bool)(resources.GetObject("menuItem4.Enabled")));
			this.menuItem4.Index = 1;
			this.menuItem4.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
																					  this.menuCut,
																					  this.menuPreview,
																					  this.menuCutAudioOnly,
																					  this.menuItem11,
																					  this.menuSaveFrame,
																					  this.menuItem3,
																					  this.menuSettings});
			this.menuItem4.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuItem4.Shortcut")));
			this.menuItem4.ShowShortcut = ((bool)(resources.GetObject("menuItem4.ShowShortcut")));
			this.menuItem4.Text = resources.GetString("menuItem4.Text");
			this.menuItem4.Visible = ((bool)(resources.GetObject("menuItem4.Visible")));
			// 
			// menuCut
			// 
			this.menuCut.Enabled = ((bool)(resources.GetObject("menuCut.Enabled")));
			this.menuCut.Index = 0;
			this.menuCut.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuCut.Shortcut")));
			this.menuCut.ShowShortcut = ((bool)(resources.GetObject("menuCut.ShowShortcut")));
			this.menuCut.Text = resources.GetString("menuCut.Text");
			this.menuCut.Visible = ((bool)(resources.GetObject("menuCut.Visible")));
			this.menuCut.Click += new System.EventHandler(this.menuCut_Click);
			// 
			// menuPreview
			// 
			this.menuPreview.Enabled = ((bool)(resources.GetObject("menuPreview.Enabled")));
			this.menuPreview.Index = 1;
			this.menuPreview.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuPreview.Shortcut")));
			this.menuPreview.ShowShortcut = ((bool)(resources.GetObject("menuPreview.ShowShortcut")));
			this.menuPreview.Text = resources.GetString("menuPreview.Text");
			this.menuPreview.Visible = ((bool)(resources.GetObject("menuPreview.Visible")));
			this.menuPreview.Click += new System.EventHandler(this.menuPreview_Click);
			// 
			// menuCutAudioOnly
			// 
			this.menuCutAudioOnly.Enabled = ((bool)(resources.GetObject("menuCutAudioOnly.Enabled")));
			this.menuCutAudioOnly.Index = 2;
			this.menuCutAudioOnly.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuCutAudioOnly.Shortcut")));
			this.menuCutAudioOnly.ShowShortcut = ((bool)(resources.GetObject("menuCutAudioOnly.ShowShortcut")));
			this.menuCutAudioOnly.Text = resources.GetString("menuCutAudioOnly.Text");
			this.menuCutAudioOnly.Visible = ((bool)(resources.GetObject("menuCutAudioOnly.Visible")));
			this.menuCutAudioOnly.Click += new System.EventHandler(this.menuCutAudioOnly_Click);
			// 
			// menuItem11
			// 
			this.menuItem11.Enabled = ((bool)(resources.GetObject("menuItem11.Enabled")));
			this.menuItem11.Index = 3;
			this.menuItem11.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuItem11.Shortcut")));
			this.menuItem11.ShowShortcut = ((bool)(resources.GetObject("menuItem11.ShowShortcut")));
			this.menuItem11.Text = resources.GetString("menuItem11.Text");
			this.menuItem11.Visible = ((bool)(resources.GetObject("menuItem11.Visible")));
			// 
			// menuSaveFrame
			// 
			this.menuSaveFrame.Enabled = ((bool)(resources.GetObject("menuSaveFrame.Enabled")));
			this.menuSaveFrame.Index = 4;
			this.menuSaveFrame.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuSaveFrame.Shortcut")));
			this.menuSaveFrame.ShowShortcut = ((bool)(resources.GetObject("menuSaveFrame.ShowShortcut")));
			this.menuSaveFrame.Text = resources.GetString("menuSaveFrame.Text");
			this.menuSaveFrame.Visible = ((bool)(resources.GetObject("menuSaveFrame.Visible")));
			this.menuSaveFrame.Click += new System.EventHandler(this.menuSaveFrame_Click);
			// 
			// menuItem3
			// 
			this.menuItem3.Enabled = ((bool)(resources.GetObject("menuItem3.Enabled")));
			this.menuItem3.Index = 5;
			this.menuItem3.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuItem3.Shortcut")));
			this.menuItem3.ShowShortcut = ((bool)(resources.GetObject("menuItem3.ShowShortcut")));
			this.menuItem3.Text = resources.GetString("menuItem3.Text");
			this.menuItem3.Visible = ((bool)(resources.GetObject("menuItem3.Visible")));
			// 
			// menuSettings
			// 
			this.menuSettings.Enabled = ((bool)(resources.GetObject("menuSettings.Enabled")));
			this.menuSettings.Index = 6;
			this.menuSettings.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuSettings.Shortcut")));
			this.menuSettings.ShowShortcut = ((bool)(resources.GetObject("menuSettings.ShowShortcut")));
			this.menuSettings.Text = resources.GetString("menuSettings.Text");
			this.menuSettings.Visible = ((bool)(resources.GetObject("menuSettings.Visible")));
			this.menuSettings.Click += new System.EventHandler(this.menuSettings_Click);
			// 
			// menuItemLanguages
			// 
			this.menuItemLanguages.Enabled = ((bool)(resources.GetObject("menuItemLanguages.Enabled")));
			this.menuItemLanguages.Index = 2;
			this.menuItemLanguages.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuItemLanguages.Shortcut")));
			this.menuItemLanguages.ShowShortcut = ((bool)(resources.GetObject("menuItemLanguages.ShowShortcut")));
			this.menuItemLanguages.Text = resources.GetString("menuItemLanguages.Text");
			this.menuItemLanguages.Visible = ((bool)(resources.GetObject("menuItemLanguages.Visible")));
			// 
			// menuItemWindows
			// 
			this.menuItemWindows.Enabled = ((bool)(resources.GetObject("menuItemWindows.Enabled")));
			this.menuItemWindows.Index = 3;
			this.menuItemWindows.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
																							this.menuItemWindowStreamInfo,
																							this.menuItemWindowCutList,
																							this.menuItemWindowChapterList,
																							this.menuItemWindowResult,
																							this.menuItemWindowCutOut,
																							this.menuItemWindowNavigation,
																							this.menuItemWindowScrollBar,
																							this.menuItemWindowMarker,
																							this.menuItem5,
																							this.menuAllowGUIFloating,
																							this.menuAllowGUIResize,
																							this.menuItem6,
																							this.menuItemPresets});
			this.menuItemWindows.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuItemWindows.Shortcut")));
			this.menuItemWindows.ShowShortcut = ((bool)(resources.GetObject("menuItemWindows.ShowShortcut")));
			this.menuItemWindows.Text = resources.GetString("menuItemWindows.Text");
			this.menuItemWindows.Visible = ((bool)(resources.GetObject("menuItemWindows.Visible")));
			// 
			// menuItemWindowStreamInfo
			// 
			this.menuItemWindowStreamInfo.Enabled = ((bool)(resources.GetObject("menuItemWindowStreamInfo.Enabled")));
			this.menuItemWindowStreamInfo.Index = 0;
			this.menuItemWindowStreamInfo.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuItemWindowStreamInfo.Shortcut")));
			this.menuItemWindowStreamInfo.ShowShortcut = ((bool)(resources.GetObject("menuItemWindowStreamInfo.ShowShortcut")));
			this.menuItemWindowStreamInfo.Text = resources.GetString("menuItemWindowStreamInfo.Text");
			this.menuItemWindowStreamInfo.Visible = ((bool)(resources.GetObject("menuItemWindowStreamInfo.Visible")));
			this.menuItemWindowStreamInfo.Click += new System.EventHandler(this.menuItemWindowStreamInfo_Click);
			// 
			// menuItemWindowCutList
			// 
			this.menuItemWindowCutList.Enabled = ((bool)(resources.GetObject("menuItemWindowCutList.Enabled")));
			this.menuItemWindowCutList.Index = 1;
			this.menuItemWindowCutList.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuItemWindowCutList.Shortcut")));
			this.menuItemWindowCutList.ShowShortcut = ((bool)(resources.GetObject("menuItemWindowCutList.ShowShortcut")));
			this.menuItemWindowCutList.Text = resources.GetString("menuItemWindowCutList.Text");
			this.menuItemWindowCutList.Visible = ((bool)(resources.GetObject("menuItemWindowCutList.Visible")));
			this.menuItemWindowCutList.Click += new System.EventHandler(this.menuItemWindowCutList_Click);
			// 
			// menuItemWindowChapterList
			// 
			this.menuItemWindowChapterList.Enabled = ((bool)(resources.GetObject("menuItemWindowChapterList.Enabled")));
			this.menuItemWindowChapterList.Index = 2;
			this.menuItemWindowChapterList.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuItemWindowChapterList.Shortcut")));
			this.menuItemWindowChapterList.ShowShortcut = ((bool)(resources.GetObject("menuItemWindowChapterList.ShowShortcut")));
			this.menuItemWindowChapterList.Text = resources.GetString("menuItemWindowChapterList.Text");
			this.menuItemWindowChapterList.Visible = ((bool)(resources.GetObject("menuItemWindowChapterList.Visible")));
			this.menuItemWindowChapterList.Click += new System.EventHandler(this.menuItemWindowChapterList_Click);
			// 
			// menuItemWindowResult
			// 
			this.menuItemWindowResult.Enabled = ((bool)(resources.GetObject("menuItemWindowResult.Enabled")));
			this.menuItemWindowResult.Index = 3;
			this.menuItemWindowResult.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuItemWindowResult.Shortcut")));
			this.menuItemWindowResult.ShowShortcut = ((bool)(resources.GetObject("menuItemWindowResult.ShowShortcut")));
			this.menuItemWindowResult.Text = resources.GetString("menuItemWindowResult.Text");
			this.menuItemWindowResult.Visible = ((bool)(resources.GetObject("menuItemWindowResult.Visible")));
			this.menuItemWindowResult.Click += new System.EventHandler(this.menuItemWindowResult_Click);
			// 
			// menuItemWindowCutOut
			// 
			this.menuItemWindowCutOut.Enabled = ((bool)(resources.GetObject("menuItemWindowCutOut.Enabled")));
			this.menuItemWindowCutOut.Index = 4;
			this.menuItemWindowCutOut.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuItemWindowCutOut.Shortcut")));
			this.menuItemWindowCutOut.ShowShortcut = ((bool)(resources.GetObject("menuItemWindowCutOut.ShowShortcut")));
			this.menuItemWindowCutOut.Text = resources.GetString("menuItemWindowCutOut.Text");
			this.menuItemWindowCutOut.Visible = ((bool)(resources.GetObject("menuItemWindowCutOut.Visible")));
			this.menuItemWindowCutOut.Click += new System.EventHandler(this.menuItemWindowCutOut_Click);
			// 
			// menuItemWindowNavigation
			// 
			this.menuItemWindowNavigation.Enabled = ((bool)(resources.GetObject("menuItemWindowNavigation.Enabled")));
			this.menuItemWindowNavigation.Index = 5;
			this.menuItemWindowNavigation.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuItemWindowNavigation.Shortcut")));
			this.menuItemWindowNavigation.ShowShortcut = ((bool)(resources.GetObject("menuItemWindowNavigation.ShowShortcut")));
			this.menuItemWindowNavigation.Text = resources.GetString("menuItemWindowNavigation.Text");
			this.menuItemWindowNavigation.Visible = ((bool)(resources.GetObject("menuItemWindowNavigation.Visible")));
			this.menuItemWindowNavigation.Click += new System.EventHandler(this.menuItemWindowNavigation_Click);
			// 
			// menuItemWindowScrollBar
			// 
			this.menuItemWindowScrollBar.Enabled = ((bool)(resources.GetObject("menuItemWindowScrollBar.Enabled")));
			this.menuItemWindowScrollBar.Index = 6;
			this.menuItemWindowScrollBar.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuItemWindowScrollBar.Shortcut")));
			this.menuItemWindowScrollBar.ShowShortcut = ((bool)(resources.GetObject("menuItemWindowScrollBar.ShowShortcut")));
			this.menuItemWindowScrollBar.Text = resources.GetString("menuItemWindowScrollBar.Text");
			this.menuItemWindowScrollBar.Visible = ((bool)(resources.GetObject("menuItemWindowScrollBar.Visible")));
			this.menuItemWindowScrollBar.Click += new System.EventHandler(this.menuItemWindowScrollBar_Click);
			// 
			// menuItemWindowMarker
			// 
			this.menuItemWindowMarker.Enabled = ((bool)(resources.GetObject("menuItemWindowMarker.Enabled")));
			this.menuItemWindowMarker.Index = 7;
			this.menuItemWindowMarker.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuItemWindowMarker.Shortcut")));
			this.menuItemWindowMarker.ShowShortcut = ((bool)(resources.GetObject("menuItemWindowMarker.ShowShortcut")));
			this.menuItemWindowMarker.Text = resources.GetString("menuItemWindowMarker.Text");
			this.menuItemWindowMarker.Visible = ((bool)(resources.GetObject("menuItemWindowMarker.Visible")));
			this.menuItemWindowMarker.Click += new System.EventHandler(this.menuItemWindowMarker_Click);
			// 
			// menuItem5
			// 
			this.menuItem5.Enabled = ((bool)(resources.GetObject("menuItem5.Enabled")));
			this.menuItem5.Index = 8;
			this.menuItem5.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuItem5.Shortcut")));
			this.menuItem5.ShowShortcut = ((bool)(resources.GetObject("menuItem5.ShowShortcut")));
			this.menuItem5.Text = resources.GetString("menuItem5.Text");
			this.menuItem5.Visible = ((bool)(resources.GetObject("menuItem5.Visible")));
			// 
			// menuAllowGUIFloating
			// 
			this.menuAllowGUIFloating.Enabled = ((bool)(resources.GetObject("menuAllowGUIFloating.Enabled")));
			this.menuAllowGUIFloating.Index = 9;
			this.menuAllowGUIFloating.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuAllowGUIFloating.Shortcut")));
			this.menuAllowGUIFloating.ShowShortcut = ((bool)(resources.GetObject("menuAllowGUIFloating.ShowShortcut")));
			this.menuAllowGUIFloating.Text = resources.GetString("menuAllowGUIFloating.Text");
			this.menuAllowGUIFloating.Visible = ((bool)(resources.GetObject("menuAllowGUIFloating.Visible")));
			this.menuAllowGUIFloating.Click += new System.EventHandler(this.menuAllowGUIFloating_Click);
			// 
			// menuAllowGUIResize
			// 
			this.menuAllowGUIResize.Enabled = ((bool)(resources.GetObject("menuAllowGUIResize.Enabled")));
			this.menuAllowGUIResize.Index = 10;
			this.menuAllowGUIResize.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuAllowGUIResize.Shortcut")));
			this.menuAllowGUIResize.ShowShortcut = ((bool)(resources.GetObject("menuAllowGUIResize.ShowShortcut")));
			this.menuAllowGUIResize.Text = resources.GetString("menuAllowGUIResize.Text");
			this.menuAllowGUIResize.Visible = ((bool)(resources.GetObject("menuAllowGUIResize.Visible")));
			this.menuAllowGUIResize.Click += new System.EventHandler(this.menuAllowGUIResize_Click);
			// 
			// menuItem6
			// 
			this.menuItem6.Enabled = ((bool)(resources.GetObject("menuItem6.Enabled")));
			this.menuItem6.Index = 11;
			this.menuItem6.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuItem6.Shortcut")));
			this.menuItem6.ShowShortcut = ((bool)(resources.GetObject("menuItem6.ShowShortcut")));
			this.menuItem6.Text = resources.GetString("menuItem6.Text");
			this.menuItem6.Visible = ((bool)(resources.GetObject("menuItem6.Visible")));
			// 
			// menuItemPresets
			// 
			this.menuItemPresets.Enabled = ((bool)(resources.GetObject("menuItemPresets.Enabled")));
			this.menuItemPresets.Index = 12;
			this.menuItemPresets.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
																							this.menuItemPrDefault,
																							this.menuItemPrPlay,
																							this.menuItemUserDefined});
			this.menuItemPresets.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuItemPresets.Shortcut")));
			this.menuItemPresets.ShowShortcut = ((bool)(resources.GetObject("menuItemPresets.ShowShortcut")));
			this.menuItemPresets.Text = resources.GetString("menuItemPresets.Text");
			this.menuItemPresets.Visible = ((bool)(resources.GetObject("menuItemPresets.Visible")));
			// 
			// menuItemPrDefault
			// 
			this.menuItemPrDefault.Enabled = ((bool)(resources.GetObject("menuItemPrDefault.Enabled")));
			this.menuItemPrDefault.Index = 0;
			this.menuItemPrDefault.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuItemPrDefault.Shortcut")));
			this.menuItemPrDefault.ShowShortcut = ((bool)(resources.GetObject("menuItemPrDefault.ShowShortcut")));
			this.menuItemPrDefault.Text = resources.GetString("menuItemPrDefault.Text");
			this.menuItemPrDefault.Visible = ((bool)(resources.GetObject("menuItemPrDefault.Visible")));
			this.menuItemPrDefault.Click += new System.EventHandler(this.menuItemPrDefault_Click);
			// 
			// menuItemPrPlay
			// 
			this.menuItemPrPlay.Enabled = ((bool)(resources.GetObject("menuItemPrPlay.Enabled")));
			this.menuItemPrPlay.Index = 1;
			this.menuItemPrPlay.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuItemPrPlay.Shortcut")));
			this.menuItemPrPlay.ShowShortcut = ((bool)(resources.GetObject("menuItemPrPlay.ShowShortcut")));
			this.menuItemPrPlay.Text = resources.GetString("menuItemPrPlay.Text");
			this.menuItemPrPlay.Visible = ((bool)(resources.GetObject("menuItemPrPlay.Visible")));
			this.menuItemPrPlay.Click += new System.EventHandler(this.menuItemPrPlay_Click);
			// 
			// menuItemUserDefined
			// 
			this.menuItemUserDefined.Enabled = ((bool)(resources.GetObject("menuItemUserDefined.Enabled")));
			this.menuItemUserDefined.Index = 2;
			this.menuItemUserDefined.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuItemUserDefined.Shortcut")));
			this.menuItemUserDefined.ShowShortcut = ((bool)(resources.GetObject("menuItemUserDefined.ShowShortcut")));
			this.menuItemUserDefined.Text = resources.GetString("menuItemUserDefined.Text");
			this.menuItemUserDefined.Visible = ((bool)(resources.GetObject("menuItemUserDefined.Visible")));
			// 
			// menuItem2
			// 
			this.menuItem2.Enabled = ((bool)(resources.GetObject("menuItem2.Enabled")));
			this.menuItem2.Index = 4;
			this.menuItem2.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
																					  this.menuItemHtmHelp,
																					  this.menuItemHomepage,
																					  this.menuItemWiki,
																					  this.menuSupportforum,
																					  this.menuAbout});
			this.menuItem2.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuItem2.Shortcut")));
			this.menuItem2.ShowShortcut = ((bool)(resources.GetObject("menuItem2.ShowShortcut")));
			this.menuItem2.Text = resources.GetString("menuItem2.Text");
			this.menuItem2.Visible = ((bool)(resources.GetObject("menuItem2.Visible")));
			// 
			// menuItemHtmHelp
			// 
			this.menuItemHtmHelp.Enabled = ((bool)(resources.GetObject("menuItemHtmHelp.Enabled")));
			this.menuItemHtmHelp.Index = 0;
			this.menuItemHtmHelp.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuItemHtmHelp.Shortcut")));
			this.menuItemHtmHelp.ShowShortcut = ((bool)(resources.GetObject("menuItemHtmHelp.ShowShortcut")));
			this.menuItemHtmHelp.Text = resources.GetString("menuItemHtmHelp.Text");
			this.menuItemHtmHelp.Visible = ((bool)(resources.GetObject("menuItemHtmHelp.Visible")));
			this.menuItemHtmHelp.Click += new System.EventHandler(this.menuItemHtmHelp_Click);
			// 
			// menuItemWiki
			// 
			this.menuItemWiki.Enabled = ((bool)(resources.GetObject("menuItemWiki.Enabled")));
			this.menuItemWiki.Index = 2;
			this.menuItemWiki.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuItemWiki.Shortcut")));
			this.menuItemWiki.ShowShortcut = ((bool)(resources.GetObject("menuItemWiki.ShowShortcut")));
			this.menuItemWiki.Text = resources.GetString("menuItemWiki.Text");
			this.menuItemWiki.Visible = ((bool)(resources.GetObject("menuItemWiki.Visible")));
			this.menuItemWiki.Click += new System.EventHandler(this.menuItemWiki_Click);
			// 
			// menuSupportforum
			// 
			this.menuSupportforum.Enabled = ((bool)(resources.GetObject("menuSupportforum.Enabled")));
			this.menuSupportforum.Index = 3;
			this.menuSupportforum.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuSupportforum.Shortcut")));
			this.menuSupportforum.ShowShortcut = ((bool)(resources.GetObject("menuSupportforum.ShowShortcut")));
			this.menuSupportforum.Text = resources.GetString("menuSupportforum.Text");
			this.menuSupportforum.Visible = ((bool)(resources.GetObject("menuSupportforum.Visible")));
			this.menuSupportforum.Click += new System.EventHandler(this.menuSupportforum_Click);
			// 
			// menuAbout
			// 
			this.menuAbout.Enabled = ((bool)(resources.GetObject("menuAbout.Enabled")));
			this.menuAbout.Index = 4;
			this.menuAbout.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuAbout.Shortcut")));
			this.menuAbout.ShowShortcut = ((bool)(resources.GetObject("menuAbout.ShowShortcut")));
			this.menuAbout.Text = resources.GetString("menuAbout.Text");
			this.menuAbout.Visible = ((bool)(resources.GetObject("menuAbout.Visible")));
			this.menuAbout.Click += new System.EventHandler(this.menuAbout_Click);
			// 
			// openProjectDialog
			// 
			this.openProjectDialog.DefaultExt = "cpf";
			this.openProjectDialog.Filter = resources.GetString("openProjectDialog.Filter");
			this.openProjectDialog.Title = resources.GetString("openProjectDialog.Title");
			// 
			// saveProjectDialog
			// 
			this.saveProjectDialog.DefaultExt = "cpf";
			this.saveProjectDialog.Filter = resources.GetString("saveProjectDialog.Filter");
			this.saveProjectDialog.Title = resources.GetString("saveProjectDialog.Title");
			// 
			// saveFrameDialog
			// 
			this.saveFrameDialog.Filter = resources.GetString("saveFrameDialog.Filter");
			this.saveFrameDialog.Title = resources.GetString("saveFrameDialog.Title");
			// 
			// saveResultAudioDialog
			// 
			this.saveResultAudioDialog.DefaultExt = "mp2";
			this.saveResultAudioDialog.Filter = ((string)(configurationAppSettings.GetValue("AudioDialog.Filter", typeof(string))));
			this.saveResultAudioDialog.Title = resources.GetString("saveResultAudioDialog.Title");
			// 
			// menuItemHomepage
			// 
			this.menuItemHomepage.Enabled = ((bool)(resources.GetObject("menuItemHomepage.Enabled")));
			this.menuItemHomepage.Index = 1;
			this.menuItemHomepage.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuItemHomepage.Shortcut")));
			this.menuItemHomepage.ShowShortcut = ((bool)(resources.GetObject("menuItemHomepage.ShowShortcut")));
			this.menuItemHomepage.Text = resources.GetString("menuItemHomepage.Text");
			this.menuItemHomepage.Visible = ((bool)(resources.GetObject("menuItemHomepage.Visible")));
			this.menuItemHomepage.Click += new System.EventHandler(this.menuItemHomepage_Click);
			// 
			// CMMain
			// 
			this.AccessibleDescription = resources.GetString("$this.AccessibleDescription");
			this.AccessibleName = resources.GetString("$this.AccessibleName");
			this.AllowDrop = true;
			this.AutoScaleBaseSize = ((System.Drawing.Size)(resources.GetObject("$this.AutoScaleBaseSize")));
			this.AutoScroll = ((bool)(resources.GetObject("$this.AutoScroll")));
			this.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("$this.AutoScrollMargin")));
			this.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("$this.AutoScrollMinSize")));
			this.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("$this.BackgroundImage")));
			this.ClientSize = ((System.Drawing.Size)(resources.GetObject("$this.ClientSize")));
			this.Enabled = ((bool)(resources.GetObject("$this.Enabled")));
			this.Font = ((System.Drawing.Font)(resources.GetObject("$this.Font")));
			this.Icon = ((System.Drawing.Icon)(resources.GetObject("$this.Icon")));
			this.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("$this.ImeMode")));
			this.KeyPreview = true;
			this.Location = ((System.Drawing.Point)(resources.GetObject("$this.Location")));
			this.MaximumSize = ((System.Drawing.Size)(resources.GetObject("$this.MaximumSize")));
			this.Menu = this.mainMenu;
			this.MinimumSize = ((System.Drawing.Size)(resources.GetObject("$this.MinimumSize")));
			this.Name = "CMMain";
			this.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("$this.RightToLeft")));
			this.StartPosition = ((System.Windows.Forms.FormStartPosition)(resources.GetObject("$this.StartPosition")));
			this.Text = resources.GetString("$this.Text");
			this.KeyDown += new System.Windows.Forms.KeyEventHandler(this.CMMain_KeyDown);
			this.Closing += new System.ComponentModel.CancelEventHandler(this.CMMain_Closing);
			this.Load += new System.EventHandler(this.CMMain_Load);
			this.DragOver += new System.Windows.Forms.DragEventHandler(this.CMMain_DragOver);
			this.DragDrop += new System.Windows.Forms.DragEventHandler(this.CMMain_DragDrop);

		}
		#endregion

		private WindowContent AddControl(Control ctrl,string name,State pos,WindowContent wc,bool addBorder,int zoneIndex,out Content c)
		{
			c = _manager.Contents.Add(ctrl,name);
			Size sz=ctrl.Size;
			sz.Height+=28;
			if (addBorder)
				sz.Height+=16;
            				
			c.AutoHideSize=c.FloatingSize=c.DisplaySize=sz;

			if (wc==null)
				return _manager.AddContentWithState(c, pos);
			else
			{
				if (zoneIndex>0)
				{
					_manager.AddContentToZone(c,wc.ParentZone,zoneIndex);
					return wc;
				}
				else
					return _manager.AddContentToWindowContent(c,wc);
			}
		}

		#region Menu Help

		private void menuAbout_Click(object sender, System.EventArgs e)
		{
			new About().ShowDialog();
		}

		private void menuSupportforum_Click(object sender, System.EventArgs e)
		{
			OpenURL("http://technik.movie2digital.de");
		}

		private void menuItemWiki_Click(object sender, System.EventArgs e)
		{
			OpenURL("http://wiki.cuttermaran.de");
		}

		private void menuItemHomepage_Click(object sender, System.EventArgs e)
		{
			OpenURL("http://cuttermaran.de");
		}

		private void menuItemHtmHelp_Click(object sender, EventArgs e)
		{
			// This path will not be valid when Cuttermaran is started by Visual Studio!
			OpenURL(Path.GetDirectoryName(Application.ExecutablePath)+ "\\doc\\index.htm");
		}

		#endregion

		private void CMMain_Load(object sender, System.EventArgs e)
		{
			// Sprachen anlegen und vorbelegen
			CreateLanguages();

			// Mentexte fr die Fenster
			menuItemWindowStreamInfo.Text=Resource.CurrentResource[Resource.WINDOW_STREAM_INFO];
			menuItemWindowCutList.Text=Resource.CurrentResource[Resource.WINDOW_CUT_LIST];
			menuItemWindowChapterList.Text=Resource.CurrentResource[Resource.WINDOW_CHAPTER_LIST];
			menuItemWindowResult.Text=Resource.CurrentResource[Resource.WINDOW_RESULT];
			menuItemWindowCutOut.Text=Resource.CurrentResource[Resource.WINDOW_CURRENT_CUT_OUT];
			menuItemWindowNavigation.Text=Resource.CurrentResource[Resource.WINDOW_NAVIGATION];
			menuItemWindowScrollBar.Text=Resource.CurrentResource[Resource.WINDOW_SCROLL];
			menuItemWindowMarker.Text=Resource.CurrentResource[Resource.WINDOW_MARKER];

			menuAllowGUIResize.  Checked=Settings.CurrentSettings.AllowGUIResize;
			menuAllowGUIFloating.Checked=Settings.CurrentSettings.AllowGUIFloating;

			// InitialDirectories setzen
			openProjectDialog.InitialDirectory=Settings.CurrentSettings.ProjectDialog_InitialDirectory;
			saveProjectDialog.InitialDirectory=Settings.CurrentSettings.ProjectDialog_InitialDirectory;
			saveFrameDialog.InitialDirectory=Settings.CurrentSettings.SaveFrameDialog_InitialDirectory;

			// sonstige Vorbelegungen
			recentProjects=new MRUFileManager(menuItemRecent,new MRUFileManager.MRUItemClick(this.LoadProjectFile));
			recentProjects.Entries=Settings.CurrentSettings.MRUFileEntries;

			// GUI laden:
			if (!LoadGUISetting(Settings.CurrentSettings.PresetCurrentName))
				LoadInternalGUISetting("default");

			// Settings laden
			OnSettingsChanged();

			// Hier geht es weiter, wenn die GUI da ist
			Application.Idle+=new EventHandler(this.Process_StartUpActions);
		}

		// Sprachen ins Men eintragen
		private void CreateLanguages()
		{
			// Englisch eintragen
			CultureInfo english=new CultureInfo("en");
			string engltext=string.Format("{0} / {1}",english.NativeName,english.EnglishName);
			MenuItem englItem=new MenuItem(engltext,new EventHandler(Language_Change));
			englItem.RadioCheck=true;
			menuItemLanguages.MenuItems.Add(englItem);
			languages.Add(english.Name,engltext);

			// Sprachen besorgen:
			CultureInfo [] cis=CultureInfo.GetCultures(CultureTypes.AllCultures);

			string currentDir=Path.GetDirectoryName(Assembly.GetEntryAssembly().Location);
			DirectoryInfo [] dis =new DirectoryInfo(currentDir).GetDirectories();
			foreach (DirectoryInfo di in dis)
				foreach (CultureInfo ci in cis)
					if (ci.Name.ToLower()==di.Name.ToLower())
					{
						string text=string.Format("{0} / {1}",ci.NativeName,ci.EnglishName);
						MenuItem newItem=new MenuItem(text,new EventHandler(Language_Change));
						newItem.RadioCheck=true;
						menuItemLanguages.MenuItems.Add(newItem);
						languages.Add(ci.Name,text);
						break;
					}

			// Sprache auch im Men selektieren
			SelectLanguage(Settings.CurrentSettings.Language);
		}

		private void SelectLanguage(string langKey)
		{
			string langText=languages["en"].ToString();
			if (languages!=null)
				if (languages.ContainsKey(langKey))
					langText=languages[langKey].ToString();
			foreach (MenuItem mi in menuItemLanguages.MenuItems)
				mi.Checked=mi.Text==langText;
			Settings.CurrentSettings.Language=langKey;
		}

		private void Language_Change(object sender, System.EventArgs e)
		{
			if (((MenuItem)sender).Checked)
				return;

			string newLangCode="en";
			if (languages!=null)
			{
				foreach (DictionaryEntry de in languages)
					if (((MenuItem)sender).Text==de.Value.ToString())
					{
						newLangCode=de.Key.ToString();
						break;
					}
			}
			SelectLanguage(newLangCode);
			MessageBox.Show(Resource.CurrentResource[Resource.RESTART],Resource.CurrentResource[Resource.INFO]);
		}

		private static void InstallLanguage(string archiveFile)
		{
			LanguageData langs=new LanguageData();
			string currentDir=Path.GetDirectoryName(Assembly.GetEntryAssembly().Location);
			string xmlResource = "GUI.languages.xml";
			using (Stream s = Assembly.GetExecutingAssembly().GetManifestResourceStream(xmlResource))
			{
				langs.ReadXml(s);
			}

			// LangCode ermitteln und einfgen
			string langCode;
			CultureInfo ci;
			try
			{
				langCode=Path.GetFileName(archiveFile).ToLower().Replace("lang_",string.Empty).Replace(".clf",string.Empty);
				ci=new CultureInfo(langCode);
			}
			catch
			{
				return;
			}

			using (ZipInputStream s = new ZipInputStream(File.OpenRead(archiveFile)))
			{
				ZipEntry theEntry;
				while ((theEntry = s.GetNextEntry()) != null) 
				{
					string fileName= Path.GetFileName(theEntry.Name);
					LanguageData.AssembliesRow ar=langs.Assemblies.FindByname(fileName.ToLower());
					if (ar==null)
						continue;

					string fullName=ar.relPath.Replace("<langCode>",ci.Name);
					fullName = Path.Combine(currentDir,fullName);
			
					// create directory
					if (!Directory.Exists(Path.GetDirectoryName(fullName)))
						Directory.CreateDirectory(Path.GetDirectoryName(fullName));
			
					if (fileName != string.Empty) 
						using (FileStream streamWriter = File.Create(fullName))
						{				
							int size = 2048;
							byte[] data = new byte[2048];
							while (true) 
							{
								size = s.Read(data, 0, data.Length);
								if (size == 0) 
									break;
								streamWriter.Write(data, 0, size);
							}
						}
				}
			}		
		}

		private delegate void OpenURLDelegate(string url);

		private void UpdateLookUp()
		{
			// ggf. auf Update prfen
			try
			{
				// Nur prfen wenn Internetverbindung besteht und nicht im CLI-Mode
				if (Settings.CurrentSettings.UseUpdateDetection && IsConnected && !Controller.CmdUnattended)
				{
					int interval=int.Parse(System.Configuration.ConfigurationSettings.AppSettings["UpdateInterval"]);
					// Ist Wartezeit verstrichen?
					if (Settings.CurrentSettings.LastUpdateLookup.AddDays(interval)<=DateTime.Today)
					{
						string url=System.Configuration.ConfigurationSettings.AppSettings["UpdateDetectUrl"];
						VersionData versionInfo=new VersionData();
						// Aktuelle Versionsnummern aus dem I-Net laden
						versionInfo.ReadXml(url);
						VersionData.VersionsRow vr=versionInfo.Versions.FindByName("Cuttermaran");
						
						string urlVersion = vr.Version;
						string appVersion = System.Configuration.ConfigurationSettings.AppSettings["Version"];

						// compare for example "1.68" with "1.69 beta4"
						// or compare "1.69 beta 4" with "1.69 RC1"
						int verURL = ParseVersion(urlVersion);
						int verAPP = ParseVersion(appVersion); // returns 0 on error

						if (verAPP > 0 && verAPP < verURL)
						{
							string msg=Resource.CurrentResource.FormatMessage(Resource.NEW_VERSION,appVersion,urlVersion,vr.ReleaseDate.ToShortDateString());
							msg=msg.Replace("<br>",Environment.NewLine);
							DialogResult dr=MessageBox.Show(this,msg,
								Resource.CurrentResource[Resource.INFO],MessageBoxButtons.YesNo);
							// Soll der Browser mit der Hompage gestartet werden?
							if (dr==DialogResult.Yes)
								this.Invoke(new OpenURLDelegate(OpenURL),new object []{vr.UpdateUrl});
						}
						// Heute wurde erfolgreich geprft...
						Settings.CurrentSettings.LastUpdateLookup=DateTime.Today;
					}
				}
			}
			catch (Exception e)
			{
				System.Diagnostics.Trace.WriteLine(e.Message);
				System.Diagnostics.Trace.WriteLine(e.StackTrace);
				// dann eben nicht...
			}
		}

		/// <summary>
		/// "1.69 beta"   will return 1690000
		/// "1.69 beta5"  will return 1690005
		/// "1.69 RC"     will return 1695000
		/// "1.69 RC 2"   will return 1695002
		/// "1.69"        will return 1699000 (final version)
		/// "1.69a"       will return 1699001 (final version with bugfix)
		/// "1.69b"       will return 1699002 (final version with second fix)
		/// Spaces and dots are ignored
		/// "1.7" is NOT allowed, there must be 3 digits at the begin -> "1.70"
		/// </summary>
		private int ParseVersion(string s_Version)
		{
			int s32_Ver = 0;
			try
			{
				string s_Parse = s_Version.Replace(" ", "").Replace(".", ""); // "169beta5"

				int s32_Digits = 0;
				for (int i=0; i<s_Parse.Length; i++)
				{
					if (s_Parse[i] < '0' || s_Parse[i] > '9')
						break;
					s32_Digits ++;
				}

				s32_Ver = 10000 * Int32.Parse(s_Parse.Substring(0, s32_Digits));
				s_Parse = s_Parse.Substring(s32_Digits).ToUpper();

				if (s_Parse.StartsWith("BETA"))
				{
					s_Parse = s_Parse.Substring(4);
					if (s_Parse.Length > 0) 
						s32_Ver += Int32.Parse(s_Parse);
				}
				else if (s_Parse.StartsWith("RC"))
				{
					s32_Ver += 5000;
					s_Parse = s_Parse.Substring(2);
					if (s_Parse.Length > 0) 
						s32_Ver += Int32.Parse(s_Parse);
				}
				else // Full Version
				{
					s32_Ver += 9000;
					if (s_Parse.Length == 1 && s_Parse[0] >= 'A' && s_Parse[0] <= 'Z')
						s32_Ver += s_Parse[0] - 'A' + 1;
				}
			}
			catch { s32_Ver=0; }

			if (s32_Ver < 1680000)
				MessageBox.Show("CMMain.ParseVersion() Invalid version number: " + s_Version, "Error");

			return s32_Ver;
		}

		// Da u.U. die Homepage mit der version.xml hngen knnte, wird asynchron geprft,
		// ob eine neue Version zur Verfgung steht. Falls ja benutzt der Thread diese Methode
		// um den default Browser im Context des aufrufenden Prozesses zu starten!
		private void OpenURL(string url)
		{
			try { System.Diagnostics.Process.Start(url); }
			catch (Exception Ex)
			{
				MessageBox.Show(Ex.Message + "\n" + url, "Cuttermaran");
			}
		}

		/// <summary>
		/// return true:  if there are no unsaved changes
		/// return true:  if the user does not want to save
		/// return true:  after successful saving
		/// return false: user clicked Cancel
		/// return false: error while saving
		/// </summary>
		public bool AskSaveChangedProject()
		{
			if (!Controller.IsModified || Controller.Cuts.Count == 0)
				return true;

			DialogResult Res = MessageBox.Show(Resource.CurrentResource[Resource.QUESTION_SAVE_STATE],
			                                   ConfigurationSettings.AppSettings["Version.Text"],
			                                   MessageBoxButtons.YesNoCancel, MessageBoxIcon.Question);
			switch (Res)
			{
				case DialogResult.Yes:
					string filename = Controller.StateFileName;
					if (filename.Length == 0)
					{
						saveProjectDialog.FileName=Path.ChangeExtension(Controller.VideoStream.StreamName,saveProjectDialog.DefaultExt);
						if (saveProjectDialog.ShowDialog() == DialogResult.OK)
							filename=saveProjectDialog.FileName;
					}

					if (filename.Length == 0)
						return false; // user clicked Cancel in OpenFile dialog

					try 
					{ 
						Controller.SaveSate(filename); 
						return true;
					}
					catch (Exception ex)
					{
						MessageBox.Show(ex.Message,Resource.CurrentResource[Resource.ERROR]);
						return false;
					}

				case DialogResult.No:
					return true;

				default: // Cancel
					return false;
			}
		}		

		private void CMMain_Closing(object sender, System.ComponentModel.CancelEventArgs e)
		{
			if (!AskSaveChangedProject())
			{
				e.Cancel = true;
				return;
			}

			if (saveProjectDialog.FileName!="")
				Settings.CurrentSettings.ProjectDialog_InitialDirectory=Path.GetDirectoryName(saveProjectDialog.FileName);

			if (saveFrameDialog.FileName!="")
				Settings.CurrentSettings.SaveFrameDialog_InitialDirectory=Path.GetDirectoryName(saveFrameDialog.FileName);

			// MRU speichern
			Settings.CurrentSettings.MRUFileEntries=recentProjects.Entries;

			// GUI-nderungen speichern
			Settings.CurrentSettings.SaveGUIPreset(Settings.CurrentSettings.PresetCurrentName,SerializeGUI());

			// Nur speichern wenn nicht im Batchmode
			// VERY IMPORTANT: If the main window is closed while minimized the window 
			// position MUST NOT be saved, otherwise PositionX + Y is -32000 and the 
			// next time Cuttermaran will start minimized with a complretely crippled GUI!
			if (!Controller.CmdCloseApp && this.WindowState != FormWindowState.Minimized)
				Settings.CurrentSettings.CommitChanges();
		}

		[DllImport("wininet.dll")]
		[return: MarshalAs(UnmanagedType.Bool)]
		private extern static bool InternetGetConnectedState( out int connectionDescription, int reservedValue ) ;
		/// <summary>
		/// Prfen ob eine Internetverbindung besteht
		/// </summary>
		private bool IsConnected
		{
			get
			{
				int connectionDescription = 0;
				return InternetGetConnectedState(out connectionDescription, 0);
			}
		}

		/// <summary>
		/// b_AskSaveChanges=true: if there are unsaved changes -> ask user if they are to be saved
		/// </summary>
		private bool LoadProjectFile(string filename, bool b_AskSaveChanges)
		{
			// before opening a new blank project ask if the user wants to save unsaved changes
			if (b_AskSaveChanges && !AskSaveChangedProject())
				return false;

			return Controller.LoadProject(new FileStream(filename,FileMode.Open));
		}

		private void menuExit_Click(object sender, System.EventArgs e)
		{
			Close();
		}

		private void menuItemSaveAs_Click(object sender, System.EventArgs e)
		{
			saveProjectDialog.FileName=Path.ChangeExtension(Controller.VideoStream.StreamName,saveProjectDialog.DefaultExt);
			if (saveProjectDialog.ShowDialog() == DialogResult.OK)
			{
				try
				{
					Controller.SaveSate(saveProjectDialog.FileName);
					recentProjects.AddItem(saveProjectDialog.FileName);
				}
				catch (Exception ex)
				{
					MessageBox.Show(ex.Message,Resource.CurrentResource[Resource.ERROR]);
				}
			}
		}

		private void menuItemSave_Click(object sender, System.EventArgs e)
		{
			if (Controller.StateFileName==string.Empty)
				menuItemSaveAs_Click(sender,e);
			else
			{
				try
				{
					Controller.SaveSate(Controller.StateFileName);
				}
				catch (Exception ex)
				{
					MessageBox.Show(ex.Message,Resource.CurrentResource[Resource.ERROR]);
				}
			}
		}

		private void menuItemOpen_Click(object sender, System.EventArgs e)
		{
			// before opening a new blank project ask if the user wants to save unsaved changes
			if (!AskSaveChangedProject())
				return;

			if (openProjectDialog.ShowDialog() == DialogResult.OK)
			{
				// b_AskSaveChanges=false because we already asked above
				if (LoadProjectFile(openProjectDialog.FileName, false))
					recentProjects.AddItem(openProjectDialog.FileName);
			}
		}

		private void Process_StartUpActions(object sender, System.EventArgs e)
		{
			// Dieses Event brauchen wir nur einmal!
			Application.Idle-=new EventHandler(this.Process_StartUpActions);

			Controller.InitializeApplication(true);

			try
			{
				CLI.ExecuteCommandLine(Controller);
			}
			catch (Exception exp)
			{
				MessageBox.Show(exp.Message,Resource.CurrentResource[Resource.ERROR]);
			}

			new CheckForUpdateDelegate(UpdateLookUp).BeginInvoke(null,null);
		}

		private delegate void CheckForUpdateDelegate();

		private void menuItemNew_Click(object sender, System.EventArgs e)
		{
			// before opening a new blank project ask if the user wants to save unsaved changes
			if (AskSaveChangedProject())
				Controller.InitializeApplication(true);
		}

		private void CMMain_KeyDown(object sender, System.Windows.Forms.KeyEventArgs e)
		{
			if (Controller.VideoStream!=null)
			{
				switch (e.KeyCode)
				{
					case Keys.PageDown:
						if (e.Shift)
							Controller.MoveToPicture(Navigation.NextPFrame);
						else if (e.Control)
							Controller.MoveToPicture(Navigation.NextBFrame);
						else if (e.Alt)
							Controller.MoveToPicture(Navigation.NextCustomStep);
						else
							Controller.MoveToPicture(Navigation.NextIFrame);
						e.Handled=true;
						break;
					case Keys.PageUp:
						if (e.Shift)
							Controller.MoveToPicture(Navigation.PrevPFrame);
						else if (e.Control)
							Controller.MoveToPicture(Navigation.PrevBFrame);
						else if (e.Alt)
							Controller.MoveToPicture(Navigation.PrevCustomStep);
						else
							Controller.MoveToPicture(Navigation.PrevIFrame);
						e.Handled=true;
						break;
					case Keys.Return:
						currentFrameControl.ReturnPressed();
						e.Handled=true;
						break;
				}
			}
		}

		// Das eigentliche Drop-Event
		public void CMMain_DragDrop(object sender, System.Windows.Forms.DragEventArgs e)
		{
			Array ar=e.Data.GetData(DataFormats.FileDrop) as Array;
			string filename=ar.GetValue(0) as string;
			this.Activate(); // Form nach vorne bringen
			switch(Helper.GetMediaType(filename))
			{
				case MediaType.Project:
					if (LoadProjectFile(filename, true))
						recentProjects.AddItem(openProjectDialog.FileName);
					return;
				case MediaType.LanguageFile:
				{
					// Sprachinstallation vorbereiten
					string dest=Path.Combine(Environment.GetFolderPath(Environment.SpecialFolder.ApplicationData),@"Cuttermaran");
					dest=Path.Combine(dest,Path.GetFileName(filename));
					File.Copy(filename,dest,true);
					Settings.CurrentSettings.Language=Path.GetFileName(filename).ToLower().Replace("lang_",string.Empty).Replace(".clf",string.Empty);
					MessageBox.Show(Resource.CurrentResource[Resource.RESTART],Resource.CurrentResource[Resource.INFO]);
					return;
				}
			}

			// Video (falls vorhanden) und Audio(s) laden
			string    videoFile  = null;
			ArrayList audioFiles = new ArrayList();
			foreach (string file in ar)
			{
				if (Helper.GetMediaType(file)==MediaType.Video)
					videoFile = file; // there is only one video file possible at once

				if (Helper.GetMediaType(file)==MediaType.Audio)
					audioFiles.Add(file);
			}
					
			Controller.LoadAudioAndVideo(videoFile, audioFiles);
		}

		// Prfen ob das Drag-Objekt eine Datei ist und ob die
		// Dateiextension untersttzt wird.
		public void CMMain_DragOver(object sender, System.Windows.Forms.DragEventArgs e)
		{
			e.Effect=DragDropEffects.None;
			if (e.Data.GetDataPresent(DataFormats.FileDrop))
			{
				Array ar=e.Data.GetData(DataFormats.FileDrop) as Array;
				if (ar==null)
					return;

				int videoCount=0;
				int audioCount=0;
				int cpfCount=0;
				int langCount=0;

				foreach (string filename in ar)
				{
					if (filename!=null)
					{
						switch(Helper.GetMediaType(filename))
						{
							case MediaType.Video:
								++videoCount;
								break;
							case MediaType.Project:
								++cpfCount;
								break;
							case MediaType.LanguageFile:
								++langCount;
								break;
							case MediaType.Audio:
								++audioCount;
								break;
							default:
								// Wird eine unsupportete Datei gefunden ist Ende!
								return;
						}
					}
				}

				if (	(cpfCount==1 && videoCount==0 && audioCount==0 && langCount==0) // Projektdatei
					||	(cpfCount==0 && videoCount==0 && audioCount==0 && langCount==1) // Languagedatei
					||	(cpfCount==0 && videoCount==0 && audioCount>0 && Controller.VideoStream!=null && langCount==0) // nur Audio, Video ist schon geladen
					||	(cpfCount==0 && videoCount==1 && audioCount>=0 && langCount==0) // Eine Video und n Audiodateien
					)
					e.Effect=DragDropEffects.Copy;
			}
		}

		protected override void OnMouseWheel(MouseEventArgs e)
		{
			if (!isInPlayMode && Controller.VideoStream!=null && Controller.VideoStream.PicturesCount>0)
			{
				if (Math.Sign(e.Delta)==-1)
				{
					if (ModifierKeys == Keys.Shift)
						Controller.MoveToPicture(Navigation.NextPFrame);
					else if (ModifierKeys == Keys.Control)
						Controller.MoveToPicture(Navigation.NextBFrame);
					else if (ModifierKeys == Keys.Alt)
						Controller.MoveToPicture(Navigation.NextCustomStep);
					else
						Controller.MoveToPicture(Navigation.NextIFrame);
				}
				if (Math.Sign(e.Delta)==+1)
				{
					if (ModifierKeys == Keys.Shift)
						Controller.MoveToPicture(Navigation.PrevPFrame);
					else if (ModifierKeys == Keys.Control)
						Controller.MoveToPicture(Navigation.PrevBFrame);
					else if (ModifierKeys == Keys.Alt)
						Controller.MoveToPicture(Navigation.PrevCustomStep);
					else
						Controller.MoveToPicture(Navigation.PrevIFrame);
				}
			}
		}

		private void OnSetDefaults(bool b_NewProject)
		{
			OnCutPointModified(0);
		}

		private void OnCutPointModified(int selectedCutIndex)
		{
			menuItemSave.Enabled=Controller.Cuts.Count>0;
			menuItemSaveAs.Enabled=Controller.Cuts.Count>0;
			menuCut.Enabled=Controller.Cuts.Count>0;
			menuCutAudioOnly.Enabled=Controller.Cuts.Count>0;
			menuPreview.Enabled=Controller.Cuts.Count>0;
		}

		private void OnAudioVideoOpened(bool videoOpened, bool audioOpened, bool reOpened)
		{
			if (!videoOpened || Controller.VideoStream == null)
				return;

			menuSaveFrame.Enabled=true;
			if (!Controller.CmdUnattended && !reOpened)
			{
				if (Controller.VideoStream.HasTempRefErros)
					MessageBox.Show(Resource.CurrentResource[Resource.TEMPREF_ERROR],Resource.CurrentResource[Resource.INFO]);
			
				if (Controller.VideoStream.HasGopWithoutSequence)
					MessageBox.Show(Resource.CurrentResource[Resource.GOP_SEQ_WARNING],Resource.CurrentResource[Resource.INFO]);
			}
		}

		private void menuSettings_Click(object sender, System.EventArgs e)
		{
			Controller.CallSettings(SerializeGUI());
		}

		private Settings.GUIPresetData SerializeGUI()
		{
			// Serialisierung und Deserialisierung immer mit "de-DE" !
			CultureInfo current=Thread.CurrentThread.CurrentCulture;
			try
			{
				Thread.CurrentThread.CurrentCulture = new CultureInfo("de-DE",false);

				byte [] guiData=_manager.SaveConfigToArray();
				Settings.GUIPresetData gpd=new Settings.GUIPresetData(this.Location,this.Size,guiData,null);
				// private Daten einsammeln
				gpd[contentStreamInfoCtrl.Control.GetType().Name]=((MainBaseControl)contentStreamInfoCtrl.Control).PersistData;
				gpd[contentCutListCtrl.Control.GetType().Name]=((MainBaseControl)contentCutListCtrl.Control).PersistData;
				gpd[contentResultCtrl.Control.GetType().Name]=((MainBaseControl)contentResultCtrl.Control).PersistData;
				return gpd;
			}
			finally
			{
				// und wieder auf default
				Thread.CurrentThread.CurrentCulture=current;
			}
		}

		private void DeserializeGUI(Settings.GUIPresetData gpd)
		{
			// Serialisierung und Deserialisierung immer mit "de-DE" !
			CultureInfo current=Thread.CurrentThread.CurrentCulture;
			try
			{
				Thread.CurrentThread.CurrentCulture = new CultureInfo("de-DE",false);

				_manager.LoadConfigFromArray(gpd.data);
				// private Daten setzen
				((MainBaseControl)contentStreamInfoCtrl.Control).PersistData=gpd[contentStreamInfoCtrl.Control.GetType().Name];
				((MainBaseControl)contentCutListCtrl.Control).PersistData=gpd[contentCutListCtrl.Control.GetType().Name];
				((MainBaseControl)contentResultCtrl.Control).PersistData=gpd[contentResultCtrl.Control.GetType().Name];
			}
			finally
			{
				// und wieder auf default
				Thread.CurrentThread.CurrentCulture=current;
			}
		}

		private void menuSaveFrame_Click(object sender, System.EventArgs e)
		{
			if (saveFrameDialog.ShowDialog(this)==DialogResult.OK)
			{
				System.Drawing.Imaging.ImageFormat format=null;
				switch (Path.GetExtension(saveFrameDialog.FileName).ToLower())
				{
					case ".jpg":
						format=System.Drawing.Imaging.ImageFormat.Jpeg;
						break;
					case ".bmp":
						format=System.Drawing.Imaging.ImageFormat.Bmp;
						break;
					case ".png":
						format=System.Drawing.Imaging.ImageFormat.Png;
						break;
					case ".gif":
						format=System.Drawing.Imaging.ImageFormat.Gif;
						break;
				}
				if (format!=null)
				{
					Bitmap bitm=null;
					bool newBMPCreated;
					if (Controller.CurrentDecoder.GetPicture(Controller.CurrentVideoPosition,ref bitm,true,out newBMPCreated))
					{
						bitm.Save(saveFrameDialog.FileName,format);
						bitm.Dispose(); // unmanaged Bitmap!
					}
				}
			}
		}

		// Called when shuttlebar becomes active or when Playback is stared
		private void OnGuiEnabled(Control sender, bool b_Enabled)
		{
			// fr MausradEvent
			isInPlayMode=!b_Enabled;

			// Mens
			foreach (MenuItem mi in mainMenu.MenuItems)
				mi.Enabled=b_Enabled;
		}

		private void menuCutAudioOnly_Click(object sender, System.EventArgs e)
		{
			// TODO: Pfad sinnvoll vorbelegen, (z.B. aus der Recentlist!)
			//saveResultAudioDialog.InitialDirectory=Path.GetDirectoryName(Settings.SaveDialog_InitialDirectory);
			saveResultAudioDialog.FileName=Path.GetFileNameWithoutExtension(Controller.Cuts[0].AudioNames[0])+"_cut";

			if (saveResultAudioDialog.ShowDialog(this)==DialogResult.OK)
			{
				string CutFileNameWOExt=Path.Combine(Path.GetDirectoryName(saveResultAudioDialog.FileName),Path.GetFileNameWithoutExtension(saveResultAudioDialog.FileName));
				Controller.CutAudioOnly(CutFileNameWOExt);
			}
		}

		private void menuCut_Click(object sender, System.EventArgs e)
		{
			CutDialog cd=new CutDialog(Controller);
			DialogResult res=cd.ShowDialog();
			if (res==DialogResult.OK || res==DialogResult.Yes)
				Controller.ProcessCut(Controller.Cuts,cd.CutFileName,res==DialogResult.Yes,false);
		}

		private void menuPreview_Click(object sender, System.EventArgs e)
		{
			Controller.PreviewAll();
		}

		private void SwitchContentMenus()
		{
			menuItemWindowCutList.Checked=contentCutListCtrl!=null && contentCutListCtrl.Visible;
			menuItemWindowScrollBar.Checked=contentScrollCtrl!=null && contentScrollCtrl.Visible;
			menuItemWindowStreamInfo.Checked=contentStreamInfoCtrl!=null && contentStreamInfoCtrl.Visible;
			menuItemWindowChapterList.Checked=contentChapterListCtrl!=null && contentChapterListCtrl.Visible;
			menuItemWindowCutOut.Checked=contentCurrentCutOutCtrl!=null && contentCurrentCutOutCtrl.Visible;
			menuItemWindowNavigation.Checked=contentNavgationCtrl!=null && contentNavgationCtrl.Visible;
			menuItemWindowResult.Checked=contentResultCtrl!=null && contentResultCtrl.Visible;
			menuItemWindowMarker.Checked=contentMarkerCtrl!=null && contentMarkerCtrl.Visible;
		}

		private void SwitchVisibility(Content cont)
		{
			if (cont != null)
			{
				if (cont.Visible)
					_manager.HideContent(cont);
				else
					_manager.ShowContent(cont);
			}
			SwitchContentMenus();
		}

		private void menuItemWindowStreamInfo_Click(object sender, System.EventArgs e)
		{
			SwitchVisibility(contentStreamInfoCtrl);
		}

		private void menuItemWindowCutList_Click(object sender, System.EventArgs e)
		{
			SwitchVisibility(contentCutListCtrl);
		}

		private void menuItemWindowChapterList_Click(object sender, System.EventArgs e)
		{
			SwitchVisibility(contentChapterListCtrl);
		}

		private void menuItemWindowResult_Click(object sender, System.EventArgs e)
		{
			SwitchVisibility(contentResultCtrl);
		}

		private void menuItemWindowCutOut_Click(object sender, System.EventArgs e)
		{
			SwitchVisibility(contentCurrentCutOutCtrl);
		}

		private void menuItemWindowNavigation_Click(object sender, System.EventArgs e)
		{
			SwitchVisibility(contentNavgationCtrl);
		}

		private void menuItemWindowScrollBar_Click(object sender, System.EventArgs e)
		{
			SwitchVisibility(contentScrollCtrl);
		}

		private void menuItemWindowMarker_Click(object sender, System.EventArgs e)
		{
			SwitchVisibility(contentMarkerCtrl);
		}

		private void OnSettingsChanged()
		{
			// Kopieren aus der config
			Helper.useNTSCDropFrame=Settings.CurrentSettings.UseNTSCDropFrame;

			// Men neu aufbauen
			CreatePresetMenu();
		}

		private void LoadInternalGUISetting(string name)
		{
			Settings.GUIPresetData gpd=Settings.CurrentSettings.LoadInternalGUIPreset(name);
			DeserializeGUI(gpd);
			this.Size=gpd.sz;
			this.Location=new Point(SystemInformation.WorkingArea.Width/2-gpd.sz.Width/2,
				SystemInformation.WorkingArea.Height/2-gpd.sz.Height/2);
			SwitchContentMenus();
		}

		private bool LoadGUISetting(string name)
		{
			Settings.GUIPresetData gpd=Settings.CurrentSettings.LoadGUIPreset(name);
			if (gpd.data!=null)
			{
				DeserializeGUI(gpd);
				this.Location=gpd.pt;
				this.Size=gpd.sz;
				SwitchContentMenus();
			}
			return gpd.data!=null;
		}

		private void menuItemPrDefault_Click(object sender, System.EventArgs e)
		{
			LoadInternalGUISetting("default");
		}

		private void menuItemPrPlay_Click(object sender, System.EventArgs e)
		{
			LoadInternalGUISetting("play");
		}

		private void CreatePresetMenu()
		{
			// Alle User-Defined Eintrge lschen ...
			while (menuItemPresets.MenuItems.Count>3)
				menuItemPresets.MenuItems.RemoveAt(3);
			// ... und neu anlegen
			string [] userDef=Settings.CurrentSettings.GetPresets();
			foreach (string name in userDef)
				menuItemPresets.MenuItems.Add(name,new EventHandler(OnUserDefPresetClicked));
			// Trenner anzeigen?
			menuItemUserDefined.Visible=userDef.Length>0;
		}

		private void OnUserDefPresetClicked(object sender, System.EventArgs e)
		{
			MenuItem menu=(MenuItem)sender;
			LoadGUISetting(menu.Text);
		}

		private void _manager_ContentShown(Content c, EventArgs cea)
		{
			SwitchContentMenus();
		}

		private void _manager_ContentHidden(Content c, EventArgs cea)
		{
			SwitchContentMenus();
		}

		private void menuAllowGUIResize_Click(object sender, System.EventArgs e)
		{
			Settings.CurrentSettings.AllowGUIResize = !Settings.CurrentSettings.AllowGUIResize;
			menuAllowGUIResize.Checked=Settings.CurrentSettings.AllowGUIResize;
		}

		private void menuAllowGUIFloating_Click(object sender, System.EventArgs e)
		{
			Settings.CurrentSettings.AllowGUIFloating=!Settings.CurrentSettings.AllowGUIFloating;
			menuAllowGUIFloating.Checked=Settings.CurrentSettings.AllowGUIFloating;
		}

		// ---------------------- VIDEO TAB HANDLING ----------------------
		/// <summary>
		/// This is called when the user clicked the "New Video Tab" 
		/// button in StreamInfoCtrl
		/// </summary>
		public void AddNewVideoTab()
		{
			WindowContentTabbed i_Tab = (WindowContentTabbed) contentStreamInfoCtrl.ParentWindowContent;

			// If display of StreamInfoCtrl is turned off and more than one video file are loaded
			// we MUST enable display of StreamInfoCtrl here otherwise the second and further tabs
			// will be missing when StreamInfoCtrl becomes enabled later
			if (i_Tab == null) 
			{
				SwitchVisibility(contentStreamInfoCtrl);
				i_Tab = (WindowContentTabbed) contentStreamInfoCtrl.ParentWindowContent;
			}

			Content i_NewContent;
			AddControl(new StreamInfoCtrl(), Resource.WINDOW_STREAM_INFO, State.DockTop, i_Tab, false, 0, out i_NewContent);
			mi_VideoTabs.AddedNewTab(i_NewContent, true);

			Controller.InitializeApplication(false);
		}

		/// <summary>
		/// This is called when the user clicked the "Close Video Tab" 
		/// button in StreamInfoCtrl. Video Data is disposed
		/// </summary>
		public void RemoveVideoTab(StreamInfoCtrl sender)
		{
			// Never remove the LAST tab!
			if (mi_VideoTabs.Count <= 1)
				return;

			// Ask user to delete relates cuts from cutlist
			if (!Controller.CheckVideoInUse())
				return;

			mi_VideoTabs.RemoveTab(sender);
			// contentStreamInfoCtrl must never become invalid!
			contentStreamInfoCtrl = mi_VideoTabs.GetTabContent(0);
		}

		/// <summary>
		/// This is called when a new project is opened
		/// All tabs except one are removed. Video Data is disposed
		/// </summary>
		public void RemoveAllVideoTabs()
		{
			if (mi_VideoTabs != null)
			{
				mi_VideoTabs.RemoveAllTabs();
				// contentStreamInfoCtrl must never become invalid!
				contentStreamInfoCtrl = mi_VideoTabs.GetTabContent(0);
			}
		}

		/// <summary>
		/// Selects the video tab which holds the given mp2 file (full path)
		/// </summary>
		public void SelectVideoTab(string s_VideoFile)
		{
			for (int T=0; T<mi_VideoTabs.Count; T++)
			{
				StreamInfoCtrl i_Ctrl = (StreamInfoCtrl) mi_VideoTabs.GetTabContent(T).Control;
				if (string.Compare(i_Ctrl.VideoFile, s_VideoFile, true) == 0)
				{
					mi_VideoTabs.SelectTab(T);
					break;
				}
			}
		}

		// ----------------------------------------------------------------
	}
}
