/*
 * Cuttermaran - The Mpeg Cutter
 * 
 * Copyright (C) 2003-2006  Tobias Arnold (cuttermaran@gmx.net)
 * 
 * This file is part of cuttermaran, a free MPEG cut program.
 * See http://www.cuttermaran.de for updates.
 *
 * This program is free software; you can redistribute it and/or modify it 
 * under the terms of the GNU General Public License as published by the 
 * Free Software Foundation; either version 2 of the License, or 
 * (at your option) any later version. 
 * 
 * This program is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the 
 * GNU General Public License for more details. 
 * 
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */

using System;
using System.IO;
using System.Collections;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Windows.Forms;
using Configuration;
using Coremoran.AVStreams;
using Coremoran.Common;
using Coremoran.Algorithms;

namespace GUI.MainForm
{
	/// <summary>
	/// Summary description for ChapterListCtrl.
	/// </summary>
	public class ChapterListCtrl : MainBaseControl
	{
		private System.Windows.Forms.Panel panelChapter;
		private System.Windows.Forms.ListView lwResultChapters;
		private System.Windows.Forms.ColumnHeader columnHeader16;
		private System.Windows.Forms.ColumnHeader columnHeader15;
		private System.Windows.Forms.ColumnHeader columnHeader17;
		private System.Windows.Forms.Panel panelControl2;
		private System.Windows.Forms.Button butDelResultChapter;
		private System.Windows.Forms.ColumnHeader columnHeader14;
		private System.Windows.Forms.Panel panelTempChapter;
		private System.Windows.Forms.ListView lwTempChapters;
		private System.Windows.Forms.Panel panelControl1;
		private System.Windows.Forms.Button butDelTempChapter;
		private System.Windows.Forms.Button butApplyAutoChapters;
		private System.Windows.Forms.Label label2;
		private System.Windows.Forms.NumericUpDown numAutoChapters;
		private System.Windows.Forms.Label label1;
		private System.Windows.Forms.ContextMenu cmChapter;
		private System.Windows.Forms.MenuItem menuShowChapterFrame;
		private System.Windows.Forms.MenuItem menuItem12;
		private System.Windows.Forms.MenuItem menuRemoveChapterFrame;
		private System.Windows.Forms.MenuItem menuRemoveAllChapterFrames;
		/// <summary> 
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;

		#region ctor / Dispose

		public ChapterListCtrl()
		{
			// This call is required by the Windows.Forms Form Designer.
			InitializeComponent();

			State.SetDefaults+=new SetDefaultsDelegate(OnSetDefaults);
			State.CutPointModified+=new CutPointModifiedDelegate(OnCutPointModified);
			State.CurrentCutModified+=new CurrentCutModifiedDelegate(OnCurrentCutModified);
			State.SettingsChanged+=new SettingsChangedDelegate(OnSettingsChanged);
		}

		/// <summary> 
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#endregion

		#region Component Designer generated code
		/// <summary> 
		/// Required method for Designer support - do not modify 
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(ChapterListCtrl));
			this.panelChapter = new System.Windows.Forms.Panel();
			this.lwResultChapters = new System.Windows.Forms.ListView();
			this.columnHeader16 = new System.Windows.Forms.ColumnHeader();
			this.columnHeader15 = new System.Windows.Forms.ColumnHeader();
			this.columnHeader17 = new System.Windows.Forms.ColumnHeader();
			this.cmChapter = new System.Windows.Forms.ContextMenu();
			this.menuShowChapterFrame = new System.Windows.Forms.MenuItem();
			this.menuItem12 = new System.Windows.Forms.MenuItem();
			this.menuRemoveChapterFrame = new System.Windows.Forms.MenuItem();
			this.menuRemoveAllChapterFrames = new System.Windows.Forms.MenuItem();
			this.panelControl2 = new System.Windows.Forms.Panel();
			this.butDelResultChapter = new System.Windows.Forms.Button();
			this.columnHeader14 = new System.Windows.Forms.ColumnHeader();
			this.panelTempChapter = new System.Windows.Forms.Panel();
			this.lwTempChapters = new System.Windows.Forms.ListView();
			this.panelControl1 = new System.Windows.Forms.Panel();
			this.butDelTempChapter = new System.Windows.Forms.Button();
			this.butApplyAutoChapters = new System.Windows.Forms.Button();
			this.label2 = new System.Windows.Forms.Label();
			this.numAutoChapters = new System.Windows.Forms.NumericUpDown();
			this.label1 = new System.Windows.Forms.Label();
			this.panelChapter.SuspendLayout();
			this.panelControl2.SuspendLayout();
			this.panelTempChapter.SuspendLayout();
			this.panelControl1.SuspendLayout();
			((System.ComponentModel.ISupportInitialize)(this.numAutoChapters)).BeginInit();
			this.SuspendLayout();
			// 
			// panelChapter
			// 
			this.panelChapter.AccessibleDescription = resources.GetString("panelChapter.AccessibleDescription");
			this.panelChapter.AccessibleName = resources.GetString("panelChapter.AccessibleName");
			this.panelChapter.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("panelChapter.Anchor")));
			this.panelChapter.AutoScroll = ((bool)(resources.GetObject("panelChapter.AutoScroll")));
			this.panelChapter.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("panelChapter.AutoScrollMargin")));
			this.panelChapter.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("panelChapter.AutoScrollMinSize")));
			this.panelChapter.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("panelChapter.BackgroundImage")));
			this.panelChapter.Controls.Add(this.lwResultChapters);
			this.panelChapter.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("panelChapter.Dock")));
			this.panelChapter.Enabled = ((bool)(resources.GetObject("panelChapter.Enabled")));
			this.panelChapter.Font = ((System.Drawing.Font)(resources.GetObject("panelChapter.Font")));
			this.panelChapter.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("panelChapter.ImeMode")));
			this.panelChapter.Location = ((System.Drawing.Point)(resources.GetObject("panelChapter.Location")));
			this.panelChapter.Name = "panelChapter";
			this.panelChapter.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("panelChapter.RightToLeft")));
			this.panelChapter.Size = ((System.Drawing.Size)(resources.GetObject("panelChapter.Size")));
			this.panelChapter.TabIndex = ((int)(resources.GetObject("panelChapter.TabIndex")));
			this.panelChapter.Text = resources.GetString("panelChapter.Text");
			this.panelChapter.Visible = ((bool)(resources.GetObject("panelChapter.Visible")));
			// 
			// lwResultChapters
			// 
			this.lwResultChapters.AccessibleDescription = resources.GetString("lwResultChapters.AccessibleDescription");
			this.lwResultChapters.AccessibleName = resources.GetString("lwResultChapters.AccessibleName");
			this.lwResultChapters.Alignment = ((System.Windows.Forms.ListViewAlignment)(resources.GetObject("lwResultChapters.Alignment")));
			this.lwResultChapters.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("lwResultChapters.Anchor")));
			this.lwResultChapters.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("lwResultChapters.BackgroundImage")));
			this.lwResultChapters.Columns.AddRange(new System.Windows.Forms.ColumnHeader[] {
																							   this.columnHeader16,
																							   this.columnHeader15,
																							   this.columnHeader17});
			this.lwResultChapters.ContextMenu = this.cmChapter;
			this.lwResultChapters.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("lwResultChapters.Dock")));
			this.lwResultChapters.Enabled = ((bool)(resources.GetObject("lwResultChapters.Enabled")));
			this.lwResultChapters.Font = ((System.Drawing.Font)(resources.GetObject("lwResultChapters.Font")));
			this.lwResultChapters.FullRowSelect = true;
			this.lwResultChapters.HeaderStyle = System.Windows.Forms.ColumnHeaderStyle.Nonclickable;
			this.lwResultChapters.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("lwResultChapters.ImeMode")));
			this.lwResultChapters.LabelWrap = ((bool)(resources.GetObject("lwResultChapters.LabelWrap")));
			this.lwResultChapters.Location = ((System.Drawing.Point)(resources.GetObject("lwResultChapters.Location")));
			this.lwResultChapters.Name = "lwResultChapters";
			this.lwResultChapters.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("lwResultChapters.RightToLeft")));
			this.lwResultChapters.Size = ((System.Drawing.Size)(resources.GetObject("lwResultChapters.Size")));
			this.lwResultChapters.TabIndex = ((int)(resources.GetObject("lwResultChapters.TabIndex")));
			this.lwResultChapters.Text = resources.GetString("lwResultChapters.Text");
			this.lwResultChapters.View = System.Windows.Forms.View.Details;
			this.lwResultChapters.Visible = ((bool)(resources.GetObject("lwResultChapters.Visible")));
			this.lwResultChapters.KeyDown += new System.Windows.Forms.KeyEventHandler(this.lwResultChapters_KeyDown);
			this.lwResultChapters.DoubleClick += new System.EventHandler(this.lwResultChapters_DoubleClick);
			// 
			// columnHeader16
			// 
			this.columnHeader16.Text = resources.GetString("columnHeader16.Text");
			this.columnHeader16.TextAlign = ((System.Windows.Forms.HorizontalAlignment)(resources.GetObject("columnHeader16.TextAlign")));
			this.columnHeader16.Width = ((int)(resources.GetObject("columnHeader16.Width")));
			// 
			// columnHeader15
			// 
			this.columnHeader15.Text = resources.GetString("columnHeader15.Text");
			this.columnHeader15.TextAlign = ((System.Windows.Forms.HorizontalAlignment)(resources.GetObject("columnHeader15.TextAlign")));
			this.columnHeader15.Width = ((int)(resources.GetObject("columnHeader15.Width")));
			// 
			// columnHeader17
			// 
			this.columnHeader17.Text = resources.GetString("columnHeader17.Text");
			this.columnHeader17.TextAlign = ((System.Windows.Forms.HorizontalAlignment)(resources.GetObject("columnHeader17.TextAlign")));
			this.columnHeader17.Width = ((int)(resources.GetObject("columnHeader17.Width")));
			// 
			// cmChapter
			// 
			this.cmChapter.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
																					  this.menuShowChapterFrame,
																					  this.menuItem12,
																					  this.menuRemoveChapterFrame,
																					  this.menuRemoveAllChapterFrames});
			this.cmChapter.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("cmChapter.RightToLeft")));
			this.cmChapter.Popup += new System.EventHandler(this.cmChapter_Popup);
			// 
			// menuShowChapterFrame
			// 
			this.menuShowChapterFrame.Enabled = ((bool)(resources.GetObject("menuShowChapterFrame.Enabled")));
			this.menuShowChapterFrame.Index = 0;
			this.menuShowChapterFrame.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuShowChapterFrame.Shortcut")));
			this.menuShowChapterFrame.ShowShortcut = ((bool)(resources.GetObject("menuShowChapterFrame.ShowShortcut")));
			this.menuShowChapterFrame.Text = resources.GetString("menuShowChapterFrame.Text");
			this.menuShowChapterFrame.Visible = ((bool)(resources.GetObject("menuShowChapterFrame.Visible")));
			this.menuShowChapterFrame.Click += new System.EventHandler(this.menuShowChapterFrame_Click);
			// 
			// menuItem12
			// 
			this.menuItem12.Enabled = ((bool)(resources.GetObject("menuItem12.Enabled")));
			this.menuItem12.Index = 1;
			this.menuItem12.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuItem12.Shortcut")));
			this.menuItem12.ShowShortcut = ((bool)(resources.GetObject("menuItem12.ShowShortcut")));
			this.menuItem12.Text = resources.GetString("menuItem12.Text");
			this.menuItem12.Visible = ((bool)(resources.GetObject("menuItem12.Visible")));
			// 
			// menuRemoveChapterFrame
			// 
			this.menuRemoveChapterFrame.Enabled = ((bool)(resources.GetObject("menuRemoveChapterFrame.Enabled")));
			this.menuRemoveChapterFrame.Index = 2;
			this.menuRemoveChapterFrame.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuRemoveChapterFrame.Shortcut")));
			this.menuRemoveChapterFrame.ShowShortcut = ((bool)(resources.GetObject("menuRemoveChapterFrame.ShowShortcut")));
			this.menuRemoveChapterFrame.Text = resources.GetString("menuRemoveChapterFrame.Text");
			this.menuRemoveChapterFrame.Visible = ((bool)(resources.GetObject("menuRemoveChapterFrame.Visible")));
			this.menuRemoveChapterFrame.Click += new System.EventHandler(this.menuRemoveChapterFrame_Click);
			// 
			// menuRemoveAllChapterFrames
			// 
			this.menuRemoveAllChapterFrames.Enabled = ((bool)(resources.GetObject("menuRemoveAllChapterFrames.Enabled")));
			this.menuRemoveAllChapterFrames.Index = 3;
			this.menuRemoveAllChapterFrames.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuRemoveAllChapterFrames.Shortcut")));
			this.menuRemoveAllChapterFrames.ShowShortcut = ((bool)(resources.GetObject("menuRemoveAllChapterFrames.ShowShortcut")));
			this.menuRemoveAllChapterFrames.Text = resources.GetString("menuRemoveAllChapterFrames.Text");
			this.menuRemoveAllChapterFrames.Visible = ((bool)(resources.GetObject("menuRemoveAllChapterFrames.Visible")));
			this.menuRemoveAllChapterFrames.Click += new System.EventHandler(this.menuRemoveAllChapterFrames_Click);
			// 
			// panelControl2
			// 
			this.panelControl2.AccessibleDescription = resources.GetString("panelControl2.AccessibleDescription");
			this.panelControl2.AccessibleName = resources.GetString("panelControl2.AccessibleName");
			this.panelControl2.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("panelControl2.Anchor")));
			this.panelControl2.AutoScroll = ((bool)(resources.GetObject("panelControl2.AutoScroll")));
			this.panelControl2.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("panelControl2.AutoScrollMargin")));
			this.panelControl2.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("panelControl2.AutoScrollMinSize")));
			this.panelControl2.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("panelControl2.BackgroundImage")));
			this.panelControl2.Controls.Add(this.butDelResultChapter);
			this.panelControl2.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("panelControl2.Dock")));
			this.panelControl2.Enabled = ((bool)(resources.GetObject("panelControl2.Enabled")));
			this.panelControl2.Font = ((System.Drawing.Font)(resources.GetObject("panelControl2.Font")));
			this.panelControl2.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("panelControl2.ImeMode")));
			this.panelControl2.Location = ((System.Drawing.Point)(resources.GetObject("panelControl2.Location")));
			this.panelControl2.Name = "panelControl2";
			this.panelControl2.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("panelControl2.RightToLeft")));
			this.panelControl2.Size = ((System.Drawing.Size)(resources.GetObject("panelControl2.Size")));
			this.panelControl2.TabIndex = ((int)(resources.GetObject("panelControl2.TabIndex")));
			this.panelControl2.Text = resources.GetString("panelControl2.Text");
			this.panelControl2.Visible = ((bool)(resources.GetObject("panelControl2.Visible")));
			// 
			// butDelResultChapter
			// 
			this.butDelResultChapter.AccessibleDescription = resources.GetString("butDelResultChapter.AccessibleDescription");
			this.butDelResultChapter.AccessibleName = resources.GetString("butDelResultChapter.AccessibleName");
			this.butDelResultChapter.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butDelResultChapter.Anchor")));
			this.butDelResultChapter.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butDelResultChapter.BackgroundImage")));
			this.butDelResultChapter.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butDelResultChapter.Dock")));
			this.butDelResultChapter.Enabled = ((bool)(resources.GetObject("butDelResultChapter.Enabled")));
			this.butDelResultChapter.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butDelResultChapter.FlatStyle")));
			this.butDelResultChapter.Font = ((System.Drawing.Font)(resources.GetObject("butDelResultChapter.Font")));
			this.butDelResultChapter.Image = ((System.Drawing.Image)(resources.GetObject("butDelResultChapter.Image")));
			this.butDelResultChapter.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butDelResultChapter.ImageAlign")));
			this.butDelResultChapter.ImageIndex = ((int)(resources.GetObject("butDelResultChapter.ImageIndex")));
			this.butDelResultChapter.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butDelResultChapter.ImeMode")));
			this.butDelResultChapter.Location = ((System.Drawing.Point)(resources.GetObject("butDelResultChapter.Location")));
			this.butDelResultChapter.Name = "butDelResultChapter";
			this.butDelResultChapter.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butDelResultChapter.RightToLeft")));
			this.butDelResultChapter.Size = ((System.Drawing.Size)(resources.GetObject("butDelResultChapter.Size")));
			this.butDelResultChapter.TabIndex = ((int)(resources.GetObject("butDelResultChapter.TabIndex")));
			this.butDelResultChapter.Text = resources.GetString("butDelResultChapter.Text");
			this.butDelResultChapter.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butDelResultChapter.TextAlign")));
			this.butDelResultChapter.Visible = ((bool)(resources.GetObject("butDelResultChapter.Visible")));
			this.butDelResultChapter.Click += new System.EventHandler(this.butDelResultChapter_Click);
			// 
			// columnHeader14
			// 
			this.columnHeader14.Text = resources.GetString("columnHeader14.Text");
			this.columnHeader14.TextAlign = ((System.Windows.Forms.HorizontalAlignment)(resources.GetObject("columnHeader14.TextAlign")));
			this.columnHeader14.Width = ((int)(resources.GetObject("columnHeader14.Width")));
			// 
			// panelTempChapter
			// 
			this.panelTempChapter.AccessibleDescription = resources.GetString("panelTempChapter.AccessibleDescription");
			this.panelTempChapter.AccessibleName = resources.GetString("panelTempChapter.AccessibleName");
			this.panelTempChapter.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("panelTempChapter.Anchor")));
			this.panelTempChapter.AutoScroll = ((bool)(resources.GetObject("panelTempChapter.AutoScroll")));
			this.panelTempChapter.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("panelTempChapter.AutoScrollMargin")));
			this.panelTempChapter.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("panelTempChapter.AutoScrollMinSize")));
			this.panelTempChapter.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("panelTempChapter.BackgroundImage")));
			this.panelTempChapter.Controls.Add(this.lwTempChapters);
			this.panelTempChapter.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("panelTempChapter.Dock")));
			this.panelTempChapter.Enabled = ((bool)(resources.GetObject("panelTempChapter.Enabled")));
			this.panelTempChapter.Font = ((System.Drawing.Font)(resources.GetObject("panelTempChapter.Font")));
			this.panelTempChapter.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("panelTempChapter.ImeMode")));
			this.panelTempChapter.Location = ((System.Drawing.Point)(resources.GetObject("panelTempChapter.Location")));
			this.panelTempChapter.Name = "panelTempChapter";
			this.panelTempChapter.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("panelTempChapter.RightToLeft")));
			this.panelTempChapter.Size = ((System.Drawing.Size)(resources.GetObject("panelTempChapter.Size")));
			this.panelTempChapter.TabIndex = ((int)(resources.GetObject("panelTempChapter.TabIndex")));
			this.panelTempChapter.Text = resources.GetString("panelTempChapter.Text");
			this.panelTempChapter.Visible = ((bool)(resources.GetObject("panelTempChapter.Visible")));
			// 
			// lwTempChapters
			// 
			this.lwTempChapters.AccessibleDescription = resources.GetString("lwTempChapters.AccessibleDescription");
			this.lwTempChapters.AccessibleName = resources.GetString("lwTempChapters.AccessibleName");
			this.lwTempChapters.Alignment = ((System.Windows.Forms.ListViewAlignment)(resources.GetObject("lwTempChapters.Alignment")));
			this.lwTempChapters.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("lwTempChapters.Anchor")));
			this.lwTempChapters.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("lwTempChapters.BackgroundImage")));
			this.lwTempChapters.Columns.AddRange(new System.Windows.Forms.ColumnHeader[] {
																							 this.columnHeader14});
			this.lwTempChapters.ContextMenu = this.cmChapter;
			this.lwTempChapters.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("lwTempChapters.Dock")));
			this.lwTempChapters.Enabled = ((bool)(resources.GetObject("lwTempChapters.Enabled")));
			this.lwTempChapters.Font = ((System.Drawing.Font)(resources.GetObject("lwTempChapters.Font")));
			this.lwTempChapters.FullRowSelect = true;
			this.lwTempChapters.HeaderStyle = System.Windows.Forms.ColumnHeaderStyle.Nonclickable;
			this.lwTempChapters.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("lwTempChapters.ImeMode")));
			this.lwTempChapters.LabelWrap = ((bool)(resources.GetObject("lwTempChapters.LabelWrap")));
			this.lwTempChapters.Location = ((System.Drawing.Point)(resources.GetObject("lwTempChapters.Location")));
			this.lwTempChapters.MultiSelect = false;
			this.lwTempChapters.Name = "lwTempChapters";
			this.lwTempChapters.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("lwTempChapters.RightToLeft")));
			this.lwTempChapters.Size = ((System.Drawing.Size)(resources.GetObject("lwTempChapters.Size")));
			this.lwTempChapters.TabIndex = ((int)(resources.GetObject("lwTempChapters.TabIndex")));
			this.lwTempChapters.Text = resources.GetString("lwTempChapters.Text");
			this.lwTempChapters.View = System.Windows.Forms.View.Details;
			this.lwTempChapters.Visible = ((bool)(resources.GetObject("lwTempChapters.Visible")));
			this.lwTempChapters.KeyDown += new System.Windows.Forms.KeyEventHandler(this.lwTempChapters_KeyDown);
			this.lwTempChapters.DoubleClick += new System.EventHandler(this.lwTempChapters_DoubleClick);
			// 
			// panelControl1
			// 
			this.panelControl1.AccessibleDescription = resources.GetString("panelControl1.AccessibleDescription");
			this.panelControl1.AccessibleName = resources.GetString("panelControl1.AccessibleName");
			this.panelControl1.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("panelControl1.Anchor")));
			this.panelControl1.AutoScroll = ((bool)(resources.GetObject("panelControl1.AutoScroll")));
			this.panelControl1.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("panelControl1.AutoScrollMargin")));
			this.panelControl1.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("panelControl1.AutoScrollMinSize")));
			this.panelControl1.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("panelControl1.BackgroundImage")));
			this.panelControl1.Controls.Add(this.butDelTempChapter);
			this.panelControl1.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("panelControl1.Dock")));
			this.panelControl1.Enabled = ((bool)(resources.GetObject("panelControl1.Enabled")));
			this.panelControl1.Font = ((System.Drawing.Font)(resources.GetObject("panelControl1.Font")));
			this.panelControl1.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("panelControl1.ImeMode")));
			this.panelControl1.Location = ((System.Drawing.Point)(resources.GetObject("panelControl1.Location")));
			this.panelControl1.Name = "panelControl1";
			this.panelControl1.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("panelControl1.RightToLeft")));
			this.panelControl1.Size = ((System.Drawing.Size)(resources.GetObject("panelControl1.Size")));
			this.panelControl1.TabIndex = ((int)(resources.GetObject("panelControl1.TabIndex")));
			this.panelControl1.Text = resources.GetString("panelControl1.Text");
			this.panelControl1.Visible = ((bool)(resources.GetObject("panelControl1.Visible")));
			// 
			// butDelTempChapter
			// 
			this.butDelTempChapter.AccessibleDescription = resources.GetString("butDelTempChapter.AccessibleDescription");
			this.butDelTempChapter.AccessibleName = resources.GetString("butDelTempChapter.AccessibleName");
			this.butDelTempChapter.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butDelTempChapter.Anchor")));
			this.butDelTempChapter.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butDelTempChapter.BackgroundImage")));
			this.butDelTempChapter.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butDelTempChapter.Dock")));
			this.butDelTempChapter.Enabled = ((bool)(resources.GetObject("butDelTempChapter.Enabled")));
			this.butDelTempChapter.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butDelTempChapter.FlatStyle")));
			this.butDelTempChapter.Font = ((System.Drawing.Font)(resources.GetObject("butDelTempChapter.Font")));
			this.butDelTempChapter.Image = ((System.Drawing.Image)(resources.GetObject("butDelTempChapter.Image")));
			this.butDelTempChapter.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butDelTempChapter.ImageAlign")));
			this.butDelTempChapter.ImageIndex = ((int)(resources.GetObject("butDelTempChapter.ImageIndex")));
			this.butDelTempChapter.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butDelTempChapter.ImeMode")));
			this.butDelTempChapter.Location = ((System.Drawing.Point)(resources.GetObject("butDelTempChapter.Location")));
			this.butDelTempChapter.Name = "butDelTempChapter";
			this.butDelTempChapter.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butDelTempChapter.RightToLeft")));
			this.butDelTempChapter.Size = ((System.Drawing.Size)(resources.GetObject("butDelTempChapter.Size")));
			this.butDelTempChapter.TabIndex = ((int)(resources.GetObject("butDelTempChapter.TabIndex")));
			this.butDelTempChapter.Text = resources.GetString("butDelTempChapter.Text");
			this.butDelTempChapter.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butDelTempChapter.TextAlign")));
			this.butDelTempChapter.Visible = ((bool)(resources.GetObject("butDelTempChapter.Visible")));
			this.butDelTempChapter.Click += new System.EventHandler(this.butDelTempChapter_Click);
			// 
			// butApplyAutoChapters
			// 
			this.butApplyAutoChapters.AccessibleDescription = resources.GetString("butApplyAutoChapters.AccessibleDescription");
			this.butApplyAutoChapters.AccessibleName = resources.GetString("butApplyAutoChapters.AccessibleName");
			this.butApplyAutoChapters.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butApplyAutoChapters.Anchor")));
			this.butApplyAutoChapters.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butApplyAutoChapters.BackgroundImage")));
			this.butApplyAutoChapters.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butApplyAutoChapters.Dock")));
			this.butApplyAutoChapters.Enabled = ((bool)(resources.GetObject("butApplyAutoChapters.Enabled")));
			this.butApplyAutoChapters.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butApplyAutoChapters.FlatStyle")));
			this.butApplyAutoChapters.Font = ((System.Drawing.Font)(resources.GetObject("butApplyAutoChapters.Font")));
			this.butApplyAutoChapters.Image = ((System.Drawing.Image)(resources.GetObject("butApplyAutoChapters.Image")));
			this.butApplyAutoChapters.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butApplyAutoChapters.ImageAlign")));
			this.butApplyAutoChapters.ImageIndex = ((int)(resources.GetObject("butApplyAutoChapters.ImageIndex")));
			this.butApplyAutoChapters.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butApplyAutoChapters.ImeMode")));
			this.butApplyAutoChapters.Location = ((System.Drawing.Point)(resources.GetObject("butApplyAutoChapters.Location")));
			this.butApplyAutoChapters.Name = "butApplyAutoChapters";
			this.butApplyAutoChapters.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butApplyAutoChapters.RightToLeft")));
			this.butApplyAutoChapters.Size = ((System.Drawing.Size)(resources.GetObject("butApplyAutoChapters.Size")));
			this.butApplyAutoChapters.TabIndex = ((int)(resources.GetObject("butApplyAutoChapters.TabIndex")));
			this.butApplyAutoChapters.Text = resources.GetString("butApplyAutoChapters.Text");
			this.butApplyAutoChapters.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butApplyAutoChapters.TextAlign")));
			this.butApplyAutoChapters.Visible = ((bool)(resources.GetObject("butApplyAutoChapters.Visible")));
			this.butApplyAutoChapters.Click += new System.EventHandler(this.butApplyAutoChapters_Click);
			// 
			// label2
			// 
			this.label2.AccessibleDescription = resources.GetString("label2.AccessibleDescription");
			this.label2.AccessibleName = resources.GetString("label2.AccessibleName");
			this.label2.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("label2.Anchor")));
			this.label2.AutoSize = ((bool)(resources.GetObject("label2.AutoSize")));
			this.label2.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("label2.Dock")));
			this.label2.Enabled = ((bool)(resources.GetObject("label2.Enabled")));
			this.label2.Font = ((System.Drawing.Font)(resources.GetObject("label2.Font")));
			this.label2.Image = ((System.Drawing.Image)(resources.GetObject("label2.Image")));
			this.label2.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label2.ImageAlign")));
			this.label2.ImageIndex = ((int)(resources.GetObject("label2.ImageIndex")));
			this.label2.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("label2.ImeMode")));
			this.label2.Location = ((System.Drawing.Point)(resources.GetObject("label2.Location")));
			this.label2.Name = "label2";
			this.label2.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("label2.RightToLeft")));
			this.label2.Size = ((System.Drawing.Size)(resources.GetObject("label2.Size")));
			this.label2.TabIndex = ((int)(resources.GetObject("label2.TabIndex")));
			this.label2.Text = resources.GetString("label2.Text");
			this.label2.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label2.TextAlign")));
			this.label2.Visible = ((bool)(resources.GetObject("label2.Visible")));
			// 
			// numAutoChapters
			// 
			this.numAutoChapters.AccessibleDescription = resources.GetString("numAutoChapters.AccessibleDescription");
			this.numAutoChapters.AccessibleName = resources.GetString("numAutoChapters.AccessibleName");
			this.numAutoChapters.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("numAutoChapters.Anchor")));
			this.numAutoChapters.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("numAutoChapters.Dock")));
			this.numAutoChapters.Enabled = ((bool)(resources.GetObject("numAutoChapters.Enabled")));
			this.numAutoChapters.Font = ((System.Drawing.Font)(resources.GetObject("numAutoChapters.Font")));
			this.numAutoChapters.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("numAutoChapters.ImeMode")));
			this.numAutoChapters.Location = ((System.Drawing.Point)(resources.GetObject("numAutoChapters.Location")));
			this.numAutoChapters.Maximum = new System.Decimal(new int[] {
																			60,
																			0,
																			0,
																			0});
			this.numAutoChapters.Minimum = new System.Decimal(new int[] {
																			1,
																			0,
																			0,
																			0});
			this.numAutoChapters.Name = "numAutoChapters";
			this.numAutoChapters.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("numAutoChapters.RightToLeft")));
			this.numAutoChapters.Size = ((System.Drawing.Size)(resources.GetObject("numAutoChapters.Size")));
			this.numAutoChapters.TabIndex = ((int)(resources.GetObject("numAutoChapters.TabIndex")));
			this.numAutoChapters.TextAlign = ((System.Windows.Forms.HorizontalAlignment)(resources.GetObject("numAutoChapters.TextAlign")));
			this.numAutoChapters.ThousandsSeparator = ((bool)(resources.GetObject("numAutoChapters.ThousandsSeparator")));
			this.numAutoChapters.UpDownAlign = ((System.Windows.Forms.LeftRightAlignment)(resources.GetObject("numAutoChapters.UpDownAlign")));
			this.numAutoChapters.Value = new System.Decimal(new int[] {
																		  5,
																		  0,
																		  0,
																		  0});
			this.numAutoChapters.Visible = ((bool)(resources.GetObject("numAutoChapters.Visible")));
			this.numAutoChapters.ValueChanged += new System.EventHandler(this.numAutoChapters_ValueChanged);
			// 
			// label1
			// 
			this.label1.AccessibleDescription = resources.GetString("label1.AccessibleDescription");
			this.label1.AccessibleName = resources.GetString("label1.AccessibleName");
			this.label1.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("label1.Anchor")));
			this.label1.AutoSize = ((bool)(resources.GetObject("label1.AutoSize")));
			this.label1.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("label1.Dock")));
			this.label1.Enabled = ((bool)(resources.GetObject("label1.Enabled")));
			this.label1.Font = ((System.Drawing.Font)(resources.GetObject("label1.Font")));
			this.label1.Image = ((System.Drawing.Image)(resources.GetObject("label1.Image")));
			this.label1.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label1.ImageAlign")));
			this.label1.ImageIndex = ((int)(resources.GetObject("label1.ImageIndex")));
			this.label1.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("label1.ImeMode")));
			this.label1.Location = ((System.Drawing.Point)(resources.GetObject("label1.Location")));
			this.label1.Name = "label1";
			this.label1.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("label1.RightToLeft")));
			this.label1.Size = ((System.Drawing.Size)(resources.GetObject("label1.Size")));
			this.label1.TabIndex = ((int)(resources.GetObject("label1.TabIndex")));
			this.label1.Text = resources.GetString("label1.Text");
			this.label1.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label1.TextAlign")));
			this.label1.Visible = ((bool)(resources.GetObject("label1.Visible")));
			// 
			// ChapterListCtrl
			// 
			this.AccessibleDescription = resources.GetString("$this.AccessibleDescription");
			this.AccessibleName = resources.GetString("$this.AccessibleName");
			this.AutoScroll = ((bool)(resources.GetObject("$this.AutoScroll")));
			this.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("$this.AutoScrollMargin")));
			this.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("$this.AutoScrollMinSize")));
			this.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("$this.BackgroundImage")));
			this.ContextMenu = this.cmChapter;
			this.Controls.Add(this.panelChapter);
			this.Controls.Add(this.panelControl2);
			this.Controls.Add(this.panelTempChapter);
			this.Controls.Add(this.panelControl1);
			this.Controls.Add(this.butApplyAutoChapters);
			this.Controls.Add(this.label2);
			this.Controls.Add(this.numAutoChapters);
			this.Controls.Add(this.label1);
			this.Enabled = ((bool)(resources.GetObject("$this.Enabled")));
			this.Font = ((System.Drawing.Font)(resources.GetObject("$this.Font")));
			this.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("$this.ImeMode")));
			this.Location = ((System.Drawing.Point)(resources.GetObject("$this.Location")));
			this.Name = "ChapterListCtrl";
			this.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("$this.RightToLeft")));
			this.Size = ((System.Drawing.Size)(resources.GetObject("$this.Size")));
			this.Load += new System.EventHandler(this.ChapterListCtrl_Load);
			this.panelChapter.ResumeLayout(false);
			this.panelControl2.ResumeLayout(false);
			this.panelTempChapter.ResumeLayout(false);
			this.panelControl1.ResumeLayout(false);
			((System.ComponentModel.ISupportInitialize)(this.numAutoChapters)).EndInit();
			this.ResumeLayout(false);

		}
		#endregion

		#region Ctrl Events

		private void ChapterListCtrl_Load(object sender, System.EventArgs e)
		{
			OnSettingsChanged();
		}

		private void numAutoChapters_ValueChanged(object sender, System.EventArgs e)
		{
			Settings.CurrentSettings.AutoChaptersValue=(int)numAutoChapters.Value;
		}

		private void lwTempChapters_KeyDown(object sender, System.Windows.Forms.KeyEventArgs e)
		{
			if (e.KeyData==Keys.Delete)
				RemoveChapter(lwTempChapters);
		}

		private void lwResultChapters_KeyDown(object sender, System.Windows.Forms.KeyEventArgs e)
		{
			if (e.KeyData==Keys.Delete)
				RemoveChapter(lwResultChapters);
		}

		private void butDelTempChapter_Click(object sender, System.EventArgs e)
		{
			RemoveChapter(lwTempChapters as ListView);
		}

		private void butDelResultChapter_Click(object sender, System.EventArgs e)
		{
			RemoveChapter(lwResultChapters as ListView);
		}

		private void butApplyAutoChapters_Click(object sender, System.EventArgs e)
		{
			State.AutoCreateChapters();
		}

		private void lwTempChapters_DoubleClick(object sender, System.EventArgs e)
		{
			ShowChapter(lwTempChapters);
		}

		private void lwResultChapters_DoubleClick(object sender, System.EventArgs e)
		{
			ShowChapter(lwResultChapters);
		}

		#endregion

		#region Event Handler

		private void OnSetDefaults(bool b_NewProject)
		{
			// b_NewProject=false: when opening a new video file -> do nothing here
			if (b_NewProject)
			{
				lwResultChapters.Items.Clear();
				lwTempChapters.Items.Clear();
				butApplyAutoChapters.Enabled=false;
			}
		}

		private void OnCutPointModified(int selectedCutIndex)
		{
			UpdateChapterList();
		}

		private void OnCurrentCutModified()
		{
			UpdateChapterList();
		}

		private void OnSettingsChanged()
		{
			numAutoChapters.Value=Settings.CurrentSettings.AutoChaptersValue;
			UpdateChapterList();
		}

		#endregion

		#region Helper Methoden

		private void UpdateChapterList()
		{
			butApplyAutoChapters.Enabled=!Settings.CurrentSettings.AutoCreateChapters && State.Cuts.Count>0;
			lwTempChapters.Items.Clear();
			if (State.CurrentCut.VideoStream!=null)
			{
				int [] chapterFrames=State.CurrentCut.ChapterItems;
				foreach (int frameNr in chapterFrames)
				{
					ListViewItem lvi=new ListViewItem();
					lvi.Tag=new DictionaryEntry(State.CurrentCut,frameNr);
					lvi.Text=Helper.FramesToTimeString(frameNr,State.CurrentCut.VideoStream.FramesPerSecond);
					if (State.CurrentCut.StartFrame>frameNr || State.CurrentCut.EndFrame<frameNr)
						lvi.ForeColor=Color.Red;
					lwTempChapters.Items.Add(lvi);
				}
			}

			lwResultChapters.Items.Clear();
			int absFramePos=0;
			foreach (CutPoint cp in State.Cuts)
			{
				string name;
				if (!Settings.CurrentSettings.DisplayFullPathInformations)
					name=Path.GetFileName(cp.VideoName);
				else
					name=cp.VideoName;
				int [] chapterFrames=cp.ChapterItems;
				foreach (int frameNr in chapterFrames)
				{
					ListViewItem lvi=new ListViewItem();
					lvi.Tag=new DictionaryEntry(cp,frameNr);
					lvi.Text=Helper.FramesToTimeString(absFramePos+frameNr-cp.StartFrame,cp.VideoStream.FramesPerSecond);
					lvi.SubItems.AddRange(new string[]
						{
							Helper.FramesToTimeString(frameNr,cp.VideoStream.FramesPerSecond),
							name
						});
					if (cp.StartFrame>frameNr || cp.EndFrame<frameNr)
						lvi.ForeColor=Color.Red;
					lwResultChapters.Items.Add(lvi);
				}
				absFramePos+=cp.EndFrame-cp.StartFrame+1;
			}
		}

		private void ShowChapter(ListView chapterView)
		{
			if (chapterView.SelectedItems.Count==1)
			{
				CutPoint cp=(CutPoint)((DictionaryEntry)chapterView.SelectedItems[0].Tag).Key;
				if (0 == string.Compare(State.VideoStream.StreamName, cp.VideoName, true))
				{
					int showFrameNr=(int)((DictionaryEntry)chapterView.SelectedItems[0].Tag).Value;
					State.GoToVideoPosition(showFrameNr);
				}
			}
		}

		private void RemoveChapter(ListView currentList)
		{
			if (currentList.SelectedItems.Count==1)
			{
				CutPoint cp=(CutPoint)((DictionaryEntry)currentList.SelectedItems[0].Tag).Key;
				int frameNr=(int)((DictionaryEntry)currentList.SelectedItems[0].Tag).Value;
				State.RemoveChapter(cp,frameNr);
			}		
		}

		#endregion

		#region Context Menu

		private void cmChapter_Popup(object sender, System.EventArgs e)
		{
			ListView currentList=(ListView)((ContextMenu)sender).SourceControl;
			bool menuVisible=currentList.SelectedItems.Count!=0;

			foreach (MenuItem mi in cmChapter.MenuItems)
				mi.Visible=menuVisible;

			// "Show chapter frame" deaktivieren, falls das geladene Video und
			// das Video des "Cuts" nicht bereinstimmen
			if (menuVisible && currentList.SelectedItems.Count==1)
			{
				CutPoint cp=(CutPoint)((DictionaryEntry)currentList.SelectedItems[0].Tag).Key;

				if (0 != string.Compare(State.VideoStream.StreamName, cp.VideoName, true))
					menuShowChapterFrame.Visible=false;
			}
		}

		private void menuShowChapterFrame_Click(object sender, System.EventArgs e)
		{
			ShowChapter((ListView)((ContextMenu)((MenuItem)sender).Parent).SourceControl);
		}

		private void menuRemoveChapterFrame_Click(object sender, System.EventArgs e)
		{
			RemoveChapter(((ContextMenu)((MenuItem)sender).Parent).SourceControl as ListView);
		}

		private void menuRemoveAllChapterFrames_Click(object sender, System.EventArgs e)
		{
			ListView lv=(ListView)((ContextMenu)((MenuItem)sender).Parent).SourceControl;
			foreach (ListViewItem lvi in lv.Items)
			{
				CutPoint cp=(CutPoint)((DictionaryEntry)lvi.Tag).Key;
				int frameNr=(int)((DictionaryEntry)lvi.Tag).Value;
				State.RemoveChapter(cp,frameNr);
			}
		}

		#endregion

	}
}
