/*
 * Cuttermaran - The Mpeg Cutter
 * 
 * Copyright (C) 2003-2006  Tobias Arnold (cuttermaran@gmx.net)
 * 
 * This file is part of cuttermaran, a free MPEG cut program.
 * See http://www.cuttermaran.de for updates.
 *
 * This program is free software; you can redistribute it and/or modify it 
 * under the terms of the GNU General Public License as published by the 
 * Free Software Foundation; either version 2 of the License, or 
 * (at your option) any later version. 
 * 
 * This program is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the 
 * GNU General Public License for more details. 
 * 
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */

using System;
using System.Collections;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Windows.Forms;
using Configuration;
using Coremoran.AVStreams;
using Coremoran.Common;
using GUI.Actions;

namespace GUI.MainForm
{
	/// <summary>
	/// Summary description for CurrentCutOutCtrl.
	/// </summary>
	public class CurrentCutOutCtrl : MainBaseControl
	{
		private System.Windows.Forms.Panel panelPic;
		private System.Windows.Forms.PictureBox picLastCutOut;
		private System.Windows.Forms.Panel panelControls;
		private System.Windows.Forms.Button butNextCutOut;
		private System.Windows.Forms.Button butPrevCutOut;
		private System.Windows.Forms.Label label29;
		private System.Windows.Forms.Label lblCutOutFramePos;
		private System.Windows.Forms.Button butStartSearch;
		private System.Windows.Forms.ToolTip stdToolTip;
		private System.ComponentModel.IContainer components;
		private System.Windows.Forms.CheckBox butLink;
		private decimal currentRatio=-1m;

		#region ctor / Dispose

		public CurrentCutOutCtrl()
		{
			// This call is required by the Windows.Forms Form Designer.
			InitializeComponent();

			// Fr Events registrieren
			State.SetDefaults+=new SetDefaultsDelegate(this.OnSetDefaults);
			State.CurrentCutOutModified+=new CurrentCutOutModifiedDelegate(this.OnCurrentCutOutModified);
			State.SettingsChanged+=new SettingsChangedDelegate(OnSettingsChanged);
		}

		/// <summary> 
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#endregion

		#region Component Designer generated code
		/// <summary> 
		/// Required method for Designer support - do not modify 
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.components = new System.ComponentModel.Container();
			System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(CurrentCutOutCtrl));
			this.panelPic = new System.Windows.Forms.Panel();
			this.picLastCutOut = new System.Windows.Forms.PictureBox();
			this.panelControls = new System.Windows.Forms.Panel();
			this.butLink = new System.Windows.Forms.CheckBox();
			this.butNextCutOut = new System.Windows.Forms.Button();
			this.butPrevCutOut = new System.Windows.Forms.Button();
			this.label29 = new System.Windows.Forms.Label();
			this.lblCutOutFramePos = new System.Windows.Forms.Label();
			this.butStartSearch = new System.Windows.Forms.Button();
			this.stdToolTip = new System.Windows.Forms.ToolTip(this.components);
			this.panelPic.SuspendLayout();
			this.panelControls.SuspendLayout();
			this.SuspendLayout();
			// 
			// panelPic
			// 
			this.panelPic.AccessibleDescription = resources.GetString("panelPic.AccessibleDescription");
			this.panelPic.AccessibleName = resources.GetString("panelPic.AccessibleName");
			this.panelPic.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("panelPic.Anchor")));
			this.panelPic.AutoScroll = ((bool)(resources.GetObject("panelPic.AutoScroll")));
			this.panelPic.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("panelPic.AutoScrollMargin")));
			this.panelPic.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("panelPic.AutoScrollMinSize")));
			this.panelPic.BackColor = System.Drawing.Color.Black;
			this.panelPic.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("panelPic.BackgroundImage")));
			this.panelPic.Controls.Add(this.picLastCutOut);
			this.panelPic.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("panelPic.Dock")));
			this.panelPic.Enabled = ((bool)(resources.GetObject("panelPic.Enabled")));
			this.panelPic.Font = ((System.Drawing.Font)(resources.GetObject("panelPic.Font")));
			this.panelPic.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("panelPic.ImeMode")));
			this.panelPic.Location = ((System.Drawing.Point)(resources.GetObject("panelPic.Location")));
			this.panelPic.Name = "panelPic";
			this.panelPic.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("panelPic.RightToLeft")));
			this.panelPic.Size = ((System.Drawing.Size)(resources.GetObject("panelPic.Size")));
			this.panelPic.TabIndex = ((int)(resources.GetObject("panelPic.TabIndex")));
			this.panelPic.Text = resources.GetString("panelPic.Text");
			this.stdToolTip.SetToolTip(this.panelPic, resources.GetString("panelPic.ToolTip"));
			this.panelPic.Visible = ((bool)(resources.GetObject("panelPic.Visible")));
			// 
			// picLastCutOut
			// 
			this.picLastCutOut.AccessibleDescription = resources.GetString("picLastCutOut.AccessibleDescription");
			this.picLastCutOut.AccessibleName = resources.GetString("picLastCutOut.AccessibleName");
			this.picLastCutOut.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("picLastCutOut.Anchor")));
			this.picLastCutOut.BackColor = System.Drawing.Color.Blue;
			this.picLastCutOut.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("picLastCutOut.BackgroundImage")));
			this.picLastCutOut.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("picLastCutOut.Dock")));
			this.picLastCutOut.Enabled = ((bool)(resources.GetObject("picLastCutOut.Enabled")));
			this.picLastCutOut.Font = ((System.Drawing.Font)(resources.GetObject("picLastCutOut.Font")));
			this.picLastCutOut.Image = ((System.Drawing.Image)(resources.GetObject("picLastCutOut.Image")));
			this.picLastCutOut.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("picLastCutOut.ImeMode")));
			this.picLastCutOut.Location = ((System.Drawing.Point)(resources.GetObject("picLastCutOut.Location")));
			this.picLastCutOut.Name = "picLastCutOut";
			this.picLastCutOut.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("picLastCutOut.RightToLeft")));
			this.picLastCutOut.Size = ((System.Drawing.Size)(resources.GetObject("picLastCutOut.Size")));
			this.picLastCutOut.SizeMode = ((System.Windows.Forms.PictureBoxSizeMode)(resources.GetObject("picLastCutOut.SizeMode")));
			this.picLastCutOut.TabIndex = ((int)(resources.GetObject("picLastCutOut.TabIndex")));
			this.picLastCutOut.TabStop = false;
			this.picLastCutOut.Text = resources.GetString("picLastCutOut.Text");
			this.stdToolTip.SetToolTip(this.picLastCutOut, resources.GetString("picLastCutOut.ToolTip"));
			this.picLastCutOut.Visible = ((bool)(resources.GetObject("picLastCutOut.Visible")));
			// 
			// panelControls
			// 
			this.panelControls.AccessibleDescription = resources.GetString("panelControls.AccessibleDescription");
			this.panelControls.AccessibleName = resources.GetString("panelControls.AccessibleName");
			this.panelControls.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("panelControls.Anchor")));
			this.panelControls.AutoScroll = ((bool)(resources.GetObject("panelControls.AutoScroll")));
			this.panelControls.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("panelControls.AutoScrollMargin")));
			this.panelControls.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("panelControls.AutoScrollMinSize")));
			this.panelControls.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("panelControls.BackgroundImage")));
			this.panelControls.Controls.Add(this.butLink);
			this.panelControls.Controls.Add(this.butNextCutOut);
			this.panelControls.Controls.Add(this.butPrevCutOut);
			this.panelControls.Controls.Add(this.label29);
			this.panelControls.Controls.Add(this.lblCutOutFramePos);
			this.panelControls.Controls.Add(this.butStartSearch);
			this.panelControls.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("panelControls.Dock")));
			this.panelControls.Enabled = ((bool)(resources.GetObject("panelControls.Enabled")));
			this.panelControls.Font = ((System.Drawing.Font)(resources.GetObject("panelControls.Font")));
			this.panelControls.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("panelControls.ImeMode")));
			this.panelControls.Location = ((System.Drawing.Point)(resources.GetObject("panelControls.Location")));
			this.panelControls.Name = "panelControls";
			this.panelControls.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("panelControls.RightToLeft")));
			this.panelControls.Size = ((System.Drawing.Size)(resources.GetObject("panelControls.Size")));
			this.panelControls.TabIndex = ((int)(resources.GetObject("panelControls.TabIndex")));
			this.panelControls.Text = resources.GetString("panelControls.Text");
			this.stdToolTip.SetToolTip(this.panelControls, resources.GetString("panelControls.ToolTip"));
			this.panelControls.Visible = ((bool)(resources.GetObject("panelControls.Visible")));
			// 
			// butLink
			// 
			this.butLink.AccessibleDescription = resources.GetString("butLink.AccessibleDescription");
			this.butLink.AccessibleName = resources.GetString("butLink.AccessibleName");
			this.butLink.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butLink.Anchor")));
			this.butLink.Appearance = ((System.Windows.Forms.Appearance)(resources.GetObject("butLink.Appearance")));
			this.butLink.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butLink.BackgroundImage")));
			this.butLink.CheckAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butLink.CheckAlign")));
			this.butLink.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butLink.Dock")));
			this.butLink.Enabled = ((bool)(resources.GetObject("butLink.Enabled")));
			this.butLink.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butLink.FlatStyle")));
			this.butLink.Font = ((System.Drawing.Font)(resources.GetObject("butLink.Font")));
			this.butLink.Image = ((System.Drawing.Image)(resources.GetObject("butLink.Image")));
			this.butLink.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butLink.ImageAlign")));
			this.butLink.ImageIndex = ((int)(resources.GetObject("butLink.ImageIndex")));
			this.butLink.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butLink.ImeMode")));
			this.butLink.Location = ((System.Drawing.Point)(resources.GetObject("butLink.Location")));
			this.butLink.Name = "butLink";
			this.butLink.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butLink.RightToLeft")));
			this.butLink.Size = ((System.Drawing.Size)(resources.GetObject("butLink.Size")));
			this.butLink.TabIndex = ((int)(resources.GetObject("butLink.TabIndex")));
			this.butLink.Text = resources.GetString("butLink.Text");
			this.butLink.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butLink.TextAlign")));
			this.stdToolTip.SetToolTip(this.butLink, resources.GetString("butLink.ToolTip"));
			this.butLink.Visible = ((bool)(resources.GetObject("butLink.Visible")));
			this.butLink.CheckedChanged += new System.EventHandler(this.butLink_CheckedChanged);
			// 
			// butNextCutOut
			// 
			this.butNextCutOut.AccessibleDescription = resources.GetString("butNextCutOut.AccessibleDescription");
			this.butNextCutOut.AccessibleName = resources.GetString("butNextCutOut.AccessibleName");
			this.butNextCutOut.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butNextCutOut.Anchor")));
			this.butNextCutOut.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butNextCutOut.BackgroundImage")));
			this.butNextCutOut.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butNextCutOut.Dock")));
			this.butNextCutOut.Enabled = ((bool)(resources.GetObject("butNextCutOut.Enabled")));
			this.butNextCutOut.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butNextCutOut.FlatStyle")));
			this.butNextCutOut.Font = ((System.Drawing.Font)(resources.GetObject("butNextCutOut.Font")));
			this.butNextCutOut.Image = ((System.Drawing.Image)(resources.GetObject("butNextCutOut.Image")));
			this.butNextCutOut.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butNextCutOut.ImageAlign")));
			this.butNextCutOut.ImageIndex = ((int)(resources.GetObject("butNextCutOut.ImageIndex")));
			this.butNextCutOut.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butNextCutOut.ImeMode")));
			this.butNextCutOut.Location = ((System.Drawing.Point)(resources.GetObject("butNextCutOut.Location")));
			this.butNextCutOut.Name = "butNextCutOut";
			this.butNextCutOut.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butNextCutOut.RightToLeft")));
			this.butNextCutOut.Size = ((System.Drawing.Size)(resources.GetObject("butNextCutOut.Size")));
			this.butNextCutOut.TabIndex = ((int)(resources.GetObject("butNextCutOut.TabIndex")));
			this.butNextCutOut.Text = resources.GetString("butNextCutOut.Text");
			this.butNextCutOut.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butNextCutOut.TextAlign")));
			this.stdToolTip.SetToolTip(this.butNextCutOut, resources.GetString("butNextCutOut.ToolTip"));
			this.butNextCutOut.Visible = ((bool)(resources.GetObject("butNextCutOut.Visible")));
			this.butNextCutOut.Click += new System.EventHandler(this.butNextCutOut_Click);
			// 
			// butPrevCutOut
			// 
			this.butPrevCutOut.AccessibleDescription = resources.GetString("butPrevCutOut.AccessibleDescription");
			this.butPrevCutOut.AccessibleName = resources.GetString("butPrevCutOut.AccessibleName");
			this.butPrevCutOut.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butPrevCutOut.Anchor")));
			this.butPrevCutOut.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butPrevCutOut.BackgroundImage")));
			this.butPrevCutOut.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butPrevCutOut.Dock")));
			this.butPrevCutOut.Enabled = ((bool)(resources.GetObject("butPrevCutOut.Enabled")));
			this.butPrevCutOut.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butPrevCutOut.FlatStyle")));
			this.butPrevCutOut.Font = ((System.Drawing.Font)(resources.GetObject("butPrevCutOut.Font")));
			this.butPrevCutOut.Image = ((System.Drawing.Image)(resources.GetObject("butPrevCutOut.Image")));
			this.butPrevCutOut.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butPrevCutOut.ImageAlign")));
			this.butPrevCutOut.ImageIndex = ((int)(resources.GetObject("butPrevCutOut.ImageIndex")));
			this.butPrevCutOut.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butPrevCutOut.ImeMode")));
			this.butPrevCutOut.Location = ((System.Drawing.Point)(resources.GetObject("butPrevCutOut.Location")));
			this.butPrevCutOut.Name = "butPrevCutOut";
			this.butPrevCutOut.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butPrevCutOut.RightToLeft")));
			this.butPrevCutOut.Size = ((System.Drawing.Size)(resources.GetObject("butPrevCutOut.Size")));
			this.butPrevCutOut.TabIndex = ((int)(resources.GetObject("butPrevCutOut.TabIndex")));
			this.butPrevCutOut.Text = resources.GetString("butPrevCutOut.Text");
			this.butPrevCutOut.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butPrevCutOut.TextAlign")));
			this.stdToolTip.SetToolTip(this.butPrevCutOut, resources.GetString("butPrevCutOut.ToolTip"));
			this.butPrevCutOut.Visible = ((bool)(resources.GetObject("butPrevCutOut.Visible")));
			this.butPrevCutOut.Click += new System.EventHandler(this.butPrevCutOut_Click);
			// 
			// label29
			// 
			this.label29.AccessibleDescription = resources.GetString("label29.AccessibleDescription");
			this.label29.AccessibleName = resources.GetString("label29.AccessibleName");
			this.label29.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("label29.Anchor")));
			this.label29.AutoSize = ((bool)(resources.GetObject("label29.AutoSize")));
			this.label29.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("label29.Dock")));
			this.label29.Enabled = ((bool)(resources.GetObject("label29.Enabled")));
			this.label29.Font = ((System.Drawing.Font)(resources.GetObject("label29.Font")));
			this.label29.Image = ((System.Drawing.Image)(resources.GetObject("label29.Image")));
			this.label29.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label29.ImageAlign")));
			this.label29.ImageIndex = ((int)(resources.GetObject("label29.ImageIndex")));
			this.label29.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("label29.ImeMode")));
			this.label29.Location = ((System.Drawing.Point)(resources.GetObject("label29.Location")));
			this.label29.Name = "label29";
			this.label29.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("label29.RightToLeft")));
			this.label29.Size = ((System.Drawing.Size)(resources.GetObject("label29.Size")));
			this.label29.TabIndex = ((int)(resources.GetObject("label29.TabIndex")));
			this.label29.Text = resources.GetString("label29.Text");
			this.label29.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label29.TextAlign")));
			this.stdToolTip.SetToolTip(this.label29, resources.GetString("label29.ToolTip"));
			this.label29.Visible = ((bool)(resources.GetObject("label29.Visible")));
			// 
			// lblCutOutFramePos
			// 
			this.lblCutOutFramePos.AccessibleDescription = resources.GetString("lblCutOutFramePos.AccessibleDescription");
			this.lblCutOutFramePos.AccessibleName = resources.GetString("lblCutOutFramePos.AccessibleName");
			this.lblCutOutFramePos.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("lblCutOutFramePos.Anchor")));
			this.lblCutOutFramePos.AutoSize = ((bool)(resources.GetObject("lblCutOutFramePos.AutoSize")));
			this.lblCutOutFramePos.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("lblCutOutFramePos.Dock")));
			this.lblCutOutFramePos.Enabled = ((bool)(resources.GetObject("lblCutOutFramePos.Enabled")));
			this.lblCutOutFramePos.Font = ((System.Drawing.Font)(resources.GetObject("lblCutOutFramePos.Font")));
			this.lblCutOutFramePos.Image = ((System.Drawing.Image)(resources.GetObject("lblCutOutFramePos.Image")));
			this.lblCutOutFramePos.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("lblCutOutFramePos.ImageAlign")));
			this.lblCutOutFramePos.ImageIndex = ((int)(resources.GetObject("lblCutOutFramePos.ImageIndex")));
			this.lblCutOutFramePos.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("lblCutOutFramePos.ImeMode")));
			this.lblCutOutFramePos.Location = ((System.Drawing.Point)(resources.GetObject("lblCutOutFramePos.Location")));
			this.lblCutOutFramePos.Name = "lblCutOutFramePos";
			this.lblCutOutFramePos.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("lblCutOutFramePos.RightToLeft")));
			this.lblCutOutFramePos.Size = ((System.Drawing.Size)(resources.GetObject("lblCutOutFramePos.Size")));
			this.lblCutOutFramePos.TabIndex = ((int)(resources.GetObject("lblCutOutFramePos.TabIndex")));
			this.lblCutOutFramePos.Text = resources.GetString("lblCutOutFramePos.Text");
			this.lblCutOutFramePos.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("lblCutOutFramePos.TextAlign")));
			this.stdToolTip.SetToolTip(this.lblCutOutFramePos, resources.GetString("lblCutOutFramePos.ToolTip"));
			this.lblCutOutFramePos.Visible = ((bool)(resources.GetObject("lblCutOutFramePos.Visible")));
			// 
			// butStartSearch
			// 
			this.butStartSearch.AccessibleDescription = resources.GetString("butStartSearch.AccessibleDescription");
			this.butStartSearch.AccessibleName = resources.GetString("butStartSearch.AccessibleName");
			this.butStartSearch.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butStartSearch.Anchor")));
			this.butStartSearch.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butStartSearch.BackgroundImage")));
			this.butStartSearch.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butStartSearch.Dock")));
			this.butStartSearch.Enabled = ((bool)(resources.GetObject("butStartSearch.Enabled")));
			this.butStartSearch.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butStartSearch.FlatStyle")));
			this.butStartSearch.Font = ((System.Drawing.Font)(resources.GetObject("butStartSearch.Font")));
			this.butStartSearch.Image = ((System.Drawing.Image)(resources.GetObject("butStartSearch.Image")));
			this.butStartSearch.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butStartSearch.ImageAlign")));
			this.butStartSearch.ImageIndex = ((int)(resources.GetObject("butStartSearch.ImageIndex")));
			this.butStartSearch.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butStartSearch.ImeMode")));
			this.butStartSearch.Location = ((System.Drawing.Point)(resources.GetObject("butStartSearch.Location")));
			this.butStartSearch.Name = "butStartSearch";
			this.butStartSearch.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butStartSearch.RightToLeft")));
			this.butStartSearch.Size = ((System.Drawing.Size)(resources.GetObject("butStartSearch.Size")));
			this.butStartSearch.TabIndex = ((int)(resources.GetObject("butStartSearch.TabIndex")));
			this.butStartSearch.Text = resources.GetString("butStartSearch.Text");
			this.butStartSearch.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butStartSearch.TextAlign")));
			this.stdToolTip.SetToolTip(this.butStartSearch, resources.GetString("butStartSearch.ToolTip"));
			this.butStartSearch.Visible = ((bool)(resources.GetObject("butStartSearch.Visible")));
			this.butStartSearch.Click += new System.EventHandler(this.butStartSearch_Click);
			// 
			// CurrentCutOutCtrl
			// 
			this.AccessibleDescription = resources.GetString("$this.AccessibleDescription");
			this.AccessibleName = resources.GetString("$this.AccessibleName");
			this.AutoScroll = ((bool)(resources.GetObject("$this.AutoScroll")));
			this.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("$this.AutoScrollMargin")));
			this.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("$this.AutoScrollMinSize")));
			this.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("$this.BackgroundImage")));
			this.Controls.Add(this.panelPic);
			this.Controls.Add(this.panelControls);
			this.Enabled = ((bool)(resources.GetObject("$this.Enabled")));
			this.Font = ((System.Drawing.Font)(resources.GetObject("$this.Font")));
			this.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("$this.ImeMode")));
			this.Location = ((System.Drawing.Point)(resources.GetObject("$this.Location")));
			this.Name = "CurrentCutOutCtrl";
			this.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("$this.RightToLeft")));
			this.Size = ((System.Drawing.Size)(resources.GetObject("$this.Size")));
			this.stdToolTip.SetToolTip(this, resources.GetString("$this.ToolTip"));
			this.Resize += new System.EventHandler(this.CurrentCutOutCtrl_Resize);
			this.panelPic.ResumeLayout(false);
			this.panelControls.ResumeLayout(false);
			this.ResumeLayout(false);

		}
		#endregion

		#region Event Handler

		private void OnSetDefaults(bool b_NewProject)
		{
			picLastCutOut.Image=null;
			lblCutOutFramePos.Text=string.Empty;
			butNextCutOut.Enabled=false;
			butPrevCutOut.Enabled=false;
			butStartSearch.Enabled=false;
			butLink.Checked=false;
			butLink.Enabled=false;
			currentRatio=-1m;
			OnSettingsChanged();
		}

		private void OnSettingsChanged()
		{
			// Bild neu einpassen
			FitImage(panelPic,picLastCutOut,currentRatio);
		}

		private void OnCurrentCutOutModified()
		{
			if (State.CurrentCutOut!=null && State.CurrentCutOut.EndFrame!=-1)
			{
				if (picLastCutOut.Image!=State.CurrentCutOut.CutOutFrame)
					picLastCutOut.Image=State.CurrentCutOut.CutOutFrame;
				else
					picLastCutOut.Invalidate();

				Sequence seq=null;
				Mpeg12Object pic=State.CurrentCutOut.VideoStream.GetPicture(State.CurrentCutOut.EndFrame);
				if (pic!=null)
					seq=(Sequence)((Mpeg12Video)State.CurrentCutOut.VideoStream).GetPrevMpeg12Object(typeof(Sequence),pic);
				if (seq==null)
					seq=((Mpeg12Video)State.CurrentCutOut.VideoStream).Sequence0;
				if (seq.sequence_extension_exist)
					currentRatio=Mpeg12VideoConst.Mpeg2RatioValue[seq.aspect_ratio_information];
				else
					currentRatio=Mpeg12VideoConst.Mpeg1RatioValue[seq.aspect_ratio_information];

				FitImage(panelPic,picLastCutOut,currentRatio);

				butNextCutOut.Enabled=true;
				butPrevCutOut.Enabled=true;
				butStartSearch.Enabled=true;
				butLink.Enabled=true;

				// Display in the form "00:12:54,920 [P] 314" where "P" is the type of the picture
				lblCutOutFramePos.Text=GUIHelper.FormatFrameTimeAndType(State.CurrentCutOut.EndFrame,State.CurrentCutOut.VideoStream);
			}
			else
				OnSetDefaults(false);

			butLink.Enabled=butPrevCutOut.Enabled=butNextCutOut.Enabled=State.CurrentCutOut!=null && State.CurrentCutOut.EndFrame!=-1;
		}

		#endregion

		#region Helper Methode

		private void ModifyCurrentCutOutFrame(int newPos)
		{
			State.SetCurrentCutOutEndFrame(newPos);

			// Nur Update in der Anzeige wenn der aktuelle Punkt gleich dem genderten
			if (State.CurrentCut==State.CurrentCutOut)
				State.SetCurrentCutEndFrame(State.CurrentCutOut.EndFrame);
		}

		#endregion

		#region Button Clicks

		private void butPrevCutOut_Click(object sender, System.EventArgs e)
		{
			int new_pos;
			if (!Settings.CurrentSettings.EncodeMode)
				new_pos=((Mpeg12Video)State.CurrentCutOut.VideoStream).CalculatePrevFramePos(State.CurrentCutOut.EndFrame,FrameType.PFrame);
			else
				new_pos=((Mpeg12Video)State.CurrentCutOut.VideoStream).CalculatePrevFramePos(State.CurrentCutOut.EndFrame,FrameType.BFrame);
			int diff=new_pos-State.CurrentCutOut.EndFrame;
			if (State.CurrentCutOut.StartFrame==-1 || new_pos>=State.CurrentCutOut.StartFrame)
				ModifyCurrentCutOutFrame(new_pos);
			if (butLink.Checked)
				State.GoToVideoPosition(State.CurrentVideoPosition+diff);
		}

		private void butNextCutOut_Click(object sender, System.EventArgs e)
		{
			int new_pos;
			if (!Settings.CurrentSettings.EncodeMode)
				new_pos=((Mpeg12Video)State.CurrentCutOut.VideoStream).CalculateNextFramePos(State.CurrentCutOut.EndFrame,FrameType.PFrame);
			else
				new_pos=((Mpeg12Video)State.CurrentCutOut.VideoStream).CalculateNextFramePos(State.CurrentCutOut.EndFrame,FrameType.BFrame);
			int diff=new_pos-State.CurrentCutOut.EndFrame;
			if (State.CurrentCutOut.StartFrame==-1 || new_pos>=State.CurrentCutOut.StartFrame)
				ModifyCurrentCutOutFrame(new_pos);
			if (butLink.Checked)
				State.GoToVideoPosition(State.CurrentVideoPosition+diff);
		}

		private void butStartSearch_Click(object sender, System.EventArgs e)
		{
			SearchPictureAction spa=new SearchPictureAction(State,State.CurrentCutOut);
			ThreadControl tc=new ThreadControl(spa);
			if (tc.ShowDialog()==DialogResult.OK)
				State.GoToVideoPosition(spa.ResultPosition);
		}

		#endregion

		private void CurrentCutOutCtrl_Resize(object sender, System.EventArgs e)
		{
			FitImage(panelPic,picLastCutOut,currentRatio);
		}

		private void butLink_CheckedChanged(object sender, System.EventArgs e)
		{
			butLink.BackColor=butLink.Checked?Color.Red:Color.FromKnownColor(KnownColor.Control);
		}
	}
}
