/*
 * Cuttermaran - The Mpeg Cutter
 * 
 * Copyright (C) 2003-2006  Tobias Arnold (cuttermaran@gmx.net)
 * 
 * This file is part of cuttermaran, a free MPEG cut program.
 * See http://www.cuttermaran.de for updates.
 *
 * This program is free software; you can redistribute it and/or modify it 
 * under the terms of the GNU General Public License as published by the 
 * Free Software Foundation; either version 2 of the License, or 
 * (at your option) any later version. 
 * 
 * This program is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the 
 * GNU General Public License for more details. 
 * 
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */

using System;
using System.IO;
using System.Collections;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Windows.Forms;
using System.Text.RegularExpressions;
using System.Diagnostics;
using Coremoran.AVStreams;
using Configuration;
using StringResources;
using Coremoran.Common;

namespace GUI.MainForm
{
	/// <summary>
	/// Summary description for CurrentFrameCtrl.
	/// </summary>
	public class CurrentFrameCtrl : MainBaseControl
	{
		private System.Windows.Forms.Panel panelControls;
		private System.Windows.Forms.Panel panelAdditionalScrollbar;
		private System.Windows.Forms.Button butPlayPause;
		private System.Windows.Forms.Label label4;
		private System.Windows.Forms.Label lblFramePos;
		/// <summary> 
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;
		private TextBox tbFramePos;

		// fr die Wiedergabe
		private DirectShowPlayer audioPlayer=null;
		private DateTime playStartTime=DateTime.Now;
		private System.Timers.Timer playTimer;
		private System.Windows.Forms.Panel panelCaption;
		private System.Windows.Forms.Label labelCaption;
		private bool playerIsRunning=false;
		private System.Windows.Forms.Panel panelPic;
		private System.Windows.Forms.PictureBox picCurrent;
		private decimal currentRatio=-1m;

		#region ctor / Dispose

		public CurrentFrameCtrl()
		{
			// This call is required by the Windows.Forms Form Designer.
			InitializeComponent();

			// Fr Events registrieren
			State.SetDefaults+=new SetDefaultsDelegate(this.OnSetDefaults);
			State.VideoPositionUpdated+=new VideoPositionUpdatedDelegate(this.OnVideoPositionUpdated);
			State.AudioVideoOpened+=new AudioVideoOpenedDelegate(this.OnAudioVideoOpened);
			State.SettingsChanged+=new SettingsChangedDelegate(OnSettingsChanged);
			State.CutListSelectionChanged+=new CutListSelChangedDelegate(OnCutListSelectionChanged);
		}

		/// <summary> 
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
				if (picCurrent!=null && picCurrent.Image!=null)
				{
					picCurrent.Image.Dispose(); // unmanaged Bitmap!!!
					picCurrent.Image=null;
				}
				if (playTimer.Enabled || playerIsRunning)
				{
					Debug.WriteLine("Stopping play timer");
					playTimer.Enabled=false;
					playerIsRunning=false;
				}
				if (audioPlayer!=null)
				{
					Debug.WriteLine("Disposing DXAudio thread");
					audioPlayer.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#endregion

		#region Component Designer generated code
		/// <summary> 
		/// Required method for Designer support - do not modify 
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(CurrentFrameCtrl));
			this.panelAdditionalScrollbar = new System.Windows.Forms.Panel();
			this.panelControls = new System.Windows.Forms.Panel();
			this.butPlayPause = new System.Windows.Forms.Button();
			this.label4 = new System.Windows.Forms.Label();
			this.lblFramePos = new System.Windows.Forms.Label();
			this.playTimer = new System.Timers.Timer();
			this.panelCaption = new System.Windows.Forms.Panel();
			this.labelCaption = new System.Windows.Forms.Label();
			this.panelPic = new System.Windows.Forms.Panel();
			this.picCurrent = new System.Windows.Forms.PictureBox();
			this.panelControls.SuspendLayout();
			((System.ComponentModel.ISupportInitialize)(this.playTimer)).BeginInit();
			this.panelCaption.SuspendLayout();
			this.panelPic.SuspendLayout();
			this.SuspendLayout();
			// 
			// panelAdditionalScrollbar
			// 
			this.panelAdditionalScrollbar.AccessibleDescription = resources.GetString("panelAdditionalScrollbar.AccessibleDescription");
			this.panelAdditionalScrollbar.AccessibleName = resources.GetString("panelAdditionalScrollbar.AccessibleName");
			this.panelAdditionalScrollbar.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("panelAdditionalScrollbar.Anchor")));
			this.panelAdditionalScrollbar.AutoScroll = ((bool)(resources.GetObject("panelAdditionalScrollbar.AutoScroll")));
			this.panelAdditionalScrollbar.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("panelAdditionalScrollbar.AutoScrollMargin")));
			this.panelAdditionalScrollbar.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("panelAdditionalScrollbar.AutoScrollMinSize")));
			this.panelAdditionalScrollbar.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("panelAdditionalScrollbar.BackgroundImage")));
			this.panelAdditionalScrollbar.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("panelAdditionalScrollbar.Dock")));
			this.panelAdditionalScrollbar.Enabled = ((bool)(resources.GetObject("panelAdditionalScrollbar.Enabled")));
			this.panelAdditionalScrollbar.Font = ((System.Drawing.Font)(resources.GetObject("panelAdditionalScrollbar.Font")));
			this.panelAdditionalScrollbar.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("panelAdditionalScrollbar.ImeMode")));
			this.panelAdditionalScrollbar.Location = ((System.Drawing.Point)(resources.GetObject("panelAdditionalScrollbar.Location")));
			this.panelAdditionalScrollbar.Name = "panelAdditionalScrollbar";
			this.panelAdditionalScrollbar.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("panelAdditionalScrollbar.RightToLeft")));
			this.panelAdditionalScrollbar.Size = ((System.Drawing.Size)(resources.GetObject("panelAdditionalScrollbar.Size")));
			this.panelAdditionalScrollbar.TabIndex = ((int)(resources.GetObject("panelAdditionalScrollbar.TabIndex")));
			this.panelAdditionalScrollbar.Text = resources.GetString("panelAdditionalScrollbar.Text");
			this.panelAdditionalScrollbar.Visible = ((bool)(resources.GetObject("panelAdditionalScrollbar.Visible")));
			// 
			// panelControls
			// 
			this.panelControls.AccessibleDescription = resources.GetString("panelControls.AccessibleDescription");
			this.panelControls.AccessibleName = resources.GetString("panelControls.AccessibleName");
			this.panelControls.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("panelControls.Anchor")));
			this.panelControls.AutoScroll = ((bool)(resources.GetObject("panelControls.AutoScroll")));
			this.panelControls.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("panelControls.AutoScrollMargin")));
			this.panelControls.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("panelControls.AutoScrollMinSize")));
			this.panelControls.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("panelControls.BackgroundImage")));
			this.panelControls.Controls.Add(this.butPlayPause);
			this.panelControls.Controls.Add(this.label4);
			this.panelControls.Controls.Add(this.lblFramePos);
			this.panelControls.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("panelControls.Dock")));
			this.panelControls.Enabled = ((bool)(resources.GetObject("panelControls.Enabled")));
			this.panelControls.Font = ((System.Drawing.Font)(resources.GetObject("panelControls.Font")));
			this.panelControls.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("panelControls.ImeMode")));
			this.panelControls.Location = ((System.Drawing.Point)(resources.GetObject("panelControls.Location")));
			this.panelControls.Name = "panelControls";
			this.panelControls.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("panelControls.RightToLeft")));
			this.panelControls.Size = ((System.Drawing.Size)(resources.GetObject("panelControls.Size")));
			this.panelControls.TabIndex = ((int)(resources.GetObject("panelControls.TabIndex")));
			this.panelControls.Text = resources.GetString("panelControls.Text");
			this.panelControls.Visible = ((bool)(resources.GetObject("panelControls.Visible")));
			// 
			// butPlayPause
			// 
			this.butPlayPause.AccessibleDescription = resources.GetString("butPlayPause.AccessibleDescription");
			this.butPlayPause.AccessibleName = resources.GetString("butPlayPause.AccessibleName");
			this.butPlayPause.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butPlayPause.Anchor")));
			this.butPlayPause.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butPlayPause.BackgroundImage")));
			this.butPlayPause.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butPlayPause.Dock")));
			this.butPlayPause.Enabled = ((bool)(resources.GetObject("butPlayPause.Enabled")));
			this.butPlayPause.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butPlayPause.FlatStyle")));
			this.butPlayPause.Font = ((System.Drawing.Font)(resources.GetObject("butPlayPause.Font")));
			this.butPlayPause.Image = ((System.Drawing.Image)(resources.GetObject("butPlayPause.Image")));
			this.butPlayPause.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butPlayPause.ImageAlign")));
			this.butPlayPause.ImageIndex = ((int)(resources.GetObject("butPlayPause.ImageIndex")));
			this.butPlayPause.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butPlayPause.ImeMode")));
			this.butPlayPause.Location = ((System.Drawing.Point)(resources.GetObject("butPlayPause.Location")));
			this.butPlayPause.Name = "butPlayPause";
			this.butPlayPause.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butPlayPause.RightToLeft")));
			this.butPlayPause.Size = ((System.Drawing.Size)(resources.GetObject("butPlayPause.Size")));
			this.butPlayPause.TabIndex = ((int)(resources.GetObject("butPlayPause.TabIndex")));
			this.butPlayPause.Text = resources.GetString("butPlayPause.Text");
			this.butPlayPause.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butPlayPause.TextAlign")));
			this.butPlayPause.Visible = ((bool)(resources.GetObject("butPlayPause.Visible")));
			this.butPlayPause.Click += new System.EventHandler(this.butPlayPause_Click);
			// 
			// label4
			// 
			this.label4.AccessibleDescription = resources.GetString("label4.AccessibleDescription");
			this.label4.AccessibleName = resources.GetString("label4.AccessibleName");
			this.label4.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("label4.Anchor")));
			this.label4.AutoSize = ((bool)(resources.GetObject("label4.AutoSize")));
			this.label4.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("label4.Dock")));
			this.label4.Enabled = ((bool)(resources.GetObject("label4.Enabled")));
			this.label4.Font = ((System.Drawing.Font)(resources.GetObject("label4.Font")));
			this.label4.Image = ((System.Drawing.Image)(resources.GetObject("label4.Image")));
			this.label4.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label4.ImageAlign")));
			this.label4.ImageIndex = ((int)(resources.GetObject("label4.ImageIndex")));
			this.label4.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("label4.ImeMode")));
			this.label4.Location = ((System.Drawing.Point)(resources.GetObject("label4.Location")));
			this.label4.Name = "label4";
			this.label4.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("label4.RightToLeft")));
			this.label4.Size = ((System.Drawing.Size)(resources.GetObject("label4.Size")));
			this.label4.TabIndex = ((int)(resources.GetObject("label4.TabIndex")));
			this.label4.Text = resources.GetString("label4.Text");
			this.label4.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label4.TextAlign")));
			this.label4.Visible = ((bool)(resources.GetObject("label4.Visible")));
			// 
			// lblFramePos
			// 
			this.lblFramePos.AccessibleDescription = resources.GetString("lblFramePos.AccessibleDescription");
			this.lblFramePos.AccessibleName = resources.GetString("lblFramePos.AccessibleName");
			this.lblFramePos.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("lblFramePos.Anchor")));
			this.lblFramePos.AutoSize = ((bool)(resources.GetObject("lblFramePos.AutoSize")));
			this.lblFramePos.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("lblFramePos.Dock")));
			this.lblFramePos.Enabled = ((bool)(resources.GetObject("lblFramePos.Enabled")));
			this.lblFramePos.Font = ((System.Drawing.Font)(resources.GetObject("lblFramePos.Font")));
			this.lblFramePos.Image = ((System.Drawing.Image)(resources.GetObject("lblFramePos.Image")));
			this.lblFramePos.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("lblFramePos.ImageAlign")));
			this.lblFramePos.ImageIndex = ((int)(resources.GetObject("lblFramePos.ImageIndex")));
			this.lblFramePos.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("lblFramePos.ImeMode")));
			this.lblFramePos.Location = ((System.Drawing.Point)(resources.GetObject("lblFramePos.Location")));
			this.lblFramePos.Name = "lblFramePos";
			this.lblFramePos.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("lblFramePos.RightToLeft")));
			this.lblFramePos.Size = ((System.Drawing.Size)(resources.GetObject("lblFramePos.Size")));
			this.lblFramePos.TabIndex = ((int)(resources.GetObject("lblFramePos.TabIndex")));
			this.lblFramePos.Text = resources.GetString("lblFramePos.Text");
			this.lblFramePos.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("lblFramePos.TextAlign")));
			this.lblFramePos.Visible = ((bool)(resources.GetObject("lblFramePos.Visible")));
			this.lblFramePos.DoubleClick += new System.EventHandler(this.lblFramePos_DoubleClick);
			// 
			// playTimer
			// 
			this.playTimer.SynchronizingObject = this;
			this.playTimer.Elapsed += new System.Timers.ElapsedEventHandler(this.playTimer_Elapsed);
			// 
			// panelCaption
			// 
			this.panelCaption.AccessibleDescription = resources.GetString("panelCaption.AccessibleDescription");
			this.panelCaption.AccessibleName = resources.GetString("panelCaption.AccessibleName");
			this.panelCaption.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("panelCaption.Anchor")));
			this.panelCaption.AutoScroll = ((bool)(resources.GetObject("panelCaption.AutoScroll")));
			this.panelCaption.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("panelCaption.AutoScrollMargin")));
			this.panelCaption.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("panelCaption.AutoScrollMinSize")));
			this.panelCaption.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("panelCaption.BackgroundImage")));
			this.panelCaption.Controls.Add(this.labelCaption);
			this.panelCaption.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("panelCaption.Dock")));
			this.panelCaption.Enabled = ((bool)(resources.GetObject("panelCaption.Enabled")));
			this.panelCaption.Font = ((System.Drawing.Font)(resources.GetObject("panelCaption.Font")));
			this.panelCaption.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("panelCaption.ImeMode")));
			this.panelCaption.Location = ((System.Drawing.Point)(resources.GetObject("panelCaption.Location")));
			this.panelCaption.Name = "panelCaption";
			this.panelCaption.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("panelCaption.RightToLeft")));
			this.panelCaption.Size = ((System.Drawing.Size)(resources.GetObject("panelCaption.Size")));
			this.panelCaption.TabIndex = ((int)(resources.GetObject("panelCaption.TabIndex")));
			this.panelCaption.Text = resources.GetString("panelCaption.Text");
			this.panelCaption.Visible = ((bool)(resources.GetObject("panelCaption.Visible")));
			// 
			// labelCaption
			// 
			this.labelCaption.AccessibleDescription = resources.GetString("labelCaption.AccessibleDescription");
			this.labelCaption.AccessibleName = resources.GetString("labelCaption.AccessibleName");
			this.labelCaption.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("labelCaption.Anchor")));
			this.labelCaption.AutoSize = ((bool)(resources.GetObject("labelCaption.AutoSize")));
			this.labelCaption.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("labelCaption.Dock")));
			this.labelCaption.Enabled = ((bool)(resources.GetObject("labelCaption.Enabled")));
			this.labelCaption.Font = ((System.Drawing.Font)(resources.GetObject("labelCaption.Font")));
			this.labelCaption.Image = ((System.Drawing.Image)(resources.GetObject("labelCaption.Image")));
			this.labelCaption.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("labelCaption.ImageAlign")));
			this.labelCaption.ImageIndex = ((int)(resources.GetObject("labelCaption.ImageIndex")));
			this.labelCaption.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("labelCaption.ImeMode")));
			this.labelCaption.Location = ((System.Drawing.Point)(resources.GetObject("labelCaption.Location")));
			this.labelCaption.Name = "labelCaption";
			this.labelCaption.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("labelCaption.RightToLeft")));
			this.labelCaption.Size = ((System.Drawing.Size)(resources.GetObject("labelCaption.Size")));
			this.labelCaption.TabIndex = ((int)(resources.GetObject("labelCaption.TabIndex")));
			this.labelCaption.Text = resources.GetString("labelCaption.Text");
			this.labelCaption.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("labelCaption.TextAlign")));
			this.labelCaption.Visible = ((bool)(resources.GetObject("labelCaption.Visible")));
			// 
			// panelPic
			// 
			this.panelPic.AccessibleDescription = resources.GetString("panelPic.AccessibleDescription");
			this.panelPic.AccessibleName = resources.GetString("panelPic.AccessibleName");
			this.panelPic.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("panelPic.Anchor")));
			this.panelPic.AutoScroll = ((bool)(resources.GetObject("panelPic.AutoScroll")));
			this.panelPic.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("panelPic.AutoScrollMargin")));
			this.panelPic.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("panelPic.AutoScrollMinSize")));
			this.panelPic.BackColor = System.Drawing.Color.Black;
			this.panelPic.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("panelPic.BackgroundImage")));
			this.panelPic.Controls.Add(this.picCurrent);
			this.panelPic.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("panelPic.Dock")));
			this.panelPic.Enabled = ((bool)(resources.GetObject("panelPic.Enabled")));
			this.panelPic.Font = ((System.Drawing.Font)(resources.GetObject("panelPic.Font")));
			this.panelPic.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("panelPic.ImeMode")));
			this.panelPic.Location = ((System.Drawing.Point)(resources.GetObject("panelPic.Location")));
			this.panelPic.Name = "panelPic";
			this.panelPic.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("panelPic.RightToLeft")));
			this.panelPic.Size = ((System.Drawing.Size)(resources.GetObject("panelPic.Size")));
			this.panelPic.TabIndex = ((int)(resources.GetObject("panelPic.TabIndex")));
			this.panelPic.Text = resources.GetString("panelPic.Text");
			this.panelPic.Visible = ((bool)(resources.GetObject("panelPic.Visible")));
			// 
			// picCurrent
			// 
			this.picCurrent.AccessibleDescription = resources.GetString("picCurrent.AccessibleDescription");
			this.picCurrent.AccessibleName = resources.GetString("picCurrent.AccessibleName");
			this.picCurrent.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("picCurrent.Anchor")));
			this.picCurrent.BackColor = System.Drawing.Color.Blue;
			this.picCurrent.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("picCurrent.BackgroundImage")));
			this.picCurrent.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("picCurrent.Dock")));
			this.picCurrent.Enabled = ((bool)(resources.GetObject("picCurrent.Enabled")));
			this.picCurrent.Font = ((System.Drawing.Font)(resources.GetObject("picCurrent.Font")));
			this.picCurrent.Image = ((System.Drawing.Image)(resources.GetObject("picCurrent.Image")));
			this.picCurrent.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("picCurrent.ImeMode")));
			this.picCurrent.Location = ((System.Drawing.Point)(resources.GetObject("picCurrent.Location")));
			this.picCurrent.Name = "picCurrent";
			this.picCurrent.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("picCurrent.RightToLeft")));
			this.picCurrent.Size = ((System.Drawing.Size)(resources.GetObject("picCurrent.Size")));
			this.picCurrent.SizeMode = ((System.Windows.Forms.PictureBoxSizeMode)(resources.GetObject("picCurrent.SizeMode")));
			this.picCurrent.TabIndex = ((int)(resources.GetObject("picCurrent.TabIndex")));
			this.picCurrent.TabStop = false;
			this.picCurrent.Text = resources.GetString("picCurrent.Text");
			this.picCurrent.Visible = ((bool)(resources.GetObject("picCurrent.Visible")));
			// 
			// CurrentFrameCtrl
			// 
			this.AccessibleDescription = resources.GetString("$this.AccessibleDescription");
			this.AccessibleName = resources.GetString("$this.AccessibleName");
			this.AutoScroll = ((bool)(resources.GetObject("$this.AutoScroll")));
			this.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("$this.AutoScrollMargin")));
			this.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("$this.AutoScrollMinSize")));
			this.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("$this.BackgroundImage")));
			this.Controls.Add(this.panelPic);
			this.Controls.Add(this.panelCaption);
			this.Controls.Add(this.panelControls);
			this.Controls.Add(this.panelAdditionalScrollbar);
			this.Enabled = ((bool)(resources.GetObject("$this.Enabled")));
			this.Font = ((System.Drawing.Font)(resources.GetObject("$this.Font")));
			this.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("$this.ImeMode")));
			this.Location = ((System.Drawing.Point)(resources.GetObject("$this.Location")));
			this.Name = "CurrentFrameCtrl";
			this.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("$this.RightToLeft")));
			this.Size = ((System.Drawing.Size)(resources.GetObject("$this.Size")));
			this.Resize += new System.EventHandler(this.CurrentFrameCtrl_Resize);
			this.Load += new System.EventHandler(this.CurrentFrameCtrl_Load);
			this.panelControls.ResumeLayout(false);
			((System.ComponentModel.ISupportInitialize)(this.playTimer)).EndInit();
			this.panelCaption.ResumeLayout(false);
			this.panelPic.ResumeLayout(false);
			this.ResumeLayout(false);

		}
		#endregion

		#region Ctrl Events

		private void CurrentFrameCtrl_Load(object sender, System.EventArgs e)
		{
			// Textbox fr die Eingabe der Position
			panelControls.SuspendLayout();
			tbFramePos=new TextBox();
			tbFramePos.Location=new Point(lblFramePos.Location.X,lblFramePos.Location.Y-4);
			tbFramePos.Size=lblFramePos.Size;
			tbFramePos.Visible=false;
			tbFramePos.Validating+=new System.ComponentModel.CancelEventHandler(tbFramePos_Validating);
			panelControls.Controls.Add(tbFramePos);
			panelControls.ResumeLayout();

			// Additional Scrollbar hinzufgen
			panelAdditionalScrollbar.SuspendLayout();
			ScrollCtrl sc=new ScrollCtrl();
			sc.Location=new Point(0,0);
			sc.Dock=DockStyle.Fill;
			panelAdditionalScrollbar.Controls.Add(sc);
			panelAdditionalScrollbar.ResumeLayout();

			// ImageList fr PlayButton
			Stream str = this.GetType().Assembly.GetManifestResourceStream("GUI.icons.play.ico");
			Bitmap bmp=new Bitmap(str);
			butPlayPause.ImageList=new ImageList();
			this.butPlayPause.ImageList.Images.Add(bmp);
			str = this.GetType().Assembly.GetManifestResourceStream("GUI.icons.pause.ico");
			bmp=new Bitmap(str);
			this.butPlayPause.ImageList.Images.Add(bmp);
		}

		private void tbFramePos_Validating(object sender, System.ComponentModel.CancelEventArgs e)
		{
			try
			{
				int newFrame=-1;
				string timeCode=tbFramePos.Text.Trim().Replace(',','.');
				Regex rg=new Regex(@"^\d*$");
				if (rg.IsMatch(timeCode))
				{
					newFrame=int.Parse(timeCode);
				}
				else
				{
					TimeSpan sp=TimeSpan.Parse(timeCode);
					newFrame=(int)((decimal)sp.TotalSeconds*State.VideoStream.FramesPerSecond);
				}
				State.GoToVideoPosition(newFrame);
			}
			catch
			{
			}
			finally
			{
				lblFramePos.Visible=true;
				tbFramePos.Visible=false;
			}
		}

		private void lblFramePos_DoubleClick(object sender, System.EventArgs e)
		{
			if (State.VideoStream!=null)
			{
				lblFramePos.Visible=false;
				tbFramePos.Text=Helper.FramesToTime(State.CurrentVideoPosition,State.VideoStream.FramesPerSecond).ToString("HH:mm:ss,fff");
				tbFramePos.Visible=true;
				tbFramePos.Focus();
			}
		}

		private void CurrentFrameCtrl_Resize(object sender, System.EventArgs e)
		{
			FitImage(panelPic,picCurrent,currentRatio);
		}

		public void ReturnPressed()
		{
			if (tbFramePos.Visible)
				butPlayPause.Focus(); // Dies lst das Validating-Event der Textbox aus!
		}

		#endregion

		#region Event Handling

		private void OnSetDefaults(bool b_NewProject)
		{
			if (picCurrent.Image!=null)
			{
				picCurrent.Image.Dispose();
				picCurrent.Image=null;
			}
			butPlayPause.Enabled=false;
			butPlayPause.ImageIndex=0;
			lblFramePos.Text=string.Empty;
			lblFramePos.Visible=true;
			tbFramePos.Visible=false;
			currentRatio=-1m;
			OnSettingsChanged();
		}

		private void OnSettingsChanged()
		{
			// Caption oder Scrollbar anzeigen
			panelCaption.Visible=Settings.CurrentSettings.ShowCurrentFrameCaption;
			panelAdditionalScrollbar.Visible=Settings.CurrentSettings.AdditionalScrollBar;
			// Bild neu einpassen
			FitImage(panelPic,picCurrent,currentRatio);
		}

		private void OnAudioVideoOpened(bool videoOpened, bool audioOpened, bool reOpened)
		{
			butPlayPause.Enabled = (State.VideoStream != null);
		}

		private void OnVideoPositionUpdated(int newPosition)
		{
			// Bild aktualisieren
			Bitmap bitm=(Bitmap)picCurrent.Image;
			bool newBMPCreated;
			if (State.CurrentDecoder.GetPicture(newPosition,ref bitm,true,out newBMPCreated))
			{
				if (newBMPCreated)
					picCurrent.Image=bitm;
				else
					picCurrent.Invalidate();
			}
			Sequence seq=null;
			if (newPosition>=0)
			{
				Mpeg12Object pic=State.VideoStream.GetPicture(newPosition);
				if (pic!=null)
					seq=(Sequence)State.VideoStream.GetPrevMpeg12Object(typeof(Sequence),pic);
			}
			if (seq==null)
				seq=State.VideoStream.Sequence0;
			if (seq.sequence_extension_exist)
				currentRatio=Mpeg12VideoConst.Mpeg2RatioValue[seq.aspect_ratio_information];
			else
				currentRatio=Mpeg12VideoConst.Mpeg1RatioValue[seq.aspect_ratio_information];

			FitImage(panelPic,picCurrent,currentRatio);

			// Positionstext anpassen
			lblFramePos.Text=Helper.FramesToTimeAndPicString(newPosition,State.VideoStream.FramesPerSecond);
			lblFramePos.ForeColor=State.CurrentDecoder.IsFrameValid?System.Drawing.Color.Black:System.Drawing.Color.Red;

			// Display in the form "00:12:54,920 [P] 314" where "P" is the type of the picture
			lblFramePos.Text = GUIHelper.FormatFrameTimeAndType(newPosition, State.VideoStream);
		}

		private void OnCutListSelectionChanged(ArrayList selectedIndices)
		{
			if (!Settings.CurrentSettings.ShowCutInPicture || selectedIndices.Count != 1)
				return;
			
			OnVideoPositionUpdated(State.Cuts[(int)selectedIndices[0]].StartFrame);			
		}

		#endregion

		#region Play/Pause Handling

		private void butPlayPause_Click(object sender, System.EventArgs e)
		{
			if (!playerIsRunning)
			{
				butPlayPause.ImageIndex=1; // pause
				playTimer.Interval=(Settings.CurrentSettings.SkipFramesPlay+1)*1000/(double)State.VideoStream.FramesPerSecond;

				try
				{
					if(State.AudioStreams.Count>0)
					{
						int audioIndex=State.SelectedAudioIndex;
						audioPlayer=new DirectShowPlayer(State.AudioStream(audioIndex).StreamName,GUIHelper.BasicPacketStream2FilterMediaType(State.AudioStream(audioIndex)),null);
						double startPosition=(double)(State.CurrentVideoPosition/State.VideoStream.FramesPerSecond);
						audioPlayer.Position=startPosition; //,SeekPositionFlags.AbsolutePositioning);
						audioPlayer.Start();
					}
				}
				catch (Exception)
				{
					MessageBox.Show(Resource.CurrentResource[Resource.NO_AUDIO_CODEC],Resource.CurrentResource[Resource.ERROR]);
				}
				playTimer.Enabled=true;
				playerIsRunning=true;
				playStartTime=DateTime.Now.AddMilliseconds(-Helper.FramesToLong(State.CurrentVideoPosition,State.VideoStream.FramesPerSecond));
				State.EnableGui(this, false);
			}
			else
				StopPlay(State.CurrentDecoder.CurrentPosition);
		}

		private void playTimer_Elapsed(object sender, System.Timers.ElapsedEventArgs e)
		{
			if (playerIsRunning)
			{
				int pos=0;
				if (audioPlayer!=null)
				{
					if (audioPlayer.Position<audioPlayer.Duration)
						pos=(int)(((decimal)audioPlayer.Position+State.AudioStream(State.SelectedAudioIndex).StartDelay/1000m)*State.VideoStream.FramesPerSecond);
					else
					{
						// StopPlay() macht hier zu viel,
						// da der Audiostream krzer als der Videostream sein kann
						audioPlayer.Dispose();
						audioPlayer=null;
						return;
					}
				}
				else
					pos=(int)((DateTime.Now-playStartTime).TotalSeconds*(double)State.VideoStream.FramesPerSecond);

				if (pos>=0)
				{
					State.UpdateVideoPlayPosition(pos);

					lblFramePos.Text=Helper.FramesToTimeAndPicString(pos,State.VideoStream.FramesPerSecond);
					if (pos<State.VideoStream.PicturesCount)
					{
						// Bugfix: unnecessary while() loop removed here!
						// This loop could run endless and make the program hang with 99% CPU load!

						Bitmap bitm=(Bitmap)picCurrent.Image;
						bool newBMPCreated;
						// get the picture at position pos
						if (State.CurrentDecoder.GetPicture(pos,ref bitm,true,out newBMPCreated))
						{
							if (newBMPCreated)
								picCurrent.Image=bitm;
							else
								picCurrent.Invalidate();
						}
						else
							StopPlay(State.CurrentDecoder.CurrentPosition-1);
					}
					else
						StopPlay(State.CurrentDecoder.CurrentPosition);
				}
			}
		}

		private void StopPlay(int newPosition)
		{
			try
			{
				playTimer.Enabled=false;
				playerIsRunning=false;
				if (audioPlayer!=null)
				{
					audioPlayer.Dispose();
					audioPlayer=null;
				}
				butPlayPause.ImageIndex=0; // play
			}
			catch (Exception e)
			{
				MessageBox.Show(e.Message);
			}
			finally
			{
				State.EnableGui(this, true);
				State.GoToVideoPosition(newPosition);
				audioPlayer=null;
			}
		}

		#endregion

	}
}
