/*
 * Cuttermaran - The Mpeg Cutter
 * 
 * Copyright (C) 2003-2006  Tobias Arnold (cuttermaran@gmx.net)
 * 
 * This file is part of cuttermaran, a free MPEG cut program.
 * See http://www.cuttermaran.de for updates.
 *
 * This program is free software; you can redistribute it and/or modify it 
 * under the terms of the GNU General Public License as published by the 
 * Free Software Foundation; either version 2 of the License, or 
 * (at your option) any later version. 
 * 
 * This program is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the 
 * GNU General Public License for more details. 
 * 
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */

using System;
using System.IO;
using System.Collections;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Windows.Forms;
using Configuration;
using StringResources;
using Coremoran.AVStreams;
using Coremoran.Common;
using Coremoran.Algorithms;

namespace GUI.MainForm
{
	internal enum CutListColumns
	{
		CutNo=0,
		VideoName=1,
		VideoStart=2,
		VideoEnd=4,
		VideoLength=8,
		VideoNewStart=16,
		VideoNewEnd=32,
		AudioName=1024,
		AudioInDelay=2048,
		AudioOutDelay=4096,
	}

	/// <summary>
	/// Summary description for CutListCtrl.
	/// </summary>
	public class CutListCtrl : MainBaseControl
	{
		private System.Windows.Forms.Panel panelList;
		private System.Windows.Forms.ListView lwCutList;
		private System.Windows.Forms.Panel panelControl;
		private System.Windows.Forms.Button butMoveCutDown;
		private System.Windows.Forms.Button butDeleteCut;
		private System.Windows.Forms.Button butMoveCutUp;
		private System.Windows.Forms.ContextMenu cmCutList;
		private System.Windows.Forms.MenuItem menuGotoCutIn;
		private System.Windows.Forms.MenuItem menuGotoCutOut;
		private System.Windows.Forms.MenuItem menuEditCut;
		private System.Windows.Forms.MenuItem menuDeleteCut;
		private System.Windows.Forms.MenuItem menuPreviewEntry;
		private System.Windows.Forms.MenuItem menuCutSelectedEntries;
		private System.Windows.Forms.MenuItem menuSpacer1;
		private System.Windows.Forms.MenuItem menuSpacer2;
		private System.Windows.Forms.MenuItem menuSingleCut;
		private System.Windows.Forms.MenuItem menuDuplicateCut;
		private System.ComponentModel.Container components = null;
		private System.Windows.Forms.MenuItem menuSpacer3;
		private System.Windows.Forms.MenuItem menuConfigure;

		internal const int LargeCol=165;
		internal const int SmallVideoCol=125;
		internal const int SmallAudioCol=75;
		internal const int LittleCol=30;

		private SortedList colCollection;
		private Guid currentColSet;
		private Guid lastColSet;
		private bool mb_BlockSelection = false;

		#region ctor / Dispose

		public CutListCtrl()
		{
			// This call is required by the Windows.Forms Form Designer.
			InitializeComponent();

			// Fr Events registrieren
			State.SetDefaults+=new SetDefaultsDelegate(this.OnSetDefaults);
			State.SettingsChanged+=new SettingsChangedDelegate(OnSettingsChanged);
			State.CutPointModified+=new CutPointModifiedDelegate(this.OnCutPointModified);
			State.AudioVideoOpened+=new AudioVideoOpenedDelegate(OnAudioVideoOpened);

			// Spaltendefaults anlegen
			colCollection=new SortedList();
			colCollection.Add(CutListColumns.CutNo,LittleCol);
			colCollection.Add(CutListColumns.VideoName,LargeCol);
			colCollection.Add(CutListColumns.VideoStart,SmallVideoCol);
			colCollection.Add(CutListColumns.VideoEnd,SmallVideoCol);
			colCollection.Add(CutListColumns.AudioName,LargeCol);
			colCollection.Add(CutListColumns.AudioOutDelay,SmallAudioCol);
			currentColSet=Guid.NewGuid();
		}

		/// <summary> 
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#endregion

		#region Component Designer generated code
		/// <summary> 
		/// Required method for Designer support - do not modify 
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(CutListCtrl));
			this.panelList = new System.Windows.Forms.Panel();
			this.lwCutList = new System.Windows.Forms.ListView();
			this.cmCutList = new System.Windows.Forms.ContextMenu();
			this.menuGotoCutIn = new System.Windows.Forms.MenuItem();
			this.menuGotoCutOut = new System.Windows.Forms.MenuItem();
			this.menuEditCut = new System.Windows.Forms.MenuItem();
			this.menuDuplicateCut = new System.Windows.Forms.MenuItem();
			this.menuSpacer1 = new System.Windows.Forms.MenuItem();
			this.menuDeleteCut = new System.Windows.Forms.MenuItem();
			this.menuSpacer2 = new System.Windows.Forms.MenuItem();
			this.menuPreviewEntry = new System.Windows.Forms.MenuItem();
			this.menuCutSelectedEntries = new System.Windows.Forms.MenuItem();
			this.menuSingleCut = new System.Windows.Forms.MenuItem();
			this.menuSpacer3 = new System.Windows.Forms.MenuItem();
			this.menuConfigure = new System.Windows.Forms.MenuItem();
			this.panelControl = new System.Windows.Forms.Panel();
			this.butMoveCutDown = new System.Windows.Forms.Button();
			this.butDeleteCut = new System.Windows.Forms.Button();
			this.butMoveCutUp = new System.Windows.Forms.Button();
			this.panelList.SuspendLayout();
			this.panelControl.SuspendLayout();
			this.SuspendLayout();
			// 
			// panelList
			// 
			this.panelList.AccessibleDescription = resources.GetString("panelList.AccessibleDescription");
			this.panelList.AccessibleName = resources.GetString("panelList.AccessibleName");
			this.panelList.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("panelList.Anchor")));
			this.panelList.AutoScroll = ((bool)(resources.GetObject("panelList.AutoScroll")));
			this.panelList.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("panelList.AutoScrollMargin")));
			this.panelList.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("panelList.AutoScrollMinSize")));
			this.panelList.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("panelList.BackgroundImage")));
			this.panelList.Controls.Add(this.lwCutList);
			this.panelList.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("panelList.Dock")));
			this.panelList.Enabled = ((bool)(resources.GetObject("panelList.Enabled")));
			this.panelList.Font = ((System.Drawing.Font)(resources.GetObject("panelList.Font")));
			this.panelList.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("panelList.ImeMode")));
			this.panelList.Location = ((System.Drawing.Point)(resources.GetObject("panelList.Location")));
			this.panelList.Name = "panelList";
			this.panelList.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("panelList.RightToLeft")));
			this.panelList.Size = ((System.Drawing.Size)(resources.GetObject("panelList.Size")));
			this.panelList.TabIndex = ((int)(resources.GetObject("panelList.TabIndex")));
			this.panelList.Text = resources.GetString("panelList.Text");
			this.panelList.Visible = ((bool)(resources.GetObject("panelList.Visible")));
			// 
			// lwCutList
			// 
			this.lwCutList.AccessibleDescription = resources.GetString("lwCutList.AccessibleDescription");
			this.lwCutList.AccessibleName = resources.GetString("lwCutList.AccessibleName");
			this.lwCutList.Alignment = ((System.Windows.Forms.ListViewAlignment)(resources.GetObject("lwCutList.Alignment")));
			this.lwCutList.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("lwCutList.Anchor")));
			this.lwCutList.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("lwCutList.BackgroundImage")));
			this.lwCutList.ContextMenu = this.cmCutList;
			this.lwCutList.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("lwCutList.Dock")));
			this.lwCutList.Enabled = ((bool)(resources.GetObject("lwCutList.Enabled")));
			this.lwCutList.Font = ((System.Drawing.Font)(resources.GetObject("lwCutList.Font")));
			this.lwCutList.FullRowSelect = true;
			this.lwCutList.HeaderStyle = System.Windows.Forms.ColumnHeaderStyle.Nonclickable;
			this.lwCutList.HideSelection = false;
			this.lwCutList.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("lwCutList.ImeMode")));
			this.lwCutList.LabelWrap = ((bool)(resources.GetObject("lwCutList.LabelWrap")));
			this.lwCutList.Location = ((System.Drawing.Point)(resources.GetObject("lwCutList.Location")));
			this.lwCutList.Name = "lwCutList";
			this.lwCutList.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("lwCutList.RightToLeft")));
			this.lwCutList.Size = ((System.Drawing.Size)(resources.GetObject("lwCutList.Size")));
			this.lwCutList.TabIndex = ((int)(resources.GetObject("lwCutList.TabIndex")));
			this.lwCutList.Text = resources.GetString("lwCutList.Text");
			this.lwCutList.View = System.Windows.Forms.View.Details;
			this.lwCutList.Visible = ((bool)(resources.GetObject("lwCutList.Visible")));
			this.lwCutList.KeyDown += new System.Windows.Forms.KeyEventHandler(this.lwCutList_KeyDown);
			this.lwCutList.SelectedIndexChanged += new System.EventHandler(this.lwCutList_SelectedIndexChanged);
			// 
			// cmCutList
			// 
			this.cmCutList.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
																					  this.menuGotoCutIn,
																					  this.menuGotoCutOut,
																					  this.menuEditCut,
																					  this.menuDuplicateCut,
																					  this.menuSpacer1,
																					  this.menuDeleteCut,
																					  this.menuSpacer2,
																					  this.menuPreviewEntry,
																					  this.menuCutSelectedEntries,
																					  this.menuSingleCut,
																					  this.menuSpacer3,
																					  this.menuConfigure});
			this.cmCutList.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("cmCutList.RightToLeft")));
			this.cmCutList.Popup += new System.EventHandler(this.cmCutList_Popup);
			// 
			// menuGotoCutIn
			// 
			this.menuGotoCutIn.Enabled = ((bool)(resources.GetObject("menuGotoCutIn.Enabled")));
			this.menuGotoCutIn.Index = 0;
			this.menuGotoCutIn.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuGotoCutIn.Shortcut")));
			this.menuGotoCutIn.ShowShortcut = ((bool)(resources.GetObject("menuGotoCutIn.ShowShortcut")));
			this.menuGotoCutIn.Text = resources.GetString("menuGotoCutIn.Text");
			this.menuGotoCutIn.Visible = ((bool)(resources.GetObject("menuGotoCutIn.Visible")));
			this.menuGotoCutIn.Click += new System.EventHandler(this.menuGotoCutIn_Click);
			// 
			// menuGotoCutOut
			// 
			this.menuGotoCutOut.Enabled = ((bool)(resources.GetObject("menuGotoCutOut.Enabled")));
			this.menuGotoCutOut.Index = 1;
			this.menuGotoCutOut.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuGotoCutOut.Shortcut")));
			this.menuGotoCutOut.ShowShortcut = ((bool)(resources.GetObject("menuGotoCutOut.ShowShortcut")));
			this.menuGotoCutOut.Text = resources.GetString("menuGotoCutOut.Text");
			this.menuGotoCutOut.Visible = ((bool)(resources.GetObject("menuGotoCutOut.Visible")));
			this.menuGotoCutOut.Click += new System.EventHandler(this.menuGotoCutOut_Click);
			// 
			// menuEditCut
			// 
			this.menuEditCut.Enabled = ((bool)(resources.GetObject("menuEditCut.Enabled")));
			this.menuEditCut.Index = 2;
			this.menuEditCut.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuEditCut.Shortcut")));
			this.menuEditCut.ShowShortcut = ((bool)(resources.GetObject("menuEditCut.ShowShortcut")));
			this.menuEditCut.Text = resources.GetString("menuEditCut.Text");
			this.menuEditCut.Visible = ((bool)(resources.GetObject("menuEditCut.Visible")));
			this.menuEditCut.Click += new System.EventHandler(this.menuEditCut_Click);
			// 
			// menuDuplicateCut
			// 
			this.menuDuplicateCut.Enabled = ((bool)(resources.GetObject("menuDuplicateCut.Enabled")));
			this.menuDuplicateCut.Index = 3;
			this.menuDuplicateCut.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuDuplicateCut.Shortcut")));
			this.menuDuplicateCut.ShowShortcut = ((bool)(resources.GetObject("menuDuplicateCut.ShowShortcut")));
			this.menuDuplicateCut.Text = resources.GetString("menuDuplicateCut.Text");
			this.menuDuplicateCut.Visible = ((bool)(resources.GetObject("menuDuplicateCut.Visible")));
			this.menuDuplicateCut.Click += new System.EventHandler(this.menuDuplicateCut_Click);
			// 
			// menuSpacer1
			// 
			this.menuSpacer1.Enabled = ((bool)(resources.GetObject("menuSpacer1.Enabled")));
			this.menuSpacer1.Index = 4;
			this.menuSpacer1.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuSpacer1.Shortcut")));
			this.menuSpacer1.ShowShortcut = ((bool)(resources.GetObject("menuSpacer1.ShowShortcut")));
			this.menuSpacer1.Text = resources.GetString("menuSpacer1.Text");
			this.menuSpacer1.Visible = ((bool)(resources.GetObject("menuSpacer1.Visible")));
			// 
			// menuDeleteCut
			// 
			this.menuDeleteCut.Enabled = ((bool)(resources.GetObject("menuDeleteCut.Enabled")));
			this.menuDeleteCut.Index = 5;
			this.menuDeleteCut.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuDeleteCut.Shortcut")));
			this.menuDeleteCut.ShowShortcut = ((bool)(resources.GetObject("menuDeleteCut.ShowShortcut")));
			this.menuDeleteCut.Text = resources.GetString("menuDeleteCut.Text");
			this.menuDeleteCut.Visible = ((bool)(resources.GetObject("menuDeleteCut.Visible")));
			this.menuDeleteCut.Click += new System.EventHandler(this.menuDeleteCut_Click);
			// 
			// menuSpacer2
			// 
			this.menuSpacer2.Enabled = ((bool)(resources.GetObject("menuSpacer2.Enabled")));
			this.menuSpacer2.Index = 6;
			this.menuSpacer2.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuSpacer2.Shortcut")));
			this.menuSpacer2.ShowShortcut = ((bool)(resources.GetObject("menuSpacer2.ShowShortcut")));
			this.menuSpacer2.Text = resources.GetString("menuSpacer2.Text");
			this.menuSpacer2.Visible = ((bool)(resources.GetObject("menuSpacer2.Visible")));
			// 
			// menuPreviewEntry
			// 
			this.menuPreviewEntry.Enabled = ((bool)(resources.GetObject("menuPreviewEntry.Enabled")));
			this.menuPreviewEntry.Index = 7;
			this.menuPreviewEntry.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuPreviewEntry.Shortcut")));
			this.menuPreviewEntry.ShowShortcut = ((bool)(resources.GetObject("menuPreviewEntry.ShowShortcut")));
			this.menuPreviewEntry.Text = resources.GetString("menuPreviewEntry.Text");
			this.menuPreviewEntry.Visible = ((bool)(resources.GetObject("menuPreviewEntry.Visible")));
			this.menuPreviewEntry.Click += new System.EventHandler(this.menuPreviewEntry_Click);
			// 
			// menuCutSelectedEntries
			// 
			this.menuCutSelectedEntries.Enabled = ((bool)(resources.GetObject("menuCutSelectedEntries.Enabled")));
			this.menuCutSelectedEntries.Index = 8;
			this.menuCutSelectedEntries.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuCutSelectedEntries.Shortcut")));
			this.menuCutSelectedEntries.ShowShortcut = ((bool)(resources.GetObject("menuCutSelectedEntries.ShowShortcut")));
			this.menuCutSelectedEntries.Text = resources.GetString("menuCutSelectedEntries.Text");
			this.menuCutSelectedEntries.Visible = ((bool)(resources.GetObject("menuCutSelectedEntries.Visible")));
			this.menuCutSelectedEntries.Click += new System.EventHandler(this.menuCutSelectedEntries_Click);
			// 
			// menuSingleCut
			// 
			this.menuSingleCut.Enabled = ((bool)(resources.GetObject("menuSingleCut.Enabled")));
			this.menuSingleCut.Index = 9;
			this.menuSingleCut.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuSingleCut.Shortcut")));
			this.menuSingleCut.ShowShortcut = ((bool)(resources.GetObject("menuSingleCut.ShowShortcut")));
			this.menuSingleCut.Text = resources.GetString("menuSingleCut.Text");
			this.menuSingleCut.Visible = ((bool)(resources.GetObject("menuSingleCut.Visible")));
			this.menuSingleCut.Click += new System.EventHandler(this.menuSingleCut_Click);
			// 
			// menuSpacer3
			// 
			this.menuSpacer3.Enabled = ((bool)(resources.GetObject("menuSpacer3.Enabled")));
			this.menuSpacer3.Index = 10;
			this.menuSpacer3.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuSpacer3.Shortcut")));
			this.menuSpacer3.ShowShortcut = ((bool)(resources.GetObject("menuSpacer3.ShowShortcut")));
			this.menuSpacer3.Text = resources.GetString("menuSpacer3.Text");
			this.menuSpacer3.Visible = ((bool)(resources.GetObject("menuSpacer3.Visible")));
			// 
			// menuConfigure
			// 
			this.menuConfigure.Enabled = ((bool)(resources.GetObject("menuConfigure.Enabled")));
			this.menuConfigure.Index = 11;
			this.menuConfigure.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuConfigure.Shortcut")));
			this.menuConfigure.ShowShortcut = ((bool)(resources.GetObject("menuConfigure.ShowShortcut")));
			this.menuConfigure.Text = resources.GetString("menuConfigure.Text");
			this.menuConfigure.Visible = ((bool)(resources.GetObject("menuConfigure.Visible")));
			this.menuConfigure.Click += new System.EventHandler(this.menuConfigure_Click);
			// 
			// panelControl
			// 
			this.panelControl.AccessibleDescription = resources.GetString("panelControl.AccessibleDescription");
			this.panelControl.AccessibleName = resources.GetString("panelControl.AccessibleName");
			this.panelControl.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("panelControl.Anchor")));
			this.panelControl.AutoScroll = ((bool)(resources.GetObject("panelControl.AutoScroll")));
			this.panelControl.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("panelControl.AutoScrollMargin")));
			this.panelControl.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("panelControl.AutoScrollMinSize")));
			this.panelControl.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("panelControl.BackgroundImage")));
			this.panelControl.Controls.Add(this.butMoveCutDown);
			this.panelControl.Controls.Add(this.butDeleteCut);
			this.panelControl.Controls.Add(this.butMoveCutUp);
			this.panelControl.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("panelControl.Dock")));
			this.panelControl.Enabled = ((bool)(resources.GetObject("panelControl.Enabled")));
			this.panelControl.Font = ((System.Drawing.Font)(resources.GetObject("panelControl.Font")));
			this.panelControl.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("panelControl.ImeMode")));
			this.panelControl.Location = ((System.Drawing.Point)(resources.GetObject("panelControl.Location")));
			this.panelControl.Name = "panelControl";
			this.panelControl.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("panelControl.RightToLeft")));
			this.panelControl.Size = ((System.Drawing.Size)(resources.GetObject("panelControl.Size")));
			this.panelControl.TabIndex = ((int)(resources.GetObject("panelControl.TabIndex")));
			this.panelControl.Text = resources.GetString("panelControl.Text");
			this.panelControl.Visible = ((bool)(resources.GetObject("panelControl.Visible")));
			// 
			// butMoveCutDown
			// 
			this.butMoveCutDown.AccessibleDescription = resources.GetString("butMoveCutDown.AccessibleDescription");
			this.butMoveCutDown.AccessibleName = resources.GetString("butMoveCutDown.AccessibleName");
			this.butMoveCutDown.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butMoveCutDown.Anchor")));
			this.butMoveCutDown.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butMoveCutDown.BackgroundImage")));
			this.butMoveCutDown.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butMoveCutDown.Dock")));
			this.butMoveCutDown.Enabled = ((bool)(resources.GetObject("butMoveCutDown.Enabled")));
			this.butMoveCutDown.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butMoveCutDown.FlatStyle")));
			this.butMoveCutDown.Font = ((System.Drawing.Font)(resources.GetObject("butMoveCutDown.Font")));
			this.butMoveCutDown.Image = ((System.Drawing.Image)(resources.GetObject("butMoveCutDown.Image")));
			this.butMoveCutDown.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butMoveCutDown.ImageAlign")));
			this.butMoveCutDown.ImageIndex = ((int)(resources.GetObject("butMoveCutDown.ImageIndex")));
			this.butMoveCutDown.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butMoveCutDown.ImeMode")));
			this.butMoveCutDown.Location = ((System.Drawing.Point)(resources.GetObject("butMoveCutDown.Location")));
			this.butMoveCutDown.Name = "butMoveCutDown";
			this.butMoveCutDown.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butMoveCutDown.RightToLeft")));
			this.butMoveCutDown.Size = ((System.Drawing.Size)(resources.GetObject("butMoveCutDown.Size")));
			this.butMoveCutDown.TabIndex = ((int)(resources.GetObject("butMoveCutDown.TabIndex")));
			this.butMoveCutDown.Text = resources.GetString("butMoveCutDown.Text");
			this.butMoveCutDown.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butMoveCutDown.TextAlign")));
			this.butMoveCutDown.Visible = ((bool)(resources.GetObject("butMoveCutDown.Visible")));
			this.butMoveCutDown.Click += new System.EventHandler(this.butMoveCutDown_Click);
			// 
			// butDeleteCut
			// 
			this.butDeleteCut.AccessibleDescription = resources.GetString("butDeleteCut.AccessibleDescription");
			this.butDeleteCut.AccessibleName = resources.GetString("butDeleteCut.AccessibleName");
			this.butDeleteCut.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butDeleteCut.Anchor")));
			this.butDeleteCut.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butDeleteCut.BackgroundImage")));
			this.butDeleteCut.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butDeleteCut.Dock")));
			this.butDeleteCut.Enabled = ((bool)(resources.GetObject("butDeleteCut.Enabled")));
			this.butDeleteCut.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butDeleteCut.FlatStyle")));
			this.butDeleteCut.Font = ((System.Drawing.Font)(resources.GetObject("butDeleteCut.Font")));
			this.butDeleteCut.Image = ((System.Drawing.Image)(resources.GetObject("butDeleteCut.Image")));
			this.butDeleteCut.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butDeleteCut.ImageAlign")));
			this.butDeleteCut.ImageIndex = ((int)(resources.GetObject("butDeleteCut.ImageIndex")));
			this.butDeleteCut.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butDeleteCut.ImeMode")));
			this.butDeleteCut.Location = ((System.Drawing.Point)(resources.GetObject("butDeleteCut.Location")));
			this.butDeleteCut.Name = "butDeleteCut";
			this.butDeleteCut.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butDeleteCut.RightToLeft")));
			this.butDeleteCut.Size = ((System.Drawing.Size)(resources.GetObject("butDeleteCut.Size")));
			this.butDeleteCut.TabIndex = ((int)(resources.GetObject("butDeleteCut.TabIndex")));
			this.butDeleteCut.Text = resources.GetString("butDeleteCut.Text");
			this.butDeleteCut.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butDeleteCut.TextAlign")));
			this.butDeleteCut.Visible = ((bool)(resources.GetObject("butDeleteCut.Visible")));
			this.butDeleteCut.Click += new System.EventHandler(this.butDeleteCut_Click);
			// 
			// butMoveCutUp
			// 
			this.butMoveCutUp.AccessibleDescription = resources.GetString("butMoveCutUp.AccessibleDescription");
			this.butMoveCutUp.AccessibleName = resources.GetString("butMoveCutUp.AccessibleName");
			this.butMoveCutUp.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butMoveCutUp.Anchor")));
			this.butMoveCutUp.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butMoveCutUp.BackgroundImage")));
			this.butMoveCutUp.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butMoveCutUp.Dock")));
			this.butMoveCutUp.Enabled = ((bool)(resources.GetObject("butMoveCutUp.Enabled")));
			this.butMoveCutUp.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butMoveCutUp.FlatStyle")));
			this.butMoveCutUp.Font = ((System.Drawing.Font)(resources.GetObject("butMoveCutUp.Font")));
			this.butMoveCutUp.Image = ((System.Drawing.Image)(resources.GetObject("butMoveCutUp.Image")));
			this.butMoveCutUp.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butMoveCutUp.ImageAlign")));
			this.butMoveCutUp.ImageIndex = ((int)(resources.GetObject("butMoveCutUp.ImageIndex")));
			this.butMoveCutUp.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butMoveCutUp.ImeMode")));
			this.butMoveCutUp.Location = ((System.Drawing.Point)(resources.GetObject("butMoveCutUp.Location")));
			this.butMoveCutUp.Name = "butMoveCutUp";
			this.butMoveCutUp.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butMoveCutUp.RightToLeft")));
			this.butMoveCutUp.Size = ((System.Drawing.Size)(resources.GetObject("butMoveCutUp.Size")));
			this.butMoveCutUp.TabIndex = ((int)(resources.GetObject("butMoveCutUp.TabIndex")));
			this.butMoveCutUp.Text = resources.GetString("butMoveCutUp.Text");
			this.butMoveCutUp.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butMoveCutUp.TextAlign")));
			this.butMoveCutUp.Visible = ((bool)(resources.GetObject("butMoveCutUp.Visible")));
			this.butMoveCutUp.Click += new System.EventHandler(this.butMoveCutUp_Click);
			// 
			// CutListCtrl
			// 
			this.AccessibleDescription = resources.GetString("$this.AccessibleDescription");
			this.AccessibleName = resources.GetString("$this.AccessibleName");
			this.AutoScroll = ((bool)(resources.GetObject("$this.AutoScroll")));
			this.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("$this.AutoScrollMargin")));
			this.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("$this.AutoScrollMinSize")));
			this.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("$this.BackgroundImage")));
			this.Controls.Add(this.panelList);
			this.Controls.Add(this.panelControl);
			this.Enabled = ((bool)(resources.GetObject("$this.Enabled")));
			this.Font = ((System.Drawing.Font)(resources.GetObject("$this.Font")));
			this.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("$this.ImeMode")));
			this.Location = ((System.Drawing.Point)(resources.GetObject("$this.Location")));
			this.Name = "CutListCtrl";
			this.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("$this.RightToLeft")));
			this.Size = ((System.Drawing.Size)(resources.GetObject("$this.Size")));
			this.panelList.ResumeLayout(false);
			this.panelControl.ResumeLayout(false);
			this.ResumeLayout(false);

		}
		#endregion

		#region Helper

		private void CreateColumns()
		{
			SaveWidth();
			lwCutList.Clear();
			lwCutList.Columns.Clear();

			// Videospalten
			if (colCollection.Contains(CutListColumns.CutNo))
				lwCutList.Columns.Add(Resource.CurrentResource[Resource.COL_CUT_NO_SHORT],(int)colCollection[CutListColumns.CutNo],HorizontalAlignment.Right);
			if (colCollection.Contains(CutListColumns.VideoName))
				lwCutList.Columns.Add(Resource.CurrentResource[Resource.COL_VIDEO_NAME],(int)colCollection[CutListColumns.VideoName],HorizontalAlignment.Left);
			if (colCollection.Contains(CutListColumns.VideoStart))
				lwCutList.Columns.Add(Resource.CurrentResource[Resource.COL_VIDEO_START],(int)colCollection[CutListColumns.VideoStart],HorizontalAlignment.Left);
			if (colCollection.Contains(CutListColumns.VideoEnd))
				lwCutList.Columns.Add(Resource.CurrentResource[Resource.COL_VIDEO_END],(int)colCollection[CutListColumns.VideoEnd],HorizontalAlignment.Left);
			if (colCollection.Contains(CutListColumns.VideoLength))
				lwCutList.Columns.Add(Resource.CurrentResource[Resource.COL_VIDEO_LENGTH],(int)colCollection[CutListColumns.VideoLength],HorizontalAlignment.Left);
			if (colCollection.Contains(CutListColumns.VideoNewStart))
				lwCutList.Columns.Add(Resource.CurrentResource[Resource.COL_VIDEO_NEW_START],(int)colCollection[CutListColumns.VideoNewStart],HorizontalAlignment.Left);
			if (colCollection.Contains(CutListColumns.VideoNewEnd))
				lwCutList.Columns.Add(Resource.CurrentResource[Resource.COL_VIDEO_NEW_END],(int)colCollection[CutListColumns.VideoNewEnd],HorizontalAlignment.Left);

			// Audiospalten
			if (State.Cuts.Count>0)
				for (int audioIndex=0;audioIndex<State.Cuts[0].AudioStreams.Count;++audioIndex)
				{
					if (colCollection.Contains(CutListColumns.AudioName))
						lwCutList.Columns.Add(Resource.CurrentResource.FormatMessage(Resource.COL_AUDIO_NAME,audioIndex+1),(int)colCollection[CutListColumns.AudioName],HorizontalAlignment.Left);
					if (colCollection.Contains(CutListColumns.AudioInDelay))
						lwCutList.Columns.Add(Resource.CurrentResource.FormatMessage(Resource.COL_AUDIO_IN_DELAY,audioIndex+1),(int)colCollection[CutListColumns.AudioInDelay],HorizontalAlignment.Left);
					if (colCollection.Contains(CutListColumns.AudioOutDelay))
						lwCutList.Columns.Add(Resource.CurrentResource.FormatMessage(Resource.COL_AUDIO_OUT_DELAY,audioIndex+1),(int)colCollection[CutListColumns.AudioOutDelay],HorizontalAlignment.Left);
				}
		}

		private void AddColValue(ListViewItem lvi,string value)
		{
			if (lvi.Text==string.Empty)
				lvi.Text=value;
			else
				lvi.SubItems.Add(value);
		}

		private void RebuildCutList()
		{
			CreateColumns();
			lastColSet=currentColSet;

			if (State.Cuts.Count>0)
			{
				int videoFrameCount=0;

				for (int index=0;index<State.Cuts.Count;++index)
				{
					CutPoint sr=State.Cuts[index];
					ListViewItem lvi=new ListViewItem();

					// Videospalten
					if (colCollection.Contains(CutListColumns.CutNo))
						AddColValue(lvi,(index+1).ToString());
					if (colCollection.Contains(CutListColumns.VideoName))
					{
						string name;
						if (!Settings.CurrentSettings.DisplayFullPathInformations)
							name=Path.GetFileName(sr.VideoName);
						else
							name=sr.VideoName;
						AddColValue(lvi,name);
					}
					// Display Start and End frame in the form "00:12:54,920 [P] 314" where "P" is the type of the picture
					if (colCollection.Contains(CutListColumns.VideoStart))
						AddColValue(lvi,GUIHelper.FormatFrameTimeAndType(sr.StartFrame,sr.VideoStream));
					if (colCollection.Contains(CutListColumns.VideoEnd))
						AddColValue(lvi,GUIHelper.FormatFrameTimeAndType(sr.EndFrame,sr.VideoStream));
					// Display duration of cuts in the form "00:12:54,920"
					if (colCollection.Contains(CutListColumns.VideoLength))
						AddColValue(lvi,Helper.FramesToTimeString(sr.EndFrame-sr.StartFrame+1,sr.VideoStream.FramesPerSecond));
					if (colCollection.Contains(CutListColumns.VideoNewStart))
						AddColValue(lvi,Helper.FramesToTimeString(videoFrameCount,sr.VideoStream.FramesPerSecond));
					videoFrameCount+=sr.EndFrame-sr.StartFrame+1;
					if (colCollection.Contains(CutListColumns.VideoNewEnd))
						AddColValue(lvi,Helper.FramesToTimeString(videoFrameCount,sr.VideoStream.FramesPerSecond));

					// falls vorhanden: Audiospalten
					for (int audioIndex=0;audioIndex<State.Cuts[0].AudioStreams.Count;++audioIndex)
					{
						if (colCollection.Contains(CutListColumns.AudioName))
						{
							string name;
							if (!Settings.CurrentSettings.DisplayFullPathInformations)
								name=Path.GetFileName(sr.AudioNames[audioIndex]);
							else
								name=sr.AudioNames[audioIndex];
							AddColValue(lvi,name);
						}
						if (colCollection.Contains(CutListColumns.AudioInDelay))
							AddColValue(lvi,Helper.DecimalRoundedToString(sr.AudioInfo(audioIndex).StartDelay,1)+" ms");
						if (colCollection.Contains(CutListColumns.AudioOutDelay))
							AddColValue(lvi,Helper.DecimalRoundedToString(sr.AudioInfo(audioIndex).EndDelay,1)+" ms");
					}
					lwCutList.Items.Add(lvi);
				}
			}
		}

		private void DeleteCuts(ListView.SelectedIndexCollection sl)
		{
			int[] indices=new int[sl.Count];
			sl.CopyTo(indices,0);
			// Rckwrts lschen, sonst stimmen die Indices nicht mehr
			for (int index=indices.Length-1;index>=0;--index)
				State.DeleteCut(indices[index]);
		}

		#endregion

		#region Event Handler

		private void OnSetDefaults(bool b_NewProject)
		{
			if (b_NewProject)
			{
				CreateColumns();
				butDeleteCut.Enabled=butMoveCutDown.Enabled=butMoveCutUp.Enabled=false;
			}
			else // Remove selection, because we loaded another video file now
			{
				foreach (ListViewItem i_Item in lwCutList.SelectedItems)
				{
					i_Item.Selected = false;
				}
			}
		}

		private void OnCutPointModified(int selectedCutIndex)
		{
			RebuildCutList();

			if (selectedCutIndex >= 0 && selectedCutIndex < lwCutList.Items.Count)
			{
				// Set selection only if not blocked or same video file
				if (!mb_BlockSelection || 0==string.Compare(State.VideoStream.StreamName, State.Cuts[selectedCutIndex].VideoName, true))
					lwCutList.Items[selectedCutIndex].Selected=true;

				lwCutList.EnsureVisible(selectedCutIndex);
			}

			State.ReportCutListSelection(new ArrayList(lwCutList.SelectedIndices));

			butMoveCutUp.Enabled=butMoveCutDown.Enabled=lwCutList.SelectedIndices.Count==1;
			butDeleteCut.Enabled=lwCutList.SelectedIndices.Count>=1;
		}

		private void OnSettingsChanged()
		{
			RebuildCutList();
		}

		/// <summary>
		/// If user switched to a video tab of another video file than the one
		/// which is currently selected in the listview -> remove selection
		/// </summary>
		private void OnAudioVideoOpened(bool videoOpened, bool audioOpened, bool reOpened)
		{
			if (!videoOpened || State.VideoStream==null || lwCutList.SelectedIndices.Count != 1)
				return;

			int index = lwCutList.SelectedIndices[0];
			if (0 == string.Compare(State.VideoStream.StreamName, State.Cuts[index].VideoName, true))
				return; // the video file did not change

			// Important!!
			// The event handler lwCutList_SelectedIndexChanged must be blocked,
			// otherwise it tries to set CurrentCutOut BEFORE ALL OnVideoOpened
			// event handlers have been called!! (wrong calling order -> crash)
			mb_BlockSelection = true;
			lwCutList.Items[index].Selected = false; // remove selection
			mb_BlockSelection = false;
		}

		#endregion

		#region ListView events und Mods

		private void butMoveCutUp_Click(object sender, System.EventArgs e)
		{
			if (lwCutList.SelectedIndices.Count==1)
			{
				int index=lwCutList.SelectedIndices[0];
				if (State.MoveCutUp(index))
				{
					// Neu selektieren
					lwCutList.EnsureVisible(index-1);
					lwCutList.Items[index-1].Selected=true;
					lwCutList.Items[index-1].Focused=true;
				}
			}
		}

		private void butMoveCutDown_Click(object sender, System.EventArgs e)
		{
			if (lwCutList.SelectedIndices.Count==1)
			{
				int index=lwCutList.SelectedIndices[0];
				if (State.MoveCutDown(index))
				{
					// Neu selektieren
					lwCutList.EnsureVisible(index+1);
					lwCutList.Items[index+1].Selected=true;
					lwCutList.Items[index+1].Focused=true;
				}
			}
		}

		private void butDeleteCut_Click(object sender, System.EventArgs e)
		{
			if (lwCutList.SelectedIndices.Count>0)
				DeleteCuts(lwCutList.SelectedIndices);
		}

		private void lwCutList_KeyDown(object sender, System.Windows.Forms.KeyEventArgs e)
		{
			if (e.KeyData==Keys.Delete)
				if (lwCutList.SelectedIndices.Count>0)
					DeleteCuts(lwCutList.SelectedIndices);
		}

		/// <summary>
		/// When the selected row changes this handler is called two times:
		/// 1.) after removing the old selection (with SelectedIndices.Count = 0)
		/// 2.) after the new selection has been set
		/// </summary>
		private void lwCutList_SelectedIndexChanged(object sender, System.EventArgs e)
		{
			if (mb_BlockSelection)
				return;

			if (lwCutList.SelectedIndices.Count==1)
			{
				CutPoint i_Cut = State.Cuts[lwCutList.SelectedIndices[0]];
				CMMain.globalApplication.SelectVideoTab(i_Cut.VideoStream.StreamName);
				State.CurrentCutOut = i_Cut;
			}
			else State.CurrentCutOut = null;

			// Draw scrollbar backgound colors in ScrollCtrl
			State.ReportCutListSelection(new ArrayList(lwCutList.SelectedIndices));

			butMoveCutUp.Enabled=butMoveCutDown.Enabled=lwCutList.SelectedIndices.Count==1;
			butDeleteCut.Enabled=lwCutList.SelectedIndices.Count>=1;
		}

		#endregion

		#region Menu events

		private void cmCutList_Popup(object sender, System.EventArgs e)
		{
			// Men nur aktiv, falls genau ein Eintrag ausgewhlt wurde
			bool crit1=lwCutList.SelectedItems.Count==1;
			bool crit2=lwCutList.SelectedItems.Count>=1;
			bool crit3=lwCutList.SelectedItems.Count>=2;

			menuGotoCutIn.Visible=crit1;
			menuGotoCutOut.Visible=crit1;
			menuEditCut.Visible=crit1;
			menuDuplicateCut.Visible=crit1;
			menuSpacer1.Visible=crit1;
			menuDeleteCut.Visible=crit2;
			menuSpacer2.Visible=crit2;
			menuPreviewEntry.Visible=crit1;
			menuCutSelectedEntries.Visible=crit2;
			menuSingleCut.Visible=crit3;
			menuSpacer3.Visible=lwCutList.SelectedItems.Count>0;
			menuConfigure.Visible=true;

			// Goto CutIn/CutOut always visible as the right mouse click 
			// also selects the correct video file
		}

		private void menuDeleteCut_Click(object sender, System.EventArgs e)
		{
			if (lwCutList.SelectedIndices.Count>0)
				if (lwCutList.SelectedIndices.Count>0)
					DeleteCuts(lwCutList.SelectedIndices);
		}

		private void menuGotoCutIn_Click(object sender, System.EventArgs e)
		{
			if (lwCutList.SelectedItems.Count>0)
			{
				ListViewItem lvi=lwCutList.SelectedItems[0];
				State.GoToVideoPosition(State.Cuts[lvi.Index].StartFrame);
			}
		}

		private void menuGotoCutOut_Click(object sender, System.EventArgs e)
		{
			if (lwCutList.SelectedItems.Count>0)
			{
				ListViewItem lvi=lwCutList.SelectedItems[0];
				State.GoToVideoPosition(State.Cuts[lvi.Index].EndFrame);
			}
		}

		private void menuEditCut_Click(object sender, System.EventArgs e)
		{
			if (lwCutList.SelectedItems.Count!=1)
				return;
			
			// The edited cut will be removed from the cutlist
			// BUT: it must NOT switch to another video file because the new
			// cutlist selection may select another video file
			mb_BlockSelection = true;
			State.EditCut(lwCutList.SelectedIndices[0]);
			mb_BlockSelection = false;
		}

		private void menuPreviewEntry_Click(object sender, System.EventArgs e)
		{
			if (lwCutList.SelectedItems.Count==1)
				State.PreviewSelectedCut(lwCutList.SelectedIndices[0]);
		}

		private void menuCutSelectedEntries_Click(object sender, System.EventArgs e)
		{
			if (lwCutList.SelectedIndices.Count>=1)
			{
				// CutList mit den gewnschten Schnitten erzeugen
				CutList tempList=new CutList();
				for (int index=0;index<lwCutList.SelectedIndices.Count;++index)
					tempList.Add(State.Cuts[lwCutList.SelectedIndices[index]]);

				// Schnittdialog bringen
				CutDialog cd=new CutDialog(State);
				DialogResult res=cd.ShowDialog();
				if (res==DialogResult.OK || res==DialogResult.Yes)
					State.ProcessCut(tempList,cd.CutFileName,res==DialogResult.Yes,false);
			}		
		}

		private void menuSingleCut_Click(object sender, System.EventArgs e)
		{
			if (lwCutList.SelectedIndices.Count>=1)
			{
				// Schnittdialog bringen
				CutDialog cd=new CutDialog(State);
				DialogResult res=cd.ShowDialog();
				if (res==DialogResult.OK || res==DialogResult.Yes)
				{
					// CutList mit dem jeweils gewnschten Schnitt erzeugen
					for (int index=0;index<lwCutList.SelectedIndices.Count;++index)
					{
						CutList tempList=new CutList();
						tempList.Add(State.Cuts[lwCutList.SelectedIndices[index]]);
						string fileExt=Path.GetExtension(cd.CutFileName);
						string baseName=Path.ChangeExtension(cd.CutFileName,null);
						State.ProcessCut(tempList,string.Format("{0}_{1:D2}{2}",baseName,index+1,fileExt),res==DialogResult.Yes,index<lwCutList.SelectedIndices.Count-1);
					}
				}
			}
		}

		private void menuDuplicateCut_Click(object sender, System.EventArgs e)
		{
			if (lwCutList.SelectedItems.Count==1)
				State.DuplicateCut(lwCutList.SelectedIndices[0]);
		}

		private void menuConfigure_Click(object sender, System.EventArgs e)
		{
			ConfigureCutList ccl=new ConfigureCutList(colCollection);
			if (ccl.ShowDialog(this.ParentForm)==DialogResult.OK)
				PersistData=ccl.Columns;
		}

		#endregion

		#region "Virtuals"

		private void SaveWidth()
		{
			if (lastColSet==currentColSet)
				for (int index=0;index<lwCutList.Columns.Count && index<colCollection.Count;++index)
					colCollection.SetByIndex(index,lwCutList.Columns[index].Width);
		}

		public override object PersistData
		{
			get
			{
				SaveWidth();
				return colCollection;
			}
			set
			{
				if (value is SortedList)
				{
					colCollection=(SortedList)value;
					currentColSet=Guid.NewGuid();
					RebuildCutList();
				}
			}
		}

		#endregion

	}
}
