/*
 * Cuttermaran - The Mpeg Cutter
 * 
 * Copyright (C) 2003-2006  Tobias Arnold (cuttermaran@gmx.net)
 * 
 * This file is part of cuttermaran, a free MPEG cut program.
 * See http://www.cuttermaran.de for updates.
 *
 * This program is free software; you can redistribute it and/or modify it 
 * under the terms of the GNU General Public License as published by the 
 * Free Software Foundation; either version 2 of the License, or 
 * (at your option) any later version. 
 * 
 * This program is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the 
 * GNU General Public License for more details. 
 * 
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */

using System;
using System.Windows.Forms;
using System.Drawing;
using Configuration;

namespace GUI.MainForm
{
	/// <summary>
	/// Summary description for MainBaseControl.
	/// </summary>
	public class MainBaseControl : UserControl
	{
		public static bool designMode=true;
		protected decimal scaleX=1m;
		protected decimal scaleY=1m;

		public MainBaseControl()
		{
		}

		private void OnGuiEnabled(Control sender, bool b_Enabled)
		{
			if (this.GetType() == sender.GetType())
				return;
			
			this.Enabled = b_Enabled;

			// enable / disable the TabControl which owns the Cut-, Chapter-, ResultList
			// We cannot be sure which of them is hidden, so we do them all
			if (this is CutListCtrl || this is ChapterListCtrl || 
				this is ResultCtrl  || this is StreamInfoCtrl)
			{
				Control i_Parent = this.Parent;
				while  (i_Parent != null)
				{
					if (i_Parent is Crownwood.Magic.Controls.TabControl)
					{
						i_Parent.Enabled = b_Enabled;
						break;
					}
					i_Parent = i_Parent.Parent;
				}
			}
		}

		static protected StateController State
		{
			get
			{
				return CMMain.globalApplication.Controller;
			}
		}

		public virtual object PersistData
		{
			get
			{
				return null;
			}
			set
			{
			}
		}

		protected void FitImage(Control parentControl,PictureBox pb,decimal ratio)
		{
			if (pb.Image!=null)
			{
				DockStyle ds=Settings.CurrentSettings.ApplyAspectRatio?DockStyle.None:DockStyle.Fill;
				if (pb.Dock!=ds)
					pb.Dock=ds;
				if (ds!=DockStyle.Fill)
				{
					Size fitSize=parentControl.ClientSize;
					Point fitLoc=new Point(0,0);
					if (ratio!=-1m)
					{
						fitSize.Width=parentControl.ClientSize.Width;
						fitSize.Height=(int)(fitSize.Width/ratio);
						if (fitSize.Height>parentControl.ClientSize.Height)
						{
							fitSize.Height=parentControl.ClientSize.Height;
							fitSize.Width=(int)(fitSize.Height*ratio);
							fitLoc.X=(parentControl.ClientSize.Width-fitSize.Width)/2;
						}
						else
						{
							fitLoc.Y=(parentControl.ClientSize.Height-fitSize.Height)/2;
						}
					}
					if (pb.Location!=fitLoc)
						pb.Location=fitLoc;
					if (pb.Size!=fitSize)
						pb.Size=fitSize;
				}
			}
			else
				pb.Dock=DockStyle.Fill;
		}

		protected override void OnLoad(EventArgs e)
		{
			if (!designMode && Settings.CurrentSettings.DPIRescaling)
				using (Graphics gr=this.CreateGraphics())
				{
					scaleX=96.0m/(decimal)gr.DpiX;
					scaleY=96.0m/(decimal)gr.DpiY;
				}

			base.OnLoad (e);

			if (!designMode)
			{
				this.AllowDrop = true;
				this.DragDrop += new System.Windows.Forms.DragEventHandler(CMMain.globalApplication.CMMain_DragDrop);
				this.DragOver += new System.Windows.Forms.DragEventHandler(CMMain.globalApplication.CMMain_DragOver);
				State.GuiEnabled+=new GuiEnabledDelegate(OnGuiEnabled);
			}

			if (scaleX!=1m || scaleY!=1m)
			{
				this.SuspendLayout();
				GUIHelper.ScaleControl(this,this,scaleX,scaleY);
				this.ResumeLayout(false);
			}

		}
	}
}
