/*
 * Cuttermaran - The Mpeg Cutter
 * 
 * Copyright (C) 2003-2006  Tobias Arnold (cuttermaran@gmx.net)
 * 
 * This file is part of cuttermaran, a free MPEG cut program.
 * See http://www.cuttermaran.de for updates.
 *
 * This program is free software; you can redistribute it and/or modify it 
 * under the terms of the GNU General Public License as published by the 
 * Free Software Foundation; either version 2 of the License, or 
 * (at your option) any later version. 
 * 
 * This program is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the 
 * GNU General Public License for more details. 
 * 
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */

using System;
using System.Collections;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Windows.Forms;
using Coremoran.AVStreams;
using Configuration;
using StringResources;
using Coremoran.Common;

namespace GUI.MainForm
{
	/// <summary>
	/// Summary description for MarkerCtrl.
	/// </summary>
	public class MarkerCtrl : MainBaseControl
	{
		private System.Windows.Forms.Panel panelSelection;
		private System.Windows.Forms.ListBox lbMarker;
		private System.Windows.Forms.Panel panelSetMarker;
		private System.Windows.Forms.Button butCreateMarker;
		private System.Windows.Forms.Panel panelDelMarker;
		private System.Windows.Forms.Button butDelMarker;
		private System.Windows.Forms.ToolTip stdToolTip;
		private System.ComponentModel.IContainer components;

		#region ctor / Dispose

		public MarkerCtrl()
		{
			// This call is required by the Windows.Forms Form Designer.
			InitializeComponent();

			State.SetDefaults+=new SetDefaultsDelegate(this.OnSetDefaults);
			State.MarkerChanged+=new MarkerChangedDelegate(OnMarkerChanged);
			State.AudioVideoOpened+=new AudioVideoOpenedDelegate(this.OnAudioVideoOpened);
		}

		/// <summary> 
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#endregion

		#region Component Designer generated code
		/// <summary> 
		/// Required method for Designer support - do not modify 
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.components = new System.ComponentModel.Container();
			System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(MarkerCtrl));
			this.panelSelection = new System.Windows.Forms.Panel();
			this.lbMarker = new System.Windows.Forms.ListBox();
			this.panelSetMarker = new System.Windows.Forms.Panel();
			this.butCreateMarker = new System.Windows.Forms.Button();
			this.panelDelMarker = new System.Windows.Forms.Panel();
			this.butDelMarker = new System.Windows.Forms.Button();
			this.stdToolTip = new System.Windows.Forms.ToolTip(this.components);
			this.panelSelection.SuspendLayout();
			this.panelSetMarker.SuspendLayout();
			this.panelDelMarker.SuspendLayout();
			this.SuspendLayout();
			// 
			// panelSelection
			// 
			this.panelSelection.AccessibleDescription = resources.GetString("panelSelection.AccessibleDescription");
			this.panelSelection.AccessibleName = resources.GetString("panelSelection.AccessibleName");
			this.panelSelection.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("panelSelection.Anchor")));
			this.panelSelection.AutoScroll = ((bool)(resources.GetObject("panelSelection.AutoScroll")));
			this.panelSelection.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("panelSelection.AutoScrollMargin")));
			this.panelSelection.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("panelSelection.AutoScrollMinSize")));
			this.panelSelection.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("panelSelection.BackgroundImage")));
			this.panelSelection.Controls.Add(this.lbMarker);
			this.panelSelection.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("panelSelection.Dock")));
			this.panelSelection.Enabled = ((bool)(resources.GetObject("panelSelection.Enabled")));
			this.panelSelection.Font = ((System.Drawing.Font)(resources.GetObject("panelSelection.Font")));
			this.panelSelection.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("panelSelection.ImeMode")));
			this.panelSelection.Location = ((System.Drawing.Point)(resources.GetObject("panelSelection.Location")));
			this.panelSelection.Name = "panelSelection";
			this.panelSelection.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("panelSelection.RightToLeft")));
			this.panelSelection.Size = ((System.Drawing.Size)(resources.GetObject("panelSelection.Size")));
			this.panelSelection.TabIndex = ((int)(resources.GetObject("panelSelection.TabIndex")));
			this.panelSelection.Text = resources.GetString("panelSelection.Text");
			this.stdToolTip.SetToolTip(this.panelSelection, resources.GetString("panelSelection.ToolTip"));
			this.panelSelection.Visible = ((bool)(resources.GetObject("panelSelection.Visible")));
			// 
			// lbMarker
			// 
			this.lbMarker.AccessibleDescription = resources.GetString("lbMarker.AccessibleDescription");
			this.lbMarker.AccessibleName = resources.GetString("lbMarker.AccessibleName");
			this.lbMarker.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("lbMarker.Anchor")));
			this.lbMarker.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("lbMarker.BackgroundImage")));
			this.lbMarker.ColumnWidth = ((int)(resources.GetObject("lbMarker.ColumnWidth")));
			this.lbMarker.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("lbMarker.Dock")));
			this.lbMarker.Enabled = ((bool)(resources.GetObject("lbMarker.Enabled")));
			this.lbMarker.Font = ((System.Drawing.Font)(resources.GetObject("lbMarker.Font")));
			this.lbMarker.HorizontalExtent = ((int)(resources.GetObject("lbMarker.HorizontalExtent")));
			this.lbMarker.HorizontalScrollbar = ((bool)(resources.GetObject("lbMarker.HorizontalScrollbar")));
			this.lbMarker.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("lbMarker.ImeMode")));
			this.lbMarker.IntegralHeight = ((bool)(resources.GetObject("lbMarker.IntegralHeight")));
			this.lbMarker.ItemHeight = ((int)(resources.GetObject("lbMarker.ItemHeight")));
			this.lbMarker.Location = ((System.Drawing.Point)(resources.GetObject("lbMarker.Location")));
			this.lbMarker.Name = "lbMarker";
			this.lbMarker.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("lbMarker.RightToLeft")));
			this.lbMarker.ScrollAlwaysVisible = ((bool)(resources.GetObject("lbMarker.ScrollAlwaysVisible")));
			this.lbMarker.Size = ((System.Drawing.Size)(resources.GetObject("lbMarker.Size")));
			this.lbMarker.TabIndex = ((int)(resources.GetObject("lbMarker.TabIndex")));
			this.stdToolTip.SetToolTip(this.lbMarker, resources.GetString("lbMarker.ToolTip"));
			this.lbMarker.Visible = ((bool)(resources.GetObject("lbMarker.Visible")));
			this.lbMarker.DoubleClick += new System.EventHandler(this.lbMarker_DoubleClick);
			// 
			// panelSetMarker
			// 
			this.panelSetMarker.AccessibleDescription = resources.GetString("panelSetMarker.AccessibleDescription");
			this.panelSetMarker.AccessibleName = resources.GetString("panelSetMarker.AccessibleName");
			this.panelSetMarker.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("panelSetMarker.Anchor")));
			this.panelSetMarker.AutoScroll = ((bool)(resources.GetObject("panelSetMarker.AutoScroll")));
			this.panelSetMarker.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("panelSetMarker.AutoScrollMargin")));
			this.panelSetMarker.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("panelSetMarker.AutoScrollMinSize")));
			this.panelSetMarker.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("panelSetMarker.BackgroundImage")));
			this.panelSetMarker.Controls.Add(this.butCreateMarker);
			this.panelSetMarker.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("panelSetMarker.Dock")));
			this.panelSetMarker.Enabled = ((bool)(resources.GetObject("panelSetMarker.Enabled")));
			this.panelSetMarker.Font = ((System.Drawing.Font)(resources.GetObject("panelSetMarker.Font")));
			this.panelSetMarker.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("panelSetMarker.ImeMode")));
			this.panelSetMarker.Location = ((System.Drawing.Point)(resources.GetObject("panelSetMarker.Location")));
			this.panelSetMarker.Name = "panelSetMarker";
			this.panelSetMarker.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("panelSetMarker.RightToLeft")));
			this.panelSetMarker.Size = ((System.Drawing.Size)(resources.GetObject("panelSetMarker.Size")));
			this.panelSetMarker.TabIndex = ((int)(resources.GetObject("panelSetMarker.TabIndex")));
			this.panelSetMarker.Text = resources.GetString("panelSetMarker.Text");
			this.stdToolTip.SetToolTip(this.panelSetMarker, resources.GetString("panelSetMarker.ToolTip"));
			this.panelSetMarker.Visible = ((bool)(resources.GetObject("panelSetMarker.Visible")));
			// 
			// butCreateMarker
			// 
			this.butCreateMarker.AccessibleDescription = resources.GetString("butCreateMarker.AccessibleDescription");
			this.butCreateMarker.AccessibleName = resources.GetString("butCreateMarker.AccessibleName");
			this.butCreateMarker.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butCreateMarker.Anchor")));
			this.butCreateMarker.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butCreateMarker.BackgroundImage")));
			this.butCreateMarker.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butCreateMarker.Dock")));
			this.butCreateMarker.Enabled = ((bool)(resources.GetObject("butCreateMarker.Enabled")));
			this.butCreateMarker.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butCreateMarker.FlatStyle")));
			this.butCreateMarker.Font = ((System.Drawing.Font)(resources.GetObject("butCreateMarker.Font")));
			this.butCreateMarker.Image = ((System.Drawing.Image)(resources.GetObject("butCreateMarker.Image")));
			this.butCreateMarker.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butCreateMarker.ImageAlign")));
			this.butCreateMarker.ImageIndex = ((int)(resources.GetObject("butCreateMarker.ImageIndex")));
			this.butCreateMarker.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butCreateMarker.ImeMode")));
			this.butCreateMarker.Location = ((System.Drawing.Point)(resources.GetObject("butCreateMarker.Location")));
			this.butCreateMarker.Name = "butCreateMarker";
			this.butCreateMarker.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butCreateMarker.RightToLeft")));
			this.butCreateMarker.Size = ((System.Drawing.Size)(resources.GetObject("butCreateMarker.Size")));
			this.butCreateMarker.TabIndex = ((int)(resources.GetObject("butCreateMarker.TabIndex")));
			this.butCreateMarker.Text = resources.GetString("butCreateMarker.Text");
			this.butCreateMarker.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butCreateMarker.TextAlign")));
			this.stdToolTip.SetToolTip(this.butCreateMarker, resources.GetString("butCreateMarker.ToolTip"));
			this.butCreateMarker.Visible = ((bool)(resources.GetObject("butCreateMarker.Visible")));
			this.butCreateMarker.Click += new System.EventHandler(this.butCreateMarker_Click);
			// 
			// panelDelMarker
			// 
			this.panelDelMarker.AccessibleDescription = resources.GetString("panelDelMarker.AccessibleDescription");
			this.panelDelMarker.AccessibleName = resources.GetString("panelDelMarker.AccessibleName");
			this.panelDelMarker.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("panelDelMarker.Anchor")));
			this.panelDelMarker.AutoScroll = ((bool)(resources.GetObject("panelDelMarker.AutoScroll")));
			this.panelDelMarker.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("panelDelMarker.AutoScrollMargin")));
			this.panelDelMarker.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("panelDelMarker.AutoScrollMinSize")));
			this.panelDelMarker.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("panelDelMarker.BackgroundImage")));
			this.panelDelMarker.Controls.Add(this.butDelMarker);
			this.panelDelMarker.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("panelDelMarker.Dock")));
			this.panelDelMarker.Enabled = ((bool)(resources.GetObject("panelDelMarker.Enabled")));
			this.panelDelMarker.Font = ((System.Drawing.Font)(resources.GetObject("panelDelMarker.Font")));
			this.panelDelMarker.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("panelDelMarker.ImeMode")));
			this.panelDelMarker.Location = ((System.Drawing.Point)(resources.GetObject("panelDelMarker.Location")));
			this.panelDelMarker.Name = "panelDelMarker";
			this.panelDelMarker.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("panelDelMarker.RightToLeft")));
			this.panelDelMarker.Size = ((System.Drawing.Size)(resources.GetObject("panelDelMarker.Size")));
			this.panelDelMarker.TabIndex = ((int)(resources.GetObject("panelDelMarker.TabIndex")));
			this.panelDelMarker.Text = resources.GetString("panelDelMarker.Text");
			this.stdToolTip.SetToolTip(this.panelDelMarker, resources.GetString("panelDelMarker.ToolTip"));
			this.panelDelMarker.Visible = ((bool)(resources.GetObject("panelDelMarker.Visible")));
			// 
			// butDelMarker
			// 
			this.butDelMarker.AccessibleDescription = resources.GetString("butDelMarker.AccessibleDescription");
			this.butDelMarker.AccessibleName = resources.GetString("butDelMarker.AccessibleName");
			this.butDelMarker.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butDelMarker.Anchor")));
			this.butDelMarker.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butDelMarker.BackgroundImage")));
			this.butDelMarker.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butDelMarker.Dock")));
			this.butDelMarker.Enabled = ((bool)(resources.GetObject("butDelMarker.Enabled")));
			this.butDelMarker.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butDelMarker.FlatStyle")));
			this.butDelMarker.Font = ((System.Drawing.Font)(resources.GetObject("butDelMarker.Font")));
			this.butDelMarker.Image = ((System.Drawing.Image)(resources.GetObject("butDelMarker.Image")));
			this.butDelMarker.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butDelMarker.ImageAlign")));
			this.butDelMarker.ImageIndex = ((int)(resources.GetObject("butDelMarker.ImageIndex")));
			this.butDelMarker.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butDelMarker.ImeMode")));
			this.butDelMarker.Location = ((System.Drawing.Point)(resources.GetObject("butDelMarker.Location")));
			this.butDelMarker.Name = "butDelMarker";
			this.butDelMarker.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butDelMarker.RightToLeft")));
			this.butDelMarker.Size = ((System.Drawing.Size)(resources.GetObject("butDelMarker.Size")));
			this.butDelMarker.TabIndex = ((int)(resources.GetObject("butDelMarker.TabIndex")));
			this.butDelMarker.Text = resources.GetString("butDelMarker.Text");
			this.butDelMarker.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butDelMarker.TextAlign")));
			this.stdToolTip.SetToolTip(this.butDelMarker, resources.GetString("butDelMarker.ToolTip"));
			this.butDelMarker.Visible = ((bool)(resources.GetObject("butDelMarker.Visible")));
			this.butDelMarker.Click += new System.EventHandler(this.butDelMarker_Click);
			// 
			// MarkerCtrl
			// 
			this.AccessibleDescription = resources.GetString("$this.AccessibleDescription");
			this.AccessibleName = resources.GetString("$this.AccessibleName");
			this.AutoScroll = ((bool)(resources.GetObject("$this.AutoScroll")));
			this.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("$this.AutoScrollMargin")));
			this.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("$this.AutoScrollMinSize")));
			this.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("$this.BackgroundImage")));
			this.Controls.Add(this.panelDelMarker);
			this.Controls.Add(this.panelSetMarker);
			this.Controls.Add(this.panelSelection);
			this.Enabled = ((bool)(resources.GetObject("$this.Enabled")));
			this.Font = ((System.Drawing.Font)(resources.GetObject("$this.Font")));
			this.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("$this.ImeMode")));
			this.Location = ((System.Drawing.Point)(resources.GetObject("$this.Location")));
			this.Name = "MarkerCtrl";
			this.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("$this.RightToLeft")));
			this.Size = ((System.Drawing.Size)(resources.GetObject("$this.Size")));
			this.stdToolTip.SetToolTip(this, resources.GetString("$this.ToolTip"));
			this.panelSelection.ResumeLayout(false);
			this.panelSetMarker.ResumeLayout(false);
			this.panelDelMarker.ResumeLayout(false);
			this.ResumeLayout(false);

		}
		#endregion

		#region Event Handler

		private void OnSetDefaults(bool b_NewProject)
		{
			// b_NewProject=false: when opening a new video file -> do nothing here
			if (b_NewProject)
			{
				butCreateMarker.Enabled=false;
				lbMarker.Items.Clear();
			}
		}

		private void OnAudioVideoOpened(bool videoOpened, bool audioOpened, bool reOpened)
		{
			if (videoOpened)
			{
				butCreateMarker.Enabled=(State.VideoStream!=null);
				OnMarkerChanged();
			}
		}

		private void OnMarkerChanged()
		{
			lbMarker.Items.Clear();
			foreach (int pos in State.AllMarkers)
			{
				lbMarker.Items.Add(Helper.FramesToTimeAndPicString(pos,State.VideoStream.FramesPerSecond));
			}
		}

		#endregion

		#region Ctrl Events

		private void butDelMarker_Click(object sender, System.EventArgs e)
		{
			State.RemoveMarker(lbMarker.SelectedIndex);
		}

		private void butCreateMarker_Click(object sender, System.EventArgs e)
		{
			State.SetMarker(State.CurrentVideoPosition);
		}

		private void lbMarker_DoubleClick(object sender, System.EventArgs e)
		{
			State.InvokeMarker(lbMarker.SelectedIndex);
		}

		#endregion
	}
}
