/*
 * Cuttermaran - The Mpeg Cutter
 * 
 * Copyright (C) 2003-2005  Tobias Arnold (cuttermaran@gmx.net)
 * 
 * This file is part of cuttermaran, a free MPEG cut program.
 * See http://wwww.cuttermaran.de for updates.
 *
 * This program is free software; you can redistribute it and/or modify it 
 * under the terms of the GNU General Public License as published by the 
 * Free Software Foundation; either version 2 of the License, or 
 * (at your option) any later version. 
 * 
 * This program is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the 
 * GNU General Public License for more details. 
 * 
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */

using System;
using System.IO;
using System.Reflection;
using System.Collections;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Windows.Forms;
using Coremoran.AVStreams;
using Configuration;
using StringResources;
using Coremoran.Common;
using Coremoran.Algorithms;

namespace GUI.MainForm
{
	/// <summary>
	/// Summary description for NavigationCtrl.
	/// </summary>
	public class NavigationCtrl : MainBaseControl
	{
		private System.Windows.Forms.Button butNextIFrame;
		private System.Windows.Forms.Button butPrevIFrame;
		private System.Windows.Forms.Button butNextIPFrame;
		private System.Windows.Forms.Button butPrevIPFrame;
		private System.Windows.Forms.Button butPrevFrame;
		private System.Windows.Forms.Button butNextFrame;
		private System.Windows.Forms.Button butJump;
		private System.Windows.Forms.Button butStreamPoints;
		private System.Windows.Forms.Button butSetCutIn;
		private System.Windows.Forms.Button butSetCutOut;
		private System.Windows.Forms.Label lblCutOut;
		private System.Windows.Forms.Label lblCutIn;
		private System.Windows.Forms.Button butGoToCutIn;
		private System.Windows.Forms.Button butGoToCutOut;
		private System.Windows.Forms.Button butAddToCutList;
		private System.Windows.Forms.Button butCreateChapter;
		private System.Windows.Forms.Button butCut;
		private System.Windows.Forms.ToolTip stdToolTip;
		private System.Windows.Forms.Button butPreview;
		private System.ComponentModel.IContainer components;

		private bool  mb_AllowCutIn  = false;
		private bool  mb_AllowCutOut = false;
		private Timer mi_IconTimer   = new Timer();
		private int ms32_LastEvent   = 0;
		private bool  mb_UpdatePending = true;
		private Image mi_CutIcon;
		private Image mi_NoCutIcon;

		#region ctor / Dispose

		public NavigationCtrl()
		{
			// This call is required by the Windows.Forms Form Designer.
			InitializeComponent();

			// Fr Events registrieren
			State.SetDefaults+=new SetDefaultsDelegate(this.OnSetDefaults);
			State.VideoPositionUpdated+=new VideoPositionUpdatedDelegate(this.OnVideoPositionUpdated);
			State.AudioVideoOpened+=new AudioVideoOpenedDelegate(this.OnAudioVideoOpened);
			State.CurrentCutModified+=new CurrentCutModifiedDelegate(this.OnCurrentCutModified);
			State.CutPointModified+=new CutPointModifiedDelegate(OnCutPointModified);
			State.SettingsChanged+=new SettingsChangedDelegate(OnSettingsChanged);

			// Load the two icons to be displayed on the CutIn and CutOut buttons
			// The icons must have been set to "embedded" in the Solution explorer
			Assembly i_Ass  = Assembly.GetExecutingAssembly();
			Stream   i_Stm0 = i_Ass.GetManifestResourceStream("GUI.icons.CutNo_16.ico");
			Stream   i_Stm1 = i_Ass.GetManifestResourceStream("GUI.icons.Cut_16.ico");
			mi_NoCutIcon    = Image.FromStream(i_Stm0);
			mi_CutIcon      = Image.FromStream(i_Stm1);

			mi_IconTimer.Tick += new EventHandler(OnIconTimer);
			mi_IconTimer.Interval = 300;
			mi_IconTimer.Start();
		}

		/// <summary> 
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#endregion

		#region Component Designer generated code
		/// <summary> 
		/// Required method for Designer support - do not modify 
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.components = new System.ComponentModel.Container();
			System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(NavigationCtrl));
			this.butNextIFrame = new System.Windows.Forms.Button();
			this.butPrevIFrame = new System.Windows.Forms.Button();
			this.butNextIPFrame = new System.Windows.Forms.Button();
			this.butPrevIPFrame = new System.Windows.Forms.Button();
			this.butPrevFrame = new System.Windows.Forms.Button();
			this.butNextFrame = new System.Windows.Forms.Button();
			this.butJump = new System.Windows.Forms.Button();
			this.butStreamPoints = new System.Windows.Forms.Button();
			this.butSetCutIn = new System.Windows.Forms.Button();
			this.butSetCutOut = new System.Windows.Forms.Button();
			this.lblCutOut = new System.Windows.Forms.Label();
			this.lblCutIn = new System.Windows.Forms.Label();
			this.butGoToCutIn = new System.Windows.Forms.Button();
			this.butGoToCutOut = new System.Windows.Forms.Button();
			this.butAddToCutList = new System.Windows.Forms.Button();
			this.butCreateChapter = new System.Windows.Forms.Button();
			this.butCut = new System.Windows.Forms.Button();
			this.stdToolTip = new System.Windows.Forms.ToolTip(this.components);
			this.butPreview = new System.Windows.Forms.Button();
			this.SuspendLayout();
			// 
			// butNextIFrame
			// 
			this.butNextIFrame.AccessibleDescription = resources.GetString("butNextIFrame.AccessibleDescription");
			this.butNextIFrame.AccessibleName = resources.GetString("butNextIFrame.AccessibleName");
			this.butNextIFrame.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butNextIFrame.Anchor")));
			this.butNextIFrame.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butNextIFrame.BackgroundImage")));
			this.butNextIFrame.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butNextIFrame.Dock")));
			this.butNextIFrame.Enabled = ((bool)(resources.GetObject("butNextIFrame.Enabled")));
			this.butNextIFrame.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butNextIFrame.FlatStyle")));
			this.butNextIFrame.Font = ((System.Drawing.Font)(resources.GetObject("butNextIFrame.Font")));
			this.butNextIFrame.Image = ((System.Drawing.Image)(resources.GetObject("butNextIFrame.Image")));
			this.butNextIFrame.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butNextIFrame.ImageAlign")));
			this.butNextIFrame.ImageIndex = ((int)(resources.GetObject("butNextIFrame.ImageIndex")));
			this.butNextIFrame.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butNextIFrame.ImeMode")));
			this.butNextIFrame.Location = ((System.Drawing.Point)(resources.GetObject("butNextIFrame.Location")));
			this.butNextIFrame.Name = "butNextIFrame";
			this.butNextIFrame.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butNextIFrame.RightToLeft")));
			this.butNextIFrame.Size = ((System.Drawing.Size)(resources.GetObject("butNextIFrame.Size")));
			this.butNextIFrame.TabIndex = ((int)(resources.GetObject("butNextIFrame.TabIndex")));
			this.butNextIFrame.Text = resources.GetString("butNextIFrame.Text");
			this.butNextIFrame.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butNextIFrame.TextAlign")));
			this.stdToolTip.SetToolTip(this.butNextIFrame, resources.GetString("butNextIFrame.ToolTip"));
			this.butNextIFrame.Visible = ((bool)(resources.GetObject("butNextIFrame.Visible")));
			this.butNextIFrame.Click += new System.EventHandler(this.butNextIFrame_Click);
			// 
			// butPrevIFrame
			// 
			this.butPrevIFrame.AccessibleDescription = resources.GetString("butPrevIFrame.AccessibleDescription");
			this.butPrevIFrame.AccessibleName = resources.GetString("butPrevIFrame.AccessibleName");
			this.butPrevIFrame.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butPrevIFrame.Anchor")));
			this.butPrevIFrame.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butPrevIFrame.BackgroundImage")));
			this.butPrevIFrame.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butPrevIFrame.Dock")));
			this.butPrevIFrame.Enabled = ((bool)(resources.GetObject("butPrevIFrame.Enabled")));
			this.butPrevIFrame.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butPrevIFrame.FlatStyle")));
			this.butPrevIFrame.Font = ((System.Drawing.Font)(resources.GetObject("butPrevIFrame.Font")));
			this.butPrevIFrame.Image = ((System.Drawing.Image)(resources.GetObject("butPrevIFrame.Image")));
			this.butPrevIFrame.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butPrevIFrame.ImageAlign")));
			this.butPrevIFrame.ImageIndex = ((int)(resources.GetObject("butPrevIFrame.ImageIndex")));
			this.butPrevIFrame.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butPrevIFrame.ImeMode")));
			this.butPrevIFrame.Location = ((System.Drawing.Point)(resources.GetObject("butPrevIFrame.Location")));
			this.butPrevIFrame.Name = "butPrevIFrame";
			this.butPrevIFrame.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butPrevIFrame.RightToLeft")));
			this.butPrevIFrame.Size = ((System.Drawing.Size)(resources.GetObject("butPrevIFrame.Size")));
			this.butPrevIFrame.TabIndex = ((int)(resources.GetObject("butPrevIFrame.TabIndex")));
			this.butPrevIFrame.Text = resources.GetString("butPrevIFrame.Text");
			this.butPrevIFrame.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butPrevIFrame.TextAlign")));
			this.stdToolTip.SetToolTip(this.butPrevIFrame, resources.GetString("butPrevIFrame.ToolTip"));
			this.butPrevIFrame.Visible = ((bool)(resources.GetObject("butPrevIFrame.Visible")));
			this.butPrevIFrame.Click += new System.EventHandler(this.butPrevIFrame_Click);
			// 
			// butNextIPFrame
			// 
			this.butNextIPFrame.AccessibleDescription = resources.GetString("butNextIPFrame.AccessibleDescription");
			this.butNextIPFrame.AccessibleName = resources.GetString("butNextIPFrame.AccessibleName");
			this.butNextIPFrame.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butNextIPFrame.Anchor")));
			this.butNextIPFrame.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butNextIPFrame.BackgroundImage")));
			this.butNextIPFrame.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butNextIPFrame.Dock")));
			this.butNextIPFrame.Enabled = ((bool)(resources.GetObject("butNextIPFrame.Enabled")));
			this.butNextIPFrame.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butNextIPFrame.FlatStyle")));
			this.butNextIPFrame.Font = ((System.Drawing.Font)(resources.GetObject("butNextIPFrame.Font")));
			this.butNextIPFrame.Image = ((System.Drawing.Image)(resources.GetObject("butNextIPFrame.Image")));
			this.butNextIPFrame.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butNextIPFrame.ImageAlign")));
			this.butNextIPFrame.ImageIndex = ((int)(resources.GetObject("butNextIPFrame.ImageIndex")));
			this.butNextIPFrame.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butNextIPFrame.ImeMode")));
			this.butNextIPFrame.Location = ((System.Drawing.Point)(resources.GetObject("butNextIPFrame.Location")));
			this.butNextIPFrame.Name = "butNextIPFrame";
			this.butNextIPFrame.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butNextIPFrame.RightToLeft")));
			this.butNextIPFrame.Size = ((System.Drawing.Size)(resources.GetObject("butNextIPFrame.Size")));
			this.butNextIPFrame.TabIndex = ((int)(resources.GetObject("butNextIPFrame.TabIndex")));
			this.butNextIPFrame.Text = resources.GetString("butNextIPFrame.Text");
			this.butNextIPFrame.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butNextIPFrame.TextAlign")));
			this.stdToolTip.SetToolTip(this.butNextIPFrame, resources.GetString("butNextIPFrame.ToolTip"));
			this.butNextIPFrame.Visible = ((bool)(resources.GetObject("butNextIPFrame.Visible")));
			this.butNextIPFrame.Click += new System.EventHandler(this.butNextIPFrame_Click);
			// 
			// butPrevIPFrame
			// 
			this.butPrevIPFrame.AccessibleDescription = resources.GetString("butPrevIPFrame.AccessibleDescription");
			this.butPrevIPFrame.AccessibleName = resources.GetString("butPrevIPFrame.AccessibleName");
			this.butPrevIPFrame.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butPrevIPFrame.Anchor")));
			this.butPrevIPFrame.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butPrevIPFrame.BackgroundImage")));
			this.butPrevIPFrame.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butPrevIPFrame.Dock")));
			this.butPrevIPFrame.Enabled = ((bool)(resources.GetObject("butPrevIPFrame.Enabled")));
			this.butPrevIPFrame.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butPrevIPFrame.FlatStyle")));
			this.butPrevIPFrame.Font = ((System.Drawing.Font)(resources.GetObject("butPrevIPFrame.Font")));
			this.butPrevIPFrame.Image = ((System.Drawing.Image)(resources.GetObject("butPrevIPFrame.Image")));
			this.butPrevIPFrame.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butPrevIPFrame.ImageAlign")));
			this.butPrevIPFrame.ImageIndex = ((int)(resources.GetObject("butPrevIPFrame.ImageIndex")));
			this.butPrevIPFrame.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butPrevIPFrame.ImeMode")));
			this.butPrevIPFrame.Location = ((System.Drawing.Point)(resources.GetObject("butPrevIPFrame.Location")));
			this.butPrevIPFrame.Name = "butPrevIPFrame";
			this.butPrevIPFrame.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butPrevIPFrame.RightToLeft")));
			this.butPrevIPFrame.Size = ((System.Drawing.Size)(resources.GetObject("butPrevIPFrame.Size")));
			this.butPrevIPFrame.TabIndex = ((int)(resources.GetObject("butPrevIPFrame.TabIndex")));
			this.butPrevIPFrame.Text = resources.GetString("butPrevIPFrame.Text");
			this.butPrevIPFrame.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butPrevIPFrame.TextAlign")));
			this.stdToolTip.SetToolTip(this.butPrevIPFrame, resources.GetString("butPrevIPFrame.ToolTip"));
			this.butPrevIPFrame.Visible = ((bool)(resources.GetObject("butPrevIPFrame.Visible")));
			this.butPrevIPFrame.Click += new System.EventHandler(this.butPrevIPFrame_Click);
			// 
			// butPrevFrame
			// 
			this.butPrevFrame.AccessibleDescription = resources.GetString("butPrevFrame.AccessibleDescription");
			this.butPrevFrame.AccessibleName = resources.GetString("butPrevFrame.AccessibleName");
			this.butPrevFrame.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butPrevFrame.Anchor")));
			this.butPrevFrame.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butPrevFrame.BackgroundImage")));
			this.butPrevFrame.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butPrevFrame.Dock")));
			this.butPrevFrame.Enabled = ((bool)(resources.GetObject("butPrevFrame.Enabled")));
			this.butPrevFrame.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butPrevFrame.FlatStyle")));
			this.butPrevFrame.Font = ((System.Drawing.Font)(resources.GetObject("butPrevFrame.Font")));
			this.butPrevFrame.Image = ((System.Drawing.Image)(resources.GetObject("butPrevFrame.Image")));
			this.butPrevFrame.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butPrevFrame.ImageAlign")));
			this.butPrevFrame.ImageIndex = ((int)(resources.GetObject("butPrevFrame.ImageIndex")));
			this.butPrevFrame.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butPrevFrame.ImeMode")));
			this.butPrevFrame.Location = ((System.Drawing.Point)(resources.GetObject("butPrevFrame.Location")));
			this.butPrevFrame.Name = "butPrevFrame";
			this.butPrevFrame.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butPrevFrame.RightToLeft")));
			this.butPrevFrame.Size = ((System.Drawing.Size)(resources.GetObject("butPrevFrame.Size")));
			this.butPrevFrame.TabIndex = ((int)(resources.GetObject("butPrevFrame.TabIndex")));
			this.butPrevFrame.Text = resources.GetString("butPrevFrame.Text");
			this.butPrevFrame.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butPrevFrame.TextAlign")));
			this.stdToolTip.SetToolTip(this.butPrevFrame, resources.GetString("butPrevFrame.ToolTip"));
			this.butPrevFrame.Visible = ((bool)(resources.GetObject("butPrevFrame.Visible")));
			this.butPrevFrame.Click += new System.EventHandler(this.butPrevFrame_Click);
			// 
			// butNextFrame
			// 
			this.butNextFrame.AccessibleDescription = resources.GetString("butNextFrame.AccessibleDescription");
			this.butNextFrame.AccessibleName = resources.GetString("butNextFrame.AccessibleName");
			this.butNextFrame.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butNextFrame.Anchor")));
			this.butNextFrame.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butNextFrame.BackgroundImage")));
			this.butNextFrame.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butNextFrame.Dock")));
			this.butNextFrame.Enabled = ((bool)(resources.GetObject("butNextFrame.Enabled")));
			this.butNextFrame.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butNextFrame.FlatStyle")));
			this.butNextFrame.Font = ((System.Drawing.Font)(resources.GetObject("butNextFrame.Font")));
			this.butNextFrame.Image = ((System.Drawing.Image)(resources.GetObject("butNextFrame.Image")));
			this.butNextFrame.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butNextFrame.ImageAlign")));
			this.butNextFrame.ImageIndex = ((int)(resources.GetObject("butNextFrame.ImageIndex")));
			this.butNextFrame.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butNextFrame.ImeMode")));
			this.butNextFrame.Location = ((System.Drawing.Point)(resources.GetObject("butNextFrame.Location")));
			this.butNextFrame.Name = "butNextFrame";
			this.butNextFrame.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butNextFrame.RightToLeft")));
			this.butNextFrame.Size = ((System.Drawing.Size)(resources.GetObject("butNextFrame.Size")));
			this.butNextFrame.TabIndex = ((int)(resources.GetObject("butNextFrame.TabIndex")));
			this.butNextFrame.Text = resources.GetString("butNextFrame.Text");
			this.butNextFrame.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butNextFrame.TextAlign")));
			this.stdToolTip.SetToolTip(this.butNextFrame, resources.GetString("butNextFrame.ToolTip"));
			this.butNextFrame.Visible = ((bool)(resources.GetObject("butNextFrame.Visible")));
			this.butNextFrame.Click += new System.EventHandler(this.butNextFrame_Click);
			// 
			// butJump
			// 
			this.butJump.AccessibleDescription = resources.GetString("butJump.AccessibleDescription");
			this.butJump.AccessibleName = resources.GetString("butJump.AccessibleName");
			this.butJump.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butJump.Anchor")));
			this.butJump.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butJump.BackgroundImage")));
			this.butJump.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butJump.Dock")));
			this.butJump.Enabled = ((bool)(resources.GetObject("butJump.Enabled")));
			this.butJump.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butJump.FlatStyle")));
			this.butJump.Font = ((System.Drawing.Font)(resources.GetObject("butJump.Font")));
			this.butJump.Image = ((System.Drawing.Image)(resources.GetObject("butJump.Image")));
			this.butJump.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butJump.ImageAlign")));
			this.butJump.ImageIndex = ((int)(resources.GetObject("butJump.ImageIndex")));
			this.butJump.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butJump.ImeMode")));
			this.butJump.Location = ((System.Drawing.Point)(resources.GetObject("butJump.Location")));
			this.butJump.Name = "butJump";
			this.butJump.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butJump.RightToLeft")));
			this.butJump.Size = ((System.Drawing.Size)(resources.GetObject("butJump.Size")));
			this.butJump.TabIndex = ((int)(resources.GetObject("butJump.TabIndex")));
			this.butJump.Text = resources.GetString("butJump.Text");
			this.butJump.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butJump.TextAlign")));
			this.stdToolTip.SetToolTip(this.butJump, resources.GetString("butJump.ToolTip"));
			this.butJump.Visible = ((bool)(resources.GetObject("butJump.Visible")));
			this.butJump.Click += new System.EventHandler(this.butJump_Click);
			// 
			// butStreamPoints
			// 
			this.butStreamPoints.AccessibleDescription = resources.GetString("butStreamPoints.AccessibleDescription");
			this.butStreamPoints.AccessibleName = resources.GetString("butStreamPoints.AccessibleName");
			this.butStreamPoints.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butStreamPoints.Anchor")));
			this.butStreamPoints.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butStreamPoints.BackgroundImage")));
			this.butStreamPoints.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butStreamPoints.Dock")));
			this.butStreamPoints.Enabled = ((bool)(resources.GetObject("butStreamPoints.Enabled")));
			this.butStreamPoints.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butStreamPoints.FlatStyle")));
			this.butStreamPoints.Font = ((System.Drawing.Font)(resources.GetObject("butStreamPoints.Font")));
			this.butStreamPoints.Image = ((System.Drawing.Image)(resources.GetObject("butStreamPoints.Image")));
			this.butStreamPoints.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butStreamPoints.ImageAlign")));
			this.butStreamPoints.ImageIndex = ((int)(resources.GetObject("butStreamPoints.ImageIndex")));
			this.butStreamPoints.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butStreamPoints.ImeMode")));
			this.butStreamPoints.Location = ((System.Drawing.Point)(resources.GetObject("butStreamPoints.Location")));
			this.butStreamPoints.Name = "butStreamPoints";
			this.butStreamPoints.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butStreamPoints.RightToLeft")));
			this.butStreamPoints.Size = ((System.Drawing.Size)(resources.GetObject("butStreamPoints.Size")));
			this.butStreamPoints.TabIndex = ((int)(resources.GetObject("butStreamPoints.TabIndex")));
			this.butStreamPoints.Text = resources.GetString("butStreamPoints.Text");
			this.butStreamPoints.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butStreamPoints.TextAlign")));
			this.stdToolTip.SetToolTip(this.butStreamPoints, resources.GetString("butStreamPoints.ToolTip"));
			this.butStreamPoints.Visible = ((bool)(resources.GetObject("butStreamPoints.Visible")));
			this.butStreamPoints.Click += new System.EventHandler(this.butStreamPoints_Click);
			// 
			// butSetCutIn
			// 
			this.butSetCutIn.AccessibleDescription = resources.GetString("butSetCutIn.AccessibleDescription");
			this.butSetCutIn.AccessibleName = resources.GetString("butSetCutIn.AccessibleName");
			this.butSetCutIn.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butSetCutIn.Anchor")));
			this.butSetCutIn.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butSetCutIn.BackgroundImage")));
			this.butSetCutIn.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butSetCutIn.Dock")));
			this.butSetCutIn.Enabled = ((bool)(resources.GetObject("butSetCutIn.Enabled")));
			this.butSetCutIn.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butSetCutIn.FlatStyle")));
			this.butSetCutIn.Font = ((System.Drawing.Font)(resources.GetObject("butSetCutIn.Font")));
			this.butSetCutIn.Image = ((System.Drawing.Image)(resources.GetObject("butSetCutIn.Image")));
			this.butSetCutIn.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butSetCutIn.ImageAlign")));
			this.butSetCutIn.ImageIndex = ((int)(resources.GetObject("butSetCutIn.ImageIndex")));
			this.butSetCutIn.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butSetCutIn.ImeMode")));
			this.butSetCutIn.Location = ((System.Drawing.Point)(resources.GetObject("butSetCutIn.Location")));
			this.butSetCutIn.Name = "butSetCutIn";
			this.butSetCutIn.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butSetCutIn.RightToLeft")));
			this.butSetCutIn.Size = ((System.Drawing.Size)(resources.GetObject("butSetCutIn.Size")));
			this.butSetCutIn.TabIndex = ((int)(resources.GetObject("butSetCutIn.TabIndex")));
			this.butSetCutIn.Text = resources.GetString("butSetCutIn.Text");
			this.butSetCutIn.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butSetCutIn.TextAlign")));
			this.stdToolTip.SetToolTip(this.butSetCutIn, resources.GetString("butSetCutIn.ToolTip"));
			this.butSetCutIn.Visible = ((bool)(resources.GetObject("butSetCutIn.Visible")));
			this.butSetCutIn.Click += new System.EventHandler(this.butSetCutIn_Click);
			// 
			// butSetCutOut
			// 
			this.butSetCutOut.AccessibleDescription = resources.GetString("butSetCutOut.AccessibleDescription");
			this.butSetCutOut.AccessibleName = resources.GetString("butSetCutOut.AccessibleName");
			this.butSetCutOut.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butSetCutOut.Anchor")));
			this.butSetCutOut.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butSetCutOut.BackgroundImage")));
			this.butSetCutOut.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butSetCutOut.Dock")));
			this.butSetCutOut.Enabled = ((bool)(resources.GetObject("butSetCutOut.Enabled")));
			this.butSetCutOut.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butSetCutOut.FlatStyle")));
			this.butSetCutOut.Font = ((System.Drawing.Font)(resources.GetObject("butSetCutOut.Font")));
			this.butSetCutOut.Image = ((System.Drawing.Image)(resources.GetObject("butSetCutOut.Image")));
			this.butSetCutOut.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butSetCutOut.ImageAlign")));
			this.butSetCutOut.ImageIndex = ((int)(resources.GetObject("butSetCutOut.ImageIndex")));
			this.butSetCutOut.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butSetCutOut.ImeMode")));
			this.butSetCutOut.Location = ((System.Drawing.Point)(resources.GetObject("butSetCutOut.Location")));
			this.butSetCutOut.Name = "butSetCutOut";
			this.butSetCutOut.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butSetCutOut.RightToLeft")));
			this.butSetCutOut.Size = ((System.Drawing.Size)(resources.GetObject("butSetCutOut.Size")));
			this.butSetCutOut.TabIndex = ((int)(resources.GetObject("butSetCutOut.TabIndex")));
			this.butSetCutOut.Text = resources.GetString("butSetCutOut.Text");
			this.butSetCutOut.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butSetCutOut.TextAlign")));
			this.stdToolTip.SetToolTip(this.butSetCutOut, resources.GetString("butSetCutOut.ToolTip"));
			this.butSetCutOut.Visible = ((bool)(resources.GetObject("butSetCutOut.Visible")));
			this.butSetCutOut.Click += new System.EventHandler(this.butSetCutOut_Click);
			// 
			// lblCutOut
			// 
			this.lblCutOut.AccessibleDescription = resources.GetString("lblCutOut.AccessibleDescription");
			this.lblCutOut.AccessibleName = resources.GetString("lblCutOut.AccessibleName");
			this.lblCutOut.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("lblCutOut.Anchor")));
			this.lblCutOut.AutoSize = ((bool)(resources.GetObject("lblCutOut.AutoSize")));
			this.lblCutOut.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("lblCutOut.Dock")));
			this.lblCutOut.Enabled = ((bool)(resources.GetObject("lblCutOut.Enabled")));
			this.lblCutOut.Font = ((System.Drawing.Font)(resources.GetObject("lblCutOut.Font")));
			this.lblCutOut.Image = ((System.Drawing.Image)(resources.GetObject("lblCutOut.Image")));
			this.lblCutOut.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("lblCutOut.ImageAlign")));
			this.lblCutOut.ImageIndex = ((int)(resources.GetObject("lblCutOut.ImageIndex")));
			this.lblCutOut.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("lblCutOut.ImeMode")));
			this.lblCutOut.Location = ((System.Drawing.Point)(resources.GetObject("lblCutOut.Location")));
			this.lblCutOut.Name = "lblCutOut";
			this.lblCutOut.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("lblCutOut.RightToLeft")));
			this.lblCutOut.Size = ((System.Drawing.Size)(resources.GetObject("lblCutOut.Size")));
			this.lblCutOut.TabIndex = ((int)(resources.GetObject("lblCutOut.TabIndex")));
			this.lblCutOut.Text = resources.GetString("lblCutOut.Text");
			this.lblCutOut.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("lblCutOut.TextAlign")));
			this.stdToolTip.SetToolTip(this.lblCutOut, resources.GetString("lblCutOut.ToolTip"));
			this.lblCutOut.Visible = ((bool)(resources.GetObject("lblCutOut.Visible")));
			// 
			// lblCutIn
			// 
			this.lblCutIn.AccessibleDescription = resources.GetString("lblCutIn.AccessibleDescription");
			this.lblCutIn.AccessibleName = resources.GetString("lblCutIn.AccessibleName");
			this.lblCutIn.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("lblCutIn.Anchor")));
			this.lblCutIn.AutoSize = ((bool)(resources.GetObject("lblCutIn.AutoSize")));
			this.lblCutIn.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("lblCutIn.Dock")));
			this.lblCutIn.Enabled = ((bool)(resources.GetObject("lblCutIn.Enabled")));
			this.lblCutIn.Font = ((System.Drawing.Font)(resources.GetObject("lblCutIn.Font")));
			this.lblCutIn.Image = ((System.Drawing.Image)(resources.GetObject("lblCutIn.Image")));
			this.lblCutIn.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("lblCutIn.ImageAlign")));
			this.lblCutIn.ImageIndex = ((int)(resources.GetObject("lblCutIn.ImageIndex")));
			this.lblCutIn.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("lblCutIn.ImeMode")));
			this.lblCutIn.Location = ((System.Drawing.Point)(resources.GetObject("lblCutIn.Location")));
			this.lblCutIn.Name = "lblCutIn";
			this.lblCutIn.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("lblCutIn.RightToLeft")));
			this.lblCutIn.Size = ((System.Drawing.Size)(resources.GetObject("lblCutIn.Size")));
			this.lblCutIn.TabIndex = ((int)(resources.GetObject("lblCutIn.TabIndex")));
			this.lblCutIn.Text = resources.GetString("lblCutIn.Text");
			this.lblCutIn.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("lblCutIn.TextAlign")));
			this.stdToolTip.SetToolTip(this.lblCutIn, resources.GetString("lblCutIn.ToolTip"));
			this.lblCutIn.Visible = ((bool)(resources.GetObject("lblCutIn.Visible")));
			// 
			// butGoToCutIn
			// 
			this.butGoToCutIn.AccessibleDescription = resources.GetString("butGoToCutIn.AccessibleDescription");
			this.butGoToCutIn.AccessibleName = resources.GetString("butGoToCutIn.AccessibleName");
			this.butGoToCutIn.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butGoToCutIn.Anchor")));
			this.butGoToCutIn.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butGoToCutIn.BackgroundImage")));
			this.butGoToCutIn.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butGoToCutIn.Dock")));
			this.butGoToCutIn.Enabled = ((bool)(resources.GetObject("butGoToCutIn.Enabled")));
			this.butGoToCutIn.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butGoToCutIn.FlatStyle")));
			this.butGoToCutIn.Font = ((System.Drawing.Font)(resources.GetObject("butGoToCutIn.Font")));
			this.butGoToCutIn.Image = ((System.Drawing.Image)(resources.GetObject("butGoToCutIn.Image")));
			this.butGoToCutIn.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butGoToCutIn.ImageAlign")));
			this.butGoToCutIn.ImageIndex = ((int)(resources.GetObject("butGoToCutIn.ImageIndex")));
			this.butGoToCutIn.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butGoToCutIn.ImeMode")));
			this.butGoToCutIn.Location = ((System.Drawing.Point)(resources.GetObject("butGoToCutIn.Location")));
			this.butGoToCutIn.Name = "butGoToCutIn";
			this.butGoToCutIn.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butGoToCutIn.RightToLeft")));
			this.butGoToCutIn.Size = ((System.Drawing.Size)(resources.GetObject("butGoToCutIn.Size")));
			this.butGoToCutIn.TabIndex = ((int)(resources.GetObject("butGoToCutIn.TabIndex")));
			this.butGoToCutIn.Text = resources.GetString("butGoToCutIn.Text");
			this.butGoToCutIn.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butGoToCutIn.TextAlign")));
			this.stdToolTip.SetToolTip(this.butGoToCutIn, resources.GetString("butGoToCutIn.ToolTip"));
			this.butGoToCutIn.Visible = ((bool)(resources.GetObject("butGoToCutIn.Visible")));
			this.butGoToCutIn.Click += new System.EventHandler(this.butGoToCutIn_Click);
			// 
			// butGoToCutOut
			// 
			this.butGoToCutOut.AccessibleDescription = resources.GetString("butGoToCutOut.AccessibleDescription");
			this.butGoToCutOut.AccessibleName = resources.GetString("butGoToCutOut.AccessibleName");
			this.butGoToCutOut.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butGoToCutOut.Anchor")));
			this.butGoToCutOut.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butGoToCutOut.BackgroundImage")));
			this.butGoToCutOut.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butGoToCutOut.Dock")));
			this.butGoToCutOut.Enabled = ((bool)(resources.GetObject("butGoToCutOut.Enabled")));
			this.butGoToCutOut.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butGoToCutOut.FlatStyle")));
			this.butGoToCutOut.Font = ((System.Drawing.Font)(resources.GetObject("butGoToCutOut.Font")));
			this.butGoToCutOut.Image = ((System.Drawing.Image)(resources.GetObject("butGoToCutOut.Image")));
			this.butGoToCutOut.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butGoToCutOut.ImageAlign")));
			this.butGoToCutOut.ImageIndex = ((int)(resources.GetObject("butGoToCutOut.ImageIndex")));
			this.butGoToCutOut.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butGoToCutOut.ImeMode")));
			this.butGoToCutOut.Location = ((System.Drawing.Point)(resources.GetObject("butGoToCutOut.Location")));
			this.butGoToCutOut.Name = "butGoToCutOut";
			this.butGoToCutOut.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butGoToCutOut.RightToLeft")));
			this.butGoToCutOut.Size = ((System.Drawing.Size)(resources.GetObject("butGoToCutOut.Size")));
			this.butGoToCutOut.TabIndex = ((int)(resources.GetObject("butGoToCutOut.TabIndex")));
			this.butGoToCutOut.Text = resources.GetString("butGoToCutOut.Text");
			this.butGoToCutOut.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butGoToCutOut.TextAlign")));
			this.stdToolTip.SetToolTip(this.butGoToCutOut, resources.GetString("butGoToCutOut.ToolTip"));
			this.butGoToCutOut.Visible = ((bool)(resources.GetObject("butGoToCutOut.Visible")));
			this.butGoToCutOut.Click += new System.EventHandler(this.butGoToCutOut_Click);
			// 
			// butAddToCutList
			// 
			this.butAddToCutList.AccessibleDescription = resources.GetString("butAddToCutList.AccessibleDescription");
			this.butAddToCutList.AccessibleName = resources.GetString("butAddToCutList.AccessibleName");
			this.butAddToCutList.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butAddToCutList.Anchor")));
			this.butAddToCutList.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butAddToCutList.BackgroundImage")));
			this.butAddToCutList.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butAddToCutList.Dock")));
			this.butAddToCutList.Enabled = ((bool)(resources.GetObject("butAddToCutList.Enabled")));
			this.butAddToCutList.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butAddToCutList.FlatStyle")));
			this.butAddToCutList.Font = ((System.Drawing.Font)(resources.GetObject("butAddToCutList.Font")));
			this.butAddToCutList.Image = ((System.Drawing.Image)(resources.GetObject("butAddToCutList.Image")));
			this.butAddToCutList.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butAddToCutList.ImageAlign")));
			this.butAddToCutList.ImageIndex = ((int)(resources.GetObject("butAddToCutList.ImageIndex")));
			this.butAddToCutList.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butAddToCutList.ImeMode")));
			this.butAddToCutList.Location = ((System.Drawing.Point)(resources.GetObject("butAddToCutList.Location")));
			this.butAddToCutList.Name = "butAddToCutList";
			this.butAddToCutList.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butAddToCutList.RightToLeft")));
			this.butAddToCutList.Size = ((System.Drawing.Size)(resources.GetObject("butAddToCutList.Size")));
			this.butAddToCutList.TabIndex = ((int)(resources.GetObject("butAddToCutList.TabIndex")));
			this.butAddToCutList.Text = resources.GetString("butAddToCutList.Text");
			this.butAddToCutList.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butAddToCutList.TextAlign")));
			this.stdToolTip.SetToolTip(this.butAddToCutList, resources.GetString("butAddToCutList.ToolTip"));
			this.butAddToCutList.Visible = ((bool)(resources.GetObject("butAddToCutList.Visible")));
			this.butAddToCutList.Click += new System.EventHandler(this.butAddToCutList_Click);
			// 
			// butCreateChapter
			// 
			this.butCreateChapter.AccessibleDescription = resources.GetString("butCreateChapter.AccessibleDescription");
			this.butCreateChapter.AccessibleName = resources.GetString("butCreateChapter.AccessibleName");
			this.butCreateChapter.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butCreateChapter.Anchor")));
			this.butCreateChapter.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butCreateChapter.BackgroundImage")));
			this.butCreateChapter.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butCreateChapter.Dock")));
			this.butCreateChapter.Enabled = ((bool)(resources.GetObject("butCreateChapter.Enabled")));
			this.butCreateChapter.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butCreateChapter.FlatStyle")));
			this.butCreateChapter.Font = ((System.Drawing.Font)(resources.GetObject("butCreateChapter.Font")));
			this.butCreateChapter.Image = ((System.Drawing.Image)(resources.GetObject("butCreateChapter.Image")));
			this.butCreateChapter.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butCreateChapter.ImageAlign")));
			this.butCreateChapter.ImageIndex = ((int)(resources.GetObject("butCreateChapter.ImageIndex")));
			this.butCreateChapter.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butCreateChapter.ImeMode")));
			this.butCreateChapter.Location = ((System.Drawing.Point)(resources.GetObject("butCreateChapter.Location")));
			this.butCreateChapter.Name = "butCreateChapter";
			this.butCreateChapter.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butCreateChapter.RightToLeft")));
			this.butCreateChapter.Size = ((System.Drawing.Size)(resources.GetObject("butCreateChapter.Size")));
			this.butCreateChapter.TabIndex = ((int)(resources.GetObject("butCreateChapter.TabIndex")));
			this.butCreateChapter.Text = resources.GetString("butCreateChapter.Text");
			this.butCreateChapter.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butCreateChapter.TextAlign")));
			this.stdToolTip.SetToolTip(this.butCreateChapter, resources.GetString("butCreateChapter.ToolTip"));
			this.butCreateChapter.Visible = ((bool)(resources.GetObject("butCreateChapter.Visible")));
			this.butCreateChapter.Click += new System.EventHandler(this.butCreateChapter_Click);
			// 
			// butCut
			// 
			this.butCut.AccessibleDescription = resources.GetString("butCut.AccessibleDescription");
			this.butCut.AccessibleName = resources.GetString("butCut.AccessibleName");
			this.butCut.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butCut.Anchor")));
			this.butCut.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butCut.BackgroundImage")));
			this.butCut.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butCut.Dock")));
			this.butCut.Enabled = ((bool)(resources.GetObject("butCut.Enabled")));
			this.butCut.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butCut.FlatStyle")));
			this.butCut.Font = ((System.Drawing.Font)(resources.GetObject("butCut.Font")));
			this.butCut.Image = ((System.Drawing.Image)(resources.GetObject("butCut.Image")));
			this.butCut.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butCut.ImageAlign")));
			this.butCut.ImageIndex = ((int)(resources.GetObject("butCut.ImageIndex")));
			this.butCut.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butCut.ImeMode")));
			this.butCut.Location = ((System.Drawing.Point)(resources.GetObject("butCut.Location")));
			this.butCut.Name = "butCut";
			this.butCut.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butCut.RightToLeft")));
			this.butCut.Size = ((System.Drawing.Size)(resources.GetObject("butCut.Size")));
			this.butCut.TabIndex = ((int)(resources.GetObject("butCut.TabIndex")));
			this.butCut.Text = resources.GetString("butCut.Text");
			this.butCut.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butCut.TextAlign")));
			this.stdToolTip.SetToolTip(this.butCut, resources.GetString("butCut.ToolTip"));
			this.butCut.Visible = ((bool)(resources.GetObject("butCut.Visible")));
			this.butCut.Click += new System.EventHandler(this.butCut_Click);
			// 
			// butPreview
			// 
			this.butPreview.AccessibleDescription = resources.GetString("butPreview.AccessibleDescription");
			this.butPreview.AccessibleName = resources.GetString("butPreview.AccessibleName");
			this.butPreview.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butPreview.Anchor")));
			this.butPreview.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butPreview.BackgroundImage")));
			this.butPreview.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butPreview.Dock")));
			this.butPreview.Enabled = ((bool)(resources.GetObject("butPreview.Enabled")));
			this.butPreview.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butPreview.FlatStyle")));
			this.butPreview.Font = ((System.Drawing.Font)(resources.GetObject("butPreview.Font")));
			this.butPreview.Image = ((System.Drawing.Image)(resources.GetObject("butPreview.Image")));
			this.butPreview.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butPreview.ImageAlign")));
			this.butPreview.ImageIndex = ((int)(resources.GetObject("butPreview.ImageIndex")));
			this.butPreview.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butPreview.ImeMode")));
			this.butPreview.Location = ((System.Drawing.Point)(resources.GetObject("butPreview.Location")));
			this.butPreview.Name = "butPreview";
			this.butPreview.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butPreview.RightToLeft")));
			this.butPreview.Size = ((System.Drawing.Size)(resources.GetObject("butPreview.Size")));
			this.butPreview.TabIndex = ((int)(resources.GetObject("butPreview.TabIndex")));
			this.butPreview.Text = resources.GetString("butPreview.Text");
			this.butPreview.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butPreview.TextAlign")));
			this.stdToolTip.SetToolTip(this.butPreview, resources.GetString("butPreview.ToolTip"));
			this.butPreview.Visible = ((bool)(resources.GetObject("butPreview.Visible")));
			this.butPreview.Click += new System.EventHandler(this.butPreview_Click);
			// 
			// NavigationCtrl
			// 
			this.AccessibleDescription = resources.GetString("$this.AccessibleDescription");
			this.AccessibleName = resources.GetString("$this.AccessibleName");
			this.AutoScroll = ((bool)(resources.GetObject("$this.AutoScroll")));
			this.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("$this.AutoScrollMargin")));
			this.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("$this.AutoScrollMinSize")));
			this.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("$this.BackgroundImage")));
			this.Controls.Add(this.butPreview);
			this.Controls.Add(this.butCut);
			this.Controls.Add(this.butCreateChapter);
			this.Controls.Add(this.butNextIFrame);
			this.Controls.Add(this.butPrevIFrame);
			this.Controls.Add(this.butNextIPFrame);
			this.Controls.Add(this.butPrevIPFrame);
			this.Controls.Add(this.butPrevFrame);
			this.Controls.Add(this.butNextFrame);
			this.Controls.Add(this.butJump);
			this.Controls.Add(this.butStreamPoints);
			this.Controls.Add(this.butSetCutIn);
			this.Controls.Add(this.butSetCutOut);
			this.Controls.Add(this.lblCutOut);
			this.Controls.Add(this.lblCutIn);
			this.Controls.Add(this.butGoToCutIn);
			this.Controls.Add(this.butGoToCutOut);
			this.Controls.Add(this.butAddToCutList);
			this.Enabled = ((bool)(resources.GetObject("$this.Enabled")));
			this.Font = ((System.Drawing.Font)(resources.GetObject("$this.Font")));
			this.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("$this.ImeMode")));
			this.Location = ((System.Drawing.Point)(resources.GetObject("$this.Location")));
			this.Name = "NavigationCtrl";
			this.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("$this.RightToLeft")));
			this.Size = ((System.Drawing.Size)(resources.GetObject("$this.Size")));
			this.stdToolTip.SetToolTip(this, resources.GetString("$this.ToolTip"));
			this.ResumeLayout(false);

		}
		#endregion

		#region Event Handler

		private void OnSetDefaults(bool b_NewProject)
		{
			butPrevFrame.Enabled=false;
			butPrevIFrame.Enabled=false;
			butPrevIPFrame.Enabled=false;
			butNextFrame.Enabled=false;
			butNextIFrame.Enabled=false;
			butNextIPFrame.Enabled=false;
			butGoToCutIn.Enabled=false;
			butGoToCutOut.Enabled=false;
			butGoToCutOut.Enabled=false;
			butSetCutIn.Enabled=false;
			butSetCutOut.Enabled=false;
			butAddToCutList.Enabled=false;
			butJump.Enabled=false;
			butStreamPoints.Enabled=false;
			butCreateChapter.Enabled=false;
			butCut.Enabled=false;
			butPreview.Enabled=false;
			butSetCutIn.BackColor=Color.FromKnownColor(KnownColor.Control);
			butSetCutOut.BackColor=Color.FromKnownColor(KnownColor.Control);

			lblCutIn.Text="---";
			lblCutOut.Text="---";
		}

		private bool IsChapterFrame(int pos)
		{
			Picture curPic=null;
			if (State.VideoStream!=null)
				curPic=State.VideoStream.GetPicture(pos);
			FrameType frametype=0;
			if (curPic!=null)
				frametype=(FrameType)curPic.picture_coding_type;

			bool frameInCutList=false;
			foreach (CutPoint cp in State.Cuts)
			{
				if (0 == string.Compare(cp.VideoName, State.VideoStream.StreamName, true) && 
					cp.StartFrame <= State.CurrentVideoPosition && 
					State.CurrentVideoPosition <= cp.EndFrame   && 
					(frametype==FrameType.IFrame || cp.StartFrame==State.CurrentVideoPosition))
				{
					frameInCutList=true;
					break;
				}
			}
			return !Settings.CurrentSettings.AutoCreateChapters
				&&	(	frameInCutList
				||	(State.CurrentCut.StartFrame!=-1 && State.CurrentCut.EndFrame==-1 && State.CurrentCut.StartFrame<=State.CurrentVideoPosition && (frametype==FrameType.IFrame || State.CurrentCut.StartFrame==State.CurrentVideoPosition))
				||	(State.CurrentCut.StartFrame!=-1 && State.CurrentCut.EndFrame!=-1 && State.CurrentCut.StartFrame<=State.CurrentVideoPosition && State.CurrentVideoPosition<=State.CurrentCut.EndFrame && (frametype==FrameType.IFrame || State.CurrentCut.StartFrame==State.CurrentVideoPosition))
				);
		}

		// -----------------------------------------------------------------------
		// The following code seems strange, but it must be exactly like this !!!
		// When the user clicks a B,P,I button, the GUI must be updated immediatly
		// When the scrollbar is running a flickering of the icons should be avoided
		// When the video position is updated in less than 250 ms -> do nothing
		// This also speeds up the scrolling / shutteling
		// It is NOT possible to Stop and Start a timer with every update of the video position
		// This would make the GUI hang because of long latencies in .NET framework !!!
		// !!!!!!!!!! DO NOT MODIFY THE FOLLOWING CODE !!!!!!!!!
		private void OnSettingsChanged()
		{
			mb_UpdatePending = true;
			UpdateGui();
		}
		private void OnVideoPositionUpdated(int newPosition)
		{
			mb_UpdatePending = true;
			UpdateGui();
		}
		private void OnIconTimer(object sender, EventArgs e)
		{
			if (mb_UpdatePending) UpdateGui();
		}
		private void UpdateGui()
		{
			if (!this.Enabled)
				return; // playback or shutteling

			int Tick = Environment.TickCount;
			int Diff = Tick - ms32_LastEvent;
			ms32_LastEvent = Tick;
			if (Diff < 250)
				return;

			mb_UpdatePending = false;

			Picture curPic=null;
			if (State.VideoStream!=null)
				curPic=State.VideoStream.GetPicture(State.CurrentVideoPosition);
			
			FrameType frametype=0;
			if (curPic!=null)
				frametype=(FrameType)curPic.picture_coding_type;

			butCreateChapter.Enabled = IsChapterFrame(State.CurrentVideoPosition);

			butSetCutIn. Enabled = State.VideoStream!=null;
			butSetCutOut.Enabled = State.VideoStream!=null;

			// It is NOT a good idea to disable the cut buttons, because the user will have
			// no idea WHY he cannot cut on a B or P frame. It is better to enable
			// the buttons and display a messagebox with a REASON why he cannot use them !!!!
			// I worked one year with Cuttermaran without knowing 
			// that there is a possibility to also cut on a B frame !!!
			bool b_Encoder = Settings.CurrentSettings.EncodeMode;
			mb_AllowCutIn  = b_Encoder || frametype==FrameType.IFrame;
			mb_AllowCutOut = b_Encoder || frametype==FrameType.IFrame || frametype==FrameType.PFrame;

			// Set the button's icon depending on whether a cut is allowed here or not
			butSetCutIn. Image = mb_AllowCutIn  ? mi_CutIcon : mi_NoCutIcon;
			butSetCutOut.Image = mb_AllowCutOut ? mi_CutIcon : mi_NoCutIcon;
		}
		// ------------------------------------------------------------------------

		private void OnAudioVideoOpened(bool videoOpened, bool audioOpened, bool reOpened)
		{
			butPrevFrame.Enabled=true;
			butPrevIFrame.Enabled=true;
			butPrevIPFrame.Enabled=true;
			butNextFrame.Enabled=true;
			butNextIFrame.Enabled=true;
			butNextIPFrame.Enabled=true;
			butStreamPoints.Enabled=(State.InterestingStreamPoints.Count > 0);
			butJump.Enabled=true;

			// After the user has switched to another video file
			// we display the StartFrame and EndFrame of this video file
			OnCurrentCutModified();
			OnCutPointModified(-1);
		}

		private void OnCurrentCutModified()
		{
			butAddToCutList.Enabled=State.CurrentCut.StartFrame!=-1 && State.CurrentCut.EndFrame!=-1 && State.CurrentCut.StartFrame<=State.CurrentCut.EndFrame;
			butGoToCutIn. Enabled=State.CurrentCut.StartFrame!=-1;
			butGoToCutOut.Enabled=State.CurrentCut.EndFrame!=-1;
			if (State.VideoStream != null)
			{
				lblCutIn.Text =Helper.FramesToTimeAndPicString(State.CurrentCut.StartFrame,State.VideoStream.FramesPerSecond);
				lblCutOut.Text=Helper.FramesToTimeAndPicString(State.CurrentCut.EndFrame,  State.VideoStream.FramesPerSecond);
			}
			butCreateChapter.Enabled=IsChapterFrame(State.CurrentVideoPosition);
			butSetCutIn. BackColor=Color.FromKnownColor((State.CurrentCut.StartFrame!=-1)?KnownColor.ControlDark:KnownColor.Control);
			butSetCutOut.BackColor=Color.FromKnownColor((State.CurrentCut.EndFrame!=-1)?KnownColor.ControlDark:KnownColor.Control);
		}

		private void OnCutPointModified(int selectedCutIndex)
		{
			butCut.Enabled=State.Cuts.Count>0;
			butPreview.Enabled=State.Cuts.Count>0;
		}

		#endregion

		#region Ctrl Events

		private void butNextFrame_Click(object sender, System.EventArgs e)
		{
			State.MoveToPicture(Navigation.NextBFrame);
		}

		private void butPrevFrame_Click(object sender, System.EventArgs e)
		{
			State.MoveToPicture(Navigation.PrevBFrame);
		}

		private void butNextIPFrame_Click(object sender, System.EventArgs e)
		{
			State.MoveToPicture(Navigation.NextPFrame);
		}

		private void butPrevIPFrame_Click(object sender, System.EventArgs e)
		{
			State.MoveToPicture(Navigation.PrevPFrame);
		}

		private void butNextIFrame_Click(object sender, System.EventArgs e)
		{
			State.MoveToPicture(Navigation.NextIFrame);
		}

		private void butPrevIFrame_Click(object sender, System.EventArgs e)
		{
			State.MoveToPicture(Navigation.PrevIFrame);
		}

		private void butSetCutIn_Click(object sender, System.EventArgs e)
		{
			if (mb_UpdatePending)
				return;

			if (!mb_AllowCutIn)
			{
				MessageBox.Show(Resource.CurrentResource[Resource.ENCODER_REQUIRED], Resource.CurrentResource[Resource.ERROR]);
				return;
			}

			if (!Settings.CurrentSettings.EncodeMode)
			{
				string result;
				result=State.VideoStream.IsCutInPoint(State.CurrentVideoPosition,State.VideoStream.FramesPerSecond);
				if (result!="")
				{
					MessageBox.Show(result,Resource.CurrentResource[Resource.ERROR]);
					return;
				}
				if (State.AudioStreams.Count>0)
				{
					result="";
					foreach (BasicAudioStream bas in State.AudioStreams)
					{
						string temp_result=bas.IsCutInPoint(State.CurrentVideoPosition,State.VideoStream.FramesPerSecond);
						if (temp_result!="")
							result=temp_result+"\n";
					}
					if (result!="")
					{
						MessageBox.Show(result,Resource.CurrentResource[Resource.ERROR]);
						return;
					}
				}
			}
			State.CurrentCut.VideoStream=State.VideoStream;
			State.SetCurrentCutStartFrame(State.CurrentVideoPosition);
		}

		private void butSetCutOut_Click(object sender, System.EventArgs e)
		{
			if (mb_UpdatePending)
				return;

			if (!mb_AllowCutOut)
			{
				MessageBox.Show(Resource.CurrentResource[Resource.ENCODER_REQUIRED], Resource.CurrentResource[Resource.ERROR]);
				return;
			}

			if (!Settings.CurrentSettings.EncodeMode)
			{
				string result;
				result=State.VideoStream.IsCutOutPoint(State.CurrentVideoPosition,State.VideoStream.FramesPerSecond);
				if (result!="")
				{
					MessageBox.Show(result,Resource.CurrentResource[Resource.ERROR]);
					return;
				}
				if (State.AudioStreams.Count>0)
				{
					result="";
					foreach (BasicAudioStream bas in State.AudioStreams)
					{
						string temp_result=bas.IsCutOutPoint(State.CurrentVideoPosition,State.VideoStream.FramesPerSecond);
						if (temp_result!="")
							result=temp_result+"\n";
					}
					if (result!="")
					{
						MessageBox.Show(result,Resource.CurrentResource[Resource.ERROR]);
						return;
					}
				}
			}

			State.CurrentCut.VideoStream=State.VideoStream;
			State.SetCurrentCutEndFrame(State.CurrentVideoPosition);
			Bitmap bitm=null;
			bool dummyNewBMPCreated;
			State.CurrentDecoder.GetPicture(State.CurrentVideoPosition,ref bitm,false,out dummyNewBMPCreated);
			State.CurrentCut.CutOutFrame=bitm;
			State.CurrentCutOut=State.CurrentCut;
		}

		private void butGoToCutIn_Click(object sender, System.EventArgs e)
		{
			State.GoToVideoPosition(State.CurrentCut.StartFrame);
		}

		private void butGoToCutOut_Click(object sender, System.EventArgs e)
		{
			State.GoToVideoPosition(State.CurrentCut.EndFrame);
		}

		private void butStreamPoints_Click(object sender, System.EventArgs e)
		{
			StreamPoints sp=new StreamPoints(State.InterestingStreamPoints);
			if (sp.ShowDialog()==DialogResult.OK)
			{
				int FrameNr=Helper.TimeToFrame(sp.selectedTime,State.VideoStream.FramesPerSecond);
				State.GoToVideoPosition(FrameNr);
			}
		}

		private void butAddToCutList_Click(object sender, System.EventArgs e)
		{
			// AudioStreams dazu
			State.CurrentCut.AudioStreams=(ArrayList)State.AudioStreams.Clone();

			if (State.Cuts.Count>0)
			{
				// noch ein paar Plausis:
				if (State.Cuts[0].AudioNames.Count!=State.CurrentCut.AudioNames.Count)
				{
					MessageBox.Show(Resource.CurrentResource[Resource.NO_OF_AUDIO],Resource.CurrentResource[Resource.ERROR]);
					return;
				}

				for (int index=0;index<State.Cuts[0].AudioStreams.Count;++index)
				{
					if (((BasicAudioStream)State.Cuts[0].AudioStreams[index]).GetType()!=
						((BasicAudioStream)State.CurrentCut.AudioStreams[index]).GetType())
					{
						MessageBox.Show(Resource.CurrentResource[Resource.ORDER_OF_AUDIO],Resource.CurrentResource[Resource.ERROR]);
						return;
					}
				}

			}

			// aktuellen Schnitt hinzufgen...
			State.AddToCutList(State.CurrentCut);
		}

		private void butJump_Click(object sender, System.EventArgs e)
		{
			State.CallQuickJump();
		}

		private void butCut_Click(object sender, System.EventArgs e)
		{
			CutDialog cd=new CutDialog(State);
			DialogResult res=cd.ShowDialog();
			if (res==DialogResult.OK || res==DialogResult.Yes)
				State.ProcessCut(State.Cuts,cd.CutFileName,res==DialogResult.Yes,false);
		}

		private void butCreateChapter_Click(object sender, System.EventArgs e)
		{
			State.CreateChapter(State.CurrentVideoPosition);
		}

		private void butPreview_Click(object sender, System.EventArgs e)
		{
			State.PreviewAll();
		}

		#endregion
	}
}
