/*
 * Cuttermaran - The Mpeg Cutter
 * 
 * Copyright (C) 2003-2005  Tobias Arnold (cuttermaran@gmx.net)
 * 
 * This file is part of cuttermaran, a free MPEG cut program.
 * See http://www.cuttermaran.de for updates.
 *
 * This program is free software; you can redistribute it and/or modify it 
 * under the terms of the GNU General Public License as published by the 
 * Free Software Foundation; either version 2 of the License, or 
 * (at your option) any later version. 
 * 
 * This program is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the 
 * GNU General Public License for more details. 
 * 
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */

using System;
using System.Collections;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Windows.Forms;
using Configuration;
using Coremoran.Algorithms;
using Coremoran.AVStreams;
using Coremoran.Common;

namespace GUI.MainForm
{
	/// <summary>
	/// Summary description for ScrollCtrl.
	/// </summary>
	public class ScrollCtrl : MainBaseControl
	{
		private System.Timers.Timer displayTimer;
		private GUI.MainForm.VideoScroller.cVideoScroller videoScroller;
		private System.ComponentModel.Container components = null;
		private int ms32_LastScrollValue = 0;
		// ATTENTION: DO NOT use SystemColors.HighLight or ActiveCaption here !!
		// This would be a boring grey on the Windows XP Silver desktop theme !!
		private Color mc_CutColorSelect = Color.FromArgb(0xFF, 0xAA, 0x44);
		private Color mc_CutColor       = SystemColors.ControlDark;

		#region ctor / Dispose

		public ScrollCtrl()
		{
			// This call is required by the Windows.Forms Form Designer.
			InitializeComponent();

			// Fr Events registrieren
			State.SetDefaults+=new SetDefaultsDelegate(this.OnSetDefaults);
			State.SettingsChanged+=new SettingsChangedDelegate(OnSettingsChanged);
			State.VideoPositionUpdated    +=new VideoPositionUpdatedDelegate(this.OnVideoPositionUpdated);
			State.VideoPlayPositionUpdated+=new VideoPositionUpdatedDelegate(this.OnVideoPositionUpdated);
			State.AudioVideoOpened+=new AudioVideoOpenedDelegate(this.OnAudioVideoOpened);
			State.GuiEnabled+=new GuiEnabledDelegate(OnGuiEnabled);
			State.CutListSelectionChanged+=new CutListSelChangedDelegate(OnCutListSelectionChanged);
		}

		/// <summary> 
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#endregion

		#region Component Designer generated code

		/// <summary> 
		/// Required method for Designer support - do not modify 
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(ScrollCtrl));
			this.videoScroller = new GUI.MainForm.VideoScroller.cVideoScroller();
			this.displayTimer = new System.Timers.Timer();
			((System.ComponentModel.ISupportInitialize)(this.displayTimer)).BeginInit();
			this.SuspendLayout();
			// 
			// videoScroller
			// 
			this.videoScroller.AccessibleDescription = resources.GetString("videoScroller.AccessibleDescription");
			this.videoScroller.AccessibleName = resources.GetString("videoScroller.AccessibleName");
			this.videoScroller.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Left) | System.Windows.Forms.AnchorStyles.Right)));
			this.videoScroller.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("videoScroller.BackgroundImage")));
			this.videoScroller.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("videoScroller.Dock")));
			this.videoScroller.Enabled = ((bool)(resources.GetObject("videoScroller.Enabled")));
			this.videoScroller.Font = ((System.Drawing.Font)(resources.GetObject("videoScroller.Font")));
			this.videoScroller.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("videoScroller.ImeMode")));
			this.videoScroller.Location = ((System.Drawing.Point)(resources.GetObject("videoScroller.Location")));
			this.videoScroller.Name = "videoScroller";
			this.videoScroller.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("videoScroller.RightToLeft")));
			this.videoScroller.Size = ((System.Drawing.Size)(resources.GetObject("videoScroller.Size")));
			this.videoScroller.TabIndex = ((int)(resources.GetObject("videoScroller.TabIndex")));
			this.videoScroller.Visible = ((bool)(resources.GetObject("videoScroller.Visible")));
			this.videoScroller.Scroll += new System.Windows.Forms.ScrollEventHandler(OnScroll);
			this.videoScroller.ShuttleStartStop += new GUI.MainForm.VideoScroller.cShuttleBarH.StartStopDelegate(OnShuttleStartStop);
			// 
			// displayTimer
			// 
			this.displayTimer.Enabled = true;
			this.displayTimer.SynchronizingObject = this;
			this.displayTimer.Elapsed += new System.Timers.ElapsedEventHandler(this.OnDisplayTimerElapsed);
			// 
			// ScrollCtrl
			// 
			this.AccessibleDescription = resources.GetString("$this.AccessibleDescription");
			this.AccessibleName = resources.GetString("$this.AccessibleName");
			this.AutoScroll = ((bool)(resources.GetObject("$this.AutoScroll")));
			this.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("$this.AutoScrollMargin")));
			this.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("$this.AutoScrollMinSize")));
			this.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("$this.BackgroundImage")));
			this.Controls.Add(this.videoScroller);
			this.Enabled = ((bool)(resources.GetObject("$this.Enabled")));
			this.Font = ((System.Drawing.Font)(resources.GetObject("$this.Font")));
			this.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("$this.ImeMode")));
			this.Location = ((System.Drawing.Point)(resources.GetObject("$this.Location")));
			this.Name = "ScrollCtrl";
			this.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("$this.RightToLeft")));
			this.Size = ((System.Drawing.Size)(resources.GetObject("$this.Size")));
			this.Load += new System.EventHandler(this.OnLoad);
			((System.ComponentModel.ISupportInitialize)(this.displayTimer)).EndInit();
			this.ResumeLayout(false);

		}
		#endregion

		#region Event handler

		private void OnLoad(object sender, System.EventArgs e)
		{
			OnSettingsChanged();
		}

		private void OnScroll(object sender, System.Windows.Forms.ScrollEventArgs ev)
		{
			int s32_NewValue = ev.NewValue;
			int s32_OldValue = ms32_LastScrollValue;
			ms32_LastScrollValue = s32_NewValue;

			// Do not set on IFrames if the video is very short
			if (videoScroller.Maximum < 1000)
				return;

			// ThumbTrack is sent when the scrollbar is draged or the ShuttleBar is active
			// SmallChange: Click on ScrollBar buttons, LargeChange: Click on ScrollBar shaft
			if (ev.Type != ScrollEventType.ThumbTrack     &&
				ev.Type != ScrollEventType.LargeDecrement &&
				ev.Type != ScrollEventType.LargeIncrement)
				return;

			// Do NOT calculate the next IFrame, when the ShuttleBar runs in slow speeds !!!
			// One I frame normally consists of 12 B/P frames --> Don't chose a value < 16 here !!!
			int s32_Speed = Math.Abs(videoScroller.ShuttleSpeed);
			if (s32_Speed != 0 && s32_Speed < 16)
				return;

			// We are already on an IFrame
			if ((FrameType)State.VideoStream.GetPicture(s32_NewValue).picture_coding_type == FrameType.IFrame)
				return;

			// Calculate previous or next IFrame depending on scroll direction
			if (s32_NewValue > s32_OldValue)
			{
				s32_NewValue = State.VideoStream.CalculateNextFramePos(s32_NewValue,FrameType.IFrame);
			}
			else if (s32_NewValue < s32_OldValue)
			{
				s32_NewValue = State.VideoStream.CalculatePrevFramePos(s32_NewValue,FrameType.IFrame);
			}

			// Adapt scrollbar position to IFrame
			videoScroller.Value = s32_NewValue;
		}

		private void OnDisplayTimerElapsed(object sender, System.Timers.ElapsedEventArgs e)
		{
			if (videoScroller.Visible && State.CurrentVideoPosition != videoScroller.Value)
				State.GoToVideoPosition(videoScroller.Value);
		}

		private void OnSetDefaults(bool b_NewProject)
		{
			videoScroller.Enabled=false;
			videoScroller.ResetBackgroundColors();
			videoScroller.Invalidate();
		}

		/// <summary>
		/// After openening a video OR audio: update InterestingStreamPoints in Scrollbar
		/// </summary>
		private void OnAudioVideoOpened(bool videoOpened, bool audioOpened, bool reOpened)
		{
			videoScroller.Enabled=(State.VideoStream!=null);
			videoScroller.Maximum=(State.VideoStream==null)? 0 : State.VideoStream.PicturesCount-1;
			videoScroller.Minimum=0;
			OnCutListSelectionChanged(null);
		}

		private void OnVideoPositionUpdated(int newPosition)
		{
			videoScroller.Value= newPosition;
		}

		private void OnSettingsChanged()
		{
			videoScroller.LargeChange=Settings.CurrentSettings.SliderPlacement;
		}

		private void OnShuttleStartStop(bool b_Active)
		{
			// disable Gui when shuttlebar is active
			State.EnableGui(this, !b_Active);
		}

		private void OnGuiEnabled(Control sender, bool b_Enabled)
		{
			if (this.GetType() == sender.GetType())
			{
				displayTimer.Enabled = true;
			}
			else // reset shuttle when playback is started
			{
				displayTimer.Enabled = b_Enabled;
				videoScroller.ResetShuttle(true);
			}
		}

		/// <summary>
		/// Refresh the background colors of the scrollbar
		/// </summary>
		private void OnCutListSelectionChanged(ArrayList selectedIndices)
		{
			videoScroller.ResetBackgroundColors();

			if (State.VideoStream != null)
			{
				for (int i=0; i<State.Cuts.Count; i++)
				{
					CutPoint i_Cut = State.Cuts[i];

					if (0 != string.Compare(State.VideoStream.StreamName, i_Cut.VideoName, true))
						continue;

					bool b_Append = (selectedIndices != null && selectedIndices.Contains(i));
					Color c_Col = b_Append ? mc_CutColorSelect : mc_CutColor;

					videoScroller.AddBackgroundColor(i_Cut.VideoInfo.StartFrame,
					                                 i_Cut.VideoInfo.EndFrame, c_Col, b_Append);
				}
			}
			
			// Add the interesting StreamPoints AFTER the cuts!! (small red lines)
			// They would otherwise be covered by the background color of the cuts
			// The scrollbar paints its background colors in the order they were added
			foreach (DateTime i_Time in State.InterestingStreamPoints.Keys)
			{
				int s32_Frame = Helper.TimeToFrame(i_Time, State.VideoStream.FramesPerSecond);
				videoScroller.AddBackgroundColor(Math.Max(0,s32_Frame-3), s32_Frame, Color.Red, true);
			}

			videoScroller.Invalidate();
		}

		#endregion
	}
}
