/*
 * Cuttermaran - The Mpeg Cutter
 * 
 * Copyright (C) 2003-2006  Tobias Arnold (cuttermaran@gmx.net)
 * 
 * This file is part of cuttermaran, a free MPEG cut program.
 * See http://www.cuttermaran.de for updates.
 *
 * This program is free software; you can redistribute it and/or modify it 
 * under the terms of the GNU General Public License as published by the 
 * Free Software Foundation; either version 2 of the License, or 
 * (at your option) any later version. 
 * 
 * This program is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the 
 * GNU General Public License for more details. 
 * 
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */

using System;
using System.IO;
using System.Drawing;
using System.Collections;
using System.Collections.Specialized;
using System.ComponentModel;
using System.Windows.Forms;

using StringResources;
using Configuration;

namespace GUI
{
	/// <summary>
	/// Summary description for PlayBack.
	/// </summary>
	public class PlayBack : GUIBaseForm
	{
		public StringCollection VideoFiles=new StringCollection();
		public ArrayList AudioFiles=new ArrayList();
		public FilterMediaType VideoFilesType=FilterMediaType.unknown;
		public ArrayList AudioFilesTypes=new ArrayList();
		public bool addCurrentCut=false;
		public bool showLeftMargin=true;
		public bool showRightMargin=true;
		public int firstCutNr=0;

		private DirectShowPlayer Videostream;
		private DirectShowPlayer Audiostream;
		private System.Windows.Forms.ComboBox comboCut;
		private System.Windows.Forms.Button butPlay;
		private System.Windows.Forms.Button butStop;
		private System.Windows.Forms.ComboBox comboAudios;
		private System.Windows.Forms.Button butClose;
		private System.Windows.Forms.Panel panelControl;
		private System.Windows.Forms.Panel panelVideo;
		private System.Windows.Forms.Button butNext;
		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;

		public PlayBack()
		{
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();

			panelVideo.Size= new Size(720,576);
		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
				Release();
			}
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(PlayBack));
			this.comboCut = new System.Windows.Forms.ComboBox();
			this.butPlay = new System.Windows.Forms.Button();
			this.butStop = new System.Windows.Forms.Button();
			this.comboAudios = new System.Windows.Forms.ComboBox();
			this.butClose = new System.Windows.Forms.Button();
			this.panelControl = new System.Windows.Forms.Panel();
			this.butNext = new System.Windows.Forms.Button();
			this.panelVideo = new System.Windows.Forms.Panel();
			this.panelControl.SuspendLayout();
			this.SuspendLayout();
			// 
			// comboCut
			// 
			this.comboCut.AccessibleDescription = resources.GetString("comboCut.AccessibleDescription");
			this.comboCut.AccessibleName = resources.GetString("comboCut.AccessibleName");
			this.comboCut.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("comboCut.Anchor")));
			this.comboCut.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("comboCut.BackgroundImage")));
			this.comboCut.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("comboCut.Dock")));
			this.comboCut.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
			this.comboCut.Enabled = ((bool)(resources.GetObject("comboCut.Enabled")));
			this.comboCut.Font = ((System.Drawing.Font)(resources.GetObject("comboCut.Font")));
			this.comboCut.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("comboCut.ImeMode")));
			this.comboCut.IntegralHeight = ((bool)(resources.GetObject("comboCut.IntegralHeight")));
			this.comboCut.ItemHeight = ((int)(resources.GetObject("comboCut.ItemHeight")));
			this.comboCut.Location = ((System.Drawing.Point)(resources.GetObject("comboCut.Location")));
			this.comboCut.MaxDropDownItems = ((int)(resources.GetObject("comboCut.MaxDropDownItems")));
			this.comboCut.MaxLength = ((int)(resources.GetObject("comboCut.MaxLength")));
			this.comboCut.Name = "comboCut";
			this.comboCut.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("comboCut.RightToLeft")));
			this.comboCut.Size = ((System.Drawing.Size)(resources.GetObject("comboCut.Size")));
			this.comboCut.TabIndex = ((int)(resources.GetObject("comboCut.TabIndex")));
			this.comboCut.Text = resources.GetString("comboCut.Text");
			this.comboCut.Visible = ((bool)(resources.GetObject("comboCut.Visible")));
			this.comboCut.SelectedIndexChanged += new EventHandler(OnComboCutSelectionChanged);
			// 
			// butPlay
			// 
			this.butPlay.AccessibleDescription = resources.GetString("butPlay.AccessibleDescription");
			this.butPlay.AccessibleName = resources.GetString("butPlay.AccessibleName");
			this.butPlay.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butPlay.Anchor")));
			this.butPlay.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butPlay.BackgroundImage")));
			this.butPlay.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butPlay.Dock")));
			this.butPlay.Enabled = ((bool)(resources.GetObject("butPlay.Enabled")));
			this.butPlay.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butPlay.FlatStyle")));
			this.butPlay.Font = ((System.Drawing.Font)(resources.GetObject("butPlay.Font")));
			this.butPlay.Image = ((System.Drawing.Image)(resources.GetObject("butPlay.Image")));
			this.butPlay.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butPlay.ImageAlign")));
			this.butPlay.ImageIndex = ((int)(resources.GetObject("butPlay.ImageIndex")));
			this.butPlay.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butPlay.ImeMode")));
			this.butPlay.Location = ((System.Drawing.Point)(resources.GetObject("butPlay.Location")));
			this.butPlay.Name = "butPlay";
			this.butPlay.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butPlay.RightToLeft")));
			this.butPlay.Size = ((System.Drawing.Size)(resources.GetObject("butPlay.Size")));
			this.butPlay.TabIndex = ((int)(resources.GetObject("butPlay.TabIndex")));
			this.butPlay.Text = resources.GetString("butPlay.Text");
			this.butPlay.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butPlay.TextAlign")));
			this.butPlay.Visible = ((bool)(resources.GetObject("butPlay.Visible")));
			this.butPlay.Click += new System.EventHandler(this.butPlay_Click);
			// 
			// butStop
			// 
			this.butStop.AccessibleDescription = resources.GetString("butStop.AccessibleDescription");
			this.butStop.AccessibleName = resources.GetString("butStop.AccessibleName");
			this.butStop.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butStop.Anchor")));
			this.butStop.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butStop.BackgroundImage")));
			this.butStop.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butStop.Dock")));
			this.butStop.Enabled = ((bool)(resources.GetObject("butStop.Enabled")));
			this.butStop.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butStop.FlatStyle")));
			this.butStop.Font = ((System.Drawing.Font)(resources.GetObject("butStop.Font")));
			this.butStop.Image = ((System.Drawing.Image)(resources.GetObject("butStop.Image")));
			this.butStop.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butStop.ImageAlign")));
			this.butStop.ImageIndex = ((int)(resources.GetObject("butStop.ImageIndex")));
			this.butStop.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butStop.ImeMode")));
			this.butStop.Location = ((System.Drawing.Point)(resources.GetObject("butStop.Location")));
			this.butStop.Name = "butStop";
			this.butStop.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butStop.RightToLeft")));
			this.butStop.Size = ((System.Drawing.Size)(resources.GetObject("butStop.Size")));
			this.butStop.TabIndex = ((int)(resources.GetObject("butStop.TabIndex")));
			this.butStop.Text = resources.GetString("butStop.Text");
			this.butStop.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butStop.TextAlign")));
			this.butStop.Visible = ((bool)(resources.GetObject("butStop.Visible")));
			this.butStop.Click += new System.EventHandler(this.butStop_Click);
			// 
			// comboAudios
			// 
			this.comboAudios.AccessibleDescription = resources.GetString("comboAudios.AccessibleDescription");
			this.comboAudios.AccessibleName = resources.GetString("comboAudios.AccessibleName");
			this.comboAudios.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("comboAudios.Anchor")));
			this.comboAudios.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("comboAudios.BackgroundImage")));
			this.comboAudios.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("comboAudios.Dock")));
			this.comboAudios.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
			this.comboAudios.Enabled = ((bool)(resources.GetObject("comboAudios.Enabled")));
			this.comboAudios.Font = ((System.Drawing.Font)(resources.GetObject("comboAudios.Font")));
			this.comboAudios.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("comboAudios.ImeMode")));
			this.comboAudios.IntegralHeight = ((bool)(resources.GetObject("comboAudios.IntegralHeight")));
			this.comboAudios.ItemHeight = ((int)(resources.GetObject("comboAudios.ItemHeight")));
			this.comboAudios.Location = ((System.Drawing.Point)(resources.GetObject("comboAudios.Location")));
			this.comboAudios.MaxDropDownItems = ((int)(resources.GetObject("comboAudios.MaxDropDownItems")));
			this.comboAudios.MaxLength = ((int)(resources.GetObject("comboAudios.MaxLength")));
			this.comboAudios.Name = "comboAudios";
			this.comboAudios.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("comboAudios.RightToLeft")));
			this.comboAudios.Size = ((System.Drawing.Size)(resources.GetObject("comboAudios.Size")));
			this.comboAudios.TabIndex = ((int)(resources.GetObject("comboAudios.TabIndex")));
			this.comboAudios.Text = resources.GetString("comboAudios.Text");
			this.comboAudios.Visible = ((bool)(resources.GetObject("comboAudios.Visible")));
			// 
			// butClose
			// 
			this.butClose.AccessibleDescription = resources.GetString("butClose.AccessibleDescription");
			this.butClose.AccessibleName = resources.GetString("butClose.AccessibleName");
			this.butClose.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butClose.Anchor")));
			this.butClose.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butClose.BackgroundImage")));
			this.butClose.DialogResult = System.Windows.Forms.DialogResult.Cancel;
			this.butClose.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butClose.Dock")));
			this.butClose.Enabled = ((bool)(resources.GetObject("butClose.Enabled")));
			this.butClose.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butClose.FlatStyle")));
			this.butClose.Font = ((System.Drawing.Font)(resources.GetObject("butClose.Font")));
			this.butClose.Image = ((System.Drawing.Image)(resources.GetObject("butClose.Image")));
			this.butClose.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butClose.ImageAlign")));
			this.butClose.ImageIndex = ((int)(resources.GetObject("butClose.ImageIndex")));
			this.butClose.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butClose.ImeMode")));
			this.butClose.Location = ((System.Drawing.Point)(resources.GetObject("butClose.Location")));
			this.butClose.Name = "butClose";
			this.butClose.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butClose.RightToLeft")));
			this.butClose.Size = ((System.Drawing.Size)(resources.GetObject("butClose.Size")));
			this.butClose.TabIndex = ((int)(resources.GetObject("butClose.TabIndex")));
			this.butClose.Text = resources.GetString("butClose.Text");
			this.butClose.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butClose.TextAlign")));
			this.butClose.Visible = ((bool)(resources.GetObject("butClose.Visible")));
			// 
			// panelControl
			// 
			this.panelControl.AccessibleDescription = resources.GetString("panelControl.AccessibleDescription");
			this.panelControl.AccessibleName = resources.GetString("panelControl.AccessibleName");
			this.panelControl.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("panelControl.Anchor")));
			this.panelControl.AutoScroll = ((bool)(resources.GetObject("panelControl.AutoScroll")));
			this.panelControl.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("panelControl.AutoScrollMargin")));
			this.panelControl.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("panelControl.AutoScrollMinSize")));
			this.panelControl.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("panelControl.BackgroundImage")));
			this.panelControl.Controls.Add(this.butNext);
			this.panelControl.Controls.Add(this.butClose);
			this.panelControl.Controls.Add(this.butStop);
			this.panelControl.Controls.Add(this.butPlay);
			this.panelControl.Controls.Add(this.comboAudios);
			this.panelControl.Controls.Add(this.comboCut);
			this.panelControl.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("panelControl.Dock")));
			this.panelControl.Enabled = ((bool)(resources.GetObject("panelControl.Enabled")));
			this.panelControl.Font = ((System.Drawing.Font)(resources.GetObject("panelControl.Font")));
			this.panelControl.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("panelControl.ImeMode")));
			this.panelControl.Location = ((System.Drawing.Point)(resources.GetObject("panelControl.Location")));
			this.panelControl.Name = "panelControl";
			this.panelControl.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("panelControl.RightToLeft")));
			this.panelControl.Size = ((System.Drawing.Size)(resources.GetObject("panelControl.Size")));
			this.panelControl.TabIndex = ((int)(resources.GetObject("panelControl.TabIndex")));
			this.panelControl.Text = resources.GetString("panelControl.Text");
			this.panelControl.Visible = ((bool)(resources.GetObject("panelControl.Visible")));
			// 
			// butNext
			// 
			this.butNext.AccessibleDescription = resources.GetString("butNext.AccessibleDescription");
			this.butNext.AccessibleName = resources.GetString("butNext.AccessibleName");
			this.butNext.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butNext.Anchor")));
			this.butNext.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butNext.BackgroundImage")));
			this.butNext.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butNext.Dock")));
			this.butNext.Enabled = ((bool)(resources.GetObject("butNext.Enabled")));
			this.butNext.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butNext.FlatStyle")));
			this.butNext.Font = ((System.Drawing.Font)(resources.GetObject("butNext.Font")));
			this.butNext.Image = ((System.Drawing.Image)(resources.GetObject("butNext.Image")));
			this.butNext.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butNext.ImageAlign")));
			this.butNext.ImageIndex = ((int)(resources.GetObject("butNext.ImageIndex")));
			this.butNext.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butNext.ImeMode")));
			this.butNext.Location = ((System.Drawing.Point)(resources.GetObject("butNext.Location")));
			this.butNext.Name = "butNext";
			this.butNext.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butNext.RightToLeft")));
			this.butNext.Size = ((System.Drawing.Size)(resources.GetObject("butNext.Size")));
			this.butNext.TabIndex = ((int)(resources.GetObject("butNext.TabIndex")));
			this.butNext.Text = resources.GetString("butNext.Text");
			this.butNext.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butNext.TextAlign")));
			this.butNext.Visible = ((bool)(resources.GetObject("butNext.Visible")));
			this.butNext.Click += new System.EventHandler(this.butPlayNext_Click);
			// 
			// panelVideo
			// 
			this.panelVideo.AccessibleDescription = resources.GetString("panelVideo.AccessibleDescription");
			this.panelVideo.AccessibleName = resources.GetString("panelVideo.AccessibleName");
			this.panelVideo.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("panelVideo.Anchor")));
			this.panelVideo.AutoScroll = ((bool)(resources.GetObject("panelVideo.AutoScroll")));
			this.panelVideo.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("panelVideo.AutoScrollMargin")));
			this.panelVideo.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("panelVideo.AutoScrollMinSize")));
			this.panelVideo.BackColor = System.Drawing.Color.Blue;
			this.panelVideo.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("panelVideo.BackgroundImage")));
			this.panelVideo.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("panelVideo.Dock")));
			this.panelVideo.Enabled = ((bool)(resources.GetObject("panelVideo.Enabled")));
			this.panelVideo.Font = ((System.Drawing.Font)(resources.GetObject("panelVideo.Font")));
			this.panelVideo.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("panelVideo.ImeMode")));
			this.panelVideo.Location = ((System.Drawing.Point)(resources.GetObject("panelVideo.Location")));
			this.panelVideo.Name = "panelVideo";
			this.panelVideo.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("panelVideo.RightToLeft")));
			this.panelVideo.Size = ((System.Drawing.Size)(resources.GetObject("panelVideo.Size")));
			this.panelVideo.TabIndex = ((int)(resources.GetObject("panelVideo.TabIndex")));
			this.panelVideo.Text = resources.GetString("panelVideo.Text");
			this.panelVideo.Visible = ((bool)(resources.GetObject("panelVideo.Visible")));
			// 
			// PlayBack
			// 
			this.AccessibleDescription = resources.GetString("$this.AccessibleDescription");
			this.AccessibleName = resources.GetString("$this.AccessibleName");
			this.AutoScaleBaseSize = ((System.Drawing.Size)(resources.GetObject("$this.AutoScaleBaseSize")));
			this.AutoScroll = ((bool)(resources.GetObject("$this.AutoScroll")));
			this.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("$this.AutoScrollMargin")));
			this.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("$this.AutoScrollMinSize")));
			this.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("$this.BackgroundImage")));
			this.ClientSize = ((System.Drawing.Size)(resources.GetObject("$this.ClientSize")));
			this.Controls.Add(this.panelVideo);
			this.Controls.Add(this.panelControl);
			this.DockPadding.All = 8;
			this.Enabled = ((bool)(resources.GetObject("$this.Enabled")));
			this.Font = ((System.Drawing.Font)(resources.GetObject("$this.Font")));
			this.Icon = ((System.Drawing.Icon)(resources.GetObject("$this.Icon")));
			this.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("$this.ImeMode")));
			this.Location = ((System.Drawing.Point)(resources.GetObject("$this.Location")));
			this.MaximumSize = ((System.Drawing.Size)(resources.GetObject("$this.MaximumSize")));
			this.MinimizeBox = false;
			this.MinimumSize = ((System.Drawing.Size)(resources.GetObject("$this.MinimumSize")));
			this.Name = "PlayBack";
			this.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("$this.RightToLeft")));
			this.ShowInTaskbar = false;
			this.StartPosition = ((System.Windows.Forms.FormStartPosition)(resources.GetObject("$this.StartPosition")));
			this.Text = resources.GetString("$this.Text");
			this.Closing += new System.ComponentModel.CancelEventHandler(this.PlayBack_Closing);
			this.Load += new System.EventHandler(this.PlayBack_Load);
			this.panelControl.ResumeLayout(false);
			this.ResumeLayout(false);

		}
		#endregion

		private void PlayBack_Load(object sender, System.EventArgs e)
		{
			int noCutTransitions=VideoFiles.Count;
			if (showLeftMargin)
				--noCutTransitions;
			else
				--firstCutNr;
			if (showRightMargin)
				--noCutTransitions;
			if (addCurrentCut)
				--noCutTransitions;

			if (showLeftMargin)
				comboCut.Items.Add(Resource.CurrentResource[Resource.BEGIN]);
			for (int index=1;index<=noCutTransitions;++index)
				comboCut.Items.Add(string.Format("{0} {1} - {2}",
					Resource.CurrentResource[Resource.CUT],index+firstCutNr,index+firstCutNr+1));
			if (addCurrentCut)
				comboCut.Items.Add(string.Format("{0} {1} - {2}",
					Resource.CurrentResource[Resource.CUT],noCutTransitions+firstCutNr+1,Resource.CurrentResource[Resource.NEW_CUT]));
			if (showRightMargin)
				comboCut.Items.Add(Resource.CurrentResource[Resource.END]);
			comboCut.SelectedIndex=0;

			if (((StringCollection)AudioFiles[0]).Count>0)
			{
				for (int index=0;index<((StringCollection)AudioFiles[0]).Count;++index)
					comboAudios.Items.Add(string.Format("Audio {0}",index+1));
				comboAudios.SelectedIndex=0;
			}
			else
				comboAudios.Enabled=false;
			butStop.Enabled=false;
		}

		private void butPlayNext_Click(object sender, System.EventArgs e)
		{
			if (comboCut.SelectedIndex < comboCut.Items.Count -1)
				comboCut.SelectedIndex ++;
		
			butPlay_Click(sender, e);
		}

		private void butPlay_Click(object sender, System.EventArgs e)
		{
			panelVideo.BackColor=Color.Blue;
			
			try
			{
				// Starting the play progress may take some seconds
				// in the mean time block the buttons !!
				butStop.Enabled=true;
				butPlay.Enabled=false;
				butNext.Enabled=false;

				Release();

				Videostream=new DirectShowPlayer(VideoFiles[comboCut.SelectedIndex],VideoFilesType,panelVideo);

				if (	((StringCollection)AudioFiles[comboCut.SelectedIndex]).Count>0
					&&	((StringCollection)AudioFiles[comboCut.SelectedIndex])[comboAudios.SelectedIndex]!=string.Empty)
					Audiostream=new DirectShowPlayer(((StringCollection)AudioFiles[comboCut.SelectedIndex])[comboAudios.SelectedIndex],(FilterMediaType)AudioFilesTypes[comboAudios.SelectedIndex],null);

				Videostream.StopPlay+=new GUI.DirectShowPlayer.DxPlayEvent(Videostream_StopPlay);

				// Start playing now
				Videostream.Start();
				if (Audiostream!=null)
					Audiostream.Start();
			}
			catch (Exception exp)
			{
				MessageBox.Show(Resource.CurrentResource.FormatMessage(Resource.CODEC_MISSING,exp.Message),Resource.CurrentResource[Resource.ERROR]);
				// re-enable buttons
				Videostream_StopPlay(null);
			}
		}

		private void butStop_Click(object sender, System.EventArgs e)
		{
			Release();
			// re-enable buttons
			Videostream_StopPlay(null);
		}

		private void PlayBack_Closing(object sender, System.ComponentModel.CancelEventArgs e)
		{
			Release();
		}

		private void Videostream_StopPlay(object sender)
		{
			butStop.Enabled=false;
			butPlay.Enabled=true;
			// disable "Next" button for the last entry in combobox
			butNext.Enabled=(comboCut.SelectedIndex < comboCut.Items.Count -1);
		}

		private void OnComboCutSelectionChanged(object sender, EventArgs e)
		{
			// disable "Next" button for the last entry in combobox
			butNext.Enabled=(comboCut.SelectedIndex < comboCut.Items.Count -1);
		}

		private void Release()
		{
			if (Videostream!=null)
			{
				Videostream.Dispose();
				Videostream=null;
			}

			if (Audiostream!=null)
			{
				Audiostream.Dispose();
				Audiostream=null;
			}
		}
	}
}
