/*
 * Cuttermaran - The Mpeg Cutter
 * 
 * Copyright (C) 2003-2006  Tobias Arnold (cuttermaran@gmx.net)
 * 
 * This file is part of cuttermaran, a free MPEG cut program.
 * See http://www.cuttermaran.de for updates.
 *
 * This program is free software; you can redistribute it and/or modify it 
 * under the terms of the GNU General Public License as published by the 
 * Free Software Foundation; either version 2 of the License, or 
 * (at your option) any later version. 
 * 
 * This program is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the 
 * GNU General Public License for more details. 
 * 
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */

using System;
using System.IO;
using System.Text;
using System.Drawing;
using System.Drawing.Imaging;
using System.Threading;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using Coremoran.AVStreams;
using Configuration;
using StringResources;
using Coremoran.Common;

namespace GUI
{
	/// <summary>
	/// Summary description for QuickJump2.
	/// </summary>
	public class QuickJump2 : Form
	{
		private System.Windows.Forms.Button butRight;
		private System.Windows.Forms.Button butLeft;
		private System.Windows.Forms.Label label18;
		private System.Windows.Forms.Label label17;
		private System.Windows.Forms.Button buttonApply;
		private System.Windows.Forms.NumericUpDown numQuickDistance;
		private System.Windows.Forms.Button butSaveAllFrames;
		private System.Windows.Forms.Button butClose;
		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;

		private ArrayList pictures=new ArrayList();
		private ArrayList timecodes=new ArrayList();
		private int [] picture_pos;
		private Mpeg12Video videoStream;
		private int videoPosition;
		private int viewStartPosition;
		private int distance;
		private System.Windows.Forms.Panel panelControls;
		private VideoDecoder decoder;
		private ArrayList marker=new ArrayList();

		// Definitionen fr den ImageUpdate Worker
		private Thread worker;
		private delegate void UpdateImageDelgate(int index,int position);
		private UpdateImageDelgate ImageUpdateCallBack;
		private ManualResetEvent eventStopThread;
		private ManualResetEvent eventThreadStopped;

		// Gren
		private readonly Size PictureSize=new Size(172,129);
		private readonly Size TextBoxSize=new Size(192,16);
		private System.Windows.Forms.SaveFileDialog saveFrameDialog;
		private System.Windows.Forms.Panel panelButton2;
		private System.Windows.Forms.Button butLeft2;
		private System.Windows.Forms.Button butRight2;
		private System.Windows.Forms.ContextMenu pictureMenu;
		private System.Windows.Forms.MenuItem menuSetMarker;
		private readonly Size AreaSize=new Size(192,160);

		public QuickJump2(BasicVideoStream videostream,int startPosition,int step)
		{
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();

			decoder=VideoDecoder.Create(videostream,Configuration.ConversionType.RGB24);
			videoStream=(Mpeg12Video)videostream;
			numQuickDistance.Value=step;
			distance=step*(int)(videoStream.FramesPerSecond+0.5m);
			int startpos=startPosition;
			viewStartPosition=videoPosition=startpos;
			ImageUpdateCallBack=new UpdateImageDelgate(UpdateImage);
			eventStopThread=new ManualResetEvent(false);
			eventThreadStopped=new ManualResetEvent(false);
		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
				foreach (PictureBox pic in pictures)
					if (pic!=null && pic.Image!=null)
					{
						pic.Image.Dispose();
						pic.Image=null;
					}
				decoder.Dispose();
			}
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(QuickJump2));
			System.Configuration.AppSettingsReader configurationAppSettings = new System.Configuration.AppSettingsReader();
			this.panelControls = new System.Windows.Forms.Panel();
			this.butSaveAllFrames = new System.Windows.Forms.Button();
			this.butClose = new System.Windows.Forms.Button();
			this.butLeft = new System.Windows.Forms.Button();
			this.butRight = new System.Windows.Forms.Button();
			this.label17 = new System.Windows.Forms.Label();
			this.label18 = new System.Windows.Forms.Label();
			this.numQuickDistance = new System.Windows.Forms.NumericUpDown();
			this.buttonApply = new System.Windows.Forms.Button();
			this.panelButton2 = new System.Windows.Forms.Panel();
			this.butRight2 = new System.Windows.Forms.Button();
			this.butLeft2 = new System.Windows.Forms.Button();
			this.saveFrameDialog = new System.Windows.Forms.SaveFileDialog();
			this.pictureMenu = new System.Windows.Forms.ContextMenu();
			this.menuSetMarker = new System.Windows.Forms.MenuItem();
			this.panelControls.SuspendLayout();
			((System.ComponentModel.ISupportInitialize)(this.numQuickDistance)).BeginInit();
			this.panelButton2.SuspendLayout();
			this.SuspendLayout();
			// 
			// panelControls
			// 
			this.panelControls.AccessibleDescription = resources.GetString("panelControls.AccessibleDescription");
			this.panelControls.AccessibleName = resources.GetString("panelControls.AccessibleName");
			this.panelControls.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("panelControls.Anchor")));
			this.panelControls.AutoScroll = ((bool)(resources.GetObject("panelControls.AutoScroll")));
			this.panelControls.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("panelControls.AutoScrollMargin")));
			this.panelControls.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("panelControls.AutoScrollMinSize")));
			this.panelControls.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("panelControls.BackgroundImage")));
			this.panelControls.Controls.Add(this.butSaveAllFrames);
			this.panelControls.Controls.Add(this.butClose);
			this.panelControls.Controls.Add(this.butLeft);
			this.panelControls.Controls.Add(this.butRight);
			this.panelControls.Controls.Add(this.label17);
			this.panelControls.Controls.Add(this.label18);
			this.panelControls.Controls.Add(this.numQuickDistance);
			this.panelControls.Controls.Add(this.buttonApply);
			this.panelControls.Controls.Add(this.panelButton2);
			this.panelControls.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("panelControls.Dock")));
			this.panelControls.Enabled = ((bool)(resources.GetObject("panelControls.Enabled")));
			this.panelControls.Font = ((System.Drawing.Font)(resources.GetObject("panelControls.Font")));
			this.panelControls.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("panelControls.ImeMode")));
			this.panelControls.Location = ((System.Drawing.Point)(resources.GetObject("panelControls.Location")));
			this.panelControls.Name = "panelControls";
			this.panelControls.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("panelControls.RightToLeft")));
			this.panelControls.Size = ((System.Drawing.Size)(resources.GetObject("panelControls.Size")));
			this.panelControls.TabIndex = ((int)(resources.GetObject("panelControls.TabIndex")));
			this.panelControls.Text = resources.GetString("panelControls.Text");
			this.panelControls.Visible = ((bool)(resources.GetObject("panelControls.Visible")));
			// 
			// butSaveAllFrames
			// 
			this.butSaveAllFrames.AccessibleDescription = resources.GetString("butSaveAllFrames.AccessibleDescription");
			this.butSaveAllFrames.AccessibleName = resources.GetString("butSaveAllFrames.AccessibleName");
			this.butSaveAllFrames.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butSaveAllFrames.Anchor")));
			this.butSaveAllFrames.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butSaveAllFrames.BackgroundImage")));
			this.butSaveAllFrames.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butSaveAllFrames.Dock")));
			this.butSaveAllFrames.Enabled = ((bool)(resources.GetObject("butSaveAllFrames.Enabled")));
			this.butSaveAllFrames.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butSaveAllFrames.FlatStyle")));
			this.butSaveAllFrames.Font = ((System.Drawing.Font)(resources.GetObject("butSaveAllFrames.Font")));
			this.butSaveAllFrames.Image = ((System.Drawing.Image)(resources.GetObject("butSaveAllFrames.Image")));
			this.butSaveAllFrames.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butSaveAllFrames.ImageAlign")));
			this.butSaveAllFrames.ImageIndex = ((int)(resources.GetObject("butSaveAllFrames.ImageIndex")));
			this.butSaveAllFrames.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butSaveAllFrames.ImeMode")));
			this.butSaveAllFrames.Location = ((System.Drawing.Point)(resources.GetObject("butSaveAllFrames.Location")));
			this.butSaveAllFrames.Name = "butSaveAllFrames";
			this.butSaveAllFrames.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butSaveAllFrames.RightToLeft")));
			this.butSaveAllFrames.Size = ((System.Drawing.Size)(resources.GetObject("butSaveAllFrames.Size")));
			this.butSaveAllFrames.TabIndex = ((int)(resources.GetObject("butSaveAllFrames.TabIndex")));
			this.butSaveAllFrames.Text = resources.GetString("butSaveAllFrames.Text");
			this.butSaveAllFrames.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butSaveAllFrames.TextAlign")));
			this.butSaveAllFrames.Visible = ((bool)(resources.GetObject("butSaveAllFrames.Visible")));
			this.butSaveAllFrames.Click += new System.EventHandler(this.butSaveAllFrames_Click);
			// 
			// butClose
			// 
			this.butClose.AccessibleDescription = resources.GetString("butClose.AccessibleDescription");
			this.butClose.AccessibleName = resources.GetString("butClose.AccessibleName");
			this.butClose.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butClose.Anchor")));
			this.butClose.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butClose.BackgroundImage")));
			this.butClose.DialogResult = System.Windows.Forms.DialogResult.Cancel;
			this.butClose.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butClose.Dock")));
			this.butClose.Enabled = ((bool)(resources.GetObject("butClose.Enabled")));
			this.butClose.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butClose.FlatStyle")));
			this.butClose.Font = ((System.Drawing.Font)(resources.GetObject("butClose.Font")));
			this.butClose.Image = ((System.Drawing.Image)(resources.GetObject("butClose.Image")));
			this.butClose.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butClose.ImageAlign")));
			this.butClose.ImageIndex = ((int)(resources.GetObject("butClose.ImageIndex")));
			this.butClose.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butClose.ImeMode")));
			this.butClose.Location = ((System.Drawing.Point)(resources.GetObject("butClose.Location")));
			this.butClose.Name = "butClose";
			this.butClose.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butClose.RightToLeft")));
			this.butClose.Size = ((System.Drawing.Size)(resources.GetObject("butClose.Size")));
			this.butClose.TabIndex = ((int)(resources.GetObject("butClose.TabIndex")));
			this.butClose.Text = resources.GetString("butClose.Text");
			this.butClose.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butClose.TextAlign")));
			this.butClose.Visible = ((bool)(resources.GetObject("butClose.Visible")));
			// 
			// butLeft
			// 
			this.butLeft.AccessibleDescription = resources.GetString("butLeft.AccessibleDescription");
			this.butLeft.AccessibleName = resources.GetString("butLeft.AccessibleName");
			this.butLeft.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butLeft.Anchor")));
			this.butLeft.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butLeft.BackgroundImage")));
			this.butLeft.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butLeft.Dock")));
			this.butLeft.Enabled = ((bool)(resources.GetObject("butLeft.Enabled")));
			this.butLeft.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butLeft.FlatStyle")));
			this.butLeft.Font = ((System.Drawing.Font)(resources.GetObject("butLeft.Font")));
			this.butLeft.Image = ((System.Drawing.Image)(resources.GetObject("butLeft.Image")));
			this.butLeft.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butLeft.ImageAlign")));
			this.butLeft.ImageIndex = ((int)(resources.GetObject("butLeft.ImageIndex")));
			this.butLeft.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butLeft.ImeMode")));
			this.butLeft.Location = ((System.Drawing.Point)(resources.GetObject("butLeft.Location")));
			this.butLeft.Name = "butLeft";
			this.butLeft.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butLeft.RightToLeft")));
			this.butLeft.Size = ((System.Drawing.Size)(resources.GetObject("butLeft.Size")));
			this.butLeft.TabIndex = ((int)(resources.GetObject("butLeft.TabIndex")));
			this.butLeft.Text = resources.GetString("butLeft.Text");
			this.butLeft.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butLeft.TextAlign")));
			this.butLeft.Visible = ((bool)(resources.GetObject("butLeft.Visible")));
			this.butLeft.Click += new System.EventHandler(this.butLeft_Click);
			// 
			// butRight
			// 
			this.butRight.AccessibleDescription = resources.GetString("butRight.AccessibleDescription");
			this.butRight.AccessibleName = resources.GetString("butRight.AccessibleName");
			this.butRight.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butRight.Anchor")));
			this.butRight.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butRight.BackgroundImage")));
			this.butRight.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butRight.Dock")));
			this.butRight.Enabled = ((bool)(resources.GetObject("butRight.Enabled")));
			this.butRight.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butRight.FlatStyle")));
			this.butRight.Font = ((System.Drawing.Font)(resources.GetObject("butRight.Font")));
			this.butRight.Image = ((System.Drawing.Image)(resources.GetObject("butRight.Image")));
			this.butRight.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butRight.ImageAlign")));
			this.butRight.ImageIndex = ((int)(resources.GetObject("butRight.ImageIndex")));
			this.butRight.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butRight.ImeMode")));
			this.butRight.Location = ((System.Drawing.Point)(resources.GetObject("butRight.Location")));
			this.butRight.Name = "butRight";
			this.butRight.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butRight.RightToLeft")));
			this.butRight.Size = ((System.Drawing.Size)(resources.GetObject("butRight.Size")));
			this.butRight.TabIndex = ((int)(resources.GetObject("butRight.TabIndex")));
			this.butRight.Text = resources.GetString("butRight.Text");
			this.butRight.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butRight.TextAlign")));
			this.butRight.Visible = ((bool)(resources.GetObject("butRight.Visible")));
			this.butRight.Click += new System.EventHandler(this.butRight_Click);
			// 
			// label17
			// 
			this.label17.AccessibleDescription = resources.GetString("label17.AccessibleDescription");
			this.label17.AccessibleName = resources.GetString("label17.AccessibleName");
			this.label17.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("label17.Anchor")));
			this.label17.AutoSize = ((bool)(resources.GetObject("label17.AutoSize")));
			this.label17.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("label17.Dock")));
			this.label17.Enabled = ((bool)(resources.GetObject("label17.Enabled")));
			this.label17.Font = ((System.Drawing.Font)(resources.GetObject("label17.Font")));
			this.label17.Image = ((System.Drawing.Image)(resources.GetObject("label17.Image")));
			this.label17.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label17.ImageAlign")));
			this.label17.ImageIndex = ((int)(resources.GetObject("label17.ImageIndex")));
			this.label17.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("label17.ImeMode")));
			this.label17.Location = ((System.Drawing.Point)(resources.GetObject("label17.Location")));
			this.label17.Name = "label17";
			this.label17.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("label17.RightToLeft")));
			this.label17.Size = ((System.Drawing.Size)(resources.GetObject("label17.Size")));
			this.label17.TabIndex = ((int)(resources.GetObject("label17.TabIndex")));
			this.label17.Text = resources.GetString("label17.Text");
			this.label17.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label17.TextAlign")));
			this.label17.Visible = ((bool)(resources.GetObject("label17.Visible")));
			// 
			// label18
			// 
			this.label18.AccessibleDescription = resources.GetString("label18.AccessibleDescription");
			this.label18.AccessibleName = resources.GetString("label18.AccessibleName");
			this.label18.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("label18.Anchor")));
			this.label18.AutoSize = ((bool)(resources.GetObject("label18.AutoSize")));
			this.label18.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("label18.Dock")));
			this.label18.Enabled = ((bool)(resources.GetObject("label18.Enabled")));
			this.label18.Font = ((System.Drawing.Font)(resources.GetObject("label18.Font")));
			this.label18.Image = ((System.Drawing.Image)(resources.GetObject("label18.Image")));
			this.label18.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label18.ImageAlign")));
			this.label18.ImageIndex = ((int)(resources.GetObject("label18.ImageIndex")));
			this.label18.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("label18.ImeMode")));
			this.label18.Location = ((System.Drawing.Point)(resources.GetObject("label18.Location")));
			this.label18.Name = "label18";
			this.label18.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("label18.RightToLeft")));
			this.label18.Size = ((System.Drawing.Size)(resources.GetObject("label18.Size")));
			this.label18.TabIndex = ((int)(resources.GetObject("label18.TabIndex")));
			this.label18.Text = resources.GetString("label18.Text");
			this.label18.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label18.TextAlign")));
			this.label18.Visible = ((bool)(resources.GetObject("label18.Visible")));
			// 
			// numQuickDistance
			// 
			this.numQuickDistance.AccessibleDescription = resources.GetString("numQuickDistance.AccessibleDescription");
			this.numQuickDistance.AccessibleName = resources.GetString("numQuickDistance.AccessibleName");
			this.numQuickDistance.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("numQuickDistance.Anchor")));
			this.numQuickDistance.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("numQuickDistance.Dock")));
			this.numQuickDistance.Enabled = ((bool)(resources.GetObject("numQuickDistance.Enabled")));
			this.numQuickDistance.Font = ((System.Drawing.Font)(resources.GetObject("numQuickDistance.Font")));
			this.numQuickDistance.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("numQuickDistance.ImeMode")));
			this.numQuickDistance.Location = ((System.Drawing.Point)(resources.GetObject("numQuickDistance.Location")));
			this.numQuickDistance.Maximum = new System.Decimal(new int[] {
																			 200,
																			 0,
																			 0,
																			 0});
			this.numQuickDistance.Minimum = new System.Decimal(new int[] {
																			 1,
																			 0,
																			 0,
																			 0});
			this.numQuickDistance.Name = "numQuickDistance";
			this.numQuickDistance.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("numQuickDistance.RightToLeft")));
			this.numQuickDistance.Size = ((System.Drawing.Size)(resources.GetObject("numQuickDistance.Size")));
			this.numQuickDistance.TabIndex = ((int)(resources.GetObject("numQuickDistance.TabIndex")));
			this.numQuickDistance.TextAlign = ((System.Windows.Forms.HorizontalAlignment)(resources.GetObject("numQuickDistance.TextAlign")));
			this.numQuickDistance.ThousandsSeparator = ((bool)(resources.GetObject("numQuickDistance.ThousandsSeparator")));
			this.numQuickDistance.UpDownAlign = ((System.Windows.Forms.LeftRightAlignment)(resources.GetObject("numQuickDistance.UpDownAlign")));
			this.numQuickDistance.Value = new System.Decimal(new int[] {
																		   1,
																		   0,
																		   0,
																		   0});
			this.numQuickDistance.Visible = ((bool)(resources.GetObject("numQuickDistance.Visible")));
			// 
			// buttonApply
			// 
			this.buttonApply.AccessibleDescription = resources.GetString("buttonApply.AccessibleDescription");
			this.buttonApply.AccessibleName = resources.GetString("buttonApply.AccessibleName");
			this.buttonApply.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("buttonApply.Anchor")));
			this.buttonApply.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("buttonApply.BackgroundImage")));
			this.buttonApply.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("buttonApply.Dock")));
			this.buttonApply.Enabled = ((bool)(resources.GetObject("buttonApply.Enabled")));
			this.buttonApply.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("buttonApply.FlatStyle")));
			this.buttonApply.Font = ((System.Drawing.Font)(resources.GetObject("buttonApply.Font")));
			this.buttonApply.Image = ((System.Drawing.Image)(resources.GetObject("buttonApply.Image")));
			this.buttonApply.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("buttonApply.ImageAlign")));
			this.buttonApply.ImageIndex = ((int)(resources.GetObject("buttonApply.ImageIndex")));
			this.buttonApply.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("buttonApply.ImeMode")));
			this.buttonApply.Location = ((System.Drawing.Point)(resources.GetObject("buttonApply.Location")));
			this.buttonApply.Name = "buttonApply";
			this.buttonApply.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("buttonApply.RightToLeft")));
			this.buttonApply.Size = ((System.Drawing.Size)(resources.GetObject("buttonApply.Size")));
			this.buttonApply.TabIndex = ((int)(resources.GetObject("buttonApply.TabIndex")));
			this.buttonApply.Text = resources.GetString("buttonApply.Text");
			this.buttonApply.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("buttonApply.TextAlign")));
			this.buttonApply.Visible = ((bool)(resources.GetObject("buttonApply.Visible")));
			this.buttonApply.Click += new System.EventHandler(this.buttonApply_Click);
			// 
			// panelButton2
			// 
			this.panelButton2.AccessibleDescription = resources.GetString("panelButton2.AccessibleDescription");
			this.panelButton2.AccessibleName = resources.GetString("panelButton2.AccessibleName");
			this.panelButton2.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("panelButton2.Anchor")));
			this.panelButton2.AutoScroll = ((bool)(resources.GetObject("panelButton2.AutoScroll")));
			this.panelButton2.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("panelButton2.AutoScrollMargin")));
			this.panelButton2.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("panelButton2.AutoScrollMinSize")));
			this.panelButton2.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("panelButton2.BackgroundImage")));
			this.panelButton2.Controls.Add(this.butRight2);
			this.panelButton2.Controls.Add(this.butLeft2);
			this.panelButton2.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("panelButton2.Dock")));
			this.panelButton2.Enabled = ((bool)(resources.GetObject("panelButton2.Enabled")));
			this.panelButton2.Font = ((System.Drawing.Font)(resources.GetObject("panelButton2.Font")));
			this.panelButton2.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("panelButton2.ImeMode")));
			this.panelButton2.Location = ((System.Drawing.Point)(resources.GetObject("panelButton2.Location")));
			this.panelButton2.Name = "panelButton2";
			this.panelButton2.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("panelButton2.RightToLeft")));
			this.panelButton2.Size = ((System.Drawing.Size)(resources.GetObject("panelButton2.Size")));
			this.panelButton2.TabIndex = ((int)(resources.GetObject("panelButton2.TabIndex")));
			this.panelButton2.Text = resources.GetString("panelButton2.Text");
			this.panelButton2.Visible = ((bool)(resources.GetObject("panelButton2.Visible")));
			// 
			// butRight2
			// 
			this.butRight2.AccessibleDescription = resources.GetString("butRight2.AccessibleDescription");
			this.butRight2.AccessibleName = resources.GetString("butRight2.AccessibleName");
			this.butRight2.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butRight2.Anchor")));
			this.butRight2.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butRight2.BackgroundImage")));
			this.butRight2.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butRight2.Dock")));
			this.butRight2.Enabled = ((bool)(resources.GetObject("butRight2.Enabled")));
			this.butRight2.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butRight2.FlatStyle")));
			this.butRight2.Font = ((System.Drawing.Font)(resources.GetObject("butRight2.Font")));
			this.butRight2.Image = ((System.Drawing.Image)(resources.GetObject("butRight2.Image")));
			this.butRight2.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butRight2.ImageAlign")));
			this.butRight2.ImageIndex = ((int)(resources.GetObject("butRight2.ImageIndex")));
			this.butRight2.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butRight2.ImeMode")));
			this.butRight2.Location = ((System.Drawing.Point)(resources.GetObject("butRight2.Location")));
			this.butRight2.Name = "butRight2";
			this.butRight2.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butRight2.RightToLeft")));
			this.butRight2.Size = ((System.Drawing.Size)(resources.GetObject("butRight2.Size")));
			this.butRight2.TabIndex = ((int)(resources.GetObject("butRight2.TabIndex")));
			this.butRight2.Text = resources.GetString("butRight2.Text");
			this.butRight2.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butRight2.TextAlign")));
			this.butRight2.Visible = ((bool)(resources.GetObject("butRight2.Visible")));
			this.butRight2.Click += new System.EventHandler(this.butRight2_Click);
			// 
			// butLeft2
			// 
			this.butLeft2.AccessibleDescription = resources.GetString("butLeft2.AccessibleDescription");
			this.butLeft2.AccessibleName = resources.GetString("butLeft2.AccessibleName");
			this.butLeft2.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butLeft2.Anchor")));
			this.butLeft2.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butLeft2.BackgroundImage")));
			this.butLeft2.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butLeft2.Dock")));
			this.butLeft2.Enabled = ((bool)(resources.GetObject("butLeft2.Enabled")));
			this.butLeft2.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butLeft2.FlatStyle")));
			this.butLeft2.Font = ((System.Drawing.Font)(resources.GetObject("butLeft2.Font")));
			this.butLeft2.Image = ((System.Drawing.Image)(resources.GetObject("butLeft2.Image")));
			this.butLeft2.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butLeft2.ImageAlign")));
			this.butLeft2.ImageIndex = ((int)(resources.GetObject("butLeft2.ImageIndex")));
			this.butLeft2.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butLeft2.ImeMode")));
			this.butLeft2.Location = ((System.Drawing.Point)(resources.GetObject("butLeft2.Location")));
			this.butLeft2.Name = "butLeft2";
			this.butLeft2.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butLeft2.RightToLeft")));
			this.butLeft2.Size = ((System.Drawing.Size)(resources.GetObject("butLeft2.Size")));
			this.butLeft2.TabIndex = ((int)(resources.GetObject("butLeft2.TabIndex")));
			this.butLeft2.Text = resources.GetString("butLeft2.Text");
			this.butLeft2.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butLeft2.TextAlign")));
			this.butLeft2.Visible = ((bool)(resources.GetObject("butLeft2.Visible")));
			this.butLeft2.Click += new System.EventHandler(this.butLeft2_Click);
			// 
			// saveFrameDialog
			// 
			this.saveFrameDialog.Filter = ((string)(configurationAppSettings.GetValue("saveFrameDialog.Filter", typeof(string))));
			this.saveFrameDialog.Title = resources.GetString("saveFrameDialog.Title");
			// 
			// pictureMenu
			// 
			this.pictureMenu.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
																						this.menuSetMarker});
			this.pictureMenu.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("pictureMenu.RightToLeft")));
			this.pictureMenu.Popup += new System.EventHandler(this.pictureMenu_Popup);
			// 
			// menuSetMarker
			// 
			this.menuSetMarker.Enabled = ((bool)(resources.GetObject("menuSetMarker.Enabled")));
			this.menuSetMarker.Index = 0;
			this.menuSetMarker.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("menuSetMarker.Shortcut")));
			this.menuSetMarker.ShowShortcut = ((bool)(resources.GetObject("menuSetMarker.ShowShortcut")));
			this.menuSetMarker.Text = resources.GetString("menuSetMarker.Text");
			this.menuSetMarker.Visible = ((bool)(resources.GetObject("menuSetMarker.Visible")));
			this.menuSetMarker.Click += new System.EventHandler(this.menuSetMarker_Click);
			// 
			// QuickJump2
			// 
			this.AccessibleDescription = resources.GetString("$this.AccessibleDescription");
			this.AccessibleName = resources.GetString("$this.AccessibleName");
			this.AutoScaleBaseSize = ((System.Drawing.Size)(resources.GetObject("$this.AutoScaleBaseSize")));
			this.AutoScroll = ((bool)(resources.GetObject("$this.AutoScroll")));
			this.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("$this.AutoScrollMargin")));
			this.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("$this.AutoScrollMinSize")));
			this.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("$this.BackgroundImage")));
			this.CancelButton = this.butClose;
			this.ClientSize = ((System.Drawing.Size)(resources.GetObject("$this.ClientSize")));
			this.Controls.Add(this.panelControls);
			this.Enabled = ((bool)(resources.GetObject("$this.Enabled")));
			this.Font = ((System.Drawing.Font)(resources.GetObject("$this.Font")));
			this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedDialog;
			this.Icon = ((System.Drawing.Icon)(resources.GetObject("$this.Icon")));
			this.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("$this.ImeMode")));
			this.Location = ((System.Drawing.Point)(resources.GetObject("$this.Location")));
			this.MaximizeBox = false;
			this.MaximumSize = ((System.Drawing.Size)(resources.GetObject("$this.MaximumSize")));
			this.MinimizeBox = false;
			this.MinimumSize = ((System.Drawing.Size)(resources.GetObject("$this.MinimumSize")));
			this.Name = "QuickJump2";
			this.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("$this.RightToLeft")));
			this.ShowInTaskbar = false;
			this.StartPosition = ((System.Windows.Forms.FormStartPosition)(resources.GetObject("$this.StartPosition")));
			this.Text = resources.GetString("$this.Text");
			this.Closing += new System.ComponentModel.CancelEventHandler(this.QuickJump2_Closing);
			this.Load += new System.EventHandler(this.QuickJump2_Load);
			this.panelControls.ResumeLayout(false);
			((System.ComponentModel.ISupportInitialize)(this.numQuickDistance)).EndInit();
			this.panelButton2.ResumeLayout(false);
			this.ResumeLayout(false);

		}
		#endregion

		private void QuickJump2_Load(object sender, System.EventArgs e)
		{
			decimal scaleX=1m;
			decimal scaleY=1m;

			if (Settings.CurrentSettings.DPIRescaling)
				using (Graphics gr=this.CreateGraphics())
				{
					scaleX=96.0m/(decimal)gr.DpiX;
					scaleY=96.0m/(decimal)gr.DpiY;
				}

			int anzX=Settings.CurrentSettings.QuickJumpX;
			int xBorder=(int)(scaleX*(AreaSize.Width-PictureSize.Width));
			int yBorder=(int)(20*scaleY);
			if (anzX<0) // automatisch ermitteln
				anzX=(SystemInformation.WorkingArea.Width-xBorder)/AreaSize.Width;
			int anzY=Settings.CurrentSettings.QuickJumpY;
			if (anzY<0) // automatisch ermitteln
				anzY=(int)((SystemInformation.WorkingArea.Height-panelControls.Height*scaleX-yBorder)/AreaSize.Height);
			Size wndSize=new Size(anzX*AreaSize.Width+xBorder,(int)(anzY*AreaSize.Height+yBorder+panelControls.Height*scaleX));

			// bergren werden billigend in Kauf genommen Gre einstellen
			this.ClientSize=wndSize;

			if (scaleX!=1m || scaleY!=1m)
			{
				// DPI anpassen:
				this.Font=new Font(this.Font.FontFamily, this.Font.Size*(float)scaleX,this.Font.Style,this.Font.Unit,this.Font.GdiCharSet,this.Font.GdiVerticalFont);
				foreach (Control childCtrl in this.Controls)
					GUIHelper.ScaleControl(this,childCtrl,scaleX,scaleY);
			}

			// Bilder dynamisch hinzufgen
			picture_pos=new int [anzX*anzY];
			this.SuspendLayout();
			for (int y=0;y<anzY;++y)
				for (int x=0;x<anzX;++x)
				{
					PictureBox pb=new PictureBox();
					pb.BackColor=Color.Blue;
					pb.BorderStyle=BorderStyle.Fixed3D;
					pb.Location=new Point(xBorder+x*AreaSize.Width,yBorder+y*AreaSize.Height);
					pb.Size=PictureSize;
					pb.SizeMode=PictureBoxSizeMode.StretchImage;
					pb.DoubleClick+=new EventHandler(SelectPosition);
					pb.ContextMenu=pictureMenu;

					Label lb=new Label();
					lb.Size=TextBoxSize;
					lb.Location=new Point(pb.Location.X,pb.Location.Y+pb.Size.Height);
					lb.Font=new Font(lb.Font.FontFamily,6.75f*(float)scaleX,lb.Font.Style,lb.Font.Unit,lb.Font.GdiCharSet,lb.Font.GdiVerticalFont);

					this.Controls.Add(pb);
					this.Controls.Add(lb);

					pictures.Add(pb);
					timecodes.Add(lb);
				}
			this.ResumeLayout(false);

			// Neu zentrieren:
			GUIHelper.CenterDialog(this);

			EnableDisableControls();
			StartShowThread();
		}

		public int NewPosition
		{
			get
			{
				return videoPosition;
			}
		}

		private void SelectPosition(object sender, System.EventArgs e)
		{
			int pos=EventPicture(sender);

			if (((PictureBox)pictures[pos]).Image!=null)
			{
				videoPosition=picture_pos[pos];
				DialogResult=DialogResult.OK;
				StopShowThread();
				Close();
			}
		}

		private void StartShowThread()
		{
			eventStopThread.Reset();
			eventThreadStopped.Reset();

			worker=new Thread(new ThreadStart(this.DisplayImages));
			worker.Name="QuickJump";
			worker.IsBackground=true;
			worker.Start();
		}

		private void StopShowThread()
		{
			if (worker!=null && worker.IsAlive)
			{
				eventStopThread.Set();

				System.Diagnostics.Debug.WriteLine(worker.ThreadState.ToString());
				System.Diagnostics.Debug.WriteLine("Forcing DisplayThread shutting down");

				while (worker.IsAlive)
				{
					if (WaitHandle.WaitAll(
						(new ManualResetEvent[] {eventThreadStopped}),
						100,true))
					{
						break;
					}
					Application.DoEvents();
				}

				System.Diagnostics.Debug.WriteLine("DisplayThread shutted down");
			}
		}

		private void UpdateImage(int index,int position)
		{
			if (position<0)
			{
				if (((PictureBox)pictures[index]).Image!=null)
					((PictureBox)pictures[index]).Image.Dispose();
				((PictureBox)pictures[index]).Image=null;
				((Label)timecodes[index]).Text=string.Empty;
				return;
			}

			lock(pictures[index])
			{
				Bitmap bitm=(Bitmap)((PictureBox)pictures[index]).Image;
				bool newBMPCreated;
				decoder.GetPicture(position,ref bitm,false,out newBMPCreated);
				if (newBMPCreated)
					((PictureBox)pictures[index]).Image=bitm;
				else
					((PictureBox)pictures[index]).Invalidate();
			}

			StringBuilder sb=new StringBuilder();
			sb.Append(Helper.FramesToTimeAndPicString(position,videoStream.FramesPerSecond));
			if (position>=viewStartPosition)
			{
				DateTime dt=Helper.FramesToTime(position-viewStartPosition,videoStream.FramesPerSecond);
				sb.AppendFormat(" [+{0}:{1:d2}:{2:d2},{3:d3}]",dt.Hour,dt.Minute,dt.Second,dt.Millisecond);
			}
			else
			{
				DateTime dt=Helper.FramesToTime(viewStartPosition-position,videoStream.FramesPerSecond);
				sb.AppendFormat(" [-{0}:{1:d2}:{2:d2},{3:d3}]",dt.Hour,dt.Minute,dt.Second,dt.Millisecond);
			}

			((Label)timecodes[index]).Text=sb.ToString();
		}

		/// <summary>
		/// Setzte das Bild "index" auf die gewnschte "Position" 
		/// Ist eine Invoke notwendig wird dieses ber das zugehrige Delegate ausgelst.
		/// </summary>
		/// <param name="index"></param>
		/// <param name="position"></param>
		private void CallImageUpdate(int index,int position)
		{
			// Invoke
			if (this.InvokeRequired)
			{
				if (this.Created)
				{
					Invoke(ImageUpdateCallBack,new object[]{index,position});
					Thread.Sleep(1); // Damit der Anwender auch was sieht!
				}
			}
			else
				UpdateImage(index,position);
		}

		private void DisplayImages()
		{
			int offset=0;
			decimal dist=numQuickDistance.Value;

			for (int i=0;i<pictures.Count;++i)
			{

				// abbrechen?
				if (eventStopThread.WaitOne(0,true))
				{
					eventThreadStopped.Set();
					return;
				}

				int showpos=videoPosition+(int)(dist*(i+offset)*videoStream.FramesPerSecond);
				if (showpos<0 || showpos>=videoStream.PicturesCount)
				{
					CallImageUpdate(i,-1);
					continue;
				}

				Mpeg12Video Mpeg2Info=(Mpeg12Video)videoStream;
				// Vor dem Zielpunkt liegendes IFrame suchen
				if ((FrameType)Mpeg2Info.GetPicture(showpos).picture_coding_type==FrameType.IFrame)
					picture_pos[i]=showpos;
				else
					picture_pos[i]=Mpeg2Info.CalculatePrevFramePos(showpos,FrameType.IFrame);

				// Invoke
				CallImageUpdate(i,picture_pos[i]);
			}
		}

		private void QuickJump2_Closing(object sender, System.ComponentModel.CancelEventArgs e)
		{
			StopShowThread();
		}

		private void EnableDisableControls()
		{
			butLeft.Enabled=butLeft2.Enabled=videoPosition>=distance;
			butRight.Enabled=butRight2.Enabled=videoPosition+pictures.Count*distance<videoStream.PicturesCount;
		}

		private void buttonApply_Click(object sender, System.EventArgs e)
		{
			distance=(int)numQuickDistance.Value*(int)(videoStream.FramesPerSecond+0.5m);
			EnableDisableControls();
			if (!worker.IsAlive)
				StartShowThread();
		}

		private void butSaveAllFrames_Click(object sender, System.EventArgs e)
		{
			if (saveFrameDialog.ShowDialog()==DialogResult.OK)
			{
				ImageFormat format=null;
				switch (Path.GetExtension(saveFrameDialog.FileName).ToLower())
				{
					case ".jpg":
						format=ImageFormat.Jpeg;
						break;
					case ".bmp":
						format=ImageFormat.Bmp;
						break;
					case ".png":
						format=ImageFormat.Png;
						break;
					case ".gif":
						format=ImageFormat.Gif;
						break;
				}
				int lfdNr=0;
				string fileName;
				for (int index=0;index<pictures.Count;++index)
				{
					if (((PictureBox)pictures[index]).Image!=null && format!=null)
					{
						do
						{
							fileName=string.Format("{0}{1:D3}{2}",Path.GetFileNameWithoutExtension(saveFrameDialog.FileName),++lfdNr,Path.GetExtension(saveFrameDialog.FileName));
							fileName=Path.Combine(Path.GetDirectoryName(saveFrameDialog.FileName),fileName);
						} while (File.Exists(fileName));
						((PictureBox)pictures[index]).Image.Save(fileName,format);
					}
				}

			}
		}

		private int EventPicture(object sender)
		{
			int pos;
			for (pos=0;pos<pictures.Count;++pos)
				if (pictures[pos]==sender)
					break;
			if (pos==pictures.Count)
				return -1;
			return pos;
		}

		private void butLeft_Click(object sender, System.EventArgs e)
		{
			if (!worker.IsAlive)
			{
				videoPosition-=pictures.Count*distance;
				EnableDisableControls();
				StartShowThread();
			}
		}

		private void butRight_Click(object sender, System.EventArgs e)
		{
			if (!worker.IsAlive)
			{
				videoPosition+=pictures.Count*distance;
				EnableDisableControls();
				StartShowThread();
			}
		}

		private void butLeft2_Click(object sender, System.EventArgs e)
		{
			butLeft_Click(sender,e);
		}

		private void butRight2_Click(object sender, System.EventArgs e)
		{
			butRight_Click(sender,e);		
		}

		private void menuSetMarker_Click(object sender, System.EventArgs e)
		{
			int pos=EventPicture(((ContextMenu)((MenuItem)sender).Parent).SourceControl);
			marker.Add(picture_pos[pos]);
		}

		private void pictureMenu_Popup(object sender, System.EventArgs e)
		{
			PictureBox pb=((ContextMenu)sender).SourceControl as PictureBox;
			menuSetMarker.Visible=pb!=null && pb.Image!=null;
		}

		public ArrayList Marker
		{
			get
			{
				return marker;
			}
		}

	}
}
