/*
 * Cuttermaran - The Mpeg Cutter
 * 
 * Copyright (C) 2003-2005  Tobias Arnold (cuttermaran@gmx.net)
 * 
 * This file is part of cuttermaran, a free MPEG cut program.
 * See http://www.cuttermaran.de for updates.
 *
 * This program is free software; you can redistribute it and/or modify it 
 * under the terms of the GNU General Public License as published by the 
 * Free Software Foundation; either version 2 of the License, or 
 * (at your option) any later version. 
 * 
 * This program is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the 
 * GNU General Public License for more details. 
 * 
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */

using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Threading;
using AVStreams;
using Configuration;

namespace GUI
{
	public delegate void ReScanCallback(bool result);
	/// <summary>
	/// Summary description for ReScanDialog.
	/// </summary>
	public class ReScanDialog : System.Windows.Forms.Form
	{
		private System.Timers.Timer RescanTimer;
		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;
		private Mpeg2Video videostream;
		private RescanController rescanCtrl;
		private System.Windows.Forms.Label lblProgress;
		private Thread worker;
		private ReScanCallback callbackMethod;

		public ReScanDialog(Mpeg2Video m2v,ReScanCallback returnMethod)
		{
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();

			videostream=m2v;
			callbackMethod=returnMethod;
		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.RescanTimer = new System.Timers.Timer();
			this.lblProgress = new System.Windows.Forms.Label();
			((System.ComponentModel.ISupportInitialize)(this.RescanTimer)).BeginInit();
			this.SuspendLayout();
			// 
			// RescanTimer
			// 
			this.RescanTimer.Interval = 1000;
			this.RescanTimer.SynchronizingObject = this;
			this.RescanTimer.Elapsed += new System.Timers.ElapsedEventHandler(this.RescanTimer_Elapsed);
			// 
			// lblProgress
			// 
			this.lblProgress.Dock = System.Windows.Forms.DockStyle.Fill;
			this.lblProgress.Font = new System.Drawing.Font("Microsoft Sans Serif", 20.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.lblProgress.Location = new System.Drawing.Point(0, 0);
			this.lblProgress.Name = "lblProgress";
			this.lblProgress.Size = new System.Drawing.Size(112, 31);
			this.lblProgress.TabIndex = 0;
			this.lblProgress.Text = "0%";
			// 
			// ReScanDialog
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(16, 37);
			this.ClientSize = new System.Drawing.Size(112, 31);
			this.ControlBox = false;
			this.Controls.Add(this.lblProgress);
			this.Font = new System.Drawing.Font("Microsoft Sans Serif", 24.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedDialog;
			this.MaximizeBox = false;
			this.MinimizeBox = false;
			this.MinimumSize = new System.Drawing.Size(118, 56);
			this.Name = "ReScanDialog";
			this.ShowInTaskbar = false;
			this.StartPosition = System.Windows.Forms.FormStartPosition.Manual;
			this.Text = "rescanning ...";
			this.TopMost = true;
			this.Closing += new System.ComponentModel.CancelEventHandler(this.ReScanDialog_Closing);
			this.Load += new System.EventHandler(this.ReScanDialog_Load);
			((System.ComponentModel.ISupportInitialize)(this.RescanTimer)).EndInit();
			this.ResumeLayout(false);

		}
		#endregion

		private void RescanTimer_Elapsed(object sender, System.Timers.ElapsedEventArgs e)
		{
			lblProgress.Text=string.Format("{0:0.0}%",rescanCtrl.PercentageComplete);
			if (worker.ThreadState==System.Threading.ThreadState.Stopped)
			{
				RescanTimer.Enabled=false;
				//this.Invoke(callbackMethod,new object [] {true});
				callbackMethod(true);
				Close();
			}
		}

		private void ReScanDialog_Load(object sender, System.EventArgs e)
		{
			rescanCtrl=new RescanController(videostream);
			worker=new Thread(new ThreadStart(rescanCtrl.Run));
			worker.CurrentUICulture=new System.Globalization.CultureInfo(Settings.CurrentSettings.Language);
			worker.IsBackground=true;
			worker.Name="rescan stream";
			worker.Priority=ThreadPriority.Lowest;
			worker.Start();
			RescanTimer.Enabled=true;
		}

		private void ReScanDialog_Closing(object sender, System.ComponentModel.CancelEventArgs e)
		{
			if (worker.ThreadState!=System.Threading.ThreadState.Stopped)
				e.Cancel=true;
		}
	}

	internal class RescanController
	{
		private decimal progress=0m;
		private Mpeg2Video videoindex;

		public decimal PercentageComplete
		{
			get
			{
				return progress*100;
			}
		}

		public RescanController(Mpeg2Video video)
		{
			videoindex=video;
		}

		public void Run()
		{
			videoindex.ReScanIndex(ref progress);
		}
	}
}
