/*
 * Cuttermaran - The Mpeg Cutter
 * 
 * Copyright (C) 2003-2005  Tobias Arnold (cuttermaran@gmx.net)
 * 
 * This file is part of cuttermaran, a free MPEG cut program.
 * See http://www.cuttermaran.de for updates.
 *
 * This program is free software; you can redistribute it and/or modify it 
 * under the terms of the GNU General Public License as published by the 
 * Free Software Foundation; either version 2 of the License, or 
 * (at your option) any later version. 
 * 
 * This program is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the 
 * GNU General Public License for more details. 
 * 
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */

using System;
using System.IO;
using System.Data;
using System.Text;
using System.Collections;
using System.Windows.Forms;
using System.Reflection;
using System.Diagnostics;
using GUI.data;
using StringResources;
using Configuration;

namespace GUI
{
	/// <summary>
	/// Summary description for Settings.CurrentSettings.
	/// </summary>
	public class SettingsDialog : GUIBaseForm
	{
		private System.Windows.Forms.Button butOK;
		private System.Windows.Forms.Button butCancel;
		private System.Windows.Forms.Label label1;
		private System.Windows.Forms.Label label2;
		private System.Windows.Forms.Label label3;
		private System.Windows.Forms.Label label4;
		private System.Windows.Forms.Label label5;
		private System.Windows.Forms.Label label6;
		private System.Windows.Forms.NumericUpDown numSearch;
		private System.Windows.Forms.NumericUpDown numPreview;
		private System.Windows.Forms.NumericUpDown numSlider;
		private System.Windows.Forms.Label label7;
		private System.Windows.Forms.NumericUpDown numQuickDistance;
		private System.Windows.Forms.Label label8;
		private System.Windows.Forms.Label label9;
		private System.Windows.Forms.Label label10;
		private System.Windows.Forms.NumericUpDown numSkipFrames;
		private System.Windows.Forms.TabControl SettingsTab;
		private System.Windows.Forms.TabPage tabPage1;
		private System.Windows.Forms.Label label16;
		private System.Windows.Forms.NumericUpDown numAltDistance;
		private System.Windows.Forms.Label label17;
		private System.Windows.Forms.CheckBox checkUpdateDetect;
		private System.Windows.Forms.Label label11;
		private System.Windows.Forms.TextBox txtTempDir;
		private System.Windows.Forms.Button butBrowseTempDir;
		private System.Windows.Forms.FolderBrowserDialog folderBrowserTempDir;
		private System.Windows.Forms.CheckBox checkRecalcSourceBitrate;
		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;
		private System.Windows.Forms.TabPage tabPage7;
		private System.Windows.Forms.CheckBox checkDisplayFullPath;
		private System.Windows.Forms.CheckBox checkCurrentFrameCaption;
		private System.Windows.Forms.CheckBox checkApplyRatio;
		private System.Windows.Forms.Panel panelNumQJ;
		private System.Windows.Forms.Label label12;
		private System.Windows.Forms.NumericUpDown numericQJY;
		private System.Windows.Forms.NumericUpDown numericQJX;
		private System.Windows.Forms.CheckBox checkManualQJ;
		private System.Windows.Forms.CheckBox checkAdditionalScrollBar;
		private System.Windows.Forms.TabPage tabEncoding;
		private System.Windows.Forms.TabPage tabCut;
		private System.Windows.Forms.TabPage tabMuxing;
		private System.Windows.Forms.TabPage tabChapter;
		private System.Windows.Forms.TabPage tabPresets;
		private Settings.GUIPresetData guiData;

		// Die Dialoge
		private CutParamControl cutParamControl=new CutParamControl();
		private EncodingControl encodingControl=new EncodingControl();
		private MuxingControl muxingControl=new MuxingControl();
		private ChapterControl chapterControl=new ChapterControl();
		private System.Windows.Forms.CheckBox checkDPIRescaling;
		private System.Windows.Forms.CheckBox checkForceClose;
		private System.Windows.Forms.CheckBox checkShowCutInPicture;
		private PresetCtrl presetControl=new PresetCtrl();

		public SettingsDialog(Settings.GUIPresetData currentGUIdata)
		{
			InitializeComponent();
			guiData=currentGUIdata;

			// Dialoge hinzufgen
			tabEncoding.Controls.Add(encodingControl);
			tabCut.Controls.Add(cutParamControl);
			tabMuxing.Controls.Add(muxingControl);
			tabChapter.Controls.Add(chapterControl);
			tabPresets.Controls.Add(presetControl);
		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		private void Settings_Load(object sender, System.EventArgs e)
		{
			checkShowCutInPicture.Checked=Settings.CurrentSettings.ShowCutInPicture;
			numSearch.Value=Settings.CurrentSettings.SecCutOutSearch;
			numPreview.Value=2*Settings.CurrentSettings.SecCutPreview;
			numSlider.Value=Settings.CurrentSettings.SliderPlacement;
			numQuickDistance.Value=Settings.CurrentSettings.SecQuickJumpStep;
			numAltDistance.Value=Settings.CurrentSettings.CustomPlacementStep;
			numSkipFrames.Value=Settings.CurrentSettings.SkipFramesPlay;
			checkUpdateDetect.Checked=Settings.CurrentSettings.UseUpdateDetection;
			checkDisplayFullPath.Checked=Settings.CurrentSettings.DisplayFullPathInformations;
			txtTempDir.Text=Settings.CurrentSettings.TempDir;
			checkRecalcSourceBitrate.Checked=Settings.CurrentSettings.RecalcSourceBitrate;
			checkCurrentFrameCaption.Checked=Settings.CurrentSettings.ShowCurrentFrameCaption;
			checkManualQJ.Checked=Settings.CurrentSettings.QuickJumpX>=0 && Settings.CurrentSettings.QuickJumpY>=0;
			if (checkManualQJ.Checked)
			{
				numericQJX.Value=Settings.CurrentSettings.QuickJumpX;
				numericQJY.Value=Settings.CurrentSettings.QuickJumpY;
			}
			checkApplyRatio.Checked=Settings.CurrentSettings.ApplyAspectRatio;
			checkAdditionalScrollBar.Checked=Settings.CurrentSettings.AdditionalScrollBar;
			checkDPIRescaling.Checked=Settings.CurrentSettings.DPIRescaling;
			checkForceClose.Checked=Settings.CurrentSettings.ForceCutAndClose;

			// Controls initialisieren
			cutParamControl.LoadData();
			encodingControl.LoadData();
			muxingControl.LoadData();
			chapterControl.LoadData();
			presetControl.LoadData(guiData);
		}

		private void butOK_Click(object sender, System.EventArgs e)
		{
			Settings.CurrentSettings.ShowCutInPicture=checkShowCutInPicture.Checked;
			Settings.CurrentSettings.SecCutOutSearch=numSearch.Value;
			Settings.CurrentSettings.SecCutPreview=numPreview.Value/2m;
			Settings.CurrentSettings.SliderPlacement=(int)numSlider.Value;
			Settings.CurrentSettings.SecQuickJumpStep=(int)numQuickDistance.Value;
			Settings.CurrentSettings.CustomPlacementStep=(int)numAltDistance.Value;
			Settings.CurrentSettings.SkipFramesPlay=(int)numSkipFrames.Value;
			Settings.CurrentSettings.UseUpdateDetection=checkUpdateDetect.Checked;
			Settings.CurrentSettings.DisplayFullPathInformations=checkDisplayFullPath.Checked;
			Settings.CurrentSettings.TempDir=txtTempDir.Text;
			Settings.CurrentSettings.RecalcSourceBitrate=checkRecalcSourceBitrate.Checked;
			Settings.CurrentSettings.ShowCurrentFrameCaption=checkCurrentFrameCaption.Checked;
			if (checkManualQJ.Checked)
			{
				Settings.CurrentSettings.QuickJumpX=(int)numericQJX.Value;
				Settings.CurrentSettings.QuickJumpY=(int)numericQJY.Value;
			}
			else
			{
				Settings.CurrentSettings.QuickJumpX=-1;
				Settings.CurrentSettings.QuickJumpY=-1;
			}
			Settings.CurrentSettings.ApplyAspectRatio=checkApplyRatio.Checked;
			Settings.CurrentSettings.AdditionalScrollBar=checkAdditionalScrollBar.Checked;
			Settings.CurrentSettings.DPIRescaling=checkDPIRescaling.Checked;
			Settings.CurrentSettings.ForceCutAndClose=checkForceClose.Checked;

			// Controls speichern
			cutParamControl.UnLoadData();
			encodingControl.UnLoadData();
			muxingControl.UnLoadData();
			chapterControl.UnLoadData();
			presetControl.UnLoadData();

			// Save to file NOW because if Cuttermaran should crash, all settings 
			// will be lost! (And crashes happen more often than they should)
			Settings.CurrentSettings.CommitChanges();
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(SettingsDialog));
			this.butOK = new System.Windows.Forms.Button();
			this.butCancel = new System.Windows.Forms.Button();
			this.label1 = new System.Windows.Forms.Label();
			this.numSearch = new System.Windows.Forms.NumericUpDown();
			this.label2 = new System.Windows.Forms.Label();
			this.label3 = new System.Windows.Forms.Label();
			this.numPreview = new System.Windows.Forms.NumericUpDown();
			this.label4 = new System.Windows.Forms.Label();
			this.label5 = new System.Windows.Forms.Label();
			this.numSlider = new System.Windows.Forms.NumericUpDown();
			this.label6 = new System.Windows.Forms.Label();
			this.label7 = new System.Windows.Forms.Label();
			this.numQuickDistance = new System.Windows.Forms.NumericUpDown();
			this.label8 = new System.Windows.Forms.Label();
			this.label9 = new System.Windows.Forms.Label();
			this.label10 = new System.Windows.Forms.Label();
			this.numSkipFrames = new System.Windows.Forms.NumericUpDown();
			this.SettingsTab = new System.Windows.Forms.TabControl();
			this.tabPage1 = new System.Windows.Forms.TabPage();
			this.checkForceClose = new System.Windows.Forms.CheckBox();
			this.checkRecalcSourceBitrate = new System.Windows.Forms.CheckBox();
			this.butBrowseTempDir = new System.Windows.Forms.Button();
			this.txtTempDir = new System.Windows.Forms.TextBox();
			this.label11 = new System.Windows.Forms.Label();
			this.checkUpdateDetect = new System.Windows.Forms.CheckBox();
			this.label17 = new System.Windows.Forms.Label();
			this.numAltDistance = new System.Windows.Forms.NumericUpDown();
			this.label16 = new System.Windows.Forms.Label();
			this.tabPage7 = new System.Windows.Forms.TabPage();
			this.checkShowCutInPicture = new System.Windows.Forms.CheckBox();
			this.checkDPIRescaling = new System.Windows.Forms.CheckBox();
			this.checkAdditionalScrollBar = new System.Windows.Forms.CheckBox();
			this.checkApplyRatio = new System.Windows.Forms.CheckBox();
			this.panelNumQJ = new System.Windows.Forms.Panel();
			this.label12 = new System.Windows.Forms.Label();
			this.numericQJY = new System.Windows.Forms.NumericUpDown();
			this.numericQJX = new System.Windows.Forms.NumericUpDown();
			this.checkManualQJ = new System.Windows.Forms.CheckBox();
			this.checkCurrentFrameCaption = new System.Windows.Forms.CheckBox();
			this.checkDisplayFullPath = new System.Windows.Forms.CheckBox();
			this.tabEncoding = new System.Windows.Forms.TabPage();
			this.tabCut = new System.Windows.Forms.TabPage();
			this.tabMuxing = new System.Windows.Forms.TabPage();
			this.tabChapter = new System.Windows.Forms.TabPage();
			this.tabPresets = new System.Windows.Forms.TabPage();
			this.folderBrowserTempDir = new System.Windows.Forms.FolderBrowserDialog();
			((System.ComponentModel.ISupportInitialize)(this.numSearch)).BeginInit();
			((System.ComponentModel.ISupportInitialize)(this.numPreview)).BeginInit();
			((System.ComponentModel.ISupportInitialize)(this.numSlider)).BeginInit();
			((System.ComponentModel.ISupportInitialize)(this.numQuickDistance)).BeginInit();
			((System.ComponentModel.ISupportInitialize)(this.numSkipFrames)).BeginInit();
			this.SettingsTab.SuspendLayout();
			this.tabPage1.SuspendLayout();
			((System.ComponentModel.ISupportInitialize)(this.numAltDistance)).BeginInit();
			this.tabPage7.SuspendLayout();
			this.panelNumQJ.SuspendLayout();
			((System.ComponentModel.ISupportInitialize)(this.numericQJY)).BeginInit();
			((System.ComponentModel.ISupportInitialize)(this.numericQJX)).BeginInit();
			this.SuspendLayout();
			// 
			// butOK
			// 
			this.butOK.AccessibleDescription = resources.GetString("butOK.AccessibleDescription");
			this.butOK.AccessibleName = resources.GetString("butOK.AccessibleName");
			this.butOK.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butOK.Anchor")));
			this.butOK.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butOK.BackgroundImage")));
			this.butOK.DialogResult = System.Windows.Forms.DialogResult.OK;
			this.butOK.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butOK.Dock")));
			this.butOK.Enabled = ((bool)(resources.GetObject("butOK.Enabled")));
			this.butOK.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butOK.FlatStyle")));
			this.butOK.Font = ((System.Drawing.Font)(resources.GetObject("butOK.Font")));
			this.butOK.Image = ((System.Drawing.Image)(resources.GetObject("butOK.Image")));
			this.butOK.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butOK.ImageAlign")));
			this.butOK.ImageIndex = ((int)(resources.GetObject("butOK.ImageIndex")));
			this.butOK.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butOK.ImeMode")));
			this.butOK.Location = ((System.Drawing.Point)(resources.GetObject("butOK.Location")));
			this.butOK.Name = "butOK";
			this.butOK.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butOK.RightToLeft")));
			this.butOK.Size = ((System.Drawing.Size)(resources.GetObject("butOK.Size")));
			this.butOK.TabIndex = ((int)(resources.GetObject("butOK.TabIndex")));
			this.butOK.Text = resources.GetString("butOK.Text");
			this.butOK.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butOK.TextAlign")));
			this.butOK.Visible = ((bool)(resources.GetObject("butOK.Visible")));
			this.butOK.Click += new System.EventHandler(this.butOK_Click);
			// 
			// butCancel
			// 
			this.butCancel.AccessibleDescription = resources.GetString("butCancel.AccessibleDescription");
			this.butCancel.AccessibleName = resources.GetString("butCancel.AccessibleName");
			this.butCancel.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butCancel.Anchor")));
			this.butCancel.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butCancel.BackgroundImage")));
			this.butCancel.DialogResult = System.Windows.Forms.DialogResult.Cancel;
			this.butCancel.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butCancel.Dock")));
			this.butCancel.Enabled = ((bool)(resources.GetObject("butCancel.Enabled")));
			this.butCancel.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butCancel.FlatStyle")));
			this.butCancel.Font = ((System.Drawing.Font)(resources.GetObject("butCancel.Font")));
			this.butCancel.Image = ((System.Drawing.Image)(resources.GetObject("butCancel.Image")));
			this.butCancel.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butCancel.ImageAlign")));
			this.butCancel.ImageIndex = ((int)(resources.GetObject("butCancel.ImageIndex")));
			this.butCancel.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butCancel.ImeMode")));
			this.butCancel.Location = ((System.Drawing.Point)(resources.GetObject("butCancel.Location")));
			this.butCancel.Name = "butCancel";
			this.butCancel.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butCancel.RightToLeft")));
			this.butCancel.Size = ((System.Drawing.Size)(resources.GetObject("butCancel.Size")));
			this.butCancel.TabIndex = ((int)(resources.GetObject("butCancel.TabIndex")));
			this.butCancel.Text = resources.GetString("butCancel.Text");
			this.butCancel.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butCancel.TextAlign")));
			this.butCancel.Visible = ((bool)(resources.GetObject("butCancel.Visible")));
			// 
			// label1
			// 
			this.label1.AccessibleDescription = resources.GetString("label1.AccessibleDescription");
			this.label1.AccessibleName = resources.GetString("label1.AccessibleName");
			this.label1.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("label1.Anchor")));
			this.label1.AutoSize = ((bool)(resources.GetObject("label1.AutoSize")));
			this.label1.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("label1.Dock")));
			this.label1.Enabled = ((bool)(resources.GetObject("label1.Enabled")));
			this.label1.Font = ((System.Drawing.Font)(resources.GetObject("label1.Font")));
			this.label1.Image = ((System.Drawing.Image)(resources.GetObject("label1.Image")));
			this.label1.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label1.ImageAlign")));
			this.label1.ImageIndex = ((int)(resources.GetObject("label1.ImageIndex")));
			this.label1.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("label1.ImeMode")));
			this.label1.Location = ((System.Drawing.Point)(resources.GetObject("label1.Location")));
			this.label1.Name = "label1";
			this.label1.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("label1.RightToLeft")));
			this.label1.Size = ((System.Drawing.Size)(resources.GetObject("label1.Size")));
			this.label1.TabIndex = ((int)(resources.GetObject("label1.TabIndex")));
			this.label1.Text = resources.GetString("label1.Text");
			this.label1.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label1.TextAlign")));
			this.label1.Visible = ((bool)(resources.GetObject("label1.Visible")));
			// 
			// numSearch
			// 
			this.numSearch.AccessibleDescription = resources.GetString("numSearch.AccessibleDescription");
			this.numSearch.AccessibleName = resources.GetString("numSearch.AccessibleName");
			this.numSearch.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("numSearch.Anchor")));
			this.numSearch.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("numSearch.Dock")));
			this.numSearch.Enabled = ((bool)(resources.GetObject("numSearch.Enabled")));
			this.numSearch.Font = ((System.Drawing.Font)(resources.GetObject("numSearch.Font")));
			this.numSearch.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("numSearch.ImeMode")));
			this.numSearch.Increment = new System.Decimal(new int[] {
																		5,
																		0,
																		0,
																		0});
			this.numSearch.Location = ((System.Drawing.Point)(resources.GetObject("numSearch.Location")));
			this.numSearch.Maximum = new System.Decimal(new int[] {
																	  995,
																	  0,
																	  0,
																	  0});
			this.numSearch.Minimum = new System.Decimal(new int[] {
																	  5,
																	  0,
																	  0,
																	  0});
			this.numSearch.Name = "numSearch";
			this.numSearch.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("numSearch.RightToLeft")));
			this.numSearch.Size = ((System.Drawing.Size)(resources.GetObject("numSearch.Size")));
			this.numSearch.TabIndex = ((int)(resources.GetObject("numSearch.TabIndex")));
			this.numSearch.TextAlign = ((System.Windows.Forms.HorizontalAlignment)(resources.GetObject("numSearch.TextAlign")));
			this.numSearch.ThousandsSeparator = ((bool)(resources.GetObject("numSearch.ThousandsSeparator")));
			this.numSearch.UpDownAlign = ((System.Windows.Forms.LeftRightAlignment)(resources.GetObject("numSearch.UpDownAlign")));
			this.numSearch.Value = new System.Decimal(new int[] {
																	5,
																	0,
																	0,
																	0});
			this.numSearch.Visible = ((bool)(resources.GetObject("numSearch.Visible")));
			// 
			// label2
			// 
			this.label2.AccessibleDescription = resources.GetString("label2.AccessibleDescription");
			this.label2.AccessibleName = resources.GetString("label2.AccessibleName");
			this.label2.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("label2.Anchor")));
			this.label2.AutoSize = ((bool)(resources.GetObject("label2.AutoSize")));
			this.label2.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("label2.Dock")));
			this.label2.Enabled = ((bool)(resources.GetObject("label2.Enabled")));
			this.label2.Font = ((System.Drawing.Font)(resources.GetObject("label2.Font")));
			this.label2.Image = ((System.Drawing.Image)(resources.GetObject("label2.Image")));
			this.label2.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label2.ImageAlign")));
			this.label2.ImageIndex = ((int)(resources.GetObject("label2.ImageIndex")));
			this.label2.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("label2.ImeMode")));
			this.label2.Location = ((System.Drawing.Point)(resources.GetObject("label2.Location")));
			this.label2.Name = "label2";
			this.label2.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("label2.RightToLeft")));
			this.label2.Size = ((System.Drawing.Size)(resources.GetObject("label2.Size")));
			this.label2.TabIndex = ((int)(resources.GetObject("label2.TabIndex")));
			this.label2.Text = resources.GetString("label2.Text");
			this.label2.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label2.TextAlign")));
			this.label2.Visible = ((bool)(resources.GetObject("label2.Visible")));
			// 
			// label3
			// 
			this.label3.AccessibleDescription = resources.GetString("label3.AccessibleDescription");
			this.label3.AccessibleName = resources.GetString("label3.AccessibleName");
			this.label3.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("label3.Anchor")));
			this.label3.AutoSize = ((bool)(resources.GetObject("label3.AutoSize")));
			this.label3.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("label3.Dock")));
			this.label3.Enabled = ((bool)(resources.GetObject("label3.Enabled")));
			this.label3.Font = ((System.Drawing.Font)(resources.GetObject("label3.Font")));
			this.label3.Image = ((System.Drawing.Image)(resources.GetObject("label3.Image")));
			this.label3.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label3.ImageAlign")));
			this.label3.ImageIndex = ((int)(resources.GetObject("label3.ImageIndex")));
			this.label3.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("label3.ImeMode")));
			this.label3.Location = ((System.Drawing.Point)(resources.GetObject("label3.Location")));
			this.label3.Name = "label3";
			this.label3.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("label3.RightToLeft")));
			this.label3.Size = ((System.Drawing.Size)(resources.GetObject("label3.Size")));
			this.label3.TabIndex = ((int)(resources.GetObject("label3.TabIndex")));
			this.label3.Text = resources.GetString("label3.Text");
			this.label3.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label3.TextAlign")));
			this.label3.Visible = ((bool)(resources.GetObject("label3.Visible")));
			// 
			// numPreview
			// 
			this.numPreview.AccessibleDescription = resources.GetString("numPreview.AccessibleDescription");
			this.numPreview.AccessibleName = resources.GetString("numPreview.AccessibleName");
			this.numPreview.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("numPreview.Anchor")));
			this.numPreview.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("numPreview.Dock")));
			this.numPreview.Enabled = ((bool)(resources.GetObject("numPreview.Enabled")));
			this.numPreview.Font = ((System.Drawing.Font)(resources.GetObject("numPreview.Font")));
			this.numPreview.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("numPreview.ImeMode")));
			this.numPreview.Location = ((System.Drawing.Point)(resources.GetObject("numPreview.Location")));
			this.numPreview.Maximum = new System.Decimal(new int[] {
																	   120,
																	   0,
																	   0,
																	   0});
			this.numPreview.Minimum = new System.Decimal(new int[] {
																	   4,
																	   0,
																	   0,
																	   0});
			this.numPreview.Name = "numPreview";
			this.numPreview.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("numPreview.RightToLeft")));
			this.numPreview.Size = ((System.Drawing.Size)(resources.GetObject("numPreview.Size")));
			this.numPreview.TabIndex = ((int)(resources.GetObject("numPreview.TabIndex")));
			this.numPreview.TextAlign = ((System.Windows.Forms.HorizontalAlignment)(resources.GetObject("numPreview.TextAlign")));
			this.numPreview.ThousandsSeparator = ((bool)(resources.GetObject("numPreview.ThousandsSeparator")));
			this.numPreview.UpDownAlign = ((System.Windows.Forms.LeftRightAlignment)(resources.GetObject("numPreview.UpDownAlign")));
			this.numPreview.Value = new System.Decimal(new int[] {
																	 4,
																	 0,
																	 0,
																	 0});
			this.numPreview.Visible = ((bool)(resources.GetObject("numPreview.Visible")));
			// 
			// label4
			// 
			this.label4.AccessibleDescription = resources.GetString("label4.AccessibleDescription");
			this.label4.AccessibleName = resources.GetString("label4.AccessibleName");
			this.label4.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("label4.Anchor")));
			this.label4.AutoSize = ((bool)(resources.GetObject("label4.AutoSize")));
			this.label4.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("label4.Dock")));
			this.label4.Enabled = ((bool)(resources.GetObject("label4.Enabled")));
			this.label4.Font = ((System.Drawing.Font)(resources.GetObject("label4.Font")));
			this.label4.Image = ((System.Drawing.Image)(resources.GetObject("label4.Image")));
			this.label4.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label4.ImageAlign")));
			this.label4.ImageIndex = ((int)(resources.GetObject("label4.ImageIndex")));
			this.label4.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("label4.ImeMode")));
			this.label4.Location = ((System.Drawing.Point)(resources.GetObject("label4.Location")));
			this.label4.Name = "label4";
			this.label4.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("label4.RightToLeft")));
			this.label4.Size = ((System.Drawing.Size)(resources.GetObject("label4.Size")));
			this.label4.TabIndex = ((int)(resources.GetObject("label4.TabIndex")));
			this.label4.Text = resources.GetString("label4.Text");
			this.label4.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label4.TextAlign")));
			this.label4.Visible = ((bool)(resources.GetObject("label4.Visible")));
			// 
			// label5
			// 
			this.label5.AccessibleDescription = resources.GetString("label5.AccessibleDescription");
			this.label5.AccessibleName = resources.GetString("label5.AccessibleName");
			this.label5.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("label5.Anchor")));
			this.label5.AutoSize = ((bool)(resources.GetObject("label5.AutoSize")));
			this.label5.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("label5.Dock")));
			this.label5.Enabled = ((bool)(resources.GetObject("label5.Enabled")));
			this.label5.Font = ((System.Drawing.Font)(resources.GetObject("label5.Font")));
			this.label5.Image = ((System.Drawing.Image)(resources.GetObject("label5.Image")));
			this.label5.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label5.ImageAlign")));
			this.label5.ImageIndex = ((int)(resources.GetObject("label5.ImageIndex")));
			this.label5.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("label5.ImeMode")));
			this.label5.Location = ((System.Drawing.Point)(resources.GetObject("label5.Location")));
			this.label5.Name = "label5";
			this.label5.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("label5.RightToLeft")));
			this.label5.Size = ((System.Drawing.Size)(resources.GetObject("label5.Size")));
			this.label5.TabIndex = ((int)(resources.GetObject("label5.TabIndex")));
			this.label5.Text = resources.GetString("label5.Text");
			this.label5.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label5.TextAlign")));
			this.label5.Visible = ((bool)(resources.GetObject("label5.Visible")));
			// 
			// numSlider
			// 
			this.numSlider.AccessibleDescription = resources.GetString("numSlider.AccessibleDescription");
			this.numSlider.AccessibleName = resources.GetString("numSlider.AccessibleName");
			this.numSlider.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("numSlider.Anchor")));
			this.numSlider.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("numSlider.Dock")));
			this.numSlider.Enabled = ((bool)(resources.GetObject("numSlider.Enabled")));
			this.numSlider.Font = ((System.Drawing.Font)(resources.GetObject("numSlider.Font")));
			this.numSlider.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("numSlider.ImeMode")));
			this.numSlider.Increment = new System.Decimal(new int[] {
																		5,
																		0,
																		0,
																		0});
			this.numSlider.Location = ((System.Drawing.Point)(resources.GetObject("numSlider.Location")));
			this.numSlider.Maximum = new System.Decimal(new int[] {
																	  2000,
																	  0,
																	  0,
																	  0});
			this.numSlider.Minimum = new System.Decimal(new int[] {
																	  10,
																	  0,
																	  0,
																	  0});
			this.numSlider.Name = "numSlider";
			this.numSlider.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("numSlider.RightToLeft")));
			this.numSlider.Size = ((System.Drawing.Size)(resources.GetObject("numSlider.Size")));
			this.numSlider.TabIndex = ((int)(resources.GetObject("numSlider.TabIndex")));
			this.numSlider.TextAlign = ((System.Windows.Forms.HorizontalAlignment)(resources.GetObject("numSlider.TextAlign")));
			this.numSlider.ThousandsSeparator = ((bool)(resources.GetObject("numSlider.ThousandsSeparator")));
			this.numSlider.UpDownAlign = ((System.Windows.Forms.LeftRightAlignment)(resources.GetObject("numSlider.UpDownAlign")));
			this.numSlider.Value = new System.Decimal(new int[] {
																	10,
																	0,
																	0,
																	0});
			this.numSlider.Visible = ((bool)(resources.GetObject("numSlider.Visible")));
			// 
			// label6
			// 
			this.label6.AccessibleDescription = resources.GetString("label6.AccessibleDescription");
			this.label6.AccessibleName = resources.GetString("label6.AccessibleName");
			this.label6.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("label6.Anchor")));
			this.label6.AutoSize = ((bool)(resources.GetObject("label6.AutoSize")));
			this.label6.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("label6.Dock")));
			this.label6.Enabled = ((bool)(resources.GetObject("label6.Enabled")));
			this.label6.Font = ((System.Drawing.Font)(resources.GetObject("label6.Font")));
			this.label6.Image = ((System.Drawing.Image)(resources.GetObject("label6.Image")));
			this.label6.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label6.ImageAlign")));
			this.label6.ImageIndex = ((int)(resources.GetObject("label6.ImageIndex")));
			this.label6.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("label6.ImeMode")));
			this.label6.Location = ((System.Drawing.Point)(resources.GetObject("label6.Location")));
			this.label6.Name = "label6";
			this.label6.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("label6.RightToLeft")));
			this.label6.Size = ((System.Drawing.Size)(resources.GetObject("label6.Size")));
			this.label6.TabIndex = ((int)(resources.GetObject("label6.TabIndex")));
			this.label6.Text = resources.GetString("label6.Text");
			this.label6.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label6.TextAlign")));
			this.label6.Visible = ((bool)(resources.GetObject("label6.Visible")));
			// 
			// label7
			// 
			this.label7.AccessibleDescription = resources.GetString("label7.AccessibleDescription");
			this.label7.AccessibleName = resources.GetString("label7.AccessibleName");
			this.label7.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("label7.Anchor")));
			this.label7.AutoSize = ((bool)(resources.GetObject("label7.AutoSize")));
			this.label7.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("label7.Dock")));
			this.label7.Enabled = ((bool)(resources.GetObject("label7.Enabled")));
			this.label7.Font = ((System.Drawing.Font)(resources.GetObject("label7.Font")));
			this.label7.Image = ((System.Drawing.Image)(resources.GetObject("label7.Image")));
			this.label7.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label7.ImageAlign")));
			this.label7.ImageIndex = ((int)(resources.GetObject("label7.ImageIndex")));
			this.label7.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("label7.ImeMode")));
			this.label7.Location = ((System.Drawing.Point)(resources.GetObject("label7.Location")));
			this.label7.Name = "label7";
			this.label7.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("label7.RightToLeft")));
			this.label7.Size = ((System.Drawing.Size)(resources.GetObject("label7.Size")));
			this.label7.TabIndex = ((int)(resources.GetObject("label7.TabIndex")));
			this.label7.Text = resources.GetString("label7.Text");
			this.label7.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label7.TextAlign")));
			this.label7.Visible = ((bool)(resources.GetObject("label7.Visible")));
			// 
			// numQuickDistance
			// 
			this.numQuickDistance.AccessibleDescription = resources.GetString("numQuickDistance.AccessibleDescription");
			this.numQuickDistance.AccessibleName = resources.GetString("numQuickDistance.AccessibleName");
			this.numQuickDistance.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("numQuickDistance.Anchor")));
			this.numQuickDistance.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("numQuickDistance.Dock")));
			this.numQuickDistance.Enabled = ((bool)(resources.GetObject("numQuickDistance.Enabled")));
			this.numQuickDistance.Font = ((System.Drawing.Font)(resources.GetObject("numQuickDistance.Font")));
			this.numQuickDistance.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("numQuickDistance.ImeMode")));
			this.numQuickDistance.Location = ((System.Drawing.Point)(resources.GetObject("numQuickDistance.Location")));
			this.numQuickDistance.Maximum = new System.Decimal(new int[] {
																			 200,
																			 0,
																			 0,
																			 0});
			this.numQuickDistance.Minimum = new System.Decimal(new int[] {
																			 1,
																			 0,
																			 0,
																			 0});
			this.numQuickDistance.Name = "numQuickDistance";
			this.numQuickDistance.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("numQuickDistance.RightToLeft")));
			this.numQuickDistance.Size = ((System.Drawing.Size)(resources.GetObject("numQuickDistance.Size")));
			this.numQuickDistance.TabIndex = ((int)(resources.GetObject("numQuickDistance.TabIndex")));
			this.numQuickDistance.TextAlign = ((System.Windows.Forms.HorizontalAlignment)(resources.GetObject("numQuickDistance.TextAlign")));
			this.numQuickDistance.ThousandsSeparator = ((bool)(resources.GetObject("numQuickDistance.ThousandsSeparator")));
			this.numQuickDistance.UpDownAlign = ((System.Windows.Forms.LeftRightAlignment)(resources.GetObject("numQuickDistance.UpDownAlign")));
			this.numQuickDistance.Value = new System.Decimal(new int[] {
																		   1,
																		   0,
																		   0,
																		   0});
			this.numQuickDistance.Visible = ((bool)(resources.GetObject("numQuickDistance.Visible")));
			// 
			// label8
			// 
			this.label8.AccessibleDescription = resources.GetString("label8.AccessibleDescription");
			this.label8.AccessibleName = resources.GetString("label8.AccessibleName");
			this.label8.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("label8.Anchor")));
			this.label8.AutoSize = ((bool)(resources.GetObject("label8.AutoSize")));
			this.label8.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("label8.Dock")));
			this.label8.Enabled = ((bool)(resources.GetObject("label8.Enabled")));
			this.label8.Font = ((System.Drawing.Font)(resources.GetObject("label8.Font")));
			this.label8.Image = ((System.Drawing.Image)(resources.GetObject("label8.Image")));
			this.label8.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label8.ImageAlign")));
			this.label8.ImageIndex = ((int)(resources.GetObject("label8.ImageIndex")));
			this.label8.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("label8.ImeMode")));
			this.label8.Location = ((System.Drawing.Point)(resources.GetObject("label8.Location")));
			this.label8.Name = "label8";
			this.label8.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("label8.RightToLeft")));
			this.label8.Size = ((System.Drawing.Size)(resources.GetObject("label8.Size")));
			this.label8.TabIndex = ((int)(resources.GetObject("label8.TabIndex")));
			this.label8.Text = resources.GetString("label8.Text");
			this.label8.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label8.TextAlign")));
			this.label8.Visible = ((bool)(resources.GetObject("label8.Visible")));
			// 
			// label9
			// 
			this.label9.AccessibleDescription = resources.GetString("label9.AccessibleDescription");
			this.label9.AccessibleName = resources.GetString("label9.AccessibleName");
			this.label9.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("label9.Anchor")));
			this.label9.AutoSize = ((bool)(resources.GetObject("label9.AutoSize")));
			this.label9.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("label9.Dock")));
			this.label9.Enabled = ((bool)(resources.GetObject("label9.Enabled")));
			this.label9.Font = ((System.Drawing.Font)(resources.GetObject("label9.Font")));
			this.label9.Image = ((System.Drawing.Image)(resources.GetObject("label9.Image")));
			this.label9.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label9.ImageAlign")));
			this.label9.ImageIndex = ((int)(resources.GetObject("label9.ImageIndex")));
			this.label9.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("label9.ImeMode")));
			this.label9.Location = ((System.Drawing.Point)(resources.GetObject("label9.Location")));
			this.label9.Name = "label9";
			this.label9.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("label9.RightToLeft")));
			this.label9.Size = ((System.Drawing.Size)(resources.GetObject("label9.Size")));
			this.label9.TabIndex = ((int)(resources.GetObject("label9.TabIndex")));
			this.label9.Text = resources.GetString("label9.Text");
			this.label9.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label9.TextAlign")));
			this.label9.Visible = ((bool)(resources.GetObject("label9.Visible")));
			// 
			// label10
			// 
			this.label10.AccessibleDescription = resources.GetString("label10.AccessibleDescription");
			this.label10.AccessibleName = resources.GetString("label10.AccessibleName");
			this.label10.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("label10.Anchor")));
			this.label10.AutoSize = ((bool)(resources.GetObject("label10.AutoSize")));
			this.label10.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("label10.Dock")));
			this.label10.Enabled = ((bool)(resources.GetObject("label10.Enabled")));
			this.label10.Font = ((System.Drawing.Font)(resources.GetObject("label10.Font")));
			this.label10.Image = ((System.Drawing.Image)(resources.GetObject("label10.Image")));
			this.label10.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label10.ImageAlign")));
			this.label10.ImageIndex = ((int)(resources.GetObject("label10.ImageIndex")));
			this.label10.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("label10.ImeMode")));
			this.label10.Location = ((System.Drawing.Point)(resources.GetObject("label10.Location")));
			this.label10.Name = "label10";
			this.label10.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("label10.RightToLeft")));
			this.label10.Size = ((System.Drawing.Size)(resources.GetObject("label10.Size")));
			this.label10.TabIndex = ((int)(resources.GetObject("label10.TabIndex")));
			this.label10.Text = resources.GetString("label10.Text");
			this.label10.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label10.TextAlign")));
			this.label10.Visible = ((bool)(resources.GetObject("label10.Visible")));
			// 
			// numSkipFrames
			// 
			this.numSkipFrames.AccessibleDescription = resources.GetString("numSkipFrames.AccessibleDescription");
			this.numSkipFrames.AccessibleName = resources.GetString("numSkipFrames.AccessibleName");
			this.numSkipFrames.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("numSkipFrames.Anchor")));
			this.numSkipFrames.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("numSkipFrames.Dock")));
			this.numSkipFrames.Enabled = ((bool)(resources.GetObject("numSkipFrames.Enabled")));
			this.numSkipFrames.Font = ((System.Drawing.Font)(resources.GetObject("numSkipFrames.Font")));
			this.numSkipFrames.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("numSkipFrames.ImeMode")));
			this.numSkipFrames.Location = ((System.Drawing.Point)(resources.GetObject("numSkipFrames.Location")));
			this.numSkipFrames.Maximum = new System.Decimal(new int[] {
																		  5,
																		  0,
																		  0,
																		  0});
			this.numSkipFrames.Name = "numSkipFrames";
			this.numSkipFrames.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("numSkipFrames.RightToLeft")));
			this.numSkipFrames.Size = ((System.Drawing.Size)(resources.GetObject("numSkipFrames.Size")));
			this.numSkipFrames.TabIndex = ((int)(resources.GetObject("numSkipFrames.TabIndex")));
			this.numSkipFrames.TextAlign = ((System.Windows.Forms.HorizontalAlignment)(resources.GetObject("numSkipFrames.TextAlign")));
			this.numSkipFrames.ThousandsSeparator = ((bool)(resources.GetObject("numSkipFrames.ThousandsSeparator")));
			this.numSkipFrames.UpDownAlign = ((System.Windows.Forms.LeftRightAlignment)(resources.GetObject("numSkipFrames.UpDownAlign")));
			this.numSkipFrames.Visible = ((bool)(resources.GetObject("numSkipFrames.Visible")));
			// 
			// SettingsTab
			// 
			this.SettingsTab.AccessibleDescription = resources.GetString("SettingsTab.AccessibleDescription");
			this.SettingsTab.AccessibleName = resources.GetString("SettingsTab.AccessibleName");
			this.SettingsTab.Alignment = ((System.Windows.Forms.TabAlignment)(resources.GetObject("SettingsTab.Alignment")));
			this.SettingsTab.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("SettingsTab.Anchor")));
			this.SettingsTab.Appearance = ((System.Windows.Forms.TabAppearance)(resources.GetObject("SettingsTab.Appearance")));
			this.SettingsTab.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("SettingsTab.BackgroundImage")));
			this.SettingsTab.Controls.Add(this.tabPage1);
			this.SettingsTab.Controls.Add(this.tabPage7);
			this.SettingsTab.Controls.Add(this.tabEncoding);
			this.SettingsTab.Controls.Add(this.tabCut);
			this.SettingsTab.Controls.Add(this.tabMuxing);
			this.SettingsTab.Controls.Add(this.tabChapter);
			this.SettingsTab.Controls.Add(this.tabPresets);
			this.SettingsTab.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("SettingsTab.Dock")));
			this.SettingsTab.Enabled = ((bool)(resources.GetObject("SettingsTab.Enabled")));
			this.SettingsTab.Font = ((System.Drawing.Font)(resources.GetObject("SettingsTab.Font")));
			this.SettingsTab.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("SettingsTab.ImeMode")));
			this.SettingsTab.ItemSize = ((System.Drawing.Size)(resources.GetObject("SettingsTab.ItemSize")));
			this.SettingsTab.Location = ((System.Drawing.Point)(resources.GetObject("SettingsTab.Location")));
			this.SettingsTab.Name = "SettingsTab";
			this.SettingsTab.Padding = ((System.Drawing.Point)(resources.GetObject("SettingsTab.Padding")));
			this.SettingsTab.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("SettingsTab.RightToLeft")));
			this.SettingsTab.SelectedIndex = 0;
			this.SettingsTab.ShowToolTips = ((bool)(resources.GetObject("SettingsTab.ShowToolTips")));
			this.SettingsTab.Size = ((System.Drawing.Size)(resources.GetObject("SettingsTab.Size")));
			this.SettingsTab.TabIndex = ((int)(resources.GetObject("SettingsTab.TabIndex")));
			this.SettingsTab.Text = resources.GetString("SettingsTab.Text");
			this.SettingsTab.Visible = ((bool)(resources.GetObject("SettingsTab.Visible")));
			// 
			// tabPage1
			// 
			this.tabPage1.AccessibleDescription = resources.GetString("tabPage1.AccessibleDescription");
			this.tabPage1.AccessibleName = resources.GetString("tabPage1.AccessibleName");
			this.tabPage1.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("tabPage1.Anchor")));
			this.tabPage1.AutoScroll = ((bool)(resources.GetObject("tabPage1.AutoScroll")));
			this.tabPage1.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("tabPage1.AutoScrollMargin")));
			this.tabPage1.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("tabPage1.AutoScrollMinSize")));
			this.tabPage1.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("tabPage1.BackgroundImage")));
			this.tabPage1.Controls.Add(this.checkForceClose);
			this.tabPage1.Controls.Add(this.checkRecalcSourceBitrate);
			this.tabPage1.Controls.Add(this.butBrowseTempDir);
			this.tabPage1.Controls.Add(this.txtTempDir);
			this.tabPage1.Controls.Add(this.label11);
			this.tabPage1.Controls.Add(this.checkUpdateDetect);
			this.tabPage1.Controls.Add(this.label17);
			this.tabPage1.Controls.Add(this.numAltDistance);
			this.tabPage1.Controls.Add(this.label16);
			this.tabPage1.Controls.Add(this.numSkipFrames);
			this.tabPage1.Controls.Add(this.label10);
			this.tabPage1.Controls.Add(this.label9);
			this.tabPage1.Controls.Add(this.label8);
			this.tabPage1.Controls.Add(this.numQuickDistance);
			this.tabPage1.Controls.Add(this.label7);
			this.tabPage1.Controls.Add(this.label6);
			this.tabPage1.Controls.Add(this.numSlider);
			this.tabPage1.Controls.Add(this.label5);
			this.tabPage1.Controls.Add(this.label4);
			this.tabPage1.Controls.Add(this.numPreview);
			this.tabPage1.Controls.Add(this.label3);
			this.tabPage1.Controls.Add(this.label2);
			this.tabPage1.Controls.Add(this.numSearch);
			this.tabPage1.Controls.Add(this.label1);
			this.tabPage1.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("tabPage1.Dock")));
			this.tabPage1.Enabled = ((bool)(resources.GetObject("tabPage1.Enabled")));
			this.tabPage1.Font = ((System.Drawing.Font)(resources.GetObject("tabPage1.Font")));
			this.tabPage1.ImageIndex = ((int)(resources.GetObject("tabPage1.ImageIndex")));
			this.tabPage1.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("tabPage1.ImeMode")));
			this.tabPage1.Location = ((System.Drawing.Point)(resources.GetObject("tabPage1.Location")));
			this.tabPage1.Name = "tabPage1";
			this.tabPage1.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("tabPage1.RightToLeft")));
			this.tabPage1.Size = ((System.Drawing.Size)(resources.GetObject("tabPage1.Size")));
			this.tabPage1.TabIndex = ((int)(resources.GetObject("tabPage1.TabIndex")));
			this.tabPage1.Text = resources.GetString("tabPage1.Text");
			this.tabPage1.ToolTipText = resources.GetString("tabPage1.ToolTipText");
			this.tabPage1.Visible = ((bool)(resources.GetObject("tabPage1.Visible")));
			// 
			// checkForceClose
			// 
			this.checkForceClose.AccessibleDescription = resources.GetString("checkForceClose.AccessibleDescription");
			this.checkForceClose.AccessibleName = resources.GetString("checkForceClose.AccessibleName");
			this.checkForceClose.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("checkForceClose.Anchor")));
			this.checkForceClose.Appearance = ((System.Windows.Forms.Appearance)(resources.GetObject("checkForceClose.Appearance")));
			this.checkForceClose.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("checkForceClose.BackgroundImage")));
			this.checkForceClose.CheckAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("checkForceClose.CheckAlign")));
			this.checkForceClose.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("checkForceClose.Dock")));
			this.checkForceClose.Enabled = ((bool)(resources.GetObject("checkForceClose.Enabled")));
			this.checkForceClose.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("checkForceClose.FlatStyle")));
			this.checkForceClose.Font = ((System.Drawing.Font)(resources.GetObject("checkForceClose.Font")));
			this.checkForceClose.Image = ((System.Drawing.Image)(resources.GetObject("checkForceClose.Image")));
			this.checkForceClose.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("checkForceClose.ImageAlign")));
			this.checkForceClose.ImageIndex = ((int)(resources.GetObject("checkForceClose.ImageIndex")));
			this.checkForceClose.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("checkForceClose.ImeMode")));
			this.checkForceClose.Location = ((System.Drawing.Point)(resources.GetObject("checkForceClose.Location")));
			this.checkForceClose.Name = "checkForceClose";
			this.checkForceClose.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("checkForceClose.RightToLeft")));
			this.checkForceClose.Size = ((System.Drawing.Size)(resources.GetObject("checkForceClose.Size")));
			this.checkForceClose.TabIndex = ((int)(resources.GetObject("checkForceClose.TabIndex")));
			this.checkForceClose.Text = resources.GetString("checkForceClose.Text");
			this.checkForceClose.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("checkForceClose.TextAlign")));
			this.checkForceClose.Visible = ((bool)(resources.GetObject("checkForceClose.Visible")));
			// 
			// checkRecalcSourceBitrate
			// 
			this.checkRecalcSourceBitrate.AccessibleDescription = resources.GetString("checkRecalcSourceBitrate.AccessibleDescription");
			this.checkRecalcSourceBitrate.AccessibleName = resources.GetString("checkRecalcSourceBitrate.AccessibleName");
			this.checkRecalcSourceBitrate.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("checkRecalcSourceBitrate.Anchor")));
			this.checkRecalcSourceBitrate.Appearance = ((System.Windows.Forms.Appearance)(resources.GetObject("checkRecalcSourceBitrate.Appearance")));
			this.checkRecalcSourceBitrate.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("checkRecalcSourceBitrate.BackgroundImage")));
			this.checkRecalcSourceBitrate.CheckAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("checkRecalcSourceBitrate.CheckAlign")));
			this.checkRecalcSourceBitrate.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("checkRecalcSourceBitrate.Dock")));
			this.checkRecalcSourceBitrate.Enabled = ((bool)(resources.GetObject("checkRecalcSourceBitrate.Enabled")));
			this.checkRecalcSourceBitrate.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("checkRecalcSourceBitrate.FlatStyle")));
			this.checkRecalcSourceBitrate.Font = ((System.Drawing.Font)(resources.GetObject("checkRecalcSourceBitrate.Font")));
			this.checkRecalcSourceBitrate.Image = ((System.Drawing.Image)(resources.GetObject("checkRecalcSourceBitrate.Image")));
			this.checkRecalcSourceBitrate.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("checkRecalcSourceBitrate.ImageAlign")));
			this.checkRecalcSourceBitrate.ImageIndex = ((int)(resources.GetObject("checkRecalcSourceBitrate.ImageIndex")));
			this.checkRecalcSourceBitrate.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("checkRecalcSourceBitrate.ImeMode")));
			this.checkRecalcSourceBitrate.Location = ((System.Drawing.Point)(resources.GetObject("checkRecalcSourceBitrate.Location")));
			this.checkRecalcSourceBitrate.Name = "checkRecalcSourceBitrate";
			this.checkRecalcSourceBitrate.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("checkRecalcSourceBitrate.RightToLeft")));
			this.checkRecalcSourceBitrate.Size = ((System.Drawing.Size)(resources.GetObject("checkRecalcSourceBitrate.Size")));
			this.checkRecalcSourceBitrate.TabIndex = ((int)(resources.GetObject("checkRecalcSourceBitrate.TabIndex")));
			this.checkRecalcSourceBitrate.Text = resources.GetString("checkRecalcSourceBitrate.Text");
			this.checkRecalcSourceBitrate.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("checkRecalcSourceBitrate.TextAlign")));
			this.checkRecalcSourceBitrate.Visible = ((bool)(resources.GetObject("checkRecalcSourceBitrate.Visible")));
			// 
			// butBrowseTempDir
			// 
			this.butBrowseTempDir.AccessibleDescription = resources.GetString("butBrowseTempDir.AccessibleDescription");
			this.butBrowseTempDir.AccessibleName = resources.GetString("butBrowseTempDir.AccessibleName");
			this.butBrowseTempDir.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butBrowseTempDir.Anchor")));
			this.butBrowseTempDir.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butBrowseTempDir.BackgroundImage")));
			this.butBrowseTempDir.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butBrowseTempDir.Dock")));
			this.butBrowseTempDir.Enabled = ((bool)(resources.GetObject("butBrowseTempDir.Enabled")));
			this.butBrowseTempDir.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butBrowseTempDir.FlatStyle")));
			this.butBrowseTempDir.Font = ((System.Drawing.Font)(resources.GetObject("butBrowseTempDir.Font")));
			this.butBrowseTempDir.Image = ((System.Drawing.Image)(resources.GetObject("butBrowseTempDir.Image")));
			this.butBrowseTempDir.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butBrowseTempDir.ImageAlign")));
			this.butBrowseTempDir.ImageIndex = ((int)(resources.GetObject("butBrowseTempDir.ImageIndex")));
			this.butBrowseTempDir.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butBrowseTempDir.ImeMode")));
			this.butBrowseTempDir.Location = ((System.Drawing.Point)(resources.GetObject("butBrowseTempDir.Location")));
			this.butBrowseTempDir.Name = "butBrowseTempDir";
			this.butBrowseTempDir.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butBrowseTempDir.RightToLeft")));
			this.butBrowseTempDir.Size = ((System.Drawing.Size)(resources.GetObject("butBrowseTempDir.Size")));
			this.butBrowseTempDir.TabIndex = ((int)(resources.GetObject("butBrowseTempDir.TabIndex")));
			this.butBrowseTempDir.Text = resources.GetString("butBrowseTempDir.Text");
			this.butBrowseTempDir.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butBrowseTempDir.TextAlign")));
			this.butBrowseTempDir.Visible = ((bool)(resources.GetObject("butBrowseTempDir.Visible")));
			this.butBrowseTempDir.Click += new System.EventHandler(this.butBrowseTempDir_Click);
			// 
			// txtTempDir
			// 
			this.txtTempDir.AccessibleDescription = resources.GetString("txtTempDir.AccessibleDescription");
			this.txtTempDir.AccessibleName = resources.GetString("txtTempDir.AccessibleName");
			this.txtTempDir.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("txtTempDir.Anchor")));
			this.txtTempDir.AutoSize = ((bool)(resources.GetObject("txtTempDir.AutoSize")));
			this.txtTempDir.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("txtTempDir.BackgroundImage")));
			this.txtTempDir.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("txtTempDir.Dock")));
			this.txtTempDir.Enabled = ((bool)(resources.GetObject("txtTempDir.Enabled")));
			this.txtTempDir.Font = ((System.Drawing.Font)(resources.GetObject("txtTempDir.Font")));
			this.txtTempDir.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("txtTempDir.ImeMode")));
			this.txtTempDir.Location = ((System.Drawing.Point)(resources.GetObject("txtTempDir.Location")));
			this.txtTempDir.MaxLength = ((int)(resources.GetObject("txtTempDir.MaxLength")));
			this.txtTempDir.Multiline = ((bool)(resources.GetObject("txtTempDir.Multiline")));
			this.txtTempDir.Name = "txtTempDir";
			this.txtTempDir.PasswordChar = ((char)(resources.GetObject("txtTempDir.PasswordChar")));
			this.txtTempDir.ReadOnly = true;
			this.txtTempDir.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("txtTempDir.RightToLeft")));
			this.txtTempDir.ScrollBars = ((System.Windows.Forms.ScrollBars)(resources.GetObject("txtTempDir.ScrollBars")));
			this.txtTempDir.Size = ((System.Drawing.Size)(resources.GetObject("txtTempDir.Size")));
			this.txtTempDir.TabIndex = ((int)(resources.GetObject("txtTempDir.TabIndex")));
			this.txtTempDir.Text = resources.GetString("txtTempDir.Text");
			this.txtTempDir.TextAlign = ((System.Windows.Forms.HorizontalAlignment)(resources.GetObject("txtTempDir.TextAlign")));
			this.txtTempDir.Visible = ((bool)(resources.GetObject("txtTempDir.Visible")));
			this.txtTempDir.WordWrap = ((bool)(resources.GetObject("txtTempDir.WordWrap")));
			// 
			// label11
			// 
			this.label11.AccessibleDescription = resources.GetString("label11.AccessibleDescription");
			this.label11.AccessibleName = resources.GetString("label11.AccessibleName");
			this.label11.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("label11.Anchor")));
			this.label11.AutoSize = ((bool)(resources.GetObject("label11.AutoSize")));
			this.label11.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("label11.Dock")));
			this.label11.Enabled = ((bool)(resources.GetObject("label11.Enabled")));
			this.label11.Font = ((System.Drawing.Font)(resources.GetObject("label11.Font")));
			this.label11.Image = ((System.Drawing.Image)(resources.GetObject("label11.Image")));
			this.label11.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label11.ImageAlign")));
			this.label11.ImageIndex = ((int)(resources.GetObject("label11.ImageIndex")));
			this.label11.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("label11.ImeMode")));
			this.label11.Location = ((System.Drawing.Point)(resources.GetObject("label11.Location")));
			this.label11.Name = "label11";
			this.label11.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("label11.RightToLeft")));
			this.label11.Size = ((System.Drawing.Size)(resources.GetObject("label11.Size")));
			this.label11.TabIndex = ((int)(resources.GetObject("label11.TabIndex")));
			this.label11.Text = resources.GetString("label11.Text");
			this.label11.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label11.TextAlign")));
			this.label11.Visible = ((bool)(resources.GetObject("label11.Visible")));
			// 
			// checkUpdateDetect
			// 
			this.checkUpdateDetect.AccessibleDescription = resources.GetString("checkUpdateDetect.AccessibleDescription");
			this.checkUpdateDetect.AccessibleName = resources.GetString("checkUpdateDetect.AccessibleName");
			this.checkUpdateDetect.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("checkUpdateDetect.Anchor")));
			this.checkUpdateDetect.Appearance = ((System.Windows.Forms.Appearance)(resources.GetObject("checkUpdateDetect.Appearance")));
			this.checkUpdateDetect.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("checkUpdateDetect.BackgroundImage")));
			this.checkUpdateDetect.CheckAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("checkUpdateDetect.CheckAlign")));
			this.checkUpdateDetect.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("checkUpdateDetect.Dock")));
			this.checkUpdateDetect.Enabled = ((bool)(resources.GetObject("checkUpdateDetect.Enabled")));
			this.checkUpdateDetect.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("checkUpdateDetect.FlatStyle")));
			this.checkUpdateDetect.Font = ((System.Drawing.Font)(resources.GetObject("checkUpdateDetect.Font")));
			this.checkUpdateDetect.Image = ((System.Drawing.Image)(resources.GetObject("checkUpdateDetect.Image")));
			this.checkUpdateDetect.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("checkUpdateDetect.ImageAlign")));
			this.checkUpdateDetect.ImageIndex = ((int)(resources.GetObject("checkUpdateDetect.ImageIndex")));
			this.checkUpdateDetect.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("checkUpdateDetect.ImeMode")));
			this.checkUpdateDetect.Location = ((System.Drawing.Point)(resources.GetObject("checkUpdateDetect.Location")));
			this.checkUpdateDetect.Name = "checkUpdateDetect";
			this.checkUpdateDetect.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("checkUpdateDetect.RightToLeft")));
			this.checkUpdateDetect.Size = ((System.Drawing.Size)(resources.GetObject("checkUpdateDetect.Size")));
			this.checkUpdateDetect.TabIndex = ((int)(resources.GetObject("checkUpdateDetect.TabIndex")));
			this.checkUpdateDetect.Text = resources.GetString("checkUpdateDetect.Text");
			this.checkUpdateDetect.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("checkUpdateDetect.TextAlign")));
			this.checkUpdateDetect.Visible = ((bool)(resources.GetObject("checkUpdateDetect.Visible")));
			// 
			// label17
			// 
			this.label17.AccessibleDescription = resources.GetString("label17.AccessibleDescription");
			this.label17.AccessibleName = resources.GetString("label17.AccessibleName");
			this.label17.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("label17.Anchor")));
			this.label17.AutoSize = ((bool)(resources.GetObject("label17.AutoSize")));
			this.label17.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("label17.Dock")));
			this.label17.Enabled = ((bool)(resources.GetObject("label17.Enabled")));
			this.label17.Font = ((System.Drawing.Font)(resources.GetObject("label17.Font")));
			this.label17.Image = ((System.Drawing.Image)(resources.GetObject("label17.Image")));
			this.label17.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label17.ImageAlign")));
			this.label17.ImageIndex = ((int)(resources.GetObject("label17.ImageIndex")));
			this.label17.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("label17.ImeMode")));
			this.label17.Location = ((System.Drawing.Point)(resources.GetObject("label17.Location")));
			this.label17.Name = "label17";
			this.label17.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("label17.RightToLeft")));
			this.label17.Size = ((System.Drawing.Size)(resources.GetObject("label17.Size")));
			this.label17.TabIndex = ((int)(resources.GetObject("label17.TabIndex")));
			this.label17.Text = resources.GetString("label17.Text");
			this.label17.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label17.TextAlign")));
			this.label17.Visible = ((bool)(resources.GetObject("label17.Visible")));
			// 
			// numAltDistance
			// 
			this.numAltDistance.AccessibleDescription = resources.GetString("numAltDistance.AccessibleDescription");
			this.numAltDistance.AccessibleName = resources.GetString("numAltDistance.AccessibleName");
			this.numAltDistance.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("numAltDistance.Anchor")));
			this.numAltDistance.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("numAltDistance.Dock")));
			this.numAltDistance.Enabled = ((bool)(resources.GetObject("numAltDistance.Enabled")));
			this.numAltDistance.Font = ((System.Drawing.Font)(resources.GetObject("numAltDistance.Font")));
			this.numAltDistance.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("numAltDistance.ImeMode")));
			this.numAltDistance.Increment = new System.Decimal(new int[] {
																			 10,
																			 0,
																			 0,
																			 0});
			this.numAltDistance.Location = ((System.Drawing.Point)(resources.GetObject("numAltDistance.Location")));
			this.numAltDistance.Maximum = new System.Decimal(new int[] {
																		   1000,
																		   0,
																		   0,
																		   0});
			this.numAltDistance.Minimum = new System.Decimal(new int[] {
																		   10,
																		   0,
																		   0,
																		   0});
			this.numAltDistance.Name = "numAltDistance";
			this.numAltDistance.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("numAltDistance.RightToLeft")));
			this.numAltDistance.Size = ((System.Drawing.Size)(resources.GetObject("numAltDistance.Size")));
			this.numAltDistance.TabIndex = ((int)(resources.GetObject("numAltDistance.TabIndex")));
			this.numAltDistance.TextAlign = ((System.Windows.Forms.HorizontalAlignment)(resources.GetObject("numAltDistance.TextAlign")));
			this.numAltDistance.ThousandsSeparator = ((bool)(resources.GetObject("numAltDistance.ThousandsSeparator")));
			this.numAltDistance.UpDownAlign = ((System.Windows.Forms.LeftRightAlignment)(resources.GetObject("numAltDistance.UpDownAlign")));
			this.numAltDistance.Value = new System.Decimal(new int[] {
																		 10,
																		 0,
																		 0,
																		 0});
			this.numAltDistance.Visible = ((bool)(resources.GetObject("numAltDistance.Visible")));
			// 
			// label16
			// 
			this.label16.AccessibleDescription = resources.GetString("label16.AccessibleDescription");
			this.label16.AccessibleName = resources.GetString("label16.AccessibleName");
			this.label16.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("label16.Anchor")));
			this.label16.AutoSize = ((bool)(resources.GetObject("label16.AutoSize")));
			this.label16.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("label16.Dock")));
			this.label16.Enabled = ((bool)(resources.GetObject("label16.Enabled")));
			this.label16.Font = ((System.Drawing.Font)(resources.GetObject("label16.Font")));
			this.label16.Image = ((System.Drawing.Image)(resources.GetObject("label16.Image")));
			this.label16.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label16.ImageAlign")));
			this.label16.ImageIndex = ((int)(resources.GetObject("label16.ImageIndex")));
			this.label16.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("label16.ImeMode")));
			this.label16.Location = ((System.Drawing.Point)(resources.GetObject("label16.Location")));
			this.label16.Name = "label16";
			this.label16.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("label16.RightToLeft")));
			this.label16.Size = ((System.Drawing.Size)(resources.GetObject("label16.Size")));
			this.label16.TabIndex = ((int)(resources.GetObject("label16.TabIndex")));
			this.label16.Text = resources.GetString("label16.Text");
			this.label16.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label16.TextAlign")));
			this.label16.Visible = ((bool)(resources.GetObject("label16.Visible")));
			// 
			// tabPage7
			// 
			this.tabPage7.AccessibleDescription = resources.GetString("tabPage7.AccessibleDescription");
			this.tabPage7.AccessibleName = resources.GetString("tabPage7.AccessibleName");
			this.tabPage7.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("tabPage7.Anchor")));
			this.tabPage7.AutoScroll = ((bool)(resources.GetObject("tabPage7.AutoScroll")));
			this.tabPage7.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("tabPage7.AutoScrollMargin")));
			this.tabPage7.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("tabPage7.AutoScrollMinSize")));
			this.tabPage7.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("tabPage7.BackgroundImage")));
			this.tabPage7.Controls.Add(this.checkShowCutInPicture);
			this.tabPage7.Controls.Add(this.checkDPIRescaling);
			this.tabPage7.Controls.Add(this.checkAdditionalScrollBar);
			this.tabPage7.Controls.Add(this.checkApplyRatio);
			this.tabPage7.Controls.Add(this.panelNumQJ);
			this.tabPage7.Controls.Add(this.checkManualQJ);
			this.tabPage7.Controls.Add(this.checkCurrentFrameCaption);
			this.tabPage7.Controls.Add(this.checkDisplayFullPath);
			this.tabPage7.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("tabPage7.Dock")));
			this.tabPage7.Enabled = ((bool)(resources.GetObject("tabPage7.Enabled")));
			this.tabPage7.Font = ((System.Drawing.Font)(resources.GetObject("tabPage7.Font")));
			this.tabPage7.ImageIndex = ((int)(resources.GetObject("tabPage7.ImageIndex")));
			this.tabPage7.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("tabPage7.ImeMode")));
			this.tabPage7.Location = ((System.Drawing.Point)(resources.GetObject("tabPage7.Location")));
			this.tabPage7.Name = "tabPage7";
			this.tabPage7.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("tabPage7.RightToLeft")));
			this.tabPage7.Size = ((System.Drawing.Size)(resources.GetObject("tabPage7.Size")));
			this.tabPage7.TabIndex = ((int)(resources.GetObject("tabPage7.TabIndex")));
			this.tabPage7.Text = resources.GetString("tabPage7.Text");
			this.tabPage7.ToolTipText = resources.GetString("tabPage7.ToolTipText");
			this.tabPage7.Visible = ((bool)(resources.GetObject("tabPage7.Visible")));
			// 
			// checkShowCutInPicture
			// 
			this.checkShowCutInPicture.AccessibleDescription = resources.GetString("checkShowCutInPicture.AccessibleDescription");
			this.checkShowCutInPicture.AccessibleName = resources.GetString("checkShowCutInPicture.AccessibleName");
			this.checkShowCutInPicture.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("checkShowCutInPicture.Anchor")));
			this.checkShowCutInPicture.Appearance = ((System.Windows.Forms.Appearance)(resources.GetObject("checkShowCutInPicture.Appearance")));
			this.checkShowCutInPicture.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("checkShowCutInPicture.BackgroundImage")));
			this.checkShowCutInPicture.CheckAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("checkShowCutInPicture.CheckAlign")));
			this.checkShowCutInPicture.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("checkShowCutInPicture.Dock")));
			this.checkShowCutInPicture.Enabled = ((bool)(resources.GetObject("checkShowCutInPicture.Enabled")));
			this.checkShowCutInPicture.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("checkShowCutInPicture.FlatStyle")));
			this.checkShowCutInPicture.Font = ((System.Drawing.Font)(resources.GetObject("checkShowCutInPicture.Font")));
			this.checkShowCutInPicture.Image = ((System.Drawing.Image)(resources.GetObject("checkShowCutInPicture.Image")));
			this.checkShowCutInPicture.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("checkShowCutInPicture.ImageAlign")));
			this.checkShowCutInPicture.ImageIndex = ((int)(resources.GetObject("checkShowCutInPicture.ImageIndex")));
			this.checkShowCutInPicture.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("checkShowCutInPicture.ImeMode")));
			this.checkShowCutInPicture.Location = ((System.Drawing.Point)(resources.GetObject("checkShowCutInPicture.Location")));
			this.checkShowCutInPicture.Name = "checkShowCutInPicture";
			this.checkShowCutInPicture.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("checkShowCutInPicture.RightToLeft")));
			this.checkShowCutInPicture.Size = ((System.Drawing.Size)(resources.GetObject("checkShowCutInPicture.Size")));
			this.checkShowCutInPicture.TabIndex = ((int)(resources.GetObject("checkShowCutInPicture.TabIndex")));
			this.checkShowCutInPicture.Text = resources.GetString("checkShowCutInPicture.Text");
			this.checkShowCutInPicture.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("checkShowCutInPicture.TextAlign")));
			this.checkShowCutInPicture.Visible = ((bool)(resources.GetObject("checkShowCutInPicture.Visible")));
			// 
			// checkDPIRescaling
			// 
			this.checkDPIRescaling.AccessibleDescription = resources.GetString("checkDPIRescaling.AccessibleDescription");
			this.checkDPIRescaling.AccessibleName = resources.GetString("checkDPIRescaling.AccessibleName");
			this.checkDPIRescaling.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("checkDPIRescaling.Anchor")));
			this.checkDPIRescaling.Appearance = ((System.Windows.Forms.Appearance)(resources.GetObject("checkDPIRescaling.Appearance")));
			this.checkDPIRescaling.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("checkDPIRescaling.BackgroundImage")));
			this.checkDPIRescaling.CheckAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("checkDPIRescaling.CheckAlign")));
			this.checkDPIRescaling.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("checkDPIRescaling.Dock")));
			this.checkDPIRescaling.Enabled = ((bool)(resources.GetObject("checkDPIRescaling.Enabled")));
			this.checkDPIRescaling.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("checkDPIRescaling.FlatStyle")));
			this.checkDPIRescaling.Font = ((System.Drawing.Font)(resources.GetObject("checkDPIRescaling.Font")));
			this.checkDPIRescaling.Image = ((System.Drawing.Image)(resources.GetObject("checkDPIRescaling.Image")));
			this.checkDPIRescaling.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("checkDPIRescaling.ImageAlign")));
			this.checkDPIRescaling.ImageIndex = ((int)(resources.GetObject("checkDPIRescaling.ImageIndex")));
			this.checkDPIRescaling.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("checkDPIRescaling.ImeMode")));
			this.checkDPIRescaling.Location = ((System.Drawing.Point)(resources.GetObject("checkDPIRescaling.Location")));
			this.checkDPIRescaling.Name = "checkDPIRescaling";
			this.checkDPIRescaling.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("checkDPIRescaling.RightToLeft")));
			this.checkDPIRescaling.Size = ((System.Drawing.Size)(resources.GetObject("checkDPIRescaling.Size")));
			this.checkDPIRescaling.TabIndex = ((int)(resources.GetObject("checkDPIRescaling.TabIndex")));
			this.checkDPIRescaling.Text = resources.GetString("checkDPIRescaling.Text");
			this.checkDPIRescaling.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("checkDPIRescaling.TextAlign")));
			this.checkDPIRescaling.Visible = ((bool)(resources.GetObject("checkDPIRescaling.Visible")));
			// 
			// checkAdditionalScrollBar
			// 
			this.checkAdditionalScrollBar.AccessibleDescription = resources.GetString("checkAdditionalScrollBar.AccessibleDescription");
			this.checkAdditionalScrollBar.AccessibleName = resources.GetString("checkAdditionalScrollBar.AccessibleName");
			this.checkAdditionalScrollBar.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("checkAdditionalScrollBar.Anchor")));
			this.checkAdditionalScrollBar.Appearance = ((System.Windows.Forms.Appearance)(resources.GetObject("checkAdditionalScrollBar.Appearance")));
			this.checkAdditionalScrollBar.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("checkAdditionalScrollBar.BackgroundImage")));
			this.checkAdditionalScrollBar.CheckAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("checkAdditionalScrollBar.CheckAlign")));
			this.checkAdditionalScrollBar.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("checkAdditionalScrollBar.Dock")));
			this.checkAdditionalScrollBar.Enabled = ((bool)(resources.GetObject("checkAdditionalScrollBar.Enabled")));
			this.checkAdditionalScrollBar.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("checkAdditionalScrollBar.FlatStyle")));
			this.checkAdditionalScrollBar.Font = ((System.Drawing.Font)(resources.GetObject("checkAdditionalScrollBar.Font")));
			this.checkAdditionalScrollBar.Image = ((System.Drawing.Image)(resources.GetObject("checkAdditionalScrollBar.Image")));
			this.checkAdditionalScrollBar.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("checkAdditionalScrollBar.ImageAlign")));
			this.checkAdditionalScrollBar.ImageIndex = ((int)(resources.GetObject("checkAdditionalScrollBar.ImageIndex")));
			this.checkAdditionalScrollBar.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("checkAdditionalScrollBar.ImeMode")));
			this.checkAdditionalScrollBar.Location = ((System.Drawing.Point)(resources.GetObject("checkAdditionalScrollBar.Location")));
			this.checkAdditionalScrollBar.Name = "checkAdditionalScrollBar";
			this.checkAdditionalScrollBar.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("checkAdditionalScrollBar.RightToLeft")));
			this.checkAdditionalScrollBar.Size = ((System.Drawing.Size)(resources.GetObject("checkAdditionalScrollBar.Size")));
			this.checkAdditionalScrollBar.TabIndex = ((int)(resources.GetObject("checkAdditionalScrollBar.TabIndex")));
			this.checkAdditionalScrollBar.Text = resources.GetString("checkAdditionalScrollBar.Text");
			this.checkAdditionalScrollBar.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("checkAdditionalScrollBar.TextAlign")));
			this.checkAdditionalScrollBar.Visible = ((bool)(resources.GetObject("checkAdditionalScrollBar.Visible")));
			// 
			// checkApplyRatio
			// 
			this.checkApplyRatio.AccessibleDescription = resources.GetString("checkApplyRatio.AccessibleDescription");
			this.checkApplyRatio.AccessibleName = resources.GetString("checkApplyRatio.AccessibleName");
			this.checkApplyRatio.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("checkApplyRatio.Anchor")));
			this.checkApplyRatio.Appearance = ((System.Windows.Forms.Appearance)(resources.GetObject("checkApplyRatio.Appearance")));
			this.checkApplyRatio.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("checkApplyRatio.BackgroundImage")));
			this.checkApplyRatio.CheckAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("checkApplyRatio.CheckAlign")));
			this.checkApplyRatio.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("checkApplyRatio.Dock")));
			this.checkApplyRatio.Enabled = ((bool)(resources.GetObject("checkApplyRatio.Enabled")));
			this.checkApplyRatio.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("checkApplyRatio.FlatStyle")));
			this.checkApplyRatio.Font = ((System.Drawing.Font)(resources.GetObject("checkApplyRatio.Font")));
			this.checkApplyRatio.Image = ((System.Drawing.Image)(resources.GetObject("checkApplyRatio.Image")));
			this.checkApplyRatio.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("checkApplyRatio.ImageAlign")));
			this.checkApplyRatio.ImageIndex = ((int)(resources.GetObject("checkApplyRatio.ImageIndex")));
			this.checkApplyRatio.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("checkApplyRatio.ImeMode")));
			this.checkApplyRatio.Location = ((System.Drawing.Point)(resources.GetObject("checkApplyRatio.Location")));
			this.checkApplyRatio.Name = "checkApplyRatio";
			this.checkApplyRatio.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("checkApplyRatio.RightToLeft")));
			this.checkApplyRatio.Size = ((System.Drawing.Size)(resources.GetObject("checkApplyRatio.Size")));
			this.checkApplyRatio.TabIndex = ((int)(resources.GetObject("checkApplyRatio.TabIndex")));
			this.checkApplyRatio.Text = resources.GetString("checkApplyRatio.Text");
			this.checkApplyRatio.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("checkApplyRatio.TextAlign")));
			this.checkApplyRatio.Visible = ((bool)(resources.GetObject("checkApplyRatio.Visible")));
			// 
			// panelNumQJ
			// 
			this.panelNumQJ.AccessibleDescription = resources.GetString("panelNumQJ.AccessibleDescription");
			this.panelNumQJ.AccessibleName = resources.GetString("panelNumQJ.AccessibleName");
			this.panelNumQJ.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("panelNumQJ.Anchor")));
			this.panelNumQJ.AutoScroll = ((bool)(resources.GetObject("panelNumQJ.AutoScroll")));
			this.panelNumQJ.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("panelNumQJ.AutoScrollMargin")));
			this.panelNumQJ.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("panelNumQJ.AutoScrollMinSize")));
			this.panelNumQJ.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("panelNumQJ.BackgroundImage")));
			this.panelNumQJ.Controls.Add(this.label12);
			this.panelNumQJ.Controls.Add(this.numericQJY);
			this.panelNumQJ.Controls.Add(this.numericQJX);
			this.panelNumQJ.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("panelNumQJ.Dock")));
			this.panelNumQJ.Enabled = ((bool)(resources.GetObject("panelNumQJ.Enabled")));
			this.panelNumQJ.Font = ((System.Drawing.Font)(resources.GetObject("panelNumQJ.Font")));
			this.panelNumQJ.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("panelNumQJ.ImeMode")));
			this.panelNumQJ.Location = ((System.Drawing.Point)(resources.GetObject("panelNumQJ.Location")));
			this.panelNumQJ.Name = "panelNumQJ";
			this.panelNumQJ.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("panelNumQJ.RightToLeft")));
			this.panelNumQJ.Size = ((System.Drawing.Size)(resources.GetObject("panelNumQJ.Size")));
			this.panelNumQJ.TabIndex = ((int)(resources.GetObject("panelNumQJ.TabIndex")));
			this.panelNumQJ.Text = resources.GetString("panelNumQJ.Text");
			this.panelNumQJ.Visible = ((bool)(resources.GetObject("panelNumQJ.Visible")));
			// 
			// label12
			// 
			this.label12.AccessibleDescription = resources.GetString("label12.AccessibleDescription");
			this.label12.AccessibleName = resources.GetString("label12.AccessibleName");
			this.label12.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("label12.Anchor")));
			this.label12.AutoSize = ((bool)(resources.GetObject("label12.AutoSize")));
			this.label12.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("label12.Dock")));
			this.label12.Enabled = ((bool)(resources.GetObject("label12.Enabled")));
			this.label12.Font = ((System.Drawing.Font)(resources.GetObject("label12.Font")));
			this.label12.Image = ((System.Drawing.Image)(resources.GetObject("label12.Image")));
			this.label12.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label12.ImageAlign")));
			this.label12.ImageIndex = ((int)(resources.GetObject("label12.ImageIndex")));
			this.label12.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("label12.ImeMode")));
			this.label12.Location = ((System.Drawing.Point)(resources.GetObject("label12.Location")));
			this.label12.Name = "label12";
			this.label12.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("label12.RightToLeft")));
			this.label12.Size = ((System.Drawing.Size)(resources.GetObject("label12.Size")));
			this.label12.TabIndex = ((int)(resources.GetObject("label12.TabIndex")));
			this.label12.Text = resources.GetString("label12.Text");
			this.label12.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label12.TextAlign")));
			this.label12.Visible = ((bool)(resources.GetObject("label12.Visible")));
			// 
			// numericQJY
			// 
			this.numericQJY.AccessibleDescription = resources.GetString("numericQJY.AccessibleDescription");
			this.numericQJY.AccessibleName = resources.GetString("numericQJY.AccessibleName");
			this.numericQJY.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("numericQJY.Anchor")));
			this.numericQJY.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("numericQJY.Dock")));
			this.numericQJY.Enabled = ((bool)(resources.GetObject("numericQJY.Enabled")));
			this.numericQJY.Font = ((System.Drawing.Font)(resources.GetObject("numericQJY.Font")));
			this.numericQJY.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("numericQJY.ImeMode")));
			this.numericQJY.Location = ((System.Drawing.Point)(resources.GetObject("numericQJY.Location")));
			this.numericQJY.Maximum = new System.Decimal(new int[] {
																	   15,
																	   0,
																	   0,
																	   0});
			this.numericQJY.Minimum = new System.Decimal(new int[] {
																	   2,
																	   0,
																	   0,
																	   0});
			this.numericQJY.Name = "numericQJY";
			this.numericQJY.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("numericQJY.RightToLeft")));
			this.numericQJY.Size = ((System.Drawing.Size)(resources.GetObject("numericQJY.Size")));
			this.numericQJY.TabIndex = ((int)(resources.GetObject("numericQJY.TabIndex")));
			this.numericQJY.TextAlign = ((System.Windows.Forms.HorizontalAlignment)(resources.GetObject("numericQJY.TextAlign")));
			this.numericQJY.ThousandsSeparator = ((bool)(resources.GetObject("numericQJY.ThousandsSeparator")));
			this.numericQJY.UpDownAlign = ((System.Windows.Forms.LeftRightAlignment)(resources.GetObject("numericQJY.UpDownAlign")));
			this.numericQJY.Value = new System.Decimal(new int[] {
																	 2,
																	 0,
																	 0,
																	 0});
			this.numericQJY.Visible = ((bool)(resources.GetObject("numericQJY.Visible")));
			// 
			// numericQJX
			// 
			this.numericQJX.AccessibleDescription = resources.GetString("numericQJX.AccessibleDescription");
			this.numericQJX.AccessibleName = resources.GetString("numericQJX.AccessibleName");
			this.numericQJX.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("numericQJX.Anchor")));
			this.numericQJX.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("numericQJX.Dock")));
			this.numericQJX.Enabled = ((bool)(resources.GetObject("numericQJX.Enabled")));
			this.numericQJX.Font = ((System.Drawing.Font)(resources.GetObject("numericQJX.Font")));
			this.numericQJX.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("numericQJX.ImeMode")));
			this.numericQJX.Location = ((System.Drawing.Point)(resources.GetObject("numericQJX.Location")));
			this.numericQJX.Maximum = new System.Decimal(new int[] {
																	   20,
																	   0,
																	   0,
																	   0});
			this.numericQJX.Minimum = new System.Decimal(new int[] {
																	   3,
																	   0,
																	   0,
																	   0});
			this.numericQJX.Name = "numericQJX";
			this.numericQJX.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("numericQJX.RightToLeft")));
			this.numericQJX.Size = ((System.Drawing.Size)(resources.GetObject("numericQJX.Size")));
			this.numericQJX.TabIndex = ((int)(resources.GetObject("numericQJX.TabIndex")));
			this.numericQJX.TextAlign = ((System.Windows.Forms.HorizontalAlignment)(resources.GetObject("numericQJX.TextAlign")));
			this.numericQJX.ThousandsSeparator = ((bool)(resources.GetObject("numericQJX.ThousandsSeparator")));
			this.numericQJX.UpDownAlign = ((System.Windows.Forms.LeftRightAlignment)(resources.GetObject("numericQJX.UpDownAlign")));
			this.numericQJX.Value = new System.Decimal(new int[] {
																	 3,
																	 0,
																	 0,
																	 0});
			this.numericQJX.Visible = ((bool)(resources.GetObject("numericQJX.Visible")));
			// 
			// checkManualQJ
			// 
			this.checkManualQJ.AccessibleDescription = resources.GetString("checkManualQJ.AccessibleDescription");
			this.checkManualQJ.AccessibleName = resources.GetString("checkManualQJ.AccessibleName");
			this.checkManualQJ.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("checkManualQJ.Anchor")));
			this.checkManualQJ.Appearance = ((System.Windows.Forms.Appearance)(resources.GetObject("checkManualQJ.Appearance")));
			this.checkManualQJ.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("checkManualQJ.BackgroundImage")));
			this.checkManualQJ.CheckAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("checkManualQJ.CheckAlign")));
			this.checkManualQJ.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("checkManualQJ.Dock")));
			this.checkManualQJ.Enabled = ((bool)(resources.GetObject("checkManualQJ.Enabled")));
			this.checkManualQJ.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("checkManualQJ.FlatStyle")));
			this.checkManualQJ.Font = ((System.Drawing.Font)(resources.GetObject("checkManualQJ.Font")));
			this.checkManualQJ.Image = ((System.Drawing.Image)(resources.GetObject("checkManualQJ.Image")));
			this.checkManualQJ.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("checkManualQJ.ImageAlign")));
			this.checkManualQJ.ImageIndex = ((int)(resources.GetObject("checkManualQJ.ImageIndex")));
			this.checkManualQJ.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("checkManualQJ.ImeMode")));
			this.checkManualQJ.Location = ((System.Drawing.Point)(resources.GetObject("checkManualQJ.Location")));
			this.checkManualQJ.Name = "checkManualQJ";
			this.checkManualQJ.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("checkManualQJ.RightToLeft")));
			this.checkManualQJ.Size = ((System.Drawing.Size)(resources.GetObject("checkManualQJ.Size")));
			this.checkManualQJ.TabIndex = ((int)(resources.GetObject("checkManualQJ.TabIndex")));
			this.checkManualQJ.Text = resources.GetString("checkManualQJ.Text");
			this.checkManualQJ.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("checkManualQJ.TextAlign")));
			this.checkManualQJ.Visible = ((bool)(resources.GetObject("checkManualQJ.Visible")));
			this.checkManualQJ.CheckedChanged += new System.EventHandler(this.checkManualQJ_CheckedChanged);
			// 
			// checkCurrentFrameCaption
			// 
			this.checkCurrentFrameCaption.AccessibleDescription = resources.GetString("checkCurrentFrameCaption.AccessibleDescription");
			this.checkCurrentFrameCaption.AccessibleName = resources.GetString("checkCurrentFrameCaption.AccessibleName");
			this.checkCurrentFrameCaption.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("checkCurrentFrameCaption.Anchor")));
			this.checkCurrentFrameCaption.Appearance = ((System.Windows.Forms.Appearance)(resources.GetObject("checkCurrentFrameCaption.Appearance")));
			this.checkCurrentFrameCaption.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("checkCurrentFrameCaption.BackgroundImage")));
			this.checkCurrentFrameCaption.CheckAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("checkCurrentFrameCaption.CheckAlign")));
			this.checkCurrentFrameCaption.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("checkCurrentFrameCaption.Dock")));
			this.checkCurrentFrameCaption.Enabled = ((bool)(resources.GetObject("checkCurrentFrameCaption.Enabled")));
			this.checkCurrentFrameCaption.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("checkCurrentFrameCaption.FlatStyle")));
			this.checkCurrentFrameCaption.Font = ((System.Drawing.Font)(resources.GetObject("checkCurrentFrameCaption.Font")));
			this.checkCurrentFrameCaption.Image = ((System.Drawing.Image)(resources.GetObject("checkCurrentFrameCaption.Image")));
			this.checkCurrentFrameCaption.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("checkCurrentFrameCaption.ImageAlign")));
			this.checkCurrentFrameCaption.ImageIndex = ((int)(resources.GetObject("checkCurrentFrameCaption.ImageIndex")));
			this.checkCurrentFrameCaption.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("checkCurrentFrameCaption.ImeMode")));
			this.checkCurrentFrameCaption.Location = ((System.Drawing.Point)(resources.GetObject("checkCurrentFrameCaption.Location")));
			this.checkCurrentFrameCaption.Name = "checkCurrentFrameCaption";
			this.checkCurrentFrameCaption.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("checkCurrentFrameCaption.RightToLeft")));
			this.checkCurrentFrameCaption.Size = ((System.Drawing.Size)(resources.GetObject("checkCurrentFrameCaption.Size")));
			this.checkCurrentFrameCaption.TabIndex = ((int)(resources.GetObject("checkCurrentFrameCaption.TabIndex")));
			this.checkCurrentFrameCaption.Text = resources.GetString("checkCurrentFrameCaption.Text");
			this.checkCurrentFrameCaption.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("checkCurrentFrameCaption.TextAlign")));
			this.checkCurrentFrameCaption.Visible = ((bool)(resources.GetObject("checkCurrentFrameCaption.Visible")));
			// 
			// checkDisplayFullPath
			// 
			this.checkDisplayFullPath.AccessibleDescription = resources.GetString("checkDisplayFullPath.AccessibleDescription");
			this.checkDisplayFullPath.AccessibleName = resources.GetString("checkDisplayFullPath.AccessibleName");
			this.checkDisplayFullPath.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("checkDisplayFullPath.Anchor")));
			this.checkDisplayFullPath.Appearance = ((System.Windows.Forms.Appearance)(resources.GetObject("checkDisplayFullPath.Appearance")));
			this.checkDisplayFullPath.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("checkDisplayFullPath.BackgroundImage")));
			this.checkDisplayFullPath.CheckAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("checkDisplayFullPath.CheckAlign")));
			this.checkDisplayFullPath.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("checkDisplayFullPath.Dock")));
			this.checkDisplayFullPath.Enabled = ((bool)(resources.GetObject("checkDisplayFullPath.Enabled")));
			this.checkDisplayFullPath.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("checkDisplayFullPath.FlatStyle")));
			this.checkDisplayFullPath.Font = ((System.Drawing.Font)(resources.GetObject("checkDisplayFullPath.Font")));
			this.checkDisplayFullPath.Image = ((System.Drawing.Image)(resources.GetObject("checkDisplayFullPath.Image")));
			this.checkDisplayFullPath.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("checkDisplayFullPath.ImageAlign")));
			this.checkDisplayFullPath.ImageIndex = ((int)(resources.GetObject("checkDisplayFullPath.ImageIndex")));
			this.checkDisplayFullPath.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("checkDisplayFullPath.ImeMode")));
			this.checkDisplayFullPath.Location = ((System.Drawing.Point)(resources.GetObject("checkDisplayFullPath.Location")));
			this.checkDisplayFullPath.Name = "checkDisplayFullPath";
			this.checkDisplayFullPath.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("checkDisplayFullPath.RightToLeft")));
			this.checkDisplayFullPath.Size = ((System.Drawing.Size)(resources.GetObject("checkDisplayFullPath.Size")));
			this.checkDisplayFullPath.TabIndex = ((int)(resources.GetObject("checkDisplayFullPath.TabIndex")));
			this.checkDisplayFullPath.Text = resources.GetString("checkDisplayFullPath.Text");
			this.checkDisplayFullPath.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("checkDisplayFullPath.TextAlign")));
			this.checkDisplayFullPath.Visible = ((bool)(resources.GetObject("checkDisplayFullPath.Visible")));
			// 
			// tabEncoding
			// 
			this.tabEncoding.AccessibleDescription = resources.GetString("tabEncoding.AccessibleDescription");
			this.tabEncoding.AccessibleName = resources.GetString("tabEncoding.AccessibleName");
			this.tabEncoding.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("tabEncoding.Anchor")));
			this.tabEncoding.AutoScroll = ((bool)(resources.GetObject("tabEncoding.AutoScroll")));
			this.tabEncoding.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("tabEncoding.AutoScrollMargin")));
			this.tabEncoding.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("tabEncoding.AutoScrollMinSize")));
			this.tabEncoding.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("tabEncoding.BackgroundImage")));
			this.tabEncoding.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("tabEncoding.Dock")));
			this.tabEncoding.Enabled = ((bool)(resources.GetObject("tabEncoding.Enabled")));
			this.tabEncoding.Font = ((System.Drawing.Font)(resources.GetObject("tabEncoding.Font")));
			this.tabEncoding.ImageIndex = ((int)(resources.GetObject("tabEncoding.ImageIndex")));
			this.tabEncoding.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("tabEncoding.ImeMode")));
			this.tabEncoding.Location = ((System.Drawing.Point)(resources.GetObject("tabEncoding.Location")));
			this.tabEncoding.Name = "tabEncoding";
			this.tabEncoding.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("tabEncoding.RightToLeft")));
			this.tabEncoding.Size = ((System.Drawing.Size)(resources.GetObject("tabEncoding.Size")));
			this.tabEncoding.TabIndex = ((int)(resources.GetObject("tabEncoding.TabIndex")));
			this.tabEncoding.Text = resources.GetString("tabEncoding.Text");
			this.tabEncoding.ToolTipText = resources.GetString("tabEncoding.ToolTipText");
			this.tabEncoding.Visible = ((bool)(resources.GetObject("tabEncoding.Visible")));
			// 
			// tabCut
			// 
			this.tabCut.AccessibleDescription = resources.GetString("tabCut.AccessibleDescription");
			this.tabCut.AccessibleName = resources.GetString("tabCut.AccessibleName");
			this.tabCut.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("tabCut.Anchor")));
			this.tabCut.AutoScroll = ((bool)(resources.GetObject("tabCut.AutoScroll")));
			this.tabCut.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("tabCut.AutoScrollMargin")));
			this.tabCut.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("tabCut.AutoScrollMinSize")));
			this.tabCut.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("tabCut.BackgroundImage")));
			this.tabCut.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("tabCut.Dock")));
			this.tabCut.Enabled = ((bool)(resources.GetObject("tabCut.Enabled")));
			this.tabCut.Font = ((System.Drawing.Font)(resources.GetObject("tabCut.Font")));
			this.tabCut.ImageIndex = ((int)(resources.GetObject("tabCut.ImageIndex")));
			this.tabCut.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("tabCut.ImeMode")));
			this.tabCut.Location = ((System.Drawing.Point)(resources.GetObject("tabCut.Location")));
			this.tabCut.Name = "tabCut";
			this.tabCut.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("tabCut.RightToLeft")));
			this.tabCut.Size = ((System.Drawing.Size)(resources.GetObject("tabCut.Size")));
			this.tabCut.TabIndex = ((int)(resources.GetObject("tabCut.TabIndex")));
			this.tabCut.Text = resources.GetString("tabCut.Text");
			this.tabCut.ToolTipText = resources.GetString("tabCut.ToolTipText");
			this.tabCut.Visible = ((bool)(resources.GetObject("tabCut.Visible")));
			// 
			// tabMuxing
			// 
			this.tabMuxing.AccessibleDescription = resources.GetString("tabMuxing.AccessibleDescription");
			this.tabMuxing.AccessibleName = resources.GetString("tabMuxing.AccessibleName");
			this.tabMuxing.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("tabMuxing.Anchor")));
			this.tabMuxing.AutoScroll = ((bool)(resources.GetObject("tabMuxing.AutoScroll")));
			this.tabMuxing.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("tabMuxing.AutoScrollMargin")));
			this.tabMuxing.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("tabMuxing.AutoScrollMinSize")));
			this.tabMuxing.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("tabMuxing.BackgroundImage")));
			this.tabMuxing.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("tabMuxing.Dock")));
			this.tabMuxing.Enabled = ((bool)(resources.GetObject("tabMuxing.Enabled")));
			this.tabMuxing.Font = ((System.Drawing.Font)(resources.GetObject("tabMuxing.Font")));
			this.tabMuxing.ImageIndex = ((int)(resources.GetObject("tabMuxing.ImageIndex")));
			this.tabMuxing.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("tabMuxing.ImeMode")));
			this.tabMuxing.Location = ((System.Drawing.Point)(resources.GetObject("tabMuxing.Location")));
			this.tabMuxing.Name = "tabMuxing";
			this.tabMuxing.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("tabMuxing.RightToLeft")));
			this.tabMuxing.Size = ((System.Drawing.Size)(resources.GetObject("tabMuxing.Size")));
			this.tabMuxing.TabIndex = ((int)(resources.GetObject("tabMuxing.TabIndex")));
			this.tabMuxing.Text = resources.GetString("tabMuxing.Text");
			this.tabMuxing.ToolTipText = resources.GetString("tabMuxing.ToolTipText");
			this.tabMuxing.Visible = ((bool)(resources.GetObject("tabMuxing.Visible")));
			// 
			// tabChapter
			// 
			this.tabChapter.AccessibleDescription = resources.GetString("tabChapter.AccessibleDescription");
			this.tabChapter.AccessibleName = resources.GetString("tabChapter.AccessibleName");
			this.tabChapter.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("tabChapter.Anchor")));
			this.tabChapter.AutoScroll = ((bool)(resources.GetObject("tabChapter.AutoScroll")));
			this.tabChapter.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("tabChapter.AutoScrollMargin")));
			this.tabChapter.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("tabChapter.AutoScrollMinSize")));
			this.tabChapter.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("tabChapter.BackgroundImage")));
			this.tabChapter.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("tabChapter.Dock")));
			this.tabChapter.Enabled = ((bool)(resources.GetObject("tabChapter.Enabled")));
			this.tabChapter.Font = ((System.Drawing.Font)(resources.GetObject("tabChapter.Font")));
			this.tabChapter.ImageIndex = ((int)(resources.GetObject("tabChapter.ImageIndex")));
			this.tabChapter.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("tabChapter.ImeMode")));
			this.tabChapter.Location = ((System.Drawing.Point)(resources.GetObject("tabChapter.Location")));
			this.tabChapter.Name = "tabChapter";
			this.tabChapter.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("tabChapter.RightToLeft")));
			this.tabChapter.Size = ((System.Drawing.Size)(resources.GetObject("tabChapter.Size")));
			this.tabChapter.TabIndex = ((int)(resources.GetObject("tabChapter.TabIndex")));
			this.tabChapter.Text = resources.GetString("tabChapter.Text");
			this.tabChapter.ToolTipText = resources.GetString("tabChapter.ToolTipText");
			this.tabChapter.Visible = ((bool)(resources.GetObject("tabChapter.Visible")));
			// 
			// tabPresets
			// 
			this.tabPresets.AccessibleDescription = resources.GetString("tabPresets.AccessibleDescription");
			this.tabPresets.AccessibleName = resources.GetString("tabPresets.AccessibleName");
			this.tabPresets.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("tabPresets.Anchor")));
			this.tabPresets.AutoScroll = ((bool)(resources.GetObject("tabPresets.AutoScroll")));
			this.tabPresets.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("tabPresets.AutoScrollMargin")));
			this.tabPresets.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("tabPresets.AutoScrollMinSize")));
			this.tabPresets.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("tabPresets.BackgroundImage")));
			this.tabPresets.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("tabPresets.Dock")));
			this.tabPresets.Enabled = ((bool)(resources.GetObject("tabPresets.Enabled")));
			this.tabPresets.Font = ((System.Drawing.Font)(resources.GetObject("tabPresets.Font")));
			this.tabPresets.ImageIndex = ((int)(resources.GetObject("tabPresets.ImageIndex")));
			this.tabPresets.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("tabPresets.ImeMode")));
			this.tabPresets.Location = ((System.Drawing.Point)(resources.GetObject("tabPresets.Location")));
			this.tabPresets.Name = "tabPresets";
			this.tabPresets.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("tabPresets.RightToLeft")));
			this.tabPresets.Size = ((System.Drawing.Size)(resources.GetObject("tabPresets.Size")));
			this.tabPresets.TabIndex = ((int)(resources.GetObject("tabPresets.TabIndex")));
			this.tabPresets.Text = resources.GetString("tabPresets.Text");
			this.tabPresets.ToolTipText = resources.GetString("tabPresets.ToolTipText");
			this.tabPresets.Visible = ((bool)(resources.GetObject("tabPresets.Visible")));
			// 
			// folderBrowserTempDir
			// 
			this.folderBrowserTempDir.Description = resources.GetString("folderBrowserTempDir.Description");
			this.folderBrowserTempDir.SelectedPath = resources.GetString("folderBrowserTempDir.SelectedPath");
			// 
			// SettingsDialog
			// 
			this.AcceptButton = this.butOK;
			this.AccessibleDescription = resources.GetString("$this.AccessibleDescription");
			this.AccessibleName = resources.GetString("$this.AccessibleName");
			this.AutoScaleBaseSize = ((System.Drawing.Size)(resources.GetObject("$this.AutoScaleBaseSize")));
			this.AutoScroll = ((bool)(resources.GetObject("$this.AutoScroll")));
			this.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("$this.AutoScrollMargin")));
			this.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("$this.AutoScrollMinSize")));
			this.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("$this.BackgroundImage")));
			this.CancelButton = this.butCancel;
			this.ClientSize = ((System.Drawing.Size)(resources.GetObject("$this.ClientSize")));
			this.Controls.Add(this.SettingsTab);
			this.Controls.Add(this.butCancel);
			this.Controls.Add(this.butOK);
			this.Enabled = ((bool)(resources.GetObject("$this.Enabled")));
			this.Font = ((System.Drawing.Font)(resources.GetObject("$this.Font")));
			this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedDialog;
			this.Icon = ((System.Drawing.Icon)(resources.GetObject("$this.Icon")));
			this.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("$this.ImeMode")));
			this.Location = ((System.Drawing.Point)(resources.GetObject("$this.Location")));
			this.MaximizeBox = false;
			this.MaximumSize = ((System.Drawing.Size)(resources.GetObject("$this.MaximumSize")));
			this.MinimizeBox = false;
			this.MinimumSize = ((System.Drawing.Size)(resources.GetObject("$this.MinimumSize")));
			this.Name = "SettingsDialog";
			this.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("$this.RightToLeft")));
			this.ShowInTaskbar = false;
			this.StartPosition = ((System.Windows.Forms.FormStartPosition)(resources.GetObject("$this.StartPosition")));
			this.Text = resources.GetString("$this.Text");
			this.Load += new System.EventHandler(this.Settings_Load);
			((System.ComponentModel.ISupportInitialize)(this.numSearch)).EndInit();
			((System.ComponentModel.ISupportInitialize)(this.numPreview)).EndInit();
			((System.ComponentModel.ISupportInitialize)(this.numSlider)).EndInit();
			((System.ComponentModel.ISupportInitialize)(this.numQuickDistance)).EndInit();
			((System.ComponentModel.ISupportInitialize)(this.numSkipFrames)).EndInit();
			this.SettingsTab.ResumeLayout(false);
			this.tabPage1.ResumeLayout(false);
			((System.ComponentModel.ISupportInitialize)(this.numAltDistance)).EndInit();
			this.tabPage7.ResumeLayout(false);
			this.panelNumQJ.ResumeLayout(false);
			((System.ComponentModel.ISupportInitialize)(this.numericQJY)).EndInit();
			((System.ComponentModel.ISupportInitialize)(this.numericQJX)).EndInit();
			this.ResumeLayout(false);

		}
		#endregion

		private void butBrowseTempDir_Click(object sender, System.EventArgs e)
		{
			folderBrowserTempDir.SelectedPath=txtTempDir.Text;
			if (folderBrowserTempDir.ShowDialog()==DialogResult.OK)
				txtTempDir.Text=folderBrowserTempDir.SelectedPath;
		}

		private void checkManualQJ_CheckedChanged(object sender, System.EventArgs e)
		{
			panelNumQJ.Enabled=checkManualQJ.Checked;
		}

	}
}
