/*
 * Cuttermaran - The Mpeg Cutter
 * 
 * Copyright (C) 2003-2005  Tobias Arnold (cuttermaran@gmx.net)
 * 
 * This file is part of cuttermaran, a free MPEG cut program.
 * See http://www.cuttermaran.de for updates.
 *
 * This program is free software; you can redistribute it and/or modify it 
 * under the terms of the GNU General Public License as published by the 
 * Free Software Foundation; either version 2 of the License, or 
 * (at your option) any later version. 
 * 
 * This program is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the 
 * GNU General Public License for more details. 
 * 
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */

using System;
using System.IO;
using System.Text;
using System.Data;
using System.Drawing;
using System.Collections;
using System.Diagnostics;
using System.Windows.Forms;
using System.Threading;
using System.Reflection;
using System.Configuration;
using Coremoran.Common;
using Coremoran.AVStreams;
using GUI.MainForm;
using GUI.data;
using GUI.Actions;
using StringResources;
using Configuration;
using Configuration.data;

namespace GUI
{
	/// <summary>
	/// Summary description for ThreadControl.
	/// </summary>
	public class ThreadControl : BaseDialog
	{
		private System.ComponentModel.Container components = null;
		private System.Windows.Forms.Label label2;
		private System.Windows.Forms.Label label3;
		private System.Windows.Forms.ProgressBar TotalProgress;
		private System.Windows.Forms.ProgressBar CurrentProgress;
		private System.Windows.Forms.Button but_cancel;
		private System.Windows.Forms.Button butPauseCont;
		private System.Windows.Forms.Label txtTime;
		private System.Windows.Forms.Label txtComplete;
		private GUI.TrimmingLabel   txtAction;
		private System.Timers.Timer InfoTimer;

		private DateTime StartTime;
		private Thread worker;
		private ActionObject actionObject;
		private DialogResult internalResult;
		private Stack msgStack;

		private StateController mi_State = CMMain.globalApplication.Controller;
		private bool            mb_ThreadFinished;
		private bool            mb_Aborted;
		private bool            mb_AddTotalProgress;
		private int           ms32_TotProgrMax;
		private int           ms32_TotProgrValue;
		private int           ms32_CurProgrValue;

		public delegate void delProviderAbortAction();
		public delegate int  delProviderGetProgress();
		public               delProviderAbortAction  CallbackAbortAction = null;
		public               delProviderGetProgress  CallbackGetProgress = null;

		static private ThreadControl mi_Instance = null;
		static public  ThreadControl    Instance { get { return mi_Instance; } }

		public ThreadControl(ActionObject action)
			: base(GUI.MainForm.CMMain.globalApplication)
		{
			mi_Instance = this;

			InitializeComponent();

			actionObject=action;
			mb_Aborted       =false;
			mb_ThreadFinished=false;
			msgStack=new Stack();
			msgStack.Push(string.Empty);

			// default: load one file
			ms32_TotProgrValue  = 0;
			ms32_TotProgrMax    = 1;
			mb_AddTotalProgress = true;
			
			// shorten very long paths in the middle "arte-Kabarett...Pispers.m2v"
			txtAction.Trimming = StringTrimming.EllipsisPath;
			// Trimmings like EllipsisPath will only work correctly if the label
			// displays ONE and only ONE line of text.
			// So the height must not be greater than 14 pixels (for the default font)
			// Overwrite any nonsence which may have been entered into the GUI designer
			txtAction.Height = 14;
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(ThreadControl));
			this.label2 = new System.Windows.Forms.Label();
			this.label3 = new System.Windows.Forms.Label();
			this.CurrentProgress = new System.Windows.Forms.ProgressBar();
			this.TotalProgress = new System.Windows.Forms.ProgressBar();
			this.InfoTimer = new System.Timers.Timer();
			this.txtAction = new GUI.TrimmingLabel();
			this.txtComplete = new System.Windows.Forms.Label();
			this.but_cancel = new System.Windows.Forms.Button();
			this.butPauseCont = new System.Windows.Forms.Button();
			this.txtTime = new System.Windows.Forms.Label();
			((System.ComponentModel.ISupportInitialize)(this.InfoTimer)).BeginInit();
			this.SuspendLayout();
			// 
			// label2
			// 
			this.label2.AccessibleDescription = resources.GetString("label2.AccessibleDescription");
			this.label2.AccessibleName = resources.GetString("label2.AccessibleName");
			this.label2.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("label2.Anchor")));
			this.label2.AutoSize = ((bool)(resources.GetObject("label2.AutoSize")));
			this.label2.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("label2.Dock")));
			this.label2.Enabled = ((bool)(resources.GetObject("label2.Enabled")));
			this.label2.Font = ((System.Drawing.Font)(resources.GetObject("label2.Font")));
			this.label2.Image = ((System.Drawing.Image)(resources.GetObject("label2.Image")));
			this.label2.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label2.ImageAlign")));
			this.label2.ImageIndex = ((int)(resources.GetObject("label2.ImageIndex")));
			this.label2.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("label2.ImeMode")));
			this.label2.Location = ((System.Drawing.Point)(resources.GetObject("label2.Location")));
			this.label2.Name = "label2";
			this.label2.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("label2.RightToLeft")));
			this.label2.Size = ((System.Drawing.Size)(resources.GetObject("label2.Size")));
			this.label2.TabIndex = ((int)(resources.GetObject("label2.TabIndex")));
			this.label2.Text = resources.GetString("label2.Text");
			this.label2.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label2.TextAlign")));
			this.label2.Visible = ((bool)(resources.GetObject("label2.Visible")));
			// 
			// label3
			// 
			this.label3.AccessibleDescription = resources.GetString("label3.AccessibleDescription");
			this.label3.AccessibleName = resources.GetString("label3.AccessibleName");
			this.label3.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("label3.Anchor")));
			this.label3.AutoSize = ((bool)(resources.GetObject("label3.AutoSize")));
			this.label3.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("label3.Dock")));
			this.label3.Enabled = ((bool)(resources.GetObject("label3.Enabled")));
			this.label3.Font = ((System.Drawing.Font)(resources.GetObject("label3.Font")));
			this.label3.Image = ((System.Drawing.Image)(resources.GetObject("label3.Image")));
			this.label3.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label3.ImageAlign")));
			this.label3.ImageIndex = ((int)(resources.GetObject("label3.ImageIndex")));
			this.label3.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("label3.ImeMode")));
			this.label3.Location = ((System.Drawing.Point)(resources.GetObject("label3.Location")));
			this.label3.Name = "label3";
			this.label3.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("label3.RightToLeft")));
			this.label3.Size = ((System.Drawing.Size)(resources.GetObject("label3.Size")));
			this.label3.TabIndex = ((int)(resources.GetObject("label3.TabIndex")));
			this.label3.Text = resources.GetString("label3.Text");
			this.label3.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label3.TextAlign")));
			this.label3.Visible = ((bool)(resources.GetObject("label3.Visible")));
			// 
			// CurrentProgress
			// 
			this.CurrentProgress.AccessibleDescription = resources.GetString("CurrentProgress.AccessibleDescription");
			this.CurrentProgress.AccessibleName = resources.GetString("CurrentProgress.AccessibleName");
			this.CurrentProgress.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("CurrentProgress.Anchor")));
			this.CurrentProgress.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("CurrentProgress.BackgroundImage")));
			this.CurrentProgress.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("CurrentProgress.Dock")));
			this.CurrentProgress.Enabled = ((bool)(resources.GetObject("CurrentProgress.Enabled")));
			this.CurrentProgress.Font = ((System.Drawing.Font)(resources.GetObject("CurrentProgress.Font")));
			this.CurrentProgress.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("CurrentProgress.ImeMode")));
			this.CurrentProgress.Location = ((System.Drawing.Point)(resources.GetObject("CurrentProgress.Location")));
			this.CurrentProgress.Name = "CurrentProgress";
			this.CurrentProgress.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("CurrentProgress.RightToLeft")));
			this.CurrentProgress.Size = ((System.Drawing.Size)(resources.GetObject("CurrentProgress.Size")));
			this.CurrentProgress.TabIndex = ((int)(resources.GetObject("CurrentProgress.TabIndex")));
			this.CurrentProgress.Text = resources.GetString("CurrentProgress.Text");
			this.CurrentProgress.Visible = ((bool)(resources.GetObject("CurrentProgress.Visible")));
			// 
			// TotalProgress
			// 
			this.TotalProgress.AccessibleDescription = resources.GetString("TotalProgress.AccessibleDescription");
			this.TotalProgress.AccessibleName = resources.GetString("TotalProgress.AccessibleName");
			this.TotalProgress.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("TotalProgress.Anchor")));
			this.TotalProgress.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("TotalProgress.BackgroundImage")));
			this.TotalProgress.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("TotalProgress.Dock")));
			this.TotalProgress.Enabled = ((bool)(resources.GetObject("TotalProgress.Enabled")));
			this.TotalProgress.Font = ((System.Drawing.Font)(resources.GetObject("TotalProgress.Font")));
			this.TotalProgress.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("TotalProgress.ImeMode")));
			this.TotalProgress.Location = ((System.Drawing.Point)(resources.GetObject("TotalProgress.Location")));
			this.TotalProgress.Name = "TotalProgress";
			this.TotalProgress.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("TotalProgress.RightToLeft")));
			this.TotalProgress.Size = ((System.Drawing.Size)(resources.GetObject("TotalProgress.Size")));
			this.TotalProgress.TabIndex = ((int)(resources.GetObject("TotalProgress.TabIndex")));
			this.TotalProgress.Text = resources.GetString("TotalProgress.Text");
			this.TotalProgress.Visible = ((bool)(resources.GetObject("TotalProgress.Visible")));
			// 
			// InfoTimer
			// 
			this.InfoTimer.Interval = 250;
			this.InfoTimer.SynchronizingObject = this;
			this.InfoTimer.Elapsed += new System.Timers.ElapsedEventHandler(this.InfoTimer_Elapsed);
			// 
			// txtAction
			// 
			this.txtAction.AccessibleDescription = resources.GetString("txtAction.AccessibleDescription");
			this.txtAction.AccessibleName = resources.GetString("txtAction.AccessibleName");
			this.txtAction.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("txtAction.Anchor")));
			this.txtAction.AutoSize = ((bool)(resources.GetObject("txtAction.AutoSize")));
			this.txtAction.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("txtAction.Dock")));
			this.txtAction.Enabled = ((bool)(resources.GetObject("txtAction.Enabled")));
			this.txtAction.Font = ((System.Drawing.Font)(resources.GetObject("txtAction.Font")));
			this.txtAction.Image = ((System.Drawing.Image)(resources.GetObject("txtAction.Image")));
			this.txtAction.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("txtAction.ImageAlign")));
			this.txtAction.ImageIndex = ((int)(resources.GetObject("txtAction.ImageIndex")));
			this.txtAction.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("txtAction.ImeMode")));
			this.txtAction.Location = ((System.Drawing.Point)(resources.GetObject("txtAction.Location")));
			this.txtAction.Name = "txtAction";
			this.txtAction.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("txtAction.RightToLeft")));
			this.txtAction.Size = ((System.Drawing.Size)(resources.GetObject("txtAction.Size")));
			this.txtAction.TabIndex = ((int)(resources.GetObject("txtAction.TabIndex")));
			this.txtAction.Text = resources.GetString("txtAction.Text");
			this.txtAction.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("txtAction.TextAlign")));
			this.txtAction.Visible = ((bool)(resources.GetObject("txtAction.Visible")));
			// 
			// txtComplete
			// 
			this.txtComplete.AccessibleDescription = resources.GetString("txtComplete.AccessibleDescription");
			this.txtComplete.AccessibleName = resources.GetString("txtComplete.AccessibleName");
			this.txtComplete.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("txtComplete.Anchor")));
			this.txtComplete.AutoSize = ((bool)(resources.GetObject("txtComplete.AutoSize")));
			this.txtComplete.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("txtComplete.Dock")));
			this.txtComplete.Enabled = ((bool)(resources.GetObject("txtComplete.Enabled")));
			this.txtComplete.Font = ((System.Drawing.Font)(resources.GetObject("txtComplete.Font")));
			this.txtComplete.Image = ((System.Drawing.Image)(resources.GetObject("txtComplete.Image")));
			this.txtComplete.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("txtComplete.ImageAlign")));
			this.txtComplete.ImageIndex = ((int)(resources.GetObject("txtComplete.ImageIndex")));
			this.txtComplete.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("txtComplete.ImeMode")));
			this.txtComplete.Location = ((System.Drawing.Point)(resources.GetObject("txtComplete.Location")));
			this.txtComplete.Name = "txtComplete";
			this.txtComplete.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("txtComplete.RightToLeft")));
			this.txtComplete.Size = ((System.Drawing.Size)(resources.GetObject("txtComplete.Size")));
			this.txtComplete.TabIndex = ((int)(resources.GetObject("txtComplete.TabIndex")));
			this.txtComplete.Text = resources.GetString("txtComplete.Text");
			this.txtComplete.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("txtComplete.TextAlign")));
			this.txtComplete.Visible = ((bool)(resources.GetObject("txtComplete.Visible")));
			// 
			// but_cancel
			// 
			this.but_cancel.AccessibleDescription = resources.GetString("but_cancel.AccessibleDescription");
			this.but_cancel.AccessibleName = resources.GetString("but_cancel.AccessibleName");
			this.but_cancel.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("but_cancel.Anchor")));
			this.but_cancel.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("but_cancel.BackgroundImage")));
			this.but_cancel.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("but_cancel.Dock")));
			this.but_cancel.Enabled = ((bool)(resources.GetObject("but_cancel.Enabled")));
			this.but_cancel.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("but_cancel.FlatStyle")));
			this.but_cancel.Font = ((System.Drawing.Font)(resources.GetObject("but_cancel.Font")));
			this.but_cancel.Image = ((System.Drawing.Image)(resources.GetObject("but_cancel.Image")));
			this.but_cancel.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("but_cancel.ImageAlign")));
			this.but_cancel.ImageIndex = ((int)(resources.GetObject("but_cancel.ImageIndex")));
			this.but_cancel.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("but_cancel.ImeMode")));
			this.but_cancel.Location = ((System.Drawing.Point)(resources.GetObject("but_cancel.Location")));
			this.but_cancel.Name = "but_cancel";
			this.but_cancel.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("but_cancel.RightToLeft")));
			this.but_cancel.Size = ((System.Drawing.Size)(resources.GetObject("but_cancel.Size")));
			this.but_cancel.TabIndex = ((int)(resources.GetObject("but_cancel.TabIndex")));
			this.but_cancel.Text = resources.GetString("but_cancel.Text");
			this.but_cancel.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("but_cancel.TextAlign")));
			this.but_cancel.Visible = ((bool)(resources.GetObject("but_cancel.Visible")));
			this.but_cancel.Click += new System.EventHandler(this.but_cancel_Click);
			// 
			// butPauseCont
			// 
			this.butPauseCont.AccessibleDescription = resources.GetString("butPauseCont.AccessibleDescription");
			this.butPauseCont.AccessibleName = resources.GetString("butPauseCont.AccessibleName");
			this.butPauseCont.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butPauseCont.Anchor")));
			this.butPauseCont.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butPauseCont.BackgroundImage")));
			this.butPauseCont.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butPauseCont.Dock")));
			this.butPauseCont.Enabled = ((bool)(resources.GetObject("butPauseCont.Enabled")));
			this.butPauseCont.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butPauseCont.FlatStyle")));
			this.butPauseCont.Font = ((System.Drawing.Font)(resources.GetObject("butPauseCont.Font")));
			this.butPauseCont.Image = ((System.Drawing.Image)(resources.GetObject("butPauseCont.Image")));
			this.butPauseCont.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butPauseCont.ImageAlign")));
			this.butPauseCont.ImageIndex = ((int)(resources.GetObject("butPauseCont.ImageIndex")));
			this.butPauseCont.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butPauseCont.ImeMode")));
			this.butPauseCont.Location = ((System.Drawing.Point)(resources.GetObject("butPauseCont.Location")));
			this.butPauseCont.Name = "butPauseCont";
			this.butPauseCont.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butPauseCont.RightToLeft")));
			this.butPauseCont.Size = ((System.Drawing.Size)(resources.GetObject("butPauseCont.Size")));
			this.butPauseCont.TabIndex = ((int)(resources.GetObject("butPauseCont.TabIndex")));
			this.butPauseCont.Text = resources.GetString("butPauseCont.Text");
			this.butPauseCont.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butPauseCont.TextAlign")));
			this.butPauseCont.Visible = ((bool)(resources.GetObject("butPauseCont.Visible")));
			this.butPauseCont.Click += new System.EventHandler(this.butPauseCont_Click);
			// 
			// txtTime
			// 
			this.txtTime.AccessibleDescription = resources.GetString("txtTime.AccessibleDescription");
			this.txtTime.AccessibleName = resources.GetString("txtTime.AccessibleName");
			this.txtTime.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("txtTime.Anchor")));
			this.txtTime.AutoSize = ((bool)(resources.GetObject("txtTime.AutoSize")));
			this.txtTime.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("txtTime.Dock")));
			this.txtTime.Enabled = ((bool)(resources.GetObject("txtTime.Enabled")));
			this.txtTime.Font = ((System.Drawing.Font)(resources.GetObject("txtTime.Font")));
			this.txtTime.Image = ((System.Drawing.Image)(resources.GetObject("txtTime.Image")));
			this.txtTime.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("txtTime.ImageAlign")));
			this.txtTime.ImageIndex = ((int)(resources.GetObject("txtTime.ImageIndex")));
			this.txtTime.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("txtTime.ImeMode")));
			this.txtTime.Location = ((System.Drawing.Point)(resources.GetObject("txtTime.Location")));
			this.txtTime.Name = "txtTime";
			this.txtTime.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("txtTime.RightToLeft")));
			this.txtTime.Size = ((System.Drawing.Size)(resources.GetObject("txtTime.Size")));
			this.txtTime.TabIndex = ((int)(resources.GetObject("txtTime.TabIndex")));
			this.txtTime.Text = resources.GetString("txtTime.Text");
			this.txtTime.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("txtTime.TextAlign")));
			this.txtTime.Visible = ((bool)(resources.GetObject("txtTime.Visible")));
			// 
			// ThreadControl
			// 
			this.AccessibleDescription = resources.GetString("$this.AccessibleDescription");
			this.AccessibleName = resources.GetString("$this.AccessibleName");
			this.AutoScaleBaseSize = ((System.Drawing.Size)(resources.GetObject("$this.AutoScaleBaseSize")));
			this.AutoScroll = ((bool)(resources.GetObject("$this.AutoScroll")));
			this.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("$this.AutoScrollMargin")));
			this.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("$this.AutoScrollMinSize")));
			this.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("$this.BackgroundImage")));
			this.ClientSize = ((System.Drawing.Size)(resources.GetObject("$this.ClientSize")));
			this.ControlBox = false;
			this.Controls.Add(this.butPauseCont);
			this.Controls.Add(this.but_cancel);
			this.Controls.Add(this.txtComplete);
			this.Controls.Add(this.txtTime);
			this.Controls.Add(this.txtAction);
			this.Controls.Add(this.CurrentProgress);
			this.Controls.Add(this.TotalProgress);
			this.Controls.Add(this.label3);
			this.Controls.Add(this.label2);
			this.Enabled = ((bool)(resources.GetObject("$this.Enabled")));
			this.Font = ((System.Drawing.Font)(resources.GetObject("$this.Font")));
			this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedDialog;
			this.Icon = ((System.Drawing.Icon)(resources.GetObject("$this.Icon")));
			this.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("$this.ImeMode")));
			this.Location = ((System.Drawing.Point)(resources.GetObject("$this.Location")));
			this.MaximizeBox = false;
			this.MaximumSize = ((System.Drawing.Size)(resources.GetObject("$this.MaximumSize")));
			this.MinimizeBox = false;
			this.MinimumSize = ((System.Drawing.Size)(resources.GetObject("$this.MinimumSize")));
			this.Name = "ThreadControl";
			this.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("$this.RightToLeft")));
			this.ShowInTaskbar = false;
			this.StartPosition = ((System.Windows.Forms.FormStartPosition)(resources.GetObject("$this.StartPosition")));
			this.Text = resources.GetString("$this.Text");
			((System.ComponentModel.ISupportInitialize)(this.InfoTimer)).EndInit();
			this.ResumeLayout(false);

		}
		#endregion

		private void InfoTimer_Elapsed(object sender, System.Timers.ElapsedEventArgs e)
		{
			if (mb_ThreadFinished)
			{
				// remove the title bar's percent display after the main window was minimized
				mi_State.SetStateFile(null);
				Close();
				return;
			}

			if (worker!=null && BasicPacketStream.KeepRunning)
			{
				if (TotalProgress.Value < 100) // stop time dispaly if finished (100%)
				{
					TimeSpan sp=DateTime.Now-StartTime;
					if ((worker.ThreadState & System.Threading.ThreadState.Suspended)==0)
						txtTime.Text=string.Format("{0:00}:{1:00}:{2:00}",
						                           sp.Hours,sp.Minutes,sp.Seconds);
					else
						StartTime=StartTime.AddMilliseconds(InfoTimer.Interval);
				}

				// If a provider has connected which supports display of progress 
				// -> retrieve the progress from the provider
				if (CallbackGetProgress != null && CallbackGetProgress() > 0)
					ms32_CurProgrValue = CallbackGetProgress();

				CurrentProgress.Value = Math.Min(ms32_CurProgrValue, CurrentProgress.Maximum);

				// Calculate the total progress
				double dbl_CurProgress = (double)CurrentProgress.Value / CurrentProgress.Maximum;
				double dbl_TotProgress = (double)ms32_TotProgrValue    / ms32_TotProgrMax;

				if (mb_AddTotalProgress) 
					dbl_TotProgress = dbl_TotProgress + (dbl_CurProgress / ms32_TotProgrMax);

				int totVal = (int)(dbl_TotProgress  *  TotalProgress.Maximum);
				TotalProgress.Value = Math.Min(totVal, TotalProgress.Maximum);

				txtComplete.Text = TotalProgress.Value.ToString() + "%";
				
				// Set the text of the taskbar button if main window is minimized
				// But if the provider supports progress display, don't do it here
				// because the provider will display the progress in its own window!
				if (CallbackGetProgress == null)
					mi_State.SetTaskbarProgress(txtComplete.Text);
			}
		}

		/// <summary>
		/// This is called from BaseDialog. It has to be used instead of OnLoad() because 
		/// this dialog may never call OnLoad() if it opens hidden while its owner is minimized
		/// </summary>
		protected override void OnStartDialog()
		{
			butPauseCont.Text=Resource.CurrentResource[Resource.PAUSE];
			internalResult=DialogResult.Cancel; // Angenommen, das klappt alles nicht, damit im Falle eines Thread.Abort auch der Dialoresult richtig ist!

			actionObject.HostingControl=this;
			actionObject.ResultDelegateMethod  =new ActionObject.SetDialogResultDelegate(SetDialogResult);
			actionObject.ActionTextMethod      =new ActionObject.SetActionTextDelegate(SetActionText);
			actionObject.CurrentProgressValue  =new ActionObject.CurrentProgressDelegate(SetCurrentProgressValue);
			actionObject.TotalProgressMaximum  =new ActionObject.TotalProgressMaxDelegate(SetTotalProgressMaximum);
			actionObject.TotalProgressIncrement=new ActionObject.TotalProgressIncrDelegate(TotalProgressIncrement);

			BasicPacketStream.CpuLoad = 95; // 95% CPU load
			BasicPacketStream.KeepRunning = true;

			worker=new Thread(new ThreadStart(actionObject.Run));
			// Sprache setzen
			worker.CurrentUICulture=new System.Globalization.CultureInfo(Settings.CurrentSettings.Language);
			worker.IsBackground=true;
			worker.Name=actionObject.GetType().Name;
			StartTime=DateTime.Now;
			worker.Start();
			InfoTimer.Enabled=true;
		}

		protected override void OnClosing(System.ComponentModel.CancelEventArgs e)
		{
			base.OnClosing (e);
			InfoTimer.Enabled = false;
			worker      = null;
			mi_Instance = null;
			
			 // ignore return value from worker thread if Cancel button was clicked!
			if (mb_Aborted)
				DialogResult = DialogResult.Abort;
			else
				DialogResult = internalResult;
		}

		/// <summary>
		/// Called from the worker thread when the thread has finished
		/// </summary>
		private void SetDialogResult(DialogResult result)
		{
			internalResult=result;
			// Schlieen asynchron machen, weil diese Methode von einem
			// anderen Thread aufgerufen wird!
			mb_ThreadFinished=true;
		}

		private void SetActionText(string text, string currentFile)
		{
			if (text==Resource.POP_MESSAGE && msgStack.Count>1)
			{
				msgStack.Pop();
				text=(string)msgStack.Peek();
			}
			else
			{
				if (text.StartsWith("~")) // Texte aus Coremoran-Engine auflsen
					text=Resource.CurrentResource[text];
				msgStack.Push(text);
			}

			// display the filename of the file which is currently processed (if any)
			if (currentFile != null && text.Length > 0) 
				text += "  \"" + Path.GetFileName(currentFile) + "\"";

			// The text will be displayed with StringTrimming.EllipsisPath
			this.txtAction.Text=text;
		}

		private void butPauseCont_Click(object sender, System.EventArgs e)
		{
			if ((worker.ThreadState & System.Threading.ThreadState.Suspended)!=0)
			{
				worker.Resume();
				butPauseCont.Text=Resource.CurrentResource[Resource.PAUSE];
			}
			else if ((worker.ThreadState & System.Threading.ThreadState.Background)!=0)
			{
				worker.Suspend();
				butPauseCont.Text=Resource.CurrentResource[Resource.RESUME];
			}
		}

		private void but_cancel_Click(object sender, System.EventArgs e)
		{
			if (worker==null || mb_Aborted)
				return;

			mb_Aborted = true; // ignore return value from worker thread!!

			// All loops in the thread will be aborted now
			BasicPacketStream.KeepRunning = false;

			// The thread will take some time to exit,
			// during this period reset the display of progress
			CurrentProgress.Value = 0;
			TotalProgress.  Value = 0;
			txtAction.Text = "";

			// Ist der Thread Suspended kurz anlaufen lassen
			if ((worker.ThreadState & System.Threading.ThreadState.Suspended)!=0)
				worker.Resume();

			// Kill Mplex / Imago Muxer when the user demands it!
			// Older Cuttermaran versions (<1.69) were running and running and
			// ignoring the user's whish to abort the action
			if (CallbackAbortAction != null) CallbackAbortAction();
		}

		/// <summary>
		/// The user clicked the Close button in the window's title bar
		/// We do NOT immediately close the window. We do the same as clicking "Cancel"
		/// </summary>
		protected override void OnCloseButton()
		{
			but_cancel_Click(null, null);
		}

		// ----------------- progress bars --------------------

		/// <summary>
		/// b_AddTotalProgress=true: add progress to total progress bar
		/// otherwise leave total progress unchanged
		/// </summary>
		private void SetCurrentProgressValue(int s32_Value, bool b_AddTotalProgress)
		{
			ms32_CurProgrValue  = s32_Value;
			mb_AddTotalProgress = b_AddTotalProgress;
		}


		public void SetTotalProgressMaximum(int s32_MaxValue)
		{
			if (s32_MaxValue < 1)
				throw new Exception("Invalid TotalProgressbar Max value");
			
			ms32_TotProgrMax   = s32_MaxValue;
			ms32_TotProgrValue = 0; // reset
		}

		public void TotalProgressIncrement()
		{
			// ms32_CurProgrValue must be reset to avoid regressing of total progess bar
			// This could happen if ms32_CurProgrValue still shows the end value
			// of the last action and this function is called before it was reset
			// to zero for the next action!
			ms32_CurProgrValue = 0;

			ms32_TotProgrValue = Math.Min(++ms32_TotProgrValue, ms32_TotProgrMax);
		}
	}
}
