/*
 * Cuttermaran - The Mpeg Cutter
 * 
 * Copyright (C) 2004  Tobias Arnold (cuttermaran@gmx.net)
 * 
 * This file is part of cuttermaran, a free MPEG cut program.
 * See http://cuttermaran.kickme.to for updates.
 *
 * This program is free software; you can redistribute it and/or modify it 
 * under the terms of the GNU General Public License as published by the 
 * Free Software Foundation; either version 2 of the License, or 
 * (at your option) any later version. 
 * 
 * This program is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the 
 * GNU General Public License for more details. 
 * 
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */

using System;
using System.Drawing;
using System.Drawing.Imaging;
using System.Windows.Forms;
using System.Runtime.InteropServices;
using Coremoran.AVStreams;
using Configuration;

namespace GUI
{
	[StructLayout( LayoutKind.Sequential )]
	public class FrameInfoStruct
	{
		public IntPtr Y;
		public IntPtr U;
		public IntPtr V;
		public int width;
		public int height;
		public int size;
		public int type;
		public int chroma_width;
		public int chroma_height;
		public int chroma_size;
	}

	/// <summary>
	/// Base class for all video decoder.
	/// </summary>
	public abstract class VideoDecoder : IDisposable
	{
		protected int currentPos;
		protected Mpeg12Video videoStream;
		protected bool getPictureResult;

		protected abstract bool OpenVideo(ConversionType ct);
		public abstract bool CloseVideo();
		public abstract void GoToFrame(int Position);
		public abstract bool MoveNextFrame();
		public abstract bool GetPicture(int Position,ref Bitmap bitm,bool silenceMode,out bool newBMPcreated);
		public abstract FrameInfoStruct CurrentFrameInfo { get; }
		public abstract void GetCurrentFrameData(byte [] data);

		public abstract void Dispose();

		protected VideoDecoder(Mpeg12Video videoInfo,ConversionType ct)
		{
			currentPos=0;
			videoStream=videoInfo;

			// TODO: Returnwert
			OpenVideo(ct);
		}

		public static VideoDecoder Create(BasicVideoStream videoInfo,ConversionType ct)
		{
			return new GUI.libmpeg2((Mpeg12Video)videoInfo,ct);
			//return new libmpeg2Decoder((Mpeg12Video)videoInfo,ct);
		}

		public int CurrentPosition
		{
			get
			{
				return currentPos;
			}
		}

		public string CurrentStreamName
		{
			get
			{
				if (videoStream!=null)
					return videoStream.StreamName;
				else
					return "";
			}
		}

		public Mpeg12Video CurrentStream
		{
			get
			{
				return videoStream;
			}
		}

		public bool IsFrameValid
		{
			get
			{
				return getPictureResult;
			}
		}

		/// <summary>
		/// Wird genutzt von FindPicture!
		/// </summary>
		/// <param name="bas"></param>
		/// <param name="state"></param>
		/// <param name="ct"></param>
		/// <param name="FrameNr"></param>
		/// <param name="fis"></param>
		/// <param name="data"></param>
		/// <returns></returns>
		public static bool GetPicture(BasicVideoStream bas,ConversionType ct,int FrameNr,out FrameInfoStruct fis,out byte [] data)
		{
			using (VideoDecoder vd=Create(bas,ct))
			{
				vd.GoToFrame(FrameNr);
				fis=vd.CurrentFrameInfo;
				if (ct==ConversionType.YV12)
					data=new byte[fis.size+2*fis.chroma_size];
				else
					throw new NotImplementedException();
				vd.GetCurrentFrameData(data);
				return true;
			}
		}

		public static bool GetPicture(BasicVideoStream bas,ConversionType ct,int FrameNr,ref Bitmap bmp,out bool newBMPCreated)
		{
			using (VideoDecoder vd=Create(bas,ct))
			{
				return vd.GetPicture(FrameNr,ref bmp,true,out newBMPCreated);
			}
		}

	}
}
