/*
 * Cuttermaran - The Mpeg Cutter
 * 
 * Copyright (C) 2004 Tobias Arnold (cuttermaran@gmx.net)
 * 
 * This file is part of cuttermaran, a free MPEG cut program.
 * See http://cuttermaran.kickme.to for updates.
 *
 * This program is free software; you can redistribute it and/or modify it 
 * under the terms of the GNU General Public License as published by the 
 * Free Software Foundation; either version 2 of the License, or 
 * (at your option) any later version. 
 * 
 * This program is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the 
 * GNU General Public License for more details. 
 * 
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */

using System;
using System.IO;
using System.Text;
using System.Data;
using System.Diagnostics;
using System.Windows.Forms;

namespace ImagoMPGMuxerProvider
{
	/// <summary>
	/// Summary description for Connector.
	/// </summary>
	public class Connector
	{
		private Form    mi_OwnerForm = null;
		private Process mi_Process   = null;

		public Connector()
		{
		}

		/// <summary>
		/// Abort the muxing process
		/// This function is called by reflection
		/// </summary>
		public void AbortAction()
		{
			if (mi_Process != null)
				mi_Process.Kill();
		}

		/// <summary>
		/// returns the current progress (0-100)
		/// This function is called by reflection
		/// </summary>
		public int GetProgress()
		{
			// not supported by Imago
			return 0;
		}

		/// <summary>
		/// This will set CMMain or Confirguration.Settings as parent for all dialogs / messageboxes
		/// This function is called by reflection
		/// </summary>
		public void SetOwnerWindow(Form i_Owner)
		{
			mi_OwnerForm = i_Owner;
		}

		/// <summary>
		/// This function is called by reflection
		/// </summary>
		public int Mux(DataSet data)
		{
			DataRow dr=null;
			try
			{
				dr=data.Tables["MuxInfo"].Rows[0];

				if((int)dr["MuxType"]==0 && !(bool)dr["Unattended"]) // Soll ein MPEG-1 gemuxt werden?
				{
					MessageBox.Show(mi_OwnerForm, "ImagoMPG-Muxer supports MPEG-2 only.");
					return -1;
				}

				// Kommandozeilenparameter zusammenbauen
				StringBuilder sb=new StringBuilder();

				sb.AppendFormat("\"{0}\"",dr["VideoFile"]);

				foreach (DataRow audiorow in data.Tables["Audio"].Rows)
					sb.AppendFormat(" \"{0}\"",audiorow["AudioFile"]);

				string outpath=Path.GetDirectoryName((string)dr["OutputMPG"]);
				outpath=outpath.TrimEnd(Path.DirectorySeparatorChar);

				sb.AppendFormat(" -o -{0} \"{1}\"",Settings.OutputType,outpath);

				// write commandline to debug output if DEBUG compiled
				System.Diagnostics.Debug.WriteLine(string.Format("Imago: {0}, CmdLine: {1}",
				                                   Settings.MuxerPath,sb.ToString()));

				// Muxer aufrufen
				ProcessStartInfo psi=new ProcessStartInfo(Settings.MuxerPath,sb.ToString());
				
				// Open Imago minimized if user has defined this in configuration settings
				// OR if the main window is minimized
				if (Settings.SilentMode || (bool)dr["Unattended"] ||
					(mi_OwnerForm != null && mi_OwnerForm.WindowState == FormWindowState.Minimized))
				{
					psi.WindowStyle = ProcessWindowStyle.Minimized;
				}

				mi_Process = Process.Start(psi);
				mi_Process.WaitForExit();
				mi_Process = null; // for AbortAction()

				// Bug im Muxer: Im Zieldateinamen werden alle Grouchstaben in
				// Kleinbuchstaben gendert. Das wird hier korrigiert.
				string s_OutFile;
				if (outpath==string.Empty)
					s_OutFile=Path.Combine(Path.GetDirectoryName((string)dr["VideoFile"]),(string)dr["OutputMPG"]);
				else
					s_OutFile=(string)dr["OutputMPG"];

				if (File.Exists(s_OutFile))
					File.Move(s_OutFile, s_OutFile);

				return 0;
			}
			catch (Exception ex)
			{
				if (dr!=null && !(bool)dr["Unattended"])
					MessageBox.Show(mi_OwnerForm, ex.Message,"ImagoMPGMuxerProvider");
				return -1;
			}
		}

		public void Config()
		{
			Settings settings=new Settings();
			settings.ShowDialog(mi_OwnerForm);
		}

	}
}
