
#include "Mplex.h"

// static function which is set as handler for all output
static void MessageHandler(log_level_t e_Level, const char* s8_Message)
{
	if (Muxer::Mplex::CallbackPrintMessage)
		Muxer::Mplex::CallbackPrintMessage((Muxer::Mplex::ePrintType)e_Level, new String(s8_Message));
}

Muxer::Mplex::Mplex()
{
	mi_Mux = 0;
	mjpeg_log_set_handler(MessageHandler);
}			

Muxer::Mplex::~Mplex()
{
	if (mi_Mux) delete mi_Mux;
	// Do NOT set CallbackPrintMessage = 0 here because the garbage collector 
	// may call the destructor after another instance has already been created!
}

void Muxer::Mplex::AbortMuxing()
{
	if (mi_Mux) mi_Mux->AbortLoop();
}

void Muxer::Mplex::SetCpuLoad(int s32_Percent)
{
	if (mi_Mux) mi_Mux->SetCpuLoad(s32_Percent);
}

// Each char in s_Commands is a command (case sensitive!)
// For each command there is a corresponding option in s_Options[]
void Muxer::Mplex::Execute(String* s_Commands, String* s_Options[])
{
	char* s8_OptList[500];
	char* s8_Commands = (char*)Marshal::StringToHGlobalAnsi(s_Commands).ToPointer();
	
	int s32_CmdCount = s_Commands->Length;
	if (s32_CmdCount > sizeof(s8_OptList) || s32_CmdCount != s_Options->Length)
		throw new Exception("Invalid parameters!");

	// store pointers to each cmdline option
	for (int P=0; P<s32_CmdCount; P++)
	{
		if (s8_Commands[P] == 'i' || s8_Commands[P] == 'o')
		{
			// Check if the path contains Unicode parameters
			for (int C=0; C<s_Options[P]->Length; C++)
			{
				if (s_Options[P]->Chars[C] > 255)
					throw new Exception("Mplex does not support Unicode paths! Please rename the file / folder!");
			}
		}
		s8_OptList[P] = (char*)Marshal::StringToHGlobalAnsi(s_Options[P]).ToPointer();
	}

	Exception* p_Ex = 0;
	try
	{
		CmdLineMultiplexJob i_Job(s32_CmdCount, s8_Commands, s8_OptList);

		FileOutputStream i_OutFile(i_Job.output_file);
		mi_Mux = new Multiplexor(i_Job, i_OutFile);
		mi_Mux->Multiplex();
	}
	catch (char* s8_Msg) // native Exceptions must be translated !!
	{
		p_Ex = new Exception(s8_Msg);
	}

	// Clean up
	mi_Mux->CleanUp(); // close any open files

	Marshal::FreeHGlobal(s8_Commands);
	for (int i=0; i<s32_CmdCount; i++)
	{
		Marshal::FreeHGlobal(s8_OptList[i]);
	}

	if (p_Ex) throw p_Ex;
}


