/*
 * Cuttermaran - The Mpeg Cutter
 * 
 * Copyright (C) 2003,2004  Tobias Arnold (cuttermaran@gmx.net)
 * 
 * This file is part of cuttermaran, a free MPEG cut program.
 * See http://cuttermaran.kickme.to for updates.
 *
 * This program is free software; you can redistribute it and/or modify it 
 * under the terms of the GNU General Public License as published by the 
 * Free Software Foundation; either version 2 of the License, or 
 * (at your option) any later version. 
 * 
 * This program is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the 
 * GNU General Public License for more details. 
 * 
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */

using System;
using System.Text;
using System.Data;
using System.Threading;
using System.Diagnostics;
using System.Windows.Forms;

namespace mplexProvider
{
	/// <summary>
	/// Summary description for Connector.
	/// </summary>
	public class Connector
	{
		private DialogResult     mi_DlgResult = DialogResult.Abort;
		private Form             mi_OwnerForm = null;
		private OutputWindow     mi_OutDlg    = null;

		public Connector()
		{
		}

		/// <summary>
		/// This will set CMMain or Confirguration.Settings as parent for all dialogs / messageboxes
		/// This function is called by reflection
		/// </summary>
		public void SetOwnerWindow(Form i_Owner)
		{
			mi_OwnerForm = i_Owner;
		}

		/// <summary>
		/// Abort the muxing process
		/// This function is called by reflection
		/// </summary>
		public void AbortAction() // called from GUI thread
		{
			if (mi_OutDlg != null) 
				mi_OutDlg.OnButtonAbort(null, null);
		}

		/// <summary>
		/// returns the current progress (0-100)
		/// This function is called by reflection
		/// </summary>
		public int GetProgress() // called from GUI thread
		{
			if (mi_OutDlg == null) return 0;
			else return mi_OutDlg.Progress;
		}

		/// <summary>
		/// This function is called by reflection
		/// </summary>
		public int Mux(DataSet i_Data)
		{
			DataRow i_Row = null;
			try
			{
				i_Row = i_Data.Tables["MuxInfo"].Rows[0];
				mi_OutDlg = new OutputWindow(i_Data, i_Row, mi_OwnerForm);

				// Open output windows minimized if user has defined this in configuration settings
				// OR if the main window is minimized
				if (Settings.SilentMode || (bool)i_Row["Unattended"] ||
					(mi_OwnerForm != null && mi_OwnerForm.WindowState == FormWindowState.Minimized))
				{
					mi_OutDlg.WindowState = FormWindowState.Minimized;
				}

				// The next command blocks until mi_OutDlg has closed
				mi_OwnerForm.Invoke(new delegateShowDlgAsync(ShowDialogAsync));

				mi_OutDlg = null; // for AbortAction()
				return (mi_DlgResult == DialogResult.OK) ? 0 : -1;
			}
			catch (Exception ex)
			{
				if (i_Row!=null && !(bool)i_Row["Unattended"])
					MessageBox.Show(mi_OwnerForm, ex.Message,"mplexProvider");
				return -1;
			}
		}

		/// <summary>
		/// IMPORTANT: The dialog mi_OutDlg must run in the GUI thread!
		/// (otherwise Cuttermaran will completely hang on Windows 98/ME)
		/// </summary>
		private delegate void delegateShowDlgAsync();
		private void ShowDialogAsync()
		{
			// Imitate a modal dialog
			// Do not use a real modal dialog, because this would completely block CMMain!
			// The user must still be able to minimize CMMain while mi_OutDlg is open!
			mi_OutDlg.Show();
			do
			{
				Thread.Sleep(15);
				Application.DoEvents();
			}
			while (!mi_OutDlg.HasClosed);

			mi_DlgResult = mi_OutDlg.DialogResult;
		}

		public void Config()
		{
			Settings settings=new Settings();
			settings.ShowDialog(mi_OwnerForm);
		}
	}
}
