///////////////////////////////////////////////////////////////////////////////////////////////////////////////
// Author: Elm (http://kickme.to/elmue)
// Date: 12-12-2006
//
// Filename: ProcessStarter.cpp
//
//
// Purpose: Create a process of the given EXE file, hook into the process
// and hide all toplevel windows which have a minimize button.
// MessageBoxes (error messages) will not be hidden.
//
// You must  use StartProcessHiddenA() and ExplainErrorA() on Windows 95,98,ME !
// Otherwise use StartProcessHiddenW() and ExplainErrorW() to support Unicode !
//
// ATTENTION: Do NOT put this code into a Managed C++ DLL !
// This DLL is hooked into another process which then would
// have to load the heavy DotNet framework!
//
// Cuttermaran uses this DLL to hide the windows of TmpgEnc.
// TmpgEnc uses a main window which is invisible but which has a taskbar button
// This Main window (TApplication) then opens the visisble dialog (TMainForm)
// The taskbar button of TmpgEnc is not hidden.
//

#include "ProcessStarter.h"

#ifdef _DEBUG
	#define _EnableDebugOutput 0  // ==0 --> completely disables ALL debug output
	// +++++++++++++++++++++++++
	#define _TraceHookProc     0  // print trace output of Hook procedure    (ALL windows)
	#define _TraceWndProc      1  // print trace output of WndProc procedure (subclassed windows)
#endif

// --------------------------------------------------------------------------

// global variable
// Shared memory (cross process access)
#pragma data_seg (".shared")
HHOOK  gh_Hook    = 0;
#pragma data_seg ()
#pragma comment(linker,"/SECTION:.shared,RWS") 

// local variables
CMap<HWND,WNDPROC> mi_Map;
HINSTANCE          mh_Module;
HHOOK              mh_Hook;

void TraceA(char* s8_Format, ...)
{
	#if _EnableDebugOutput
		va_list  args; 
		va_start(args, s8_Format);
		
		char s8_Buf[5001];
		_vsnprintf(s8_Buf, 5000, s8_Format, args);
		OutputDebugStringA(s8_Buf);
	#endif
}

void TraceW(WCHAR* u16_Format, ...)
{
	#if _EnableDebugOutput
		va_list  args; 
		va_start(args, u16_Format);
		
		WCHAR u16_Buf[5000];
		_vsnwprintf(u16_Buf, 5000, u16_Format, args);
		OutputDebugStringW(u16_Buf);
	#endif
}

// ----------------------------------------------------------------------------

BOOL APIENTRY DllMain(HINSTANCE h_Module, DWORD u32_Reason, LPVOID p_Reserved)
{
	mh_Module = h_Module;

	if (u32_Reason == DLL_PROCESS_ATTACH)
	{
		TraceA("------=======***========------");
		TraceA("PROCESS_STARTER_ATTACH  Module 0x%08X, Process %d, Thread %d", mh_Module, GetCurrentProcessId(), GetCurrentThreadId());

		if (gh_Hook) // are we already inside the hooked process ?
		{
			mh_Hook = gh_Hook; // copy to local variable
			gh_Hook = 0;       // must be reset for the next process to be started!

			// Increase the reference count of this DLL otherwise it will 
			// be unloaded when the caller process (which has set the hook) terminates.
			// -> the new process would crash because the hook is still set.
			WCHAR u16_Buf[MAX_PATH];
			if (GetModuleFileNameW(mh_Module, u16_Buf, MAX_PATH)) // returns 0 on Win 95,98,ME
			{
				LoadLibraryW(u16_Buf);
				TraceW(L"LoadLibraryW(%s)", u16_Buf);
			}
			else // Windows 95,98,ME
			{
				char s8_Buf[MAX_PATH];
				GetModuleFileNameA(mh_Module, s8_Buf, MAX_PATH);
				LoadLibraryA(s8_Buf);
				TraceA("LoadLibraryA(%s)", s8_Buf);
			}
		}
	}
    if (u32_Reason == DLL_PROCESS_DETACH)
	{
		TraceA("PROCESS_STARTER_DETACH");
	}
    return TRUE;
}

// -----------------------------------------------------------------------------

// Retrieves an explanation for the Win32 API error code from Windows
void ExplainAPIErrorA(int  s32_ErrCode, // C#: Int32
					  char* s8_Buffer,  // C#: StringBuilder (CharSet=CharSet.Ansi, Windos 98,ME)
					  int  s32_BufSize) // C#: Int32 (=StringBuilder.Capacity)
{
	s8_Buffer[0] = 0;
	FormatMessageA(FORMAT_MESSAGE_FROM_SYSTEM, 0, s32_ErrCode, 0, s8_Buffer, s32_BufSize, 0);

	// remove stupid "\r\n" at the end
	int s32_Len = strlen(s8_Buffer);
	if (s32_Len > 3 && s8_Buffer[s32_Len-2] == '\r') s8_Buffer[s32_Len-2] = 0;
}
void ExplainAPIErrorW(int    s32_ErrCode, // C#: Int32
					  WCHAR* u16_Buffer,  // C#: StringBuilder (CharSet=CharSet.Unicode, Windos NT,2k,XP)
					  int    s32_BufSize) // C#: Int32 (=StringBuilder.Capacity)
{
	u16_Buffer[0] = 0;
	FormatMessageW(FORMAT_MESSAGE_FROM_SYSTEM, 0, s32_ErrCode, 0, u16_Buffer, s32_BufSize, 0);

	// remove stupid "\r\n" at the end
	int s32_Len = wcslen(u16_Buffer);
	if (s32_Len > 3 && u16_Buffer[s32_Len-2] == '\r') u16_Buffer[s32_Len-2] = 0;
}

// Start the given file and hide all toplevel windows which have a minimize button
// Messageboxes will not be hidden
// returns Win32 API Error code
int StartProcessHiddenA(char*   s8_File,        // C#: String (CharSet=CharSet.Ansi, Windos 98,ME)
						char*   s8_CmdArgs,     // C#: String (CharSet=CharSet.Ansi, Windos 98,ME)
						bool     b_WaitForExit, // C#: bool   (wait until the process has exited)
						int*  ps32_ProcessID,   // C#: out Int32
						int*  ps32_ExitCode)    // C#: out Int32
{
	char    s8_Command[3000];
	sprintf(s8_Command, "\"%s\" %s", s8_File, s8_CmdArgs); // Workaround for Windows Bug
	TraceA ("StartProcesHiddenA(%s)", s8_Command);

	STARTUPINFOA        k_Start;
	PROCESS_INFORMATION k_Proc;
	memset(&k_Start, 0, sizeof(k_Start));
	memset(&k_Proc,  0, sizeof(k_Proc));

	// TmpgEnc uses a main window which is invisible but which has a taskbar button
	// This Main window (TApplication) then opens the visisble dialog (TMainForm)
	// We are not able to hide this window HERE but we can avoid that it steals the focus
	k_Start.cb          = sizeof(k_Start);
	k_Start.dwFlags     = STARTF_USESHOWWINDOW;
	k_Start.wShowWindow = SW_SHOWMINNOACTIVE;

	// We must get full attention from Windows to hook onto the first window
	// which the new process will create as soon as possible.
	// If we miss the first WM_CREATE in the new process it may be too late!
	SetThreadPriority(GetCurrentThread(), THREAD_PRIORITY_TIME_CRITICAL);

	// Windows Bug: Do not use Parameter 1 AND 2 of CreateProcess()! The command arguments
	// will not be passed correctly if ApplicationName and CommandLine are passed separately
	int s32_Err = 0;
	if (CreateProcessA(0, s8_Command, 0, 0, TRUE,
	                   CREATE_DEFAULT_ERROR_MODE | NORMAL_PRIORITY_CLASS,
	                   0, 0, &k_Start, &k_Proc))
	{
		*ps32_ExitCode = Attach(k_Proc, b_WaitForExit);
	}
	else s32_Err = GetLastError();

	SetThreadPriority(GetCurrentThread(), THREAD_PRIORITY_NORMAL);
	*ps32_ProcessID = k_Proc.dwProcessId;
	return s32_Err;
}
int StartProcessHiddenW(WCHAR* u16_File,        // C#: String (CharSet=CharSet.Unicode, Windos NT,2k,XP)
						WCHAR* u16_CmdArgs,     // C#: String (CharSet=CharSet.Unicode, Windos NT,2k,XP)
						bool     b_WaitForExit, // C#: bool   (wait until the process has exited)
						int*  ps32_ProcessID,   // C#: out Int32
						int*  ps32_ExitCode)    // C#: out Int32
{
	WCHAR    u16_Command[3000];
	swprintf(u16_Command, L"\"%s\" %s", u16_File, u16_CmdArgs); // Workaround for Windows Bug
	TraceW  (L"StartProcesHiddenW(%s)", u16_Command);

	STARTUPINFOW        k_Start;
	PROCESS_INFORMATION k_Proc;
	memset(&k_Start, 0, sizeof(k_Start));
	memset(&k_Proc,  0, sizeof(k_Proc));

	k_Start.cb          = sizeof(k_Start);
	k_Start.dwFlags     = STARTF_USESHOWWINDOW;
	k_Start.wShowWindow = SW_SHOWMINNOACTIVE;

	SetThreadPriority(GetCurrentThread(), THREAD_PRIORITY_TIME_CRITICAL);

	int s32_Err = 0;
	if (CreateProcessW(0, u16_Command, 0, 0, TRUE,
	                   CREATE_DEFAULT_ERROR_MODE | NORMAL_PRIORITY_CLASS,
	                   0, 0, &k_Start, &k_Proc))
	{
		*ps32_ExitCode = Attach(k_Proc, b_WaitForExit);
	}
	else s32_Err = GetLastError();

	SetThreadPriority(GetCurrentThread(), THREAD_PRIORITY_NORMAL);
	*ps32_ProcessID = k_Proc.dwProcessId;
	return s32_Err;
}

// Set the Hook and wait until the process has exited
// returns the Exit code of the process (if b_WaitForExit == true)
int Attach(PROCESS_INFORMATION& k_Proc, bool b_WaitForExit)
{
	TraceA("Process %d created", k_Proc.dwProcessId);
	TraceA("Setting Hook on Module 0x%08X, ThreadID %d", mh_Module, k_Proc.dwThreadId);

	int s32_Time = 0;
	while (true)
	{
		gh_Hook = SetWindowsHookEx(WH_CALLWNDPROC, (HOOKPROC)HookProc, mh_Module, k_Proc.dwThreadId);
		if (gh_Hook)
		{
			TraceA("SetWindowsHookEx() --> Hook set with handle 0x%08X", gh_Hook);
			break;
		}
		
		if (s32_Time < 5000) // try for 5 seconds each 5 ms to set the hook
		{
			TraceA("SetWindowsHookEx() TRY AGAIN");
			Sleep(5);
			s32_Time += 5;
		}
		else
		{
			// we don't return an error if the window could not be hidden because
			// this is not really a problem which must be displayed to the user!
			TraceA("SetWindowsHookEx() FAILED");
			break;
		}
	}

	DWORD u32_ExitCode = 0;
	if (b_WaitForExit)
	{
		while (GetExitCodeProcess(k_Proc.hProcess, &u32_ExitCode) && u32_ExitCode == STILL_ACTIVE)
		{
			Sleep(100);
		}
		TraceA("The process has exited with exit code %u", u32_ExitCode);
	}
	return u32_ExitCode;
}

// ---------------------------------------------------------------------------------

// Receives all windows messages of all windows
// But here we can not MODIFY messages!
LRESULT CALLBACK HookProc(int nCode, WPARAM wParam, LPARAM lParam)
{
	if (nCode == HC_ACTION) 
	{
		CWPSTRUCT *P = (CWPSTRUCT*) lParam;
		#if _TraceHookProc
			TraceA("HookProc: HC_ACTION, Origin:%s, HWND %08X, Msg %04X, wParam %08X, lParam %08X", 
				   (wParam ? "OWN" : "EXT"), P->hwnd, P->message, P->wParam, P->lParam);
		#endif

		if (P->message == WM_CREATE)
		{
			// ATTENTION: ((CREATESTRUCT*)P->lParam)->lpszClass returns invalid pointer
			// if the japanese language pack is installed and the very first window
			// is created which then will be "IME" -> Crash. We use GetClassName instead.
			char s8_Class[500];
			GetClassName(P->hwnd, s8_Class, sizeof(s8_Class));
			UINT u32_Width   = ((CREATESTRUCT*)P->lParam)->cx;
			UINT u32_Height  = ((CREATESTRUCT*)P->lParam)->cy;
			UINT u32_Style   = ((CREATESTRUCT*)P->lParam)->style;
			UINT u32_ExStyle = ((CREATESTRUCT*)P->lParam)->dwExStyle;

			TraceA("Hook: WM_CREATE Hwnd %08X, Style %08X, ExStyle %08X, Size %3d x %3d, Class '%s'", 
			       P->hwnd, u32_Style, u32_ExStyle, u32_Width, u32_Height, s8_Class);

			// Subclass all toplevel windows
			// ATTENTION: Do NOT check WS_VISIBLE flag here as some windows are
			// created invisible and made visible later!!
			if ((u32_Style & WS_CHILD)   == 0   &&      // Child -> not toplevel
				(u32_Style & WS_CAPTION) == WS_CAPTION) // has Title bar ?
			{
				WNDPROC p_OldProc = 0;
				if (IsWindowUnicode(P->hwnd))
					p_OldProc = (WNDPROC) SetWindowLongW(P->hwnd, GWL_WNDPROC, (LONG)WndProc);
				else
					p_OldProc = (WNDPROC) SetWindowLongA(P->hwnd, GWL_WNDPROC, (LONG)WndProc);

				// Store the WindowProc for this window handle in the map
				mi_Map.Set(P->hwnd, p_OldProc);

				TraceA("--> Subclassing HWND %08X (%s) -> OldWndProc %08X", P->hwnd, s8_Class, p_OldProc);
			}
		}
	}
	return CallNextHookEx(mh_Hook, nCode, wParam, lParam);
}

// This callback is called for every subclassed window 
// (only for toplevel windows or messageboxes)
LRESULT CALLBACK WndProc(HWND h_Wnd, UINT uMsg, WPARAM wParam, LPARAM lParam)
{
	WNDPROC p_OldProc = (WNDPROC) mi_Map.Get(h_Wnd);

	char s8_Class[500];
	GetClassName(h_Wnd, s8_Class, sizeof(s8_Class));
	UINT u32_Style = GetWindowLong(h_Wnd, GWL_STYLE);
	// Messageboxes never have a Minimize button!
	BOOL b_MsgBox = (u32_Style & WS_MINIMIZEBOX) == 0;

	#if _TraceWndProc
	TraceA("WndProc:  %s, Proc %08X, HWND %08X, Msg %04X, wParam %08X, lParam %08X", 
	                 (b_MsgBox ? "MsgBox":"TopLev"), p_OldProc, h_Wnd, uMsg, wParam, lParam);
	#endif

	// Messageboxes (error messages) are not hidden.
	// Bring the window to foreground instead!
	if (b_MsgBox)
	{
		if (uMsg == WM_SIZE || uMsg == WM_MOVE)
		{
			SetForegroundWindow(h_Wnd);
			TraceA("--> Setting to foreground HWND %08X (%s)", h_Wnd, s8_Class);
		}
	}
	else // normal toplevel window with minimize button
	{
		// Hide Main application window
		if (uMsg == WM_WINDOWPOSCHANGING)
		{
			WINDOWPOS *pk_Pos = (WINDOWPOS*) lParam;
			// Important: The flags SWP_NOSIZE and SWP_NOMOVE must NOT be modified!
			pk_Pos->flags &= ~SWP_SHOWWINDOW;
			pk_Pos->flags &= ~SWP_NOZORDER;
			pk_Pos->flags |=  SWP_NOACTIVATE;
			pk_Pos->flags |=  SWP_HIDEWINDOW;
			pk_Pos->flags |=  SWP_NOOWNERZORDER;
			pk_Pos->hwndInsertAfter = HWND_BOTTOM;

			TraceA("--> Hiding HWND %08X (%s)", h_Wnd, s8_Class);
		}
		if (uMsg == WM_ACTIVATE) 
		{
			wParam &= 0xFFFF0000;
			TraceA("--> Do not allow Activation of HWND %08X (%s)", h_Wnd, s8_Class);
		}
	}
	if (IsWindowUnicode(h_Wnd))
		return CallWindowProcW(p_OldProc, h_Wnd, uMsg, wParam, lParam);
	else
		return CallWindowProcA(p_OldProc, h_Wnd, uMsg, wParam, lParam);
}
