/*
 * Cuttermaran - The Mpeg Cutter
 * 
 * Copyright (C) 2003-2005 Tobias Arnold (cuttermaran@gmx.net)
 * 
 * This file is part of cuttermaran, a free MPEG cut program.
 * See http://www.cuttermaran.de for updates.
 *
 * This program is free software; you can redistribute it and/or modify it 
 * under the terms of the GNU General Public License as published by the 
 * Free Software Foundation; either version 2 of the License, or 
 * (at your option) any later version. 
 * 
 * This program is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the 
 * GNU General Public License for more details. 
 * 
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */

using System;
using System.Collections;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Windows.Forms;
using Configuration.data;

namespace Configuration
{
	/// <summary>
	/// Summary description for EncodingControl.
	/// </summary>
	public class EncodingControl : System.Windows.Forms.UserControl
	{
		private System.Windows.Forms.Panel panelEncode;
		private System.Windows.Forms.Button butConfigureEncoder;
		private System.Windows.Forms.ComboBox comboBitrate;
		private System.Windows.Forms.Label label14;
		private System.Windows.Forms.ComboBox comboEncoder;
		private System.Windows.Forms.Label label11;
		private System.Windows.Forms.CheckBox checkStreamDVDCompliant;
		private System.Windows.Forms.CheckBox checkUseEncodingMode;
		private System.Windows.Forms.ComboBox comboColorSpace;
		private System.Windows.Forms.Label label1;
		/// <summary> 
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;

		private Hashtable colorModes=new Hashtable();
		private ArrayList colorEntries=new ArrayList();

		public EncodingControl()
		{
			// This call is required by the Windows.Forms Form Designer.
			InitializeComponent();

			// TODO: Add any initialization after the InitializeComponent call

		}

		// Das Load-Event kann nicht genutzt werden, da dies eine Exception im
		// Designer verursachen wrde!
		public void LoadData()
		{
			checkUseEncodingMode.Checked=Settings.CurrentSettings.EncodeMode;
			panelEncode.Enabled=Settings.CurrentSettings.EncodeMode;
			int index=Settings.CurrentSettings.Encode_Bitrate/500-1;
			if (index<0) index=0;
			if (index>19) index=19;
			comboBitrate.SelectedIndex=index;
			colorModes.Add("YV12",comboColorSpace.Items[0]);
			colorModes.Add("RGB24",comboColorSpace.Items[1]);
			// FillCombo will uncheck checkUseEncodingMode if specified Encoder not found
			Settings.CurrentSettings.FillCombo(comboEncoder,"'encoder'",butConfigureEncoder,checkUseEncodingMode,Settings.CurrentSettings.UsedEncoder);
			comboEncoder.SelectedIndexChanged += new System.EventHandler(this.comboEncoder_SelectedIndexChanged);
			checkStreamDVDCompliant.Checked=Settings.CurrentSettings.CreateDVDCompliantStream;
		}

		public void UnLoadData()
		{
			Settings.CurrentSettings.EncodeMode=checkUseEncodingMode.Checked;
			if (comboEncoder.SelectedIndex!=-1)
				Settings.CurrentSettings.UsedEncoder=(string)comboEncoder.SelectedItem;
			if (comboBitrate.SelectedIndex==0)
				Settings.CurrentSettings.Encode_Bitrate=0;
			else
				Settings.CurrentSettings.Encode_Bitrate=int.Parse(comboBitrate.SelectedItem.ToString());
			Settings.CurrentSettings.CreateDVDCompliantStream=checkStreamDVDCompliant.Checked;
			if (comboColorSpace.SelectedIndex >= 0) // avoid crash!
				Settings.CurrentSettings.TempAVIColorEncoding=(string)colorEntries[comboColorSpace.SelectedIndex]=="YV12"?ConversionType.YV12:ConversionType.RGB24;
		}

		/// <summary> 
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Component Designer generated code
		/// <summary> 
		/// Required method for Designer support - do not modify 
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(EncodingControl));
			this.panelEncode = new System.Windows.Forms.Panel();
			this.label1 = new System.Windows.Forms.Label();
			this.comboColorSpace = new System.Windows.Forms.ComboBox();
			this.butConfigureEncoder = new System.Windows.Forms.Button();
			this.comboBitrate = new System.Windows.Forms.ComboBox();
			this.label14 = new System.Windows.Forms.Label();
			this.comboEncoder = new System.Windows.Forms.ComboBox();
			this.label11 = new System.Windows.Forms.Label();
			this.checkStreamDVDCompliant = new System.Windows.Forms.CheckBox();
			this.checkUseEncodingMode = new System.Windows.Forms.CheckBox();
			this.panelEncode.SuspendLayout();
			this.SuspendLayout();
			// 
			// panelEncode
			// 
			this.panelEncode.AccessibleDescription = resources.GetString("panelEncode.AccessibleDescription");
			this.panelEncode.AccessibleName = resources.GetString("panelEncode.AccessibleName");
			this.panelEncode.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("panelEncode.Anchor")));
			this.panelEncode.AutoScroll = ((bool)(resources.GetObject("panelEncode.AutoScroll")));
			this.panelEncode.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("panelEncode.AutoScrollMargin")));
			this.panelEncode.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("panelEncode.AutoScrollMinSize")));
			this.panelEncode.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("panelEncode.BackgroundImage")));
			this.panelEncode.Controls.Add(this.label1);
			this.panelEncode.Controls.Add(this.comboColorSpace);
			this.panelEncode.Controls.Add(this.butConfigureEncoder);
			this.panelEncode.Controls.Add(this.comboBitrate);
			this.panelEncode.Controls.Add(this.label14);
			this.panelEncode.Controls.Add(this.comboEncoder);
			this.panelEncode.Controls.Add(this.label11);
			this.panelEncode.Controls.Add(this.checkStreamDVDCompliant);
			this.panelEncode.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("panelEncode.Dock")));
			this.panelEncode.Enabled = ((bool)(resources.GetObject("panelEncode.Enabled")));
			this.panelEncode.Font = ((System.Drawing.Font)(resources.GetObject("panelEncode.Font")));
			this.panelEncode.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("panelEncode.ImeMode")));
			this.panelEncode.Location = ((System.Drawing.Point)(resources.GetObject("panelEncode.Location")));
			this.panelEncode.Name = "panelEncode";
			this.panelEncode.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("panelEncode.RightToLeft")));
			this.panelEncode.Size = ((System.Drawing.Size)(resources.GetObject("panelEncode.Size")));
			this.panelEncode.TabIndex = ((int)(resources.GetObject("panelEncode.TabIndex")));
			this.panelEncode.Text = resources.GetString("panelEncode.Text");
			this.panelEncode.Visible = ((bool)(resources.GetObject("panelEncode.Visible")));
			// 
			// label1
			// 
			this.label1.AccessibleDescription = resources.GetString("label1.AccessibleDescription");
			this.label1.AccessibleName = resources.GetString("label1.AccessibleName");
			this.label1.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("label1.Anchor")));
			this.label1.AutoSize = ((bool)(resources.GetObject("label1.AutoSize")));
			this.label1.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("label1.Dock")));
			this.label1.Enabled = ((bool)(resources.GetObject("label1.Enabled")));
			this.label1.Font = ((System.Drawing.Font)(resources.GetObject("label1.Font")));
			this.label1.Image = ((System.Drawing.Image)(resources.GetObject("label1.Image")));
			this.label1.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label1.ImageAlign")));
			this.label1.ImageIndex = ((int)(resources.GetObject("label1.ImageIndex")));
			this.label1.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("label1.ImeMode")));
			this.label1.Location = ((System.Drawing.Point)(resources.GetObject("label1.Location")));
			this.label1.Name = "label1";
			this.label1.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("label1.RightToLeft")));
			this.label1.Size = ((System.Drawing.Size)(resources.GetObject("label1.Size")));
			this.label1.TabIndex = ((int)(resources.GetObject("label1.TabIndex")));
			this.label1.Text = resources.GetString("label1.Text");
			this.label1.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label1.TextAlign")));
			this.label1.Visible = ((bool)(resources.GetObject("label1.Visible")));
			// 
			// comboColorSpace
			// 
			this.comboColorSpace.AccessibleDescription = resources.GetString("comboColorSpace.AccessibleDescription");
			this.comboColorSpace.AccessibleName = resources.GetString("comboColorSpace.AccessibleName");
			this.comboColorSpace.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("comboColorSpace.Anchor")));
			this.comboColorSpace.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("comboColorSpace.BackgroundImage")));
			this.comboColorSpace.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("comboColorSpace.Dock")));
			this.comboColorSpace.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
			this.comboColorSpace.Enabled = ((bool)(resources.GetObject("comboColorSpace.Enabled")));
			this.comboColorSpace.Font = ((System.Drawing.Font)(resources.GetObject("comboColorSpace.Font")));
			this.comboColorSpace.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("comboColorSpace.ImeMode")));
			this.comboColorSpace.IntegralHeight = ((bool)(resources.GetObject("comboColorSpace.IntegralHeight")));
			this.comboColorSpace.ItemHeight = ((int)(resources.GetObject("comboColorSpace.ItemHeight")));
			this.comboColorSpace.Items.AddRange(new object[] {
																 resources.GetString("comboColorSpace.Items"),
																 resources.GetString("comboColorSpace.Items1")});
			this.comboColorSpace.Location = ((System.Drawing.Point)(resources.GetObject("comboColorSpace.Location")));
			this.comboColorSpace.MaxDropDownItems = ((int)(resources.GetObject("comboColorSpace.MaxDropDownItems")));
			this.comboColorSpace.MaxLength = ((int)(resources.GetObject("comboColorSpace.MaxLength")));
			this.comboColorSpace.Name = "comboColorSpace";
			this.comboColorSpace.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("comboColorSpace.RightToLeft")));
			this.comboColorSpace.Size = ((System.Drawing.Size)(resources.GetObject("comboColorSpace.Size")));
			this.comboColorSpace.TabIndex = ((int)(resources.GetObject("comboColorSpace.TabIndex")));
			this.comboColorSpace.Text = resources.GetString("comboColorSpace.Text");
			this.comboColorSpace.Visible = ((bool)(resources.GetObject("comboColorSpace.Visible")));
			// 
			// butConfigureEncoder
			// 
			this.butConfigureEncoder.AccessibleDescription = resources.GetString("butConfigureEncoder.AccessibleDescription");
			this.butConfigureEncoder.AccessibleName = resources.GetString("butConfigureEncoder.AccessibleName");
			this.butConfigureEncoder.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butConfigureEncoder.Anchor")));
			this.butConfigureEncoder.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butConfigureEncoder.BackgroundImage")));
			this.butConfigureEncoder.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butConfigureEncoder.Dock")));
			this.butConfigureEncoder.Enabled = ((bool)(resources.GetObject("butConfigureEncoder.Enabled")));
			this.butConfigureEncoder.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butConfigureEncoder.FlatStyle")));
			this.butConfigureEncoder.Font = ((System.Drawing.Font)(resources.GetObject("butConfigureEncoder.Font")));
			this.butConfigureEncoder.Image = ((System.Drawing.Image)(resources.GetObject("butConfigureEncoder.Image")));
			this.butConfigureEncoder.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butConfigureEncoder.ImageAlign")));
			this.butConfigureEncoder.ImageIndex = ((int)(resources.GetObject("butConfigureEncoder.ImageIndex")));
			this.butConfigureEncoder.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butConfigureEncoder.ImeMode")));
			this.butConfigureEncoder.Location = ((System.Drawing.Point)(resources.GetObject("butConfigureEncoder.Location")));
			this.butConfigureEncoder.Name = "butConfigureEncoder";
			this.butConfigureEncoder.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butConfigureEncoder.RightToLeft")));
			this.butConfigureEncoder.Size = ((System.Drawing.Size)(resources.GetObject("butConfigureEncoder.Size")));
			this.butConfigureEncoder.TabIndex = ((int)(resources.GetObject("butConfigureEncoder.TabIndex")));
			this.butConfigureEncoder.Text = resources.GetString("butConfigureEncoder.Text");
			this.butConfigureEncoder.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butConfigureEncoder.TextAlign")));
			this.butConfigureEncoder.Visible = ((bool)(resources.GetObject("butConfigureEncoder.Visible")));
			this.butConfigureEncoder.Click += new System.EventHandler(this.butConfigureEncoder_Click);
			// 
			// comboBitrate
			// 
			this.comboBitrate.AccessibleDescription = resources.GetString("comboBitrate.AccessibleDescription");
			this.comboBitrate.AccessibleName = resources.GetString("comboBitrate.AccessibleName");
			this.comboBitrate.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("comboBitrate.Anchor")));
			this.comboBitrate.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("comboBitrate.BackgroundImage")));
			this.comboBitrate.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("comboBitrate.Dock")));
			this.comboBitrate.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
			this.comboBitrate.Enabled = ((bool)(resources.GetObject("comboBitrate.Enabled")));
			this.comboBitrate.Font = ((System.Drawing.Font)(resources.GetObject("comboBitrate.Font")));
			this.comboBitrate.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("comboBitrate.ImeMode")));
			this.comboBitrate.IntegralHeight = ((bool)(resources.GetObject("comboBitrate.IntegralHeight")));
			this.comboBitrate.ItemHeight = ((int)(resources.GetObject("comboBitrate.ItemHeight")));
			this.comboBitrate.Items.AddRange(new object[] {
															  resources.GetString("comboBitrate.Items"),
															  resources.GetString("comboBitrate.Items1"),
															  resources.GetString("comboBitrate.Items2"),
															  resources.GetString("comboBitrate.Items3"),
															  resources.GetString("comboBitrate.Items4"),
															  resources.GetString("comboBitrate.Items5"),
															  resources.GetString("comboBitrate.Items6"),
															  resources.GetString("comboBitrate.Items7"),
															  resources.GetString("comboBitrate.Items8"),
															  resources.GetString("comboBitrate.Items9"),
															  resources.GetString("comboBitrate.Items10"),
															  resources.GetString("comboBitrate.Items11"),
															  resources.GetString("comboBitrate.Items12"),
															  resources.GetString("comboBitrate.Items13"),
															  resources.GetString("comboBitrate.Items14"),
															  resources.GetString("comboBitrate.Items15"),
															  resources.GetString("comboBitrate.Items16"),
															  resources.GetString("comboBitrate.Items17"),
															  resources.GetString("comboBitrate.Items18"),
															  resources.GetString("comboBitrate.Items19")});
			this.comboBitrate.Location = ((System.Drawing.Point)(resources.GetObject("comboBitrate.Location")));
			this.comboBitrate.MaxDropDownItems = ((int)(resources.GetObject("comboBitrate.MaxDropDownItems")));
			this.comboBitrate.MaxLength = ((int)(resources.GetObject("comboBitrate.MaxLength")));
			this.comboBitrate.Name = "comboBitrate";
			this.comboBitrate.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("comboBitrate.RightToLeft")));
			this.comboBitrate.Size = ((System.Drawing.Size)(resources.GetObject("comboBitrate.Size")));
			this.comboBitrate.TabIndex = ((int)(resources.GetObject("comboBitrate.TabIndex")));
			this.comboBitrate.Text = resources.GetString("comboBitrate.Text");
			this.comboBitrate.Visible = ((bool)(resources.GetObject("comboBitrate.Visible")));
			// 
			// label14
			// 
			this.label14.AccessibleDescription = resources.GetString("label14.AccessibleDescription");
			this.label14.AccessibleName = resources.GetString("label14.AccessibleName");
			this.label14.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("label14.Anchor")));
			this.label14.AutoSize = ((bool)(resources.GetObject("label14.AutoSize")));
			this.label14.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("label14.Dock")));
			this.label14.Enabled = ((bool)(resources.GetObject("label14.Enabled")));
			this.label14.Font = ((System.Drawing.Font)(resources.GetObject("label14.Font")));
			this.label14.Image = ((System.Drawing.Image)(resources.GetObject("label14.Image")));
			this.label14.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label14.ImageAlign")));
			this.label14.ImageIndex = ((int)(resources.GetObject("label14.ImageIndex")));
			this.label14.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("label14.ImeMode")));
			this.label14.Location = ((System.Drawing.Point)(resources.GetObject("label14.Location")));
			this.label14.Name = "label14";
			this.label14.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("label14.RightToLeft")));
			this.label14.Size = ((System.Drawing.Size)(resources.GetObject("label14.Size")));
			this.label14.TabIndex = ((int)(resources.GetObject("label14.TabIndex")));
			this.label14.Text = resources.GetString("label14.Text");
			this.label14.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label14.TextAlign")));
			this.label14.Visible = ((bool)(resources.GetObject("label14.Visible")));
			// 
			// comboEncoder
			// 
			this.comboEncoder.AccessibleDescription = resources.GetString("comboEncoder.AccessibleDescription");
			this.comboEncoder.AccessibleName = resources.GetString("comboEncoder.AccessibleName");
			this.comboEncoder.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("comboEncoder.Anchor")));
			this.comboEncoder.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("comboEncoder.BackgroundImage")));
			this.comboEncoder.DisplayMember = "DisplayName";
			this.comboEncoder.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("comboEncoder.Dock")));
			this.comboEncoder.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
			this.comboEncoder.Enabled = ((bool)(resources.GetObject("comboEncoder.Enabled")));
			this.comboEncoder.Font = ((System.Drawing.Font)(resources.GetObject("comboEncoder.Font")));
			this.comboEncoder.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("comboEncoder.ImeMode")));
			this.comboEncoder.IntegralHeight = ((bool)(resources.GetObject("comboEncoder.IntegralHeight")));
			this.comboEncoder.ItemHeight = ((int)(resources.GetObject("comboEncoder.ItemHeight")));
			this.comboEncoder.Location = ((System.Drawing.Point)(resources.GetObject("comboEncoder.Location")));
			this.comboEncoder.MaxDropDownItems = ((int)(resources.GetObject("comboEncoder.MaxDropDownItems")));
			this.comboEncoder.MaxLength = ((int)(resources.GetObject("comboEncoder.MaxLength")));
			this.comboEncoder.Name = "comboEncoder";
			this.comboEncoder.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("comboEncoder.RightToLeft")));
			this.comboEncoder.Size = ((System.Drawing.Size)(resources.GetObject("comboEncoder.Size")));
			this.comboEncoder.TabIndex = ((int)(resources.GetObject("comboEncoder.TabIndex")));
			this.comboEncoder.Text = resources.GetString("comboEncoder.Text");
			this.comboEncoder.ValueMember = "DisplayName";
			this.comboEncoder.Visible = ((bool)(resources.GetObject("comboEncoder.Visible")));
			this.comboEncoder.SelectedIndexChanged += new System.EventHandler(this.comboEncoder_SelectedIndexChanged);
			// 
			// label11
			// 
			this.label11.AccessibleDescription = resources.GetString("label11.AccessibleDescription");
			this.label11.AccessibleName = resources.GetString("label11.AccessibleName");
			this.label11.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("label11.Anchor")));
			this.label11.AutoSize = ((bool)(resources.GetObject("label11.AutoSize")));
			this.label11.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("label11.Dock")));
			this.label11.Enabled = ((bool)(resources.GetObject("label11.Enabled")));
			this.label11.Font = ((System.Drawing.Font)(resources.GetObject("label11.Font")));
			this.label11.Image = ((System.Drawing.Image)(resources.GetObject("label11.Image")));
			this.label11.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label11.ImageAlign")));
			this.label11.ImageIndex = ((int)(resources.GetObject("label11.ImageIndex")));
			this.label11.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("label11.ImeMode")));
			this.label11.Location = ((System.Drawing.Point)(resources.GetObject("label11.Location")));
			this.label11.Name = "label11";
			this.label11.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("label11.RightToLeft")));
			this.label11.Size = ((System.Drawing.Size)(resources.GetObject("label11.Size")));
			this.label11.TabIndex = ((int)(resources.GetObject("label11.TabIndex")));
			this.label11.Text = resources.GetString("label11.Text");
			this.label11.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label11.TextAlign")));
			this.label11.Visible = ((bool)(resources.GetObject("label11.Visible")));
			// 
			// checkStreamDVDCompliant
			// 
			this.checkStreamDVDCompliant.AccessibleDescription = resources.GetString("checkStreamDVDCompliant.AccessibleDescription");
			this.checkStreamDVDCompliant.AccessibleName = resources.GetString("checkStreamDVDCompliant.AccessibleName");
			this.checkStreamDVDCompliant.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("checkStreamDVDCompliant.Anchor")));
			this.checkStreamDVDCompliant.Appearance = ((System.Windows.Forms.Appearance)(resources.GetObject("checkStreamDVDCompliant.Appearance")));
			this.checkStreamDVDCompliant.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("checkStreamDVDCompliant.BackgroundImage")));
			this.checkStreamDVDCompliant.CheckAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("checkStreamDVDCompliant.CheckAlign")));
			this.checkStreamDVDCompliant.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("checkStreamDVDCompliant.Dock")));
			this.checkStreamDVDCompliant.Enabled = ((bool)(resources.GetObject("checkStreamDVDCompliant.Enabled")));
			this.checkStreamDVDCompliant.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("checkStreamDVDCompliant.FlatStyle")));
			this.checkStreamDVDCompliant.Font = ((System.Drawing.Font)(resources.GetObject("checkStreamDVDCompliant.Font")));
			this.checkStreamDVDCompliant.Image = ((System.Drawing.Image)(resources.GetObject("checkStreamDVDCompliant.Image")));
			this.checkStreamDVDCompliant.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("checkStreamDVDCompliant.ImageAlign")));
			this.checkStreamDVDCompliant.ImageIndex = ((int)(resources.GetObject("checkStreamDVDCompliant.ImageIndex")));
			this.checkStreamDVDCompliant.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("checkStreamDVDCompliant.ImeMode")));
			this.checkStreamDVDCompliant.Location = ((System.Drawing.Point)(resources.GetObject("checkStreamDVDCompliant.Location")));
			this.checkStreamDVDCompliant.Name = "checkStreamDVDCompliant";
			this.checkStreamDVDCompliant.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("checkStreamDVDCompliant.RightToLeft")));
			this.checkStreamDVDCompliant.Size = ((System.Drawing.Size)(resources.GetObject("checkStreamDVDCompliant.Size")));
			this.checkStreamDVDCompliant.TabIndex = ((int)(resources.GetObject("checkStreamDVDCompliant.TabIndex")));
			this.checkStreamDVDCompliant.Text = resources.GetString("checkStreamDVDCompliant.Text");
			this.checkStreamDVDCompliant.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("checkStreamDVDCompliant.TextAlign")));
			this.checkStreamDVDCompliant.Visible = ((bool)(resources.GetObject("checkStreamDVDCompliant.Visible")));
			// 
			// checkUseEncodingMode
			// 
			this.checkUseEncodingMode.AccessibleDescription = resources.GetString("checkUseEncodingMode.AccessibleDescription");
			this.checkUseEncodingMode.AccessibleName = resources.GetString("checkUseEncodingMode.AccessibleName");
			this.checkUseEncodingMode.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("checkUseEncodingMode.Anchor")));
			this.checkUseEncodingMode.Appearance = ((System.Windows.Forms.Appearance)(resources.GetObject("checkUseEncodingMode.Appearance")));
			this.checkUseEncodingMode.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("checkUseEncodingMode.BackgroundImage")));
			this.checkUseEncodingMode.CheckAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("checkUseEncodingMode.CheckAlign")));
			this.checkUseEncodingMode.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("checkUseEncodingMode.Dock")));
			this.checkUseEncodingMode.Enabled = ((bool)(resources.GetObject("checkUseEncodingMode.Enabled")));
			this.checkUseEncodingMode.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("checkUseEncodingMode.FlatStyle")));
			this.checkUseEncodingMode.Font = ((System.Drawing.Font)(resources.GetObject("checkUseEncodingMode.Font")));
			this.checkUseEncodingMode.Image = ((System.Drawing.Image)(resources.GetObject("checkUseEncodingMode.Image")));
			this.checkUseEncodingMode.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("checkUseEncodingMode.ImageAlign")));
			this.checkUseEncodingMode.ImageIndex = ((int)(resources.GetObject("checkUseEncodingMode.ImageIndex")));
			this.checkUseEncodingMode.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("checkUseEncodingMode.ImeMode")));
			this.checkUseEncodingMode.Location = ((System.Drawing.Point)(resources.GetObject("checkUseEncodingMode.Location")));
			this.checkUseEncodingMode.Name = "checkUseEncodingMode";
			this.checkUseEncodingMode.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("checkUseEncodingMode.RightToLeft")));
			this.checkUseEncodingMode.Size = ((System.Drawing.Size)(resources.GetObject("checkUseEncodingMode.Size")));
			this.checkUseEncodingMode.TabIndex = ((int)(resources.GetObject("checkUseEncodingMode.TabIndex")));
			this.checkUseEncodingMode.Text = resources.GetString("checkUseEncodingMode.Text");
			this.checkUseEncodingMode.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("checkUseEncodingMode.TextAlign")));
			this.checkUseEncodingMode.Visible = ((bool)(resources.GetObject("checkUseEncodingMode.Visible")));
			this.checkUseEncodingMode.CheckedChanged += new System.EventHandler(this.checkUseEncodingMode_CheckedChanged);
			// 
			// EncodingControl
			// 
			this.AccessibleDescription = resources.GetString("$this.AccessibleDescription");
			this.AccessibleName = resources.GetString("$this.AccessibleName");
			this.AutoScroll = ((bool)(resources.GetObject("$this.AutoScroll")));
			this.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("$this.AutoScrollMargin")));
			this.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("$this.AutoScrollMinSize")));
			this.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("$this.BackgroundImage")));
			this.Controls.Add(this.panelEncode);
			this.Controls.Add(this.checkUseEncodingMode);
			this.Enabled = ((bool)(resources.GetObject("$this.Enabled")));
			this.Font = ((System.Drawing.Font)(resources.GetObject("$this.Font")));
			this.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("$this.ImeMode")));
			this.Location = ((System.Drawing.Point)(resources.GetObject("$this.Location")));
			this.Name = "EncodingControl";
			this.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("$this.RightToLeft")));
			this.Size = ((System.Drawing.Size)(resources.GetObject("$this.Size")));
			this.panelEncode.ResumeLayout(false);
			this.ResumeLayout(false);

		}
		#endregion

		private void comboEncoder_SelectedIndexChanged(object sender, System.EventArgs e)
		{
			if (comboEncoder.SelectedIndex!=-1)
			{
				ExternalToolProviderData.ConfigurationRow confRow=Settings.CurrentSettings.ExternalTools.Configuration.FindByDisplayName((string)comboEncoder.SelectedItem);
				butConfigureEncoder.Enabled=(confRow!=null) &&  !confRow.IsConfigMethodNull();
				
				// Combobox fr die Farbrume bestcken
				if (confRow!=null)
				{
					comboColorSpace.Items.Clear();
					colorEntries.Clear();
					if (confRow.IsSupportedEncodingColorsNull())
						colorEntries.Add("YV12");
					else
					{
						ArrayList al=new ArrayList();
						al.AddRange(confRow.SupportedEncodingColors.Split(','));
						if (al.Contains("YV12"))
							colorEntries.Add("YV12");
						if (al.Contains("RGB24"))
							colorEntries.Add("RGB24");
					}

					foreach (string entry in colorEntries)
						comboColorSpace.Items.Add(colorModes[entry]);

					// Gewhlten Eintrag selektieren
					int index=colorEntries.IndexOf(Settings.CurrentSettings.TempAVIColorEncoding==ConversionType.YV12?"YV12":"RGB24");
					if (index<0)
						index=0;
					comboColorSpace.SelectedIndex=index;
				}
			}
		}

		private void butConfigureEncoder_Click(object sender, System.EventArgs e)
		{
			Settings.CurrentSettings.CallExternalToolConfig((string)comboEncoder.SelectedItem, this.ParentForm);
		}

		private void checkUseEncodingMode_CheckedChanged(object sender, System.EventArgs e)
		{
			panelEncode.Enabled=checkUseEncodingMode.Checked;
		}

	}
}
