/*
 * Cuttermaran - The Mpeg Cutter
 * 
 * Copyright (C) 2003-2005 Tobias Arnold (cuttermaran@gmx.net)
 * 
 * This file is part of cuttermaran, a free MPEG cut program.
 * See http://www.cuttermaran.de for updates.
 *
 * This program is free software; you can redistribute it and/or modify it 
 * under the terms of the GNU General Public License as published by the 
 * Free Software Foundation; either version 2 of the License, or 
 * (at your option) any later version. 
 * 
 * This program is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the 
 * GNU General Public License for more details. 
 * 
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */

using System;
using System.IO;
using System.Collections;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Windows.Forms;
using Configuration.data;
using StringResources;

namespace Configuration
{
	/// <summary>
	/// Summary description for MuxingControl.
	/// </summary>
	public class MuxingControl : System.Windows.Forms.UserControl
	{
		private System.Windows.Forms.Panel panelMux;
		private System.Windows.Forms.ComboBox comboMuxPath;
		private System.Windows.Forms.GroupBox groupBox2;
		private System.Windows.Forms.CheckBox checkMuxPause;
		private System.Windows.Forms.CheckBox checkDeleteFiles;
		private System.Windows.Forms.Label label13;
		private System.Windows.Forms.ComboBox comboTargetType;
		private System.Windows.Forms.Label label12;
		private System.Windows.Forms.Button butBrowseMuxOutput;
		private System.Windows.Forms.Label label15;
		private System.Windows.Forms.Button butConfigureMuxer;
		private System.Windows.Forms.ComboBox comboMuxer;
		private System.Windows.Forms.CheckBox checkUseMuxing;
		private System.Windows.Forms.FolderBrowserDialog folderBrowserOutput;
		/// <summary> 
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;
		private MRUPathManager recentMuxPaths;
		private bool validateCancel=false;

		public MuxingControl()
		{
			// This call is required by the Windows.Forms Form Designer.
			InitializeComponent();

			recentMuxPaths=new MRUPathManager();
		}

		/// <summary> 
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Component Designer generated code
		/// <summary> 
		/// Required method for Designer support - do not modify 
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(MuxingControl));
			this.panelMux = new System.Windows.Forms.Panel();
			this.comboMuxPath = new System.Windows.Forms.ComboBox();
			this.groupBox2 = new System.Windows.Forms.GroupBox();
			this.checkMuxPause = new System.Windows.Forms.CheckBox();
			this.checkDeleteFiles = new System.Windows.Forms.CheckBox();
			this.label13 = new System.Windows.Forms.Label();
			this.comboTargetType = new System.Windows.Forms.ComboBox();
			this.label12 = new System.Windows.Forms.Label();
			this.butBrowseMuxOutput = new System.Windows.Forms.Button();
			this.label15 = new System.Windows.Forms.Label();
			this.butConfigureMuxer = new System.Windows.Forms.Button();
			this.comboMuxer = new System.Windows.Forms.ComboBox();
			this.checkUseMuxing = new System.Windows.Forms.CheckBox();
			this.folderBrowserOutput = new System.Windows.Forms.FolderBrowserDialog();
			this.panelMux.SuspendLayout();
			this.groupBox2.SuspendLayout();
			this.SuspendLayout();
			// 
			// panelMux
			// 
			this.panelMux.AccessibleDescription = resources.GetString("panelMux.AccessibleDescription");
			this.panelMux.AccessibleName = resources.GetString("panelMux.AccessibleName");
			this.panelMux.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("panelMux.Anchor")));
			this.panelMux.AutoScroll = ((bool)(resources.GetObject("panelMux.AutoScroll")));
			this.panelMux.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("panelMux.AutoScrollMargin")));
			this.panelMux.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("panelMux.AutoScrollMinSize")));
			this.panelMux.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("panelMux.BackgroundImage")));
			this.panelMux.Controls.Add(this.comboMuxPath);
			this.panelMux.Controls.Add(this.groupBox2);
			this.panelMux.Controls.Add(this.label13);
			this.panelMux.Controls.Add(this.comboTargetType);
			this.panelMux.Controls.Add(this.label12);
			this.panelMux.Controls.Add(this.butBrowseMuxOutput);
			this.panelMux.Controls.Add(this.label15);
			this.panelMux.Controls.Add(this.butConfigureMuxer);
			this.panelMux.Controls.Add(this.comboMuxer);
			this.panelMux.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("panelMux.Dock")));
			this.panelMux.Enabled = ((bool)(resources.GetObject("panelMux.Enabled")));
			this.panelMux.Font = ((System.Drawing.Font)(resources.GetObject("panelMux.Font")));
			this.panelMux.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("panelMux.ImeMode")));
			this.panelMux.Location = ((System.Drawing.Point)(resources.GetObject("panelMux.Location")));
			this.panelMux.Name = "panelMux";
			this.panelMux.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("panelMux.RightToLeft")));
			this.panelMux.Size = ((System.Drawing.Size)(resources.GetObject("panelMux.Size")));
			this.panelMux.TabIndex = ((int)(resources.GetObject("panelMux.TabIndex")));
			this.panelMux.Text = resources.GetString("panelMux.Text");
			this.panelMux.Visible = ((bool)(resources.GetObject("panelMux.Visible")));
			// 
			// comboMuxPath
			// 
			this.comboMuxPath.AccessibleDescription = resources.GetString("comboMuxPath.AccessibleDescription");
			this.comboMuxPath.AccessibleName = resources.GetString("comboMuxPath.AccessibleName");
			this.comboMuxPath.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("comboMuxPath.Anchor")));
			this.comboMuxPath.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("comboMuxPath.BackgroundImage")));
			this.comboMuxPath.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("comboMuxPath.Dock")));
			this.comboMuxPath.Enabled = ((bool)(resources.GetObject("comboMuxPath.Enabled")));
			this.comboMuxPath.Font = ((System.Drawing.Font)(resources.GetObject("comboMuxPath.Font")));
			this.comboMuxPath.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("comboMuxPath.ImeMode")));
			this.comboMuxPath.IntegralHeight = ((bool)(resources.GetObject("comboMuxPath.IntegralHeight")));
			this.comboMuxPath.ItemHeight = ((int)(resources.GetObject("comboMuxPath.ItemHeight")));
			this.comboMuxPath.Location = ((System.Drawing.Point)(resources.GetObject("comboMuxPath.Location")));
			this.comboMuxPath.MaxDropDownItems = ((int)(resources.GetObject("comboMuxPath.MaxDropDownItems")));
			this.comboMuxPath.MaxLength = ((int)(resources.GetObject("comboMuxPath.MaxLength")));
			this.comboMuxPath.Name = "comboMuxPath";
			this.comboMuxPath.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("comboMuxPath.RightToLeft")));
			this.comboMuxPath.Size = ((System.Drawing.Size)(resources.GetObject("comboMuxPath.Size")));
			this.comboMuxPath.TabIndex = ((int)(resources.GetObject("comboMuxPath.TabIndex")));
			this.comboMuxPath.Text = resources.GetString("comboMuxPath.Text");
			this.comboMuxPath.Visible = ((bool)(resources.GetObject("comboMuxPath.Visible")));
			this.comboMuxPath.Validating += new System.ComponentModel.CancelEventHandler(this.comboMuxPath_Validating);
			this.comboMuxPath.SelectedIndexChanged += new System.EventHandler(this.comboMuxPath_SelectedIndexChanged);
			// 
			// groupBox2
			// 
			this.groupBox2.AccessibleDescription = resources.GetString("groupBox2.AccessibleDescription");
			this.groupBox2.AccessibleName = resources.GetString("groupBox2.AccessibleName");
			this.groupBox2.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("groupBox2.Anchor")));
			this.groupBox2.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("groupBox2.BackgroundImage")));
			this.groupBox2.Controls.Add(this.checkMuxPause);
			this.groupBox2.Controls.Add(this.checkDeleteFiles);
			this.groupBox2.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("groupBox2.Dock")));
			this.groupBox2.Enabled = ((bool)(resources.GetObject("groupBox2.Enabled")));
			this.groupBox2.Font = ((System.Drawing.Font)(resources.GetObject("groupBox2.Font")));
			this.groupBox2.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("groupBox2.ImeMode")));
			this.groupBox2.Location = ((System.Drawing.Point)(resources.GetObject("groupBox2.Location")));
			this.groupBox2.Name = "groupBox2";
			this.groupBox2.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("groupBox2.RightToLeft")));
			this.groupBox2.Size = ((System.Drawing.Size)(resources.GetObject("groupBox2.Size")));
			this.groupBox2.TabIndex = ((int)(resources.GetObject("groupBox2.TabIndex")));
			this.groupBox2.TabStop = false;
			this.groupBox2.Text = resources.GetString("groupBox2.Text");
			this.groupBox2.Visible = ((bool)(resources.GetObject("groupBox2.Visible")));
			// 
			// checkMuxPause
			// 
			this.checkMuxPause.AccessibleDescription = resources.GetString("checkMuxPause.AccessibleDescription");
			this.checkMuxPause.AccessibleName = resources.GetString("checkMuxPause.AccessibleName");
			this.checkMuxPause.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("checkMuxPause.Anchor")));
			this.checkMuxPause.Appearance = ((System.Windows.Forms.Appearance)(resources.GetObject("checkMuxPause.Appearance")));
			this.checkMuxPause.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("checkMuxPause.BackgroundImage")));
			this.checkMuxPause.CheckAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("checkMuxPause.CheckAlign")));
			this.checkMuxPause.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("checkMuxPause.Dock")));
			this.checkMuxPause.Enabled = ((bool)(resources.GetObject("checkMuxPause.Enabled")));
			this.checkMuxPause.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("checkMuxPause.FlatStyle")));
			this.checkMuxPause.Font = ((System.Drawing.Font)(resources.GetObject("checkMuxPause.Font")));
			this.checkMuxPause.Image = ((System.Drawing.Image)(resources.GetObject("checkMuxPause.Image")));
			this.checkMuxPause.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("checkMuxPause.ImageAlign")));
			this.checkMuxPause.ImageIndex = ((int)(resources.GetObject("checkMuxPause.ImageIndex")));
			this.checkMuxPause.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("checkMuxPause.ImeMode")));
			this.checkMuxPause.Location = ((System.Drawing.Point)(resources.GetObject("checkMuxPause.Location")));
			this.checkMuxPause.Name = "checkMuxPause";
			this.checkMuxPause.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("checkMuxPause.RightToLeft")));
			this.checkMuxPause.Size = ((System.Drawing.Size)(resources.GetObject("checkMuxPause.Size")));
			this.checkMuxPause.TabIndex = ((int)(resources.GetObject("checkMuxPause.TabIndex")));
			this.checkMuxPause.Text = resources.GetString("checkMuxPause.Text");
			this.checkMuxPause.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("checkMuxPause.TextAlign")));
			this.checkMuxPause.Visible = ((bool)(resources.GetObject("checkMuxPause.Visible")));
			// 
			// checkDeleteFiles
			// 
			this.checkDeleteFiles.AccessibleDescription = resources.GetString("checkDeleteFiles.AccessibleDescription");
			this.checkDeleteFiles.AccessibleName = resources.GetString("checkDeleteFiles.AccessibleName");
			this.checkDeleteFiles.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("checkDeleteFiles.Anchor")));
			this.checkDeleteFiles.Appearance = ((System.Windows.Forms.Appearance)(resources.GetObject("checkDeleteFiles.Appearance")));
			this.checkDeleteFiles.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("checkDeleteFiles.BackgroundImage")));
			this.checkDeleteFiles.CheckAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("checkDeleteFiles.CheckAlign")));
			this.checkDeleteFiles.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("checkDeleteFiles.Dock")));
			this.checkDeleteFiles.Enabled = ((bool)(resources.GetObject("checkDeleteFiles.Enabled")));
			this.checkDeleteFiles.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("checkDeleteFiles.FlatStyle")));
			this.checkDeleteFiles.Font = ((System.Drawing.Font)(resources.GetObject("checkDeleteFiles.Font")));
			this.checkDeleteFiles.Image = ((System.Drawing.Image)(resources.GetObject("checkDeleteFiles.Image")));
			this.checkDeleteFiles.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("checkDeleteFiles.ImageAlign")));
			this.checkDeleteFiles.ImageIndex = ((int)(resources.GetObject("checkDeleteFiles.ImageIndex")));
			this.checkDeleteFiles.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("checkDeleteFiles.ImeMode")));
			this.checkDeleteFiles.Location = ((System.Drawing.Point)(resources.GetObject("checkDeleteFiles.Location")));
			this.checkDeleteFiles.Name = "checkDeleteFiles";
			this.checkDeleteFiles.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("checkDeleteFiles.RightToLeft")));
			this.checkDeleteFiles.Size = ((System.Drawing.Size)(resources.GetObject("checkDeleteFiles.Size")));
			this.checkDeleteFiles.TabIndex = ((int)(resources.GetObject("checkDeleteFiles.TabIndex")));
			this.checkDeleteFiles.Text = resources.GetString("checkDeleteFiles.Text");
			this.checkDeleteFiles.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("checkDeleteFiles.TextAlign")));
			this.checkDeleteFiles.Visible = ((bool)(resources.GetObject("checkDeleteFiles.Visible")));
			// 
			// label13
			// 
			this.label13.AccessibleDescription = resources.GetString("label13.AccessibleDescription");
			this.label13.AccessibleName = resources.GetString("label13.AccessibleName");
			this.label13.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("label13.Anchor")));
			this.label13.AutoSize = ((bool)(resources.GetObject("label13.AutoSize")));
			this.label13.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("label13.Dock")));
			this.label13.Enabled = ((bool)(resources.GetObject("label13.Enabled")));
			this.label13.Font = ((System.Drawing.Font)(resources.GetObject("label13.Font")));
			this.label13.Image = ((System.Drawing.Image)(resources.GetObject("label13.Image")));
			this.label13.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label13.ImageAlign")));
			this.label13.ImageIndex = ((int)(resources.GetObject("label13.ImageIndex")));
			this.label13.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("label13.ImeMode")));
			this.label13.Location = ((System.Drawing.Point)(resources.GetObject("label13.Location")));
			this.label13.Name = "label13";
			this.label13.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("label13.RightToLeft")));
			this.label13.Size = ((System.Drawing.Size)(resources.GetObject("label13.Size")));
			this.label13.TabIndex = ((int)(resources.GetObject("label13.TabIndex")));
			this.label13.Text = resources.GetString("label13.Text");
			this.label13.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label13.TextAlign")));
			this.label13.Visible = ((bool)(resources.GetObject("label13.Visible")));
			// 
			// comboTargetType
			// 
			this.comboTargetType.AccessibleDescription = resources.GetString("comboTargetType.AccessibleDescription");
			this.comboTargetType.AccessibleName = resources.GetString("comboTargetType.AccessibleName");
			this.comboTargetType.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("comboTargetType.Anchor")));
			this.comboTargetType.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("comboTargetType.BackgroundImage")));
			this.comboTargetType.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("comboTargetType.Dock")));
			this.comboTargetType.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
			this.comboTargetType.Enabled = ((bool)(resources.GetObject("comboTargetType.Enabled")));
			this.comboTargetType.Font = ((System.Drawing.Font)(resources.GetObject("comboTargetType.Font")));
			this.comboTargetType.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("comboTargetType.ImeMode")));
			this.comboTargetType.IntegralHeight = ((bool)(resources.GetObject("comboTargetType.IntegralHeight")));
			this.comboTargetType.ItemHeight = ((int)(resources.GetObject("comboTargetType.ItemHeight")));
			this.comboTargetType.Items.AddRange(new object[] {
																 resources.GetString("comboTargetType.Items"),
																 resources.GetString("comboTargetType.Items1")});
			this.comboTargetType.Location = ((System.Drawing.Point)(resources.GetObject("comboTargetType.Location")));
			this.comboTargetType.MaxDropDownItems = ((int)(resources.GetObject("comboTargetType.MaxDropDownItems")));
			this.comboTargetType.MaxLength = ((int)(resources.GetObject("comboTargetType.MaxLength")));
			this.comboTargetType.Name = "comboTargetType";
			this.comboTargetType.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("comboTargetType.RightToLeft")));
			this.comboTargetType.Size = ((System.Drawing.Size)(resources.GetObject("comboTargetType.Size")));
			this.comboTargetType.TabIndex = ((int)(resources.GetObject("comboTargetType.TabIndex")));
			this.comboTargetType.Text = resources.GetString("comboTargetType.Text");
			this.comboTargetType.Visible = ((bool)(resources.GetObject("comboTargetType.Visible")));
			// 
			// label12
			// 
			this.label12.AccessibleDescription = resources.GetString("label12.AccessibleDescription");
			this.label12.AccessibleName = resources.GetString("label12.AccessibleName");
			this.label12.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("label12.Anchor")));
			this.label12.AutoSize = ((bool)(resources.GetObject("label12.AutoSize")));
			this.label12.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("label12.Dock")));
			this.label12.Enabled = ((bool)(resources.GetObject("label12.Enabled")));
			this.label12.Font = ((System.Drawing.Font)(resources.GetObject("label12.Font")));
			this.label12.Image = ((System.Drawing.Image)(resources.GetObject("label12.Image")));
			this.label12.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label12.ImageAlign")));
			this.label12.ImageIndex = ((int)(resources.GetObject("label12.ImageIndex")));
			this.label12.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("label12.ImeMode")));
			this.label12.Location = ((System.Drawing.Point)(resources.GetObject("label12.Location")));
			this.label12.Name = "label12";
			this.label12.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("label12.RightToLeft")));
			this.label12.Size = ((System.Drawing.Size)(resources.GetObject("label12.Size")));
			this.label12.TabIndex = ((int)(resources.GetObject("label12.TabIndex")));
			this.label12.Text = resources.GetString("label12.Text");
			this.label12.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label12.TextAlign")));
			this.label12.Visible = ((bool)(resources.GetObject("label12.Visible")));
			// 
			// butBrowseMuxOutput
			// 
			this.butBrowseMuxOutput.AccessibleDescription = resources.GetString("butBrowseMuxOutput.AccessibleDescription");
			this.butBrowseMuxOutput.AccessibleName = resources.GetString("butBrowseMuxOutput.AccessibleName");
			this.butBrowseMuxOutput.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butBrowseMuxOutput.Anchor")));
			this.butBrowseMuxOutput.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butBrowseMuxOutput.BackgroundImage")));
			this.butBrowseMuxOutput.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butBrowseMuxOutput.Dock")));
			this.butBrowseMuxOutput.Enabled = ((bool)(resources.GetObject("butBrowseMuxOutput.Enabled")));
			this.butBrowseMuxOutput.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butBrowseMuxOutput.FlatStyle")));
			this.butBrowseMuxOutput.Font = ((System.Drawing.Font)(resources.GetObject("butBrowseMuxOutput.Font")));
			this.butBrowseMuxOutput.Image = ((System.Drawing.Image)(resources.GetObject("butBrowseMuxOutput.Image")));
			this.butBrowseMuxOutput.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butBrowseMuxOutput.ImageAlign")));
			this.butBrowseMuxOutput.ImageIndex = ((int)(resources.GetObject("butBrowseMuxOutput.ImageIndex")));
			this.butBrowseMuxOutput.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butBrowseMuxOutput.ImeMode")));
			this.butBrowseMuxOutput.Location = ((System.Drawing.Point)(resources.GetObject("butBrowseMuxOutput.Location")));
			this.butBrowseMuxOutput.Name = "butBrowseMuxOutput";
			this.butBrowseMuxOutput.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butBrowseMuxOutput.RightToLeft")));
			this.butBrowseMuxOutput.Size = ((System.Drawing.Size)(resources.GetObject("butBrowseMuxOutput.Size")));
			this.butBrowseMuxOutput.TabIndex = ((int)(resources.GetObject("butBrowseMuxOutput.TabIndex")));
			this.butBrowseMuxOutput.Text = resources.GetString("butBrowseMuxOutput.Text");
			this.butBrowseMuxOutput.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butBrowseMuxOutput.TextAlign")));
			this.butBrowseMuxOutput.Visible = ((bool)(resources.GetObject("butBrowseMuxOutput.Visible")));
			this.butBrowseMuxOutput.Click += new System.EventHandler(this.butBrowseMuxOutput_Click);
			// 
			// label15
			// 
			this.label15.AccessibleDescription = resources.GetString("label15.AccessibleDescription");
			this.label15.AccessibleName = resources.GetString("label15.AccessibleName");
			this.label15.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("label15.Anchor")));
			this.label15.AutoSize = ((bool)(resources.GetObject("label15.AutoSize")));
			this.label15.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("label15.Dock")));
			this.label15.Enabled = ((bool)(resources.GetObject("label15.Enabled")));
			this.label15.Font = ((System.Drawing.Font)(resources.GetObject("label15.Font")));
			this.label15.Image = ((System.Drawing.Image)(resources.GetObject("label15.Image")));
			this.label15.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label15.ImageAlign")));
			this.label15.ImageIndex = ((int)(resources.GetObject("label15.ImageIndex")));
			this.label15.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("label15.ImeMode")));
			this.label15.Location = ((System.Drawing.Point)(resources.GetObject("label15.Location")));
			this.label15.Name = "label15";
			this.label15.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("label15.RightToLeft")));
			this.label15.Size = ((System.Drawing.Size)(resources.GetObject("label15.Size")));
			this.label15.TabIndex = ((int)(resources.GetObject("label15.TabIndex")));
			this.label15.Text = resources.GetString("label15.Text");
			this.label15.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("label15.TextAlign")));
			this.label15.Visible = ((bool)(resources.GetObject("label15.Visible")));
			// 
			// butConfigureMuxer
			// 
			this.butConfigureMuxer.AccessibleDescription = resources.GetString("butConfigureMuxer.AccessibleDescription");
			this.butConfigureMuxer.AccessibleName = resources.GetString("butConfigureMuxer.AccessibleName");
			this.butConfigureMuxer.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("butConfigureMuxer.Anchor")));
			this.butConfigureMuxer.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("butConfigureMuxer.BackgroundImage")));
			this.butConfigureMuxer.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("butConfigureMuxer.Dock")));
			this.butConfigureMuxer.Enabled = ((bool)(resources.GetObject("butConfigureMuxer.Enabled")));
			this.butConfigureMuxer.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("butConfigureMuxer.FlatStyle")));
			this.butConfigureMuxer.Font = ((System.Drawing.Font)(resources.GetObject("butConfigureMuxer.Font")));
			this.butConfigureMuxer.Image = ((System.Drawing.Image)(resources.GetObject("butConfigureMuxer.Image")));
			this.butConfigureMuxer.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butConfigureMuxer.ImageAlign")));
			this.butConfigureMuxer.ImageIndex = ((int)(resources.GetObject("butConfigureMuxer.ImageIndex")));
			this.butConfigureMuxer.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("butConfigureMuxer.ImeMode")));
			this.butConfigureMuxer.Location = ((System.Drawing.Point)(resources.GetObject("butConfigureMuxer.Location")));
			this.butConfigureMuxer.Name = "butConfigureMuxer";
			this.butConfigureMuxer.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("butConfigureMuxer.RightToLeft")));
			this.butConfigureMuxer.Size = ((System.Drawing.Size)(resources.GetObject("butConfigureMuxer.Size")));
			this.butConfigureMuxer.TabIndex = ((int)(resources.GetObject("butConfigureMuxer.TabIndex")));
			this.butConfigureMuxer.Text = resources.GetString("butConfigureMuxer.Text");
			this.butConfigureMuxer.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("butConfigureMuxer.TextAlign")));
			this.butConfigureMuxer.Visible = ((bool)(resources.GetObject("butConfigureMuxer.Visible")));
			this.butConfigureMuxer.Click += new System.EventHandler(this.butConfigureMuxer_Click);
			// 
			// comboMuxer
			// 
			this.comboMuxer.AccessibleDescription = resources.GetString("comboMuxer.AccessibleDescription");
			this.comboMuxer.AccessibleName = resources.GetString("comboMuxer.AccessibleName");
			this.comboMuxer.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("comboMuxer.Anchor")));
			this.comboMuxer.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("comboMuxer.BackgroundImage")));
			this.comboMuxer.DisplayMember = "DisplayName";
			this.comboMuxer.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("comboMuxer.Dock")));
			this.comboMuxer.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
			this.comboMuxer.Enabled = ((bool)(resources.GetObject("comboMuxer.Enabled")));
			this.comboMuxer.Font = ((System.Drawing.Font)(resources.GetObject("comboMuxer.Font")));
			this.comboMuxer.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("comboMuxer.ImeMode")));
			this.comboMuxer.IntegralHeight = ((bool)(resources.GetObject("comboMuxer.IntegralHeight")));
			this.comboMuxer.ItemHeight = ((int)(resources.GetObject("comboMuxer.ItemHeight")));
			this.comboMuxer.Location = ((System.Drawing.Point)(resources.GetObject("comboMuxer.Location")));
			this.comboMuxer.MaxDropDownItems = ((int)(resources.GetObject("comboMuxer.MaxDropDownItems")));
			this.comboMuxer.MaxLength = ((int)(resources.GetObject("comboMuxer.MaxLength")));
			this.comboMuxer.Name = "comboMuxer";
			this.comboMuxer.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("comboMuxer.RightToLeft")));
			this.comboMuxer.Size = ((System.Drawing.Size)(resources.GetObject("comboMuxer.Size")));
			this.comboMuxer.TabIndex = ((int)(resources.GetObject("comboMuxer.TabIndex")));
			this.comboMuxer.Text = resources.GetString("comboMuxer.Text");
			this.comboMuxer.ValueMember = "DisplayName";
			this.comboMuxer.Visible = ((bool)(resources.GetObject("comboMuxer.Visible")));
			this.comboMuxer.SelectedIndexChanged += new System.EventHandler(this.comboMuxer_SelectedIndexChanged);
			// 
			// checkUseMuxing
			// 
			this.checkUseMuxing.AccessibleDescription = resources.GetString("checkUseMuxing.AccessibleDescription");
			this.checkUseMuxing.AccessibleName = resources.GetString("checkUseMuxing.AccessibleName");
			this.checkUseMuxing.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("checkUseMuxing.Anchor")));
			this.checkUseMuxing.Appearance = ((System.Windows.Forms.Appearance)(resources.GetObject("checkUseMuxing.Appearance")));
			this.checkUseMuxing.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("checkUseMuxing.BackgroundImage")));
			this.checkUseMuxing.CheckAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("checkUseMuxing.CheckAlign")));
			this.checkUseMuxing.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("checkUseMuxing.Dock")));
			this.checkUseMuxing.Enabled = ((bool)(resources.GetObject("checkUseMuxing.Enabled")));
			this.checkUseMuxing.FlatStyle = ((System.Windows.Forms.FlatStyle)(resources.GetObject("checkUseMuxing.FlatStyle")));
			this.checkUseMuxing.Font = ((System.Drawing.Font)(resources.GetObject("checkUseMuxing.Font")));
			this.checkUseMuxing.Image = ((System.Drawing.Image)(resources.GetObject("checkUseMuxing.Image")));
			this.checkUseMuxing.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("checkUseMuxing.ImageAlign")));
			this.checkUseMuxing.ImageIndex = ((int)(resources.GetObject("checkUseMuxing.ImageIndex")));
			this.checkUseMuxing.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("checkUseMuxing.ImeMode")));
			this.checkUseMuxing.Location = ((System.Drawing.Point)(resources.GetObject("checkUseMuxing.Location")));
			this.checkUseMuxing.Name = "checkUseMuxing";
			this.checkUseMuxing.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("checkUseMuxing.RightToLeft")));
			this.checkUseMuxing.Size = ((System.Drawing.Size)(resources.GetObject("checkUseMuxing.Size")));
			this.checkUseMuxing.TabIndex = ((int)(resources.GetObject("checkUseMuxing.TabIndex")));
			this.checkUseMuxing.Text = resources.GetString("checkUseMuxing.Text");
			this.checkUseMuxing.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("checkUseMuxing.TextAlign")));
			this.checkUseMuxing.Visible = ((bool)(resources.GetObject("checkUseMuxing.Visible")));
			this.checkUseMuxing.CheckedChanged += new System.EventHandler(this.checkUseMuxing_CheckedChanged);
			// 
			// folderBrowserOutput
			// 
			this.folderBrowserOutput.Description = resources.GetString("folderBrowserOutput.Description");
			this.folderBrowserOutput.SelectedPath = resources.GetString("folderBrowserOutput.SelectedPath");
			// 
			// MuxingControl
			// 
			this.AccessibleDescription = resources.GetString("$this.AccessibleDescription");
			this.AccessibleName = resources.GetString("$this.AccessibleName");
			this.AutoScroll = ((bool)(resources.GetObject("$this.AutoScroll")));
			this.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("$this.AutoScrollMargin")));
			this.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("$this.AutoScrollMinSize")));
			this.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("$this.BackgroundImage")));
			this.Controls.Add(this.panelMux);
			this.Controls.Add(this.checkUseMuxing);
			this.Enabled = ((bool)(resources.GetObject("$this.Enabled")));
			this.Font = ((System.Drawing.Font)(resources.GetObject("$this.Font")));
			this.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("$this.ImeMode")));
			this.Location = ((System.Drawing.Point)(resources.GetObject("$this.Location")));
			this.Name = "MuxingControl";
			this.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("$this.RightToLeft")));
			this.Size = ((System.Drawing.Size)(resources.GetObject("$this.Size")));
			this.panelMux.ResumeLayout(false);
			this.groupBox2.ResumeLayout(false);
			this.ResumeLayout(false);

		}
		#endregion

		// Das Load-Event kann nicht genutzt werden, da dies eine Exception im
		// Designer verursachen wrde!
		public void LoadData()
		{
			checkUseMuxing.Checked=Settings.CurrentSettings.MuxingMode;
			panelMux.Enabled=Settings.CurrentSettings.MuxingMode;
			comboTargetType.SelectedIndex=Settings.CurrentSettings.MPEG2MuxTarget;
			// FillCombo will uncheck checkUseMuxing if specified Encoder not found
			Settings.CurrentSettings.FillCombo(comboMuxer,"'muxer'",butConfigureMuxer,checkUseMuxing,Settings.CurrentSettings.UsedMuxer);
			comboMuxer.SelectedIndexChanged += new System.EventHandler(this.comboMuxer_SelectedIndexChanged);
			recentMuxPaths.Entries=Settings.CurrentSettings.MRUMuxPathEntries;
			if (recentMuxPaths.Entries.Count==0)
				recentMuxPaths.AddItem(Settings.CurrentSettings.TempDir);
			recentMuxPaths.FillRecentList(comboMuxPath);
			checkMuxPause.Checked=Settings.CurrentSettings.MuxPause;
			checkDeleteFiles.Checked=Settings.CurrentSettings.OnMuxDeleteES;
		}

		public void UnLoadData()
		{
			Settings.CurrentSettings.MuxingMode=checkUseMuxing.Checked;
			Settings.CurrentSettings.MRUMuxPathEntries=recentMuxPaths.Entries;
			if (comboMuxer.SelectedIndex!=-1)
				Settings.CurrentSettings.UsedMuxer=(string)comboMuxer.SelectedItem;
			if (comboTargetType.SelectedIndex!=-1)
				Settings.CurrentSettings.MPEG2MuxTarget=comboTargetType.SelectedIndex;
			Settings.CurrentSettings.MuxPause=checkMuxPause.Checked;
			Settings.CurrentSettings.OnMuxDeleteES=checkDeleteFiles.Checked;
		}

		private void checkUseMuxing_CheckedChanged(object sender, System.EventArgs e)
		{
			panelMux.Enabled=checkUseMuxing.Checked;
		}

		private void butConfigureMuxer_Click(object sender, System.EventArgs e)
		{
			Settings.CurrentSettings.CallExternalToolConfig((string)comboMuxer.SelectedItem, this.ParentForm);
		}

		private void butBrowseMuxOutput_Click(object sender, System.EventArgs e)
		{
			folderBrowserOutput.SelectedPath=comboMuxPath.Text;
			if (folderBrowserOutput.ShowDialog()==DialogResult.OK)
			{
				recentMuxPaths.AddItem(folderBrowserOutput.SelectedPath);
				recentMuxPaths.FillRecentList(comboMuxPath);
			}
		}

		private void comboMuxPath_SelectedIndexChanged(object sender, System.EventArgs e)
		{
			recentMuxPaths.AddItem(comboMuxPath.Text);
		}

		private void comboMuxPath_Validating(object sender, System.ComponentModel.CancelEventArgs e)
		{
			if (comboMuxPath.Text.Trim()!=string.Empty)
			{
				if (Directory.Exists(comboMuxPath.Text))
				{
					recentMuxPaths.AddItem(comboMuxPath.Text);
					recentMuxPaths.FillRecentList(comboMuxPath);
				}
				else
				{
					MessageBox.Show(Resource.CurrentResource.FormatMessage(Resource.PATH_NOT_EXIST,comboMuxPath.Text),this.ParentForm.Text,MessageBoxButtons.OK,MessageBoxIcon.Error);
					if (validateCancel)
						e.Cancel=true;
				}
			}
		}

		private void comboMuxer_SelectedIndexChanged(object sender, System.EventArgs e)
		{
			if (comboMuxer.SelectedIndex!=-1)
			{
				ExternalToolProviderData.ConfigurationRow confRow=Settings.CurrentSettings.ExternalTools.Configuration.FindByDisplayName((string)comboMuxer.SelectedItem);
				butConfigureMuxer.Enabled=(confRow!=null) &&  !confRow.IsConfigMethodNull();
			}
		}

		public bool ValidateCancel
		{
			get
			{
				return validateCancel;
			}
			set
			{
				validateCancel=value;
			}
		}

	}
}
