/*
 * Cuttermaran - The Mpeg Cutter
 * 
 * Copyright (C) 2003-2006 Tobias Arnold (cuttermaran@gmx.net)
 * 
 * This file is part of cuttermaran, a free MPEG cut program.
 * See http://www.cuttermaran.de for updates.
 *
 * This program is free software; you can redistribute it and/or modify it 
 * under the terms of the GNU General Public License as published by the 
 * Free Software Foundation; either version 2 of the License, or 
 * (at your option) any later version. 
 * 
 * This program is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the 
 * GNU General Public License for more details. 
 * 
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */

using System;
using System.Resources;
using System.Reflection; 
using System.IO;

namespace StringResources
{
	public sealed class Resource : Coremoran.Common.CustomMessages
	{
		// Konstanten
		public const string ERROR="ERROR";
		public const string CUT_FINISHED="CUT_FINISHED";
		public const string NO_OF_AUDIO="NO_OF_AUDIO";
		public const string ORDER_OF_AUDIO="ORDER_OF_AUDIO";
		public const string AUDIO_CUT_FINISHED="AUDIO_CUT_FINISHED";
		public const string NO_AUDIO_CODEC="NO_AUDIO_CODEC";
		public const string RESTART="RESTART";
		public const string INFO="INFO";
		public const string UNKNOWN="UNKNOWN";
		public const string CODEC_MISSING="CODEC_MISSING";
		public const string CUTTING_VIDEO_MSG="CUTTING_VIDEO_MSG";
		public const string CUTTING_AUDIO_MSG="CUTTING_AUDIO_MSG";
		public const string LIBMPEG2_DISPLAY="LIBMPEG2_DISPLAY";
		public const string PROJECT_ERROR="PROJECT_ERROR";
		public const string SCANNING_PICS="SCANNING_PICS";
		public const string UNKNOWN_AUDIO_FORMAT="UNKNOWN_AUDIO_FORMAT";
		public const string QUICK_SECONDS="QUICK_SECONDS";
		public const string NO_ENCODER="NO_ENCODER";
		public const string INTERNAL_ENCODER_ERROR="INTERNAL_ENCODER_ERROR";
		public const string MULTIPLEX_RESULT="MULTIPLEX_RESULT";
		public const string QUESTION_SAVE_STATE="QUESTION_SAVE_STATE";
		public const string AUDIO_DELAY_MSG="AUDIO_DELAY_MSG";
		public const string AUDIO_DELAY_ERROR="AUDIO_DELAY_ERROR";
		public const string NEW_VERSION="NEW_VERSION";
		public const string NO_MUXER="NO_MUXER";
		public const string BEGIN="BEGIN";
		public const string END="END";
		public const string CUT="CUT";
		public const string NEW_CUT="NEW_CUT";
		public const string EMPTY="EMPTY";
		public const string NONAME="NONAME";
		public const string FILE_EXIST="FILE_EXIST";
		public const string PATH_NOT_EXIST="PATH_NOT_EXIST";
		public const string FILENAME_NOT_VALID="FILENAME_NOT_VALID";
		public const string UNKNOWN_DRIVE="UNKNOWN_DRIVE";
		public const string ERROR_SUCC_SUBMITTED="ERROR_SUCC_SUBMITTED";
		public const string ERROR_SUBMITTED_ERROR="ERROR_SUBMITTED_ERROR";
		public const string PAUSE="PAUSE";
		public const string RESUME="RESUME";
		public const string NO_ENCODER_RESULT="NO_ENCODER_RESULT";
		public const string FILE_IS_IN_USE="FILE_IS_IN_USE";
		public const string INVALID_PROJECT_FILE="INVALID_PROJECT_FILE";
		public const string WINDOW_CUT_LIST="WINDOW_CUT_LIST";
		public const string WINDOW_SCROLL="WINDOW_SCROLL";
		public const string WINDOW_STREAM_INFO="WINDOW_STREAM_INFO";
		public const string WINDOW_CHAPTER_LIST="WINDOW_CHAPTER_LIST";
		public const string WINDOW_CURRENT_CUT_OUT="WINDOW_CURRENT_CUT_OUT";
		public const string WINDOW_NAVIGATION="WINDOW_NAVIGATION";
		public const string WINDOW_RESULT="WINDOW_RESULT";
		public const string WINDOW_MARKER="WINDOW_MARKER";
		public const string PRESET_EXISTS="PRESET_EXISTS";
		public const string GOP_ERROR="GOP_ERROR";
		public const string DELETE_SETTINGS="DELETE_SETTINGS";
		public const string DELETE_OK="DELETE_OK";
		public const string DELETE_ERROR="DELETE_ERROR";
		public const string FILE_EXIST_OVERWRITE="FILE_EXIST_OVERWRITE";
		public const string ATTENTION="ATTENTION";
		public const string COL_VIDEO_NAME="COL_VIDEO_NAME";
		public const string COL_VIDEO_START="COL_VIDEO_START";
		public const string COL_VIDEO_END="COL_VIDEO_END";
		public const string COL_VIDEO_LENGTH="COL_VIDEO_LENGTH";
		public const string COL_VIDEO_NEW_START="COL_VIDEO_NEW_START";
		public const string COL_VIDEO_NEW_END="COL_VIDEO_NEW_END";
		public const string COL_AUDIO_NAME="COL_AUDIO_NAME";
		public const string COL_AUDIO_IN_DELAY="COL_AUDIO_IN_DELAY";
		public const string COL_AUDIO_OUT_DELAY="COL_AUDIO_OUT_DELAY";
		public const string COL_CUT_NO_SHORT="COL_CUT_NO_SHORT";
		public const string COL_CUT_NO_LONG="COL_CUT_NO_LONG";
		public const string ROW_RESULT_VIDEO="ROW_RESULT_VIDEO";
		public const string ROW_RESULT_AUDIO="ROW_RESULT_AUDIO";
		public const string TEMPREF_ERROR="TEMPREF_ERROR";
		public const string GOP_SEQ_WARNING="GOP_SEQ_WARNING";
		public const string ENCODER_REQUIRED="ENCODER_REQUIRED";
		public const string VIDEO="VIDEO";
		public const string VIDEO_USED_IN_CUTLIST="VIDEO_USED_IN_CUTLIST";
		public const string OLD_PROVIDER1="OLD_PROVIDER1";
		public const string OLD_PROVIDER2="OLD_PROVIDER2";

		private const string ResourceFileName = ".Strings";

		private static Resource currentResource = new Resource();
		public static Resource CurrentResource
		{
			get
			{
				return currentResource;
			}
		}
		
		private ResourceManager rm = null;
		public ResourceManager Manager
		{
			get
			{
				return rm;
			}
		}

		public Resource()
		{
			rm = new ResourceManager(this.GetType().Namespace+ ".strings" + ResourceFileName, Assembly.GetExecutingAssembly());
		}

		public string this [ string key ]
		{
			get
			{
				return rm.GetString(key);
			}
		}

		public string FormatMessage( string key, params object[] format )
		{
			return string.Format( this[key], format );  
		}
	}
}
