/*
 * Cuttermaran - The Mpeg Cutter
 * 
 * Copyright (C) 2003,2004  Tobias Arnold (cuttermaran@gmx.net)
 * 
 * This file is part of cuttermaran, a free MPEG cut program.
 * See http://cuttermaran.kickme.to for updates.
 *
 * This program is free software; you can redistribute it and/or modify it 
 * under the terms of the GNU General Public License as published by the 
 * Free Software Foundation; either version 2 of the License, or 
 * (at your option) any later version. 
 * 
 * This program is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the 
 * GNU General Public License for more details. 
 * 
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */

using System;
using System.IO;
using System.Diagnostics;

namespace TMPGEncProvider
{
	/// <summary>
	/// Summary description for TMPGEncProjectFileCreator.
	/// Codebytes der tpr-Datei
	/// 0x01 = ?
	/// 0x02 = 1 Byte int
	/// 0x03 = 2 Byte int
	/// 0x04 = 4 Byte int
	/// 0x05 = ?
	/// 0x06 = Text (1 Byte Lnge + String)
	/// 0x07 = String ('xxxx' 1 Byte Lnge + String)
	/// 0x08 = 1 Byte bool (false)
	/// 0x09 = 1 Byte bool (true)
	/// 0x0a = Array 4 Byte Lnge + Data
	/// </summary>
	public class TMPGEncProjectFileCreator
	{
		byte [] data;

		public TMPGEncProjectFileCreator(string templateFileName)
		{
			using (FileStream fs=File.OpenRead(templateFileName))
			{
				data=new byte[fs.Length];
				fs.Read(data,0,(int)fs.Length);
			}
		}

		public bool SetParameter(string parameterName,object val)
		{
			// Parameter suchen
			string match;
			int pos=-1;
			do
			{
				pos=Array.IndexOf(data,(byte)parameterName.Length,pos+1);
				if (pos==-1)
				{
					System.Diagnostics.Debug.Assert(false);
					return false;
				}
				match=System.Text.Encoding.ASCII.GetString(data,pos+1,parameterName.Length);
			} while (match!=parameterName);
			pos+=parameterName.Length+1; // +1 fr das Lngenbyte
			MemoryStream ms=new MemoryStream();
			using (BinaryWriter bw=new BinaryWriter(ms))
			{
				// Vom Anfang bis Ende Parameter Name
				bw.BaseStream.Write(data,0,pos);
				// Typ ermitteln und Typcode kopieren
				int type=data[pos];
				switch(type)
				{
					case 2: //Byte
						bw.Write((byte)type);
						bw.Write(Convert.ToByte(val));
						pos+=2;
						break;
					case 3: //Int16
						bw.Write((byte)type);
						bw.Write(Convert.ToInt16(val));
						pos+=3;
						break;
					case 4: //Int32
						bw.Write((byte)type);
						bw.Write(Convert.ToInt32(val));
						pos+=5;
						break;
					case 6: // 'String'
					case 7: // String
						bw.Write((byte)type);
						bw.Write((string)val);
						pos+=data[pos+1]+2; // +1 fr Lngenbyte
						break;
					case 8: // false
					case 9: // true
						bw.Write((byte)(Convert.ToBoolean(val)?9:8));
						++pos;
						break;
					case 0x0a: // Byte-Array
						bw.Write((byte)type);
						bw.Write((Int32)((byte [])val).Length);
						bw.Write((byte [])val);
						pos+=((byte [])val).Length+5;
						break;
					default:
						Debug.Assert(false);
						return false;
				}

				// Rest schreiben
				bw.BaseStream.Write(data,pos,data.Length-pos);
			}
			ms.Close();
			// neues Array erzeugen
			data=ms.ToArray();
			return true;
		}

		public void Write(string fileName)
		{
			// Lnge schreiben
			int headerlength=data[1]+data[2]*256+3;
			MemoryStream ms=new MemoryStream();
			using (BinaryWriter bw=new BinaryWriter(ms))
			{
				bw.Write((UInt16)(data.Length-headerlength));
			}
			ms.ToArray().CopyTo(data,headerlength-4);

			// ab in die Datei
			using (FileStream fs=File.OpenWrite(fileName))
			{
				fs.Write(data,0,data.Length);
			}
		}
	}
}
